@@ -1,23 +1,37 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int ccopy_(integer *n, complex *cx, integer *incx, complex *
 	cy, integer *incy)
 {
     /* System generated locals */
     integer i__1, i__2, i__3;
+
     /* Local variables */
-    static integer i__, ix, iy;
-/*  Purpose   
-    =======   
-       CCOPY copies a vector x to a vector y.   
-    Further Details   
-    ===============   
-       jack dongarra, linpack, 3/11/78.   
-       modified 12/3/93, array(1) declarations changed to array(*)   
-       Parameter adjustments */
+    integer i__, ix, iy;
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*     CCOPY copies a vector x to a vector y. */
+
+/*  Further Details */
+/*  =============== */
+
+/*     jack dongarra, linpack, 3/11/78. */
+/*     modified 12/3/93, array(1) declarations changed to array(*) */
+
+/*     .. Local Scalars .. */
+/*     .. */
+    /* Parameter adjustments */
     --cy;
     --cx;
+
     /* Function Body */
     if (*n <= 0) {
 	return 0;
@@ -25,8 +39,10 @@
     if (*incx == 1 && *incy == 1) {
 	goto L20;
     }
-/*        code for unequal increments or equal increments   
-            not equal to 1 */
+
+/*        code for unequal increments or equal increments */
+/*          not equal to 1 */
+
     ix = 1;
     iy = 1;
     if (*incx < 0) {
@@ -45,7 +61,9 @@
 /* L10: */
     }
     return 0;
+
 /*        code for both increments equal to 1 */
+
 L20:
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -56,4 +74,3 @@ L20:
     }
     return 0;
 } /* ccopy_ */
-
