@@ -1,23 +1,38 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 doublereal dzasum_(integer *n, doublecomplex *zx, integer *incx)
 {
     /* System generated locals */
     integer i__1;
     doublereal ret_val;
+
     /* Local variables */
-    static integer i__, ix;
-    static doublereal stemp;
+    integer i__, ix;
+    doublereal stemp;
     extern doublereal dcabs1_(doublecomplex *);
-/*  Purpose   
-    =======   
-       takes the sum of the absolute values.   
-       jack dongarra, 3/11/78.   
-       modified 3/93 to return if incx .le. 0.   
-       modified 12/3/93, array(1) declarations changed to array(*)   
-       Parameter adjustments */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*     takes the sum of the absolute values. */
+/*     jack dongarra, 3/11/78. */
+/*     modified 3/93 to return if incx .le. 0. */
+/*     modified 12/3/93, array(1) declarations changed to array(*) */
+
+
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+    /* Parameter adjustments */
     --zx;
+
     /* Function Body */
     ret_val = 0.;
     stemp = 0.;
@@ -27,7 +42,9 @@ doublereal dzasum_(integer *n, doublecomplex *zx, integer *incx)
     if (*incx == 1) {
 	goto L20;
     }
+
 /*        code for increment not equal to 1 */
+
     ix = 1;
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -37,7 +54,9 @@ doublereal dzasum_(integer *n, doublecomplex *zx, integer *incx)
     }
     ret_val = stemp;
     return ret_val;
+
 /*        code for increment equal to 1 */
+
 L20:
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -47,4 +66,3 @@ L20:
     ret_val = stemp;
     return ret_val;
 } /* dzasum_ */
-
