@@ -1,22 +1,37 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 integer izamax_(integer *n, doublecomplex *zx, integer *incx)
 {
     /* System generated locals */
     integer ret_val, i__1;
+
     /* Local variables */
-    static integer i__, ix;
-    static doublereal smax;
+    integer i__, ix;
+    doublereal smax;
     extern doublereal dcabs1_(doublecomplex *);
-/*  Purpose   
-    =======   
-       finds the index of element having max. absolute value.   
-       jack dongarra, 1/15/85.   
-       modified 3/93 to return if incx .le. 0.   
-       modified 12/3/93, array(1) declarations changed to array(*)   
-       Parameter adjustments */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*     finds the index of element having max. absolute value. */
+/*     jack dongarra, 1/15/85. */
+/*     modified 3/93 to return if incx .le. 0. */
+/*     modified 12/3/93, array(1) declarations changed to array(*) */
+
+
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+    /* Parameter adjustments */
     --zx;
+
     /* Function Body */
     ret_val = 0;
     if (*n < 1 || *incx <= 0) {
@@ -29,7 +44,9 @@ integer izamax_(integer *n, doublecomplex *zx, integer *incx)
     if (*incx == 1) {
 	goto L20;
     }
+
 /*        code for increment not equal to 1 */
+
     ix = 1;
     smax = dcabs1_(&zx[1]);
     ix += *incx;
@@ -45,7 +62,9 @@ L5:
 /* L10: */
     }
     return ret_val;
+
 /*        code for increment equal to 1 */
+
 L20:
     smax = dcabs1_(&zx[1]);
     i__1 = *n;
@@ -60,4 +79,3 @@ L30:
     }
     return ret_val;
 } /* izamax_ */
-
