@@ -1,24 +1,39 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int srot_(integer *n, real *sx, integer *incx, real *sy, 
 	integer *incy, real *c__, real *s)
 {
     /* System generated locals */
     integer i__1;
+
     /* Local variables */
-    static integer i__, ix, iy;
-    static real stemp;
-/*  Purpose   
-    =======   
-       applies a plane rotation.   
-    Further Details   
-    ===============   
-       jack dongarra, linpack, 3/11/78.   
-       modified 12/3/93, array(1) declarations changed to array(*)   
-       Parameter adjustments */
+    integer i__, ix, iy;
+    real stemp;
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*     applies a plane rotation. */
+
+/*  Further Details */
+/*  =============== */
+
+/*     jack dongarra, linpack, 3/11/78. */
+/*     modified 12/3/93, array(1) declarations changed to array(*) */
+
+
+/*     .. Local Scalars .. */
+/*     .. */
+    /* Parameter adjustments */
     --sy;
     --sx;
+
     /* Function Body */
     if (*n <= 0) {
 	return 0;
@@ -26,8 +41,10 @@
     if (*incx == 1 && *incy == 1) {
 	goto L20;
     }
-/*       code for unequal increments or equal increments not equal   
-           to 1 */
+
+/*       code for unequal increments or equal increments not equal */
+/*         to 1 */
+
     ix = 1;
     iy = 1;
     if (*incx < 0) {
@@ -46,7 +63,9 @@
 /* L10: */
     }
     return 0;
+
 /*       code for both increments equal to 1 */
+
 L20:
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -57,4 +76,3 @@ L20:
     }
     return 0;
 } /* srot_ */
-
