@@ -1,21 +1,34 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int zcopy_(integer *n, doublecomplex *zx, integer *incx, 
 	doublecomplex *zy, integer *incy)
 {
     /* System generated locals */
     integer i__1, i__2, i__3;
+
     /* Local variables */
-    static integer i__, ix, iy;
-/*  Purpose   
-    =======   
-       copies a vector, x, to a vector, y.   
-       jack dongarra, linpack, 4/11/78.   
-       modified 12/3/93, array(1) declarations changed to array(*)   
-       Parameter adjustments */
+    integer i__, ix, iy;
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*     copies a vector, x, to a vector, y. */
+/*     jack dongarra, linpack, 4/11/78. */
+/*     modified 12/3/93, array(1) declarations changed to array(*) */
+
+
+/*     .. Local Scalars .. */
+/*     .. */
+    /* Parameter adjustments */
     --zy;
     --zx;
+
     /* Function Body */
     if (*n <= 0) {
 	return 0;
@@ -23,8 +36,10 @@
     if (*incx == 1 && *incy == 1) {
 	goto L20;
     }
-/*        code for unequal increments or equal increments   
-            not equal to 1 */
+
+/*        code for unequal increments or equal increments */
+/*          not equal to 1 */
+
     ix = 1;
     iy = 1;
     if (*incx < 0) {
@@ -43,7 +58,9 @@
 /* L10: */
     }
     return 0;
+
 /*        code for both increments equal to 1 */
+
 L20:
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -54,4 +71,3 @@ L20:
     }
     return 0;
 } /* zcopy_ */
-
