@@ -1,5 +1,5 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int zdscal_(integer *n, doublereal *da, doublecomplex *zx, 
 	integer *incx)
@@ -7,16 +7,31 @@
     /* System generated locals */
     integer i__1, i__2, i__3;
     doublecomplex z__1, z__2;
+
     /* Local variables */
-    static integer i__, ix;
-/*  Purpose   
-    =======   
-       scales a vector by a constant.   
-       jack dongarra, 3/11/78.   
-       modified 3/93 to return if incx .le. 0.   
-       modified 12/3/93, array(1) declarations changed to array(*)   
-       Parameter adjustments */
+    integer i__, ix;
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*     scales a vector by a constant. */
+/*     jack dongarra, 3/11/78. */
+/*     modified 3/93 to return if incx .le. 0. */
+/*     modified 12/3/93, array(1) declarations changed to array(*) */
+
+
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+    /* Parameter adjustments */
     --zx;
+
     /* Function Body */
     if (*n <= 0 || *incx <= 0) {
 	return 0;
@@ -24,7 +39,9 @@
     if (*incx == 1) {
 	goto L20;
     }
+
 /*        code for increment not equal to 1 */
+
     ix = 1;
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -38,7 +55,9 @@
 /* L10: */
     }
     return 0;
+
 /*        code for increment equal to 1 */
+
 L20:
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -52,4 +71,3 @@ L20:
     }
     return 0;
 } /* zdscal_ */
-
