@@ -1,5 +1,5 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int zgemm_(char *transa, char *transb, integer *m, integer *
 	n, integer *k, doublecomplex *alpha, doublecomplex *a, integer *lda, 
@@ -10,111 +10,163 @@
     integer a_dim1, a_offset, b_dim1, b_offset, c_dim1, c_offset, i__1, i__2, 
 	    i__3, i__4, i__5, i__6;
     doublecomplex z__1, z__2, z__3, z__4;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, l, info;
-    static logical nota, notb;
-    static doublecomplex temp;
-    static logical conja, conjb;
-    static integer ncola;
+    integer i__, j, l, info;
+    logical nota, notb;
+    doublecomplex temp;
+    logical conja, conjb;
+    integer ncola;
     extern logical lsame_(char *, char *);
-    static integer nrowa, nrowb;
+    integer nrowa, nrowb;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-/*  Purpose   
-    =======   
-    ZGEMM  performs one of the matrix-matrix operations   
-       C := alpha*op( A )*op( B ) + beta*C,   
-    where  op( X ) is one of   
-       op( X ) = X   or   op( X ) = X'   or   op( X ) = conjg( X' ),   
-    alpha and beta are scalars, and A, B and C are matrices, with op( A )   
-    an m by k matrix,  op( B )  a  k by n matrix and  C an m by n matrix.   
-    Arguments   
-    ==========   
-    TRANSA - CHARACTER*1.   
-             On entry, TRANSA specifies the form of op( A ) to be used in   
-             the matrix multiplication as follows:   
-                TRANSA = 'N' or 'n',  op( A ) = A.   
-                TRANSA = 'T' or 't',  op( A ) = A'.   
-                TRANSA = 'C' or 'c',  op( A ) = conjg( A' ).   
-             Unchanged on exit.   
-    TRANSB - CHARACTER*1.   
-             On entry, TRANSB specifies the form of op( B ) to be used in   
-             the matrix multiplication as follows:   
-                TRANSB = 'N' or 'n',  op( B ) = B.   
-                TRANSB = 'T' or 't',  op( B ) = B'.   
-                TRANSB = 'C' or 'c',  op( B ) = conjg( B' ).   
-             Unchanged on exit.   
-    M      - INTEGER.   
-             On entry,  M  specifies  the number  of rows  of the  matrix   
-             op( A )  and of the  matrix  C.  M  must  be at least  zero.   
-             Unchanged on exit.   
-    N      - INTEGER.   
-             On entry,  N  specifies the number  of columns of the matrix   
-             op( B ) and the number of columns of the matrix C. N must be   
-             at least zero.   
-             Unchanged on exit.   
-    K      - INTEGER.   
-             On entry,  K  specifies  the number of columns of the matrix   
-             op( A ) and the number of rows of the matrix op( B ). K must   
-             be at least  zero.   
-             Unchanged on exit.   
-    ALPHA  - COMPLEX*16      .   
-             On entry, ALPHA specifies the scalar alpha.   
-             Unchanged on exit.   
-    A      - COMPLEX*16       array of DIMENSION ( LDA, ka ), where ka is   
-             k  when  TRANSA = 'N' or 'n',  and is  m  otherwise.   
-             Before entry with  TRANSA = 'N' or 'n',  the leading  m by k   
-             part of the array  A  must contain the matrix  A,  otherwise   
-             the leading  k by m  part of the array  A  must contain  the   
-             matrix A.   
-             Unchanged on exit.   
-    LDA    - INTEGER.   
-             On entry, LDA specifies the first dimension of A as declared   
-             in the calling (sub) program. When  TRANSA = 'N' or 'n' then   
-             LDA must be at least  max( 1, m ), otherwise  LDA must be at   
-             least  max( 1, k ).   
-             Unchanged on exit.   
-    B      - COMPLEX*16       array of DIMENSION ( LDB, kb ), where kb is   
-             n  when  TRANSB = 'N' or 'n',  and is  k  otherwise.   
-             Before entry with  TRANSB = 'N' or 'n',  the leading  k by n   
-             part of the array  B  must contain the matrix  B,  otherwise   
-             the leading  n by k  part of the array  B  must contain  the   
-             matrix B.   
-             Unchanged on exit.   
-    LDB    - INTEGER.   
-             On entry, LDB specifies the first dimension of B as declared   
-             in the calling (sub) program. When  TRANSB = 'N' or 'n' then   
-             LDB must be at least  max( 1, k ), otherwise  LDB must be at   
-             least  max( 1, n ).   
-             Unchanged on exit.   
-    BETA   - COMPLEX*16      .   
-             On entry,  BETA  specifies the scalar  beta.  When  BETA  is   
-             supplied as zero then C need not be set on input.   
-             Unchanged on exit.   
-    C      - COMPLEX*16       array of DIMENSION ( LDC, n ).   
-             Before entry, the leading  m by n  part of the array  C must   
-             contain the matrix  C,  except when  beta  is zero, in which   
-             case C need not be set on entry.   
-             On exit, the array  C  is overwritten by the  m by n  matrix   
-             ( alpha*op( A )*op( B ) + beta*C ).   
-    LDC    - INTEGER.   
-             On entry, LDC specifies the first dimension of C as declared   
-             in  the  calling  (sub)  program.   LDC  must  be  at  least   
-             max( 1, m ).   
-             Unchanged on exit.   
-    Level 3 Blas routine.   
-    -- Written on 8-February-1989.   
-       Jack Dongarra, Argonne National Laboratory.   
-       Iain Duff, AERE Harwell.   
-       Jeremy Du Croz, Numerical Algorithms Group Ltd.   
-       Sven Hammarling, Numerical Algorithms Group Ltd.   
-       Set  NOTA  and  NOTB  as  true if  A  and  B  respectively are not   
-       conjugated or transposed, set  CONJA and CONJB  as true if  A  and   
-       B  respectively are to be  transposed but  not conjugated  and set   
-       NROWA, NCOLA and  NROWB  as the number of rows and  columns  of  A   
-       and the number of rows of  B  respectively.   
-       Parameter adjustments */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZGEMM  performs one of the matrix-matrix operations */
+
+/*     C := alpha*op( A )*op( B ) + beta*C, */
+
+/*  where  op( X ) is one of */
+
+/*     op( X ) = X   or   op( X ) = X'   or   op( X ) = conjg( X' ), */
+
+/*  alpha and beta are scalars, and A, B and C are matrices, with op( A ) */
+/*  an m by k matrix,  op( B )  a  k by n matrix and  C an m by n matrix. */
+
+/*  Arguments */
+/*  ========== */
+
+/*  TRANSA - CHARACTER*1. */
+/*           On entry, TRANSA specifies the form of op( A ) to be used in */
+/*           the matrix multiplication as follows: */
+
+/*              TRANSA = 'N' or 'n',  op( A ) = A. */
+
+/*              TRANSA = 'T' or 't',  op( A ) = A'. */
+
+/*              TRANSA = 'C' or 'c',  op( A ) = conjg( A' ). */
+
+/*           Unchanged on exit. */
+
+/*  TRANSB - CHARACTER*1. */
+/*           On entry, TRANSB specifies the form of op( B ) to be used in */
+/*           the matrix multiplication as follows: */
+
+/*              TRANSB = 'N' or 'n',  op( B ) = B. */
+
+/*              TRANSB = 'T' or 't',  op( B ) = B'. */
+
+/*              TRANSB = 'C' or 'c',  op( B ) = conjg( B' ). */
+
+/*           Unchanged on exit. */
+
+/*  M      - INTEGER. */
+/*           On entry,  M  specifies  the number  of rows  of the  matrix */
+/*           op( A )  and of the  matrix  C.  M  must  be at least  zero. */
+/*           Unchanged on exit. */
+
+/*  N      - INTEGER. */
+/*           On entry,  N  specifies the number  of columns of the matrix */
+/*           op( B ) and the number of columns of the matrix C. N must be */
+/*           at least zero. */
+/*           Unchanged on exit. */
+
+/*  K      - INTEGER. */
+/*           On entry,  K  specifies  the number of columns of the matrix */
+/*           op( A ) and the number of rows of the matrix op( B ). K must */
+/*           be at least  zero. */
+/*           Unchanged on exit. */
+
+/*  ALPHA  - COMPLEX*16      . */
+/*           On entry, ALPHA specifies the scalar alpha. */
+/*           Unchanged on exit. */
+
+/*  A      - COMPLEX*16       array of DIMENSION ( LDA, ka ), where ka is */
+/*           k  when  TRANSA = 'N' or 'n',  and is  m  otherwise. */
+/*           Before entry with  TRANSA = 'N' or 'n',  the leading  m by k */
+/*           part of the array  A  must contain the matrix  A,  otherwise */
+/*           the leading  k by m  part of the array  A  must contain  the */
+/*           matrix A. */
+/*           Unchanged on exit. */
+
+/*  LDA    - INTEGER. */
+/*           On entry, LDA specifies the first dimension of A as declared */
+/*           in the calling (sub) program. When  TRANSA = 'N' or 'n' then */
+/*           LDA must be at least  max( 1, m ), otherwise  LDA must be at */
+/*           least  max( 1, k ). */
+/*           Unchanged on exit. */
+
+/*  B      - COMPLEX*16       array of DIMENSION ( LDB, kb ), where kb is */
+/*           n  when  TRANSB = 'N' or 'n',  and is  k  otherwise. */
+/*           Before entry with  TRANSB = 'N' or 'n',  the leading  k by n */
+/*           part of the array  B  must contain the matrix  B,  otherwise */
+/*           the leading  n by k  part of the array  B  must contain  the */
+/*           matrix B. */
+/*           Unchanged on exit. */
+
+/*  LDB    - INTEGER. */
+/*           On entry, LDB specifies the first dimension of B as declared */
+/*           in the calling (sub) program. When  TRANSB = 'N' or 'n' then */
+/*           LDB must be at least  max( 1, k ), otherwise  LDB must be at */
+/*           least  max( 1, n ). */
+/*           Unchanged on exit. */
+
+/*  BETA   - COMPLEX*16      . */
+/*           On entry,  BETA  specifies the scalar  beta.  When  BETA  is */
+/*           supplied as zero then C need not be set on input. */
+/*           Unchanged on exit. */
+
+/*  C      - COMPLEX*16       array of DIMENSION ( LDC, n ). */
+/*           Before entry, the leading  m by n  part of the array  C must */
+/*           contain the matrix  C,  except when  beta  is zero, in which */
+/*           case C need not be set on entry. */
+/*           On exit, the array  C  is overwritten by the  m by n  matrix */
+/*           ( alpha*op( A )*op( B ) + beta*C ). */
+
+/*  LDC    - INTEGER. */
+/*           On entry, LDC specifies the first dimension of C as declared */
+/*           in  the  calling  (sub)  program.   LDC  must  be  at  least */
+/*           max( 1, m ). */
+/*           Unchanged on exit. */
+
+
+/*  Level 3 Blas routine. */
+
+/*  -- Written on 8-February-1989. */
+/*     Jack Dongarra, Argonne National Laboratory. */
+/*     Iain Duff, AERE Harwell. */
+/*     Jeremy Du Croz, Numerical Algorithms Group Ltd. */
+/*     Sven Hammarling, Numerical Algorithms Group Ltd. */
+
+
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Parameters .. */
+/*     .. */
+
+/*     Set  NOTA  and  NOTB  as  true if  A  and  B  respectively are not */
+/*     conjugated or transposed, set  CONJA and CONJB  as true if  A  and */
+/*     B  respectively are to be  transposed but  not conjugated  and set */
+/*     NROWA, NCOLA and  NROWB  as the number of rows and  columns  of  A */
+/*     and the number of rows of  B  respectively. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -124,6 +176,7 @@
     c_dim1 = *ldc;
     c_offset = 1 + c_dim1;
     c__ -= c_offset;
+
     /* Function Body */
     nota = lsame_(transa, "N");
     notb = lsame_(transb, "N");
@@ -141,7 +194,9 @@
     } else {
 	nrowb = *n;
     }
+
 /*     Test the input parameters. */
+
     info = 0;
     if (! nota && ! conja && ! lsame_(transa, "T")) {
 	info = 1;
@@ -164,12 +219,16 @@
 	xerbla_("ZGEMM ", &info);
 	return 0;
     }
+
 /*     Quick return if possible. */
+
     if (*m == 0 || *n == 0 || (alpha->r == 0. && alpha->i == 0. || *k == 0) &&
 	     (beta->r == 1. && beta->i == 0.)) {
 	return 0;
     }
+
 /*     And when  alpha.eq.zero. */
+
     if (alpha->r == 0. && alpha->i == 0.) {
 	if (beta->r == 0. && beta->i == 0.) {
 	    i__1 = *n;
@@ -200,10 +259,14 @@
 	}
 	return 0;
     }
+
 /*     Start the operations. */
+
     if (notb) {
 	if (nota) {
+
 /*           Form  C := alpha*A*B + beta*C. */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		if (beta->r == 0. && beta->i == 0.) {
@@ -253,7 +316,9 @@
 /* L90: */
 	    }
 	} else if (conja) {
+
 /*           Form  C := alpha*conjg( A' )*B + beta*C. */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		i__2 = *m;
@@ -293,7 +358,9 @@
 /* L120: */
 	    }
 	} else {
+
 /*           Form  C := alpha*A'*B + beta*C */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		i__2 = *m;
@@ -335,7 +402,9 @@
 	}
     } else if (nota) {
 	if (conjb) {
+
 /*           Form  C := alpha*A*conjg( B' ) + beta*C. */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		if (beta->r == 0. && beta->i == 0.) {
@@ -385,7 +454,9 @@
 /* L200: */
 	    }
 	} else {
+
 /*           Form  C := alpha*A*B'          + beta*C */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		if (beta->r == 0. && beta->i == 0.) {
@@ -437,7 +508,9 @@
 	}
     } else if (conja) {
 	if (conjb) {
+
 /*           Form  C := alpha*conjg( A' )*conjg( B' ) + beta*C. */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		i__2 = *m;
@@ -476,7 +549,9 @@
 /* L280: */
 	    }
 	} else {
+
 /*           Form  C := alpha*conjg( A' )*B' + beta*C */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		i__2 = *m;
@@ -518,7 +593,9 @@
 	}
     } else {
 	if (conjb) {
+
 /*           Form  C := alpha*A'*conjg( B' ) + beta*C */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		i__2 = *m;
@@ -558,7 +635,9 @@
 /* L340: */
 	    }
 	} else {
+
 /*           Form  C := alpha*A'*B' + beta*C */
+
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
 		i__2 = *m;
@@ -599,7 +678,9 @@
 	    }
 	}
     }
-    return 0;
-/*     End of ZGEMM . */
-} /* zgemm_ */
 
+    return 0;
+
+/*     End of ZGEMM . */
+
+} /* zgemm_ */
