@@ -1,5 +1,5 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int zher2k_(char *uplo, char *trans, integer *n, integer *k, 
 	doublecomplex *alpha, doublecomplex *a, integer *lda, doublecomplex *
@@ -10,118 +10,168 @@
 	    i__3, i__4, i__5, i__6, i__7;
     doublereal d__1;
     doublecomplex z__1, z__2, z__3, z__4, z__5, z__6;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, l, info;
-    static doublecomplex temp1, temp2;
+    integer i__, j, l, info;
+    doublecomplex temp1, temp2;
     extern logical lsame_(char *, char *);
-    static integer nrowa;
-    static logical upper;
+    integer nrowa;
+    logical upper;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-/*  Purpose   
-    =======   
-    ZHER2K  performs one of the hermitian rank 2k operations   
-       C := alpha*A*conjg( B' ) + conjg( alpha )*B*conjg( A' ) + beta*C,   
-    or   
-       C := alpha*conjg( A' )*B + conjg( alpha )*conjg( B' )*A + beta*C,   
-    where  alpha and beta  are scalars with  beta  real,  C is an  n by n   
-    hermitian matrix and  A and B  are  n by k matrices in the first case   
-    and  k by n  matrices in the second case.   
-    Arguments   
-    ==========   
-    UPLO   - CHARACTER*1.   
-             On  entry,   UPLO  specifies  whether  the  upper  or  lower   
-             triangular  part  of the  array  C  is to be  referenced  as   
-             follows:   
-                UPLO = 'U' or 'u'   Only the  upper triangular part of  C   
-                                    is to be referenced.   
-                UPLO = 'L' or 'l'   Only the  lower triangular part of  C   
-                                    is to be referenced.   
-             Unchanged on exit.   
-    TRANS  - CHARACTER*1.   
-             On entry,  TRANS  specifies the operation to be performed as   
-             follows:   
-                TRANS = 'N' or 'n'    C := alpha*A*conjg( B' )          +   
-                                           conjg( alpha )*B*conjg( A' ) +   
-                                           beta*C.   
-                TRANS = 'C' or 'c'    C := alpha*conjg( A' )*B          +   
-                                           conjg( alpha )*conjg( B' )*A +   
-                                           beta*C.   
-             Unchanged on exit.   
-    N      - INTEGER.   
-             On entry,  N specifies the order of the matrix C.  N must be   
-             at least zero.   
-             Unchanged on exit.   
-    K      - INTEGER.   
-             On entry with  TRANS = 'N' or 'n',  K  specifies  the number   
-             of  columns  of the  matrices  A and B,  and on  entry  with   
-             TRANS = 'C' or 'c',  K  specifies  the number of rows of the   
-             matrices  A and B.  K must be at least zero.   
-             Unchanged on exit.   
-    ALPHA  - COMPLEX*16         .   
-             On entry, ALPHA specifies the scalar alpha.   
-             Unchanged on exit.   
-    A      - COMPLEX*16       array of DIMENSION ( LDA, ka ), where ka is   
-             k  when  TRANS = 'N' or 'n',  and is  n  otherwise.   
-             Before entry with  TRANS = 'N' or 'n',  the  leading  n by k   
-             part of the array  A  must contain the matrix  A,  otherwise   
-             the leading  k by n  part of the array  A  must contain  the   
-             matrix A.   
-             Unchanged on exit.   
-    LDA    - INTEGER.   
-             On entry, LDA specifies the first dimension of A as declared   
-             in  the  calling  (sub)  program.   When  TRANS = 'N' or 'n'   
-             then  LDA must be at least  max( 1, n ), otherwise  LDA must   
-             be at least  max( 1, k ).   
-             Unchanged on exit.   
-    B      - COMPLEX*16       array of DIMENSION ( LDB, kb ), where kb is   
-             k  when  TRANS = 'N' or 'n',  and is  n  otherwise.   
-             Before entry with  TRANS = 'N' or 'n',  the  leading  n by k   
-             part of the array  B  must contain the matrix  B,  otherwise   
-             the leading  k by n  part of the array  B  must contain  the   
-             matrix B.   
-             Unchanged on exit.   
-    LDB    - INTEGER.   
-             On entry, LDB specifies the first dimension of B as declared   
-             in  the  calling  (sub)  program.   When  TRANS = 'N' or 'n'   
-             then  LDB must be at least  max( 1, n ), otherwise  LDB must   
-             be at least  max( 1, k ).   
-             Unchanged on exit.   
-    BETA   - DOUBLE PRECISION            .   
-             On entry, BETA specifies the scalar beta.   
-             Unchanged on exit.   
-    C      - COMPLEX*16          array of DIMENSION ( LDC, n ).   
-             Before entry  with  UPLO = 'U' or 'u',  the leading  n by n   
-             upper triangular part of the array C must contain the upper   
-             triangular part  of the  hermitian matrix  and the strictly   
-             lower triangular part of C is not referenced.  On exit, the   
-             upper triangular part of the array  C is overwritten by the   
-             upper triangular part of the updated matrix.   
-             Before entry  with  UPLO = 'L' or 'l',  the leading  n by n   
-             lower triangular part of the array C must contain the lower   
-             triangular part  of the  hermitian matrix  and the strictly   
-             upper triangular part of C is not referenced.  On exit, the   
-             lower triangular part of the array  C is overwritten by the   
-             lower triangular part of the updated matrix.   
-             Note that the imaginary parts of the diagonal elements need   
-             not be set,  they are assumed to be zero,  and on exit they   
-             are set to zero.   
-    LDC    - INTEGER.   
-             On entry, LDC specifies the first dimension of C as declared   
-             in  the  calling  (sub)  program.   LDC  must  be  at  least   
-             max( 1, n ).   
-             Unchanged on exit.   
-    Level 3 Blas routine.   
-    -- Written on 8-February-1989.   
-       Jack Dongarra, Argonne National Laboratory.   
-       Iain Duff, AERE Harwell.   
-       Jeremy Du Croz, Numerical Algorithms Group Ltd.   
-       Sven Hammarling, Numerical Algorithms Group Ltd.   
-    -- Modified 8-Nov-93 to set C(J,J) to DBLE( C(J,J) ) when BETA = 1.   
-       Ed Anderson, Cray Research Inc.   
-       Test the input parameters.   
-       Parameter adjustments */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZHER2K  performs one of the hermitian rank 2k operations */
+
+/*     C := alpha*A*conjg( B' ) + conjg( alpha )*B*conjg( A' ) + beta*C, */
+
+/*  or */
+
+/*     C := alpha*conjg( A' )*B + conjg( alpha )*conjg( B' )*A + beta*C, */
+
+/*  where  alpha and beta  are scalars with  beta  real,  C is an  n by n */
+/*  hermitian matrix and  A and B  are  n by k matrices in the first case */
+/*  and  k by n  matrices in the second case. */
+
+/*  Arguments */
+/*  ========== */
+
+/*  UPLO   - CHARACTER*1. */
+/*           On  entry,   UPLO  specifies  whether  the  upper  or  lower */
+/*           triangular  part  of the  array  C  is to be  referenced  as */
+/*           follows: */
+
+/*              UPLO = 'U' or 'u'   Only the  upper triangular part of  C */
+/*                                  is to be referenced. */
+
+/*              UPLO = 'L' or 'l'   Only the  lower triangular part of  C */
+/*                                  is to be referenced. */
+
+/*           Unchanged on exit. */
+
+/*  TRANS  - CHARACTER*1. */
+/*           On entry,  TRANS  specifies the operation to be performed as */
+/*           follows: */
+
+/*              TRANS = 'N' or 'n'    C := alpha*A*conjg( B' )          + */
+/*                                         conjg( alpha )*B*conjg( A' ) + */
+/*                                         beta*C. */
+
+/*              TRANS = 'C' or 'c'    C := alpha*conjg( A' )*B          + */
+/*                                         conjg( alpha )*conjg( B' )*A + */
+/*                                         beta*C. */
+
+/*           Unchanged on exit. */
+
+/*  N      - INTEGER. */
+/*           On entry,  N specifies the order of the matrix C.  N must be */
+/*           at least zero. */
+/*           Unchanged on exit. */
+
+/*  K      - INTEGER. */
+/*           On entry with  TRANS = 'N' or 'n',  K  specifies  the number */
+/*           of  columns  of the  matrices  A and B,  and on  entry  with */
+/*           TRANS = 'C' or 'c',  K  specifies  the number of rows of the */
+/*           matrices  A and B.  K must be at least zero. */
+/*           Unchanged on exit. */
+
+/*  ALPHA  - COMPLEX*16         . */
+/*           On entry, ALPHA specifies the scalar alpha. */
+/*           Unchanged on exit. */
+
+/*  A      - COMPLEX*16       array of DIMENSION ( LDA, ka ), where ka is */
+/*           k  when  TRANS = 'N' or 'n',  and is  n  otherwise. */
+/*           Before entry with  TRANS = 'N' or 'n',  the  leading  n by k */
+/*           part of the array  A  must contain the matrix  A,  otherwise */
+/*           the leading  k by n  part of the array  A  must contain  the */
+/*           matrix A. */
+/*           Unchanged on exit. */
+
+/*  LDA    - INTEGER. */
+/*           On entry, LDA specifies the first dimension of A as declared */
+/*           in  the  calling  (sub)  program.   When  TRANS = 'N' or 'n' */
+/*           then  LDA must be at least  max( 1, n ), otherwise  LDA must */
+/*           be at least  max( 1, k ). */
+/*           Unchanged on exit. */
+
+/*  B      - COMPLEX*16       array of DIMENSION ( LDB, kb ), where kb is */
+/*           k  when  TRANS = 'N' or 'n',  and is  n  otherwise. */
+/*           Before entry with  TRANS = 'N' or 'n',  the  leading  n by k */
+/*           part of the array  B  must contain the matrix  B,  otherwise */
+/*           the leading  k by n  part of the array  B  must contain  the */
+/*           matrix B. */
+/*           Unchanged on exit. */
+
+/*  LDB    - INTEGER. */
+/*           On entry, LDB specifies the first dimension of B as declared */
+/*           in  the  calling  (sub)  program.   When  TRANS = 'N' or 'n' */
+/*           then  LDB must be at least  max( 1, n ), otherwise  LDB must */
+/*           be at least  max( 1, k ). */
+/*           Unchanged on exit. */
+
+/*  BETA   - DOUBLE PRECISION            . */
+/*           On entry, BETA specifies the scalar beta. */
+/*           Unchanged on exit. */
+
+/*  C      - COMPLEX*16          array of DIMENSION ( LDC, n ). */
+/*           Before entry  with  UPLO = 'U' or 'u',  the leading  n by n */
+/*           upper triangular part of the array C must contain the upper */
+/*           triangular part  of the  hermitian matrix  and the strictly */
+/*           lower triangular part of C is not referenced.  On exit, the */
+/*           upper triangular part of the array  C is overwritten by the */
+/*           upper triangular part of the updated matrix. */
+/*           Before entry  with  UPLO = 'L' or 'l',  the leading  n by n */
+/*           lower triangular part of the array C must contain the lower */
+/*           triangular part  of the  hermitian matrix  and the strictly */
+/*           upper triangular part of C is not referenced.  On exit, the */
+/*           lower triangular part of the array  C is overwritten by the */
+/*           lower triangular part of the updated matrix. */
+/*           Note that the imaginary parts of the diagonal elements need */
+/*           not be set,  they are assumed to be zero,  and on exit they */
+/*           are set to zero. */
+
+/*  LDC    - INTEGER. */
+/*           On entry, LDC specifies the first dimension of C as declared */
+/*           in  the  calling  (sub)  program.   LDC  must  be  at  least */
+/*           max( 1, n ). */
+/*           Unchanged on exit. */
+
+
+/*  Level 3 Blas routine. */
+
+/*  -- Written on 8-February-1989. */
+/*     Jack Dongarra, Argonne National Laboratory. */
+/*     Iain Duff, AERE Harwell. */
+/*     Jeremy Du Croz, Numerical Algorithms Group Ltd. */
+/*     Sven Hammarling, Numerical Algorithms Group Ltd. */
+
+/*  -- Modified 8-Nov-93 to set C(J,J) to DBLE( C(J,J) ) when BETA = 1. */
+/*     Ed Anderson, Cray Research Inc. */
+
+
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Parameters .. */
+/*     .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -131,6 +181,7 @@
     c_dim1 = *ldc;
     c_offset = 1 + c_dim1;
     c__ -= c_offset;
+
     /* Function Body */
     if (lsame_(trans, "N")) {
 	nrowa = *n;
@@ -138,6 +189,7 @@
 	nrowa = *k;
     }
     upper = lsame_(uplo, "U");
+
     info = 0;
     if (! upper && ! lsame_(uplo, "L")) {
 	info = 1;
@@ -159,12 +211,16 @@
 	xerbla_("ZHER2K", &info);
 	return 0;
     }
+
 /*     Quick return if possible. */
+
     if (*n == 0 || (alpha->r == 0. && alpha->i == 0. || *k == 0) && *beta == 
 	    1.) {
 	return 0;
     }
+
 /*     And when  alpha.eq.zero. */
+
     if (alpha->r == 0. && alpha->i == 0.) {
 	if (upper) {
 	    if (*beta == 0.) {
@@ -231,10 +287,14 @@
 	}
 	return 0;
     }
+
 /*     Start the operations. */
+
     if (lsame_(trans, "N")) {
-/*        Form  C := alpha*A*conjg( B' ) + conjg( alpha )*B*conjg( A' ) +   
-                     C. */
+
+/*        Form  C := alpha*A*conjg( B' ) + conjg( alpha )*B*conjg( A' ) + */
+/*                   C. */
+
 	if (upper) {
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
@@ -405,8 +465,10 @@
 	    }
 	}
     } else {
-/*        Form  C := alpha*conjg( A' )*B + conjg( alpha )*conjg( B' )*A +   
-                     C. */
+
+/*        Form  C := alpha*conjg( A' )*B + conjg( alpha )*conjg( B' )*A + */
+/*                   C. */
+
 	if (upper) {
 	    i__1 = *n;
 	    for (j = 1; j <= i__1; ++j) {
@@ -589,7 +651,9 @@
 	    }
 	}
     }
-    return 0;
-/*     End of ZHER2K. */
-} /* zher2k_ */
 
+    return 0;
+
+/*     End of ZHER2K. */
+
+} /* zher2k_ */
