@@ -1,5 +1,5 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int ztbmv_(char *uplo, char *trans, char *diag, integer *n, 
 	integer *k, doublecomplex *a, integer *lda, doublecomplex *x, integer 
@@ -8,117 +8,170 @@
     /* System generated locals */
     integer a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5;
     doublecomplex z__1, z__2, z__3;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, l, ix, jx, kx, info;
-    static doublecomplex temp;
+    integer i__, j, l, ix, jx, kx, info;
+    doublecomplex temp;
     extern logical lsame_(char *, char *);
-    static integer kplus1;
+    integer kplus1;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static logical noconj, nounit;
-/*  Purpose   
-    =======   
-    ZTBMV  performs one of the matrix-vector operations   
-       x := A*x,   or   x := A'*x,   or   x := conjg( A' )*x,   
-    where x is an n element vector and  A is an n by n unit, or non-unit,   
-    upper or lower triangular band matrix, with ( k + 1 ) diagonals.   
-    Arguments   
-    ==========   
-    UPLO   - CHARACTER*1.   
-             On entry, UPLO specifies whether the matrix is an upper or   
-             lower triangular matrix as follows:   
-                UPLO = 'U' or 'u'   A is an upper triangular matrix.   
-                UPLO = 'L' or 'l'   A is a lower triangular matrix.   
-             Unchanged on exit.   
-    TRANS  - CHARACTER*1.   
-             On entry, TRANS specifies the operation to be performed as   
-             follows:   
-                TRANS = 'N' or 'n'   x := A*x.   
-                TRANS = 'T' or 't'   x := A'*x.   
-                TRANS = 'C' or 'c'   x := conjg( A' )*x.   
-             Unchanged on exit.   
-    DIAG   - CHARACTER*1.   
-             On entry, DIAG specifies whether or not A is unit   
-             triangular as follows:   
-                DIAG = 'U' or 'u'   A is assumed to be unit triangular.   
-                DIAG = 'N' or 'n'   A is not assumed to be unit   
-                                    triangular.   
-             Unchanged on exit.   
-    N      - INTEGER.   
-             On entry, N specifies the order of the matrix A.   
-             N must be at least zero.   
-             Unchanged on exit.   
-    K      - INTEGER.   
-             On entry with UPLO = 'U' or 'u', K specifies the number of   
-             super-diagonals of the matrix A.   
-             On entry with UPLO = 'L' or 'l', K specifies the number of   
-             sub-diagonals of the matrix A.   
-             K must satisfy  0 .le. K.   
-             Unchanged on exit.   
-    A      - COMPLEX*16       array of DIMENSION ( LDA, n ).   
-             Before entry with UPLO = 'U' or 'u', the leading ( k + 1 )   
-             by n part of the array A must contain the upper triangular   
-             band part of the matrix of coefficients, supplied column by   
-             column, with the leading diagonal of the matrix in row   
-             ( k + 1 ) of the array, the first super-diagonal starting at   
-             position 2 in row k, and so on. The top left k by k triangle   
-             of the array A is not referenced.   
-             The following program segment will transfer an upper   
-             triangular band matrix from conventional full matrix storage   
-             to band storage:   
-                   DO 20, J = 1, N   
-                      M = K + 1 - J   
-                      DO 10, I = MAX( 1, J - K ), J   
-                         A( M + I, J ) = matrix( I, J )   
-                10    CONTINUE   
-                20 CONTINUE   
-             Before entry with UPLO = 'L' or 'l', the leading ( k + 1 )   
-             by n part of the array A must contain the lower triangular   
-             band part of the matrix of coefficients, supplied column by   
-             column, with the leading diagonal of the matrix in row 1 of   
-             the array, the first sub-diagonal starting at position 1 in   
-             row 2, and so on. The bottom right k by k triangle of the   
-             array A is not referenced.   
-             The following program segment will transfer a lower   
-             triangular band matrix from conventional full matrix storage   
-             to band storage:   
-                   DO 20, J = 1, N   
-                      M = 1 - J   
-                      DO 10, I = J, MIN( N, J + K )   
-                         A( M + I, J ) = matrix( I, J )   
-                10    CONTINUE   
-                20 CONTINUE   
-             Note that when DIAG = 'U' or 'u' the elements of the array A   
-             corresponding to the diagonal elements of the matrix are not   
-             referenced, but are assumed to be unity.   
-             Unchanged on exit.   
-    LDA    - INTEGER.   
-             On entry, LDA specifies the first dimension of A as declared   
-             in the calling (sub) program. LDA must be at least   
-             ( k + 1 ).   
-             Unchanged on exit.   
-    X      - COMPLEX*16       array of dimension at least   
-             ( 1 + ( n - 1 )*abs( INCX ) ).   
-             Before entry, the incremented array X must contain the n   
-             element vector x. On exit, X is overwritten with the   
-             tranformed vector x.   
-    INCX   - INTEGER.   
-             On entry, INCX specifies the increment for the elements of   
-             X. INCX must not be zero.   
-             Unchanged on exit.   
-    Level 2 Blas routine.   
-    -- Written on 22-October-1986.   
-       Jack Dongarra, Argonne National Lab.   
-       Jeremy Du Croz, Nag Central Office.   
-       Sven Hammarling, Nag Central Office.   
-       Richard Hanson, Sandia National Labs.   
-       Test the input parameters.   
-       Parameter adjustments */
+    logical noconj, nounit;
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZTBMV  performs one of the matrix-vector operations */
+
+/*     x := A*x,   or   x := A'*x,   or   x := conjg( A' )*x, */
+
+/*  where x is an n element vector and  A is an n by n unit, or non-unit, */
+/*  upper or lower triangular band matrix, with ( k + 1 ) diagonals. */
+
+/*  Arguments */
+/*  ========== */
+
+/*  UPLO   - CHARACTER*1. */
+/*           On entry, UPLO specifies whether the matrix is an upper or */
+/*           lower triangular matrix as follows: */
+
+/*              UPLO = 'U' or 'u'   A is an upper triangular matrix. */
+
+/*              UPLO = 'L' or 'l'   A is a lower triangular matrix. */
+
+/*           Unchanged on exit. */
+
+/*  TRANS  - CHARACTER*1. */
+/*           On entry, TRANS specifies the operation to be performed as */
+/*           follows: */
+
+/*              TRANS = 'N' or 'n'   x := A*x. */
+
+/*              TRANS = 'T' or 't'   x := A'*x. */
+
+/*              TRANS = 'C' or 'c'   x := conjg( A' )*x. */
+
+/*           Unchanged on exit. */
+
+/*  DIAG   - CHARACTER*1. */
+/*           On entry, DIAG specifies whether or not A is unit */
+/*           triangular as follows: */
+
+/*              DIAG = 'U' or 'u'   A is assumed to be unit triangular. */
+
+/*              DIAG = 'N' or 'n'   A is not assumed to be unit */
+/*                                  triangular. */
+
+/*           Unchanged on exit. */
+
+/*  N      - INTEGER. */
+/*           On entry, N specifies the order of the matrix A. */
+/*           N must be at least zero. */
+/*           Unchanged on exit. */
+
+/*  K      - INTEGER. */
+/*           On entry with UPLO = 'U' or 'u', K specifies the number of */
+/*           super-diagonals of the matrix A. */
+/*           On entry with UPLO = 'L' or 'l', K specifies the number of */
+/*           sub-diagonals of the matrix A. */
+/*           K must satisfy  0 .le. K. */
+/*           Unchanged on exit. */
+
+/*  A      - COMPLEX*16       array of DIMENSION ( LDA, n ). */
+/*           Before entry with UPLO = 'U' or 'u', the leading ( k + 1 ) */
+/*           by n part of the array A must contain the upper triangular */
+/*           band part of the matrix of coefficients, supplied column by */
+/*           column, with the leading diagonal of the matrix in row */
+/*           ( k + 1 ) of the array, the first super-diagonal starting at */
+/*           position 2 in row k, and so on. The top left k by k triangle */
+/*           of the array A is not referenced. */
+/*           The following program segment will transfer an upper */
+/*           triangular band matrix from conventional full matrix storage */
+/*           to band storage: */
+
+/*                 DO 20, J = 1, N */
+/*                    M = K + 1 - J */
+/*                    DO 10, I = MAX( 1, J - K ), J */
+/*                       A( M + I, J ) = matrix( I, J ) */
+/*              10    CONTINUE */
+/*              20 CONTINUE */
+
+/*           Before entry with UPLO = 'L' or 'l', the leading ( k + 1 ) */
+/*           by n part of the array A must contain the lower triangular */
+/*           band part of the matrix of coefficients, supplied column by */
+/*           column, with the leading diagonal of the matrix in row 1 of */
+/*           the array, the first sub-diagonal starting at position 1 in */
+/*           row 2, and so on. The bottom right k by k triangle of the */
+/*           array A is not referenced. */
+/*           The following program segment will transfer a lower */
+/*           triangular band matrix from conventional full matrix storage */
+/*           to band storage: */
+
+/*                 DO 20, J = 1, N */
+/*                    M = 1 - J */
+/*                    DO 10, I = J, MIN( N, J + K ) */
+/*                       A( M + I, J ) = matrix( I, J ) */
+/*              10    CONTINUE */
+/*              20 CONTINUE */
+
+/*           Note that when DIAG = 'U' or 'u' the elements of the array A */
+/*           corresponding to the diagonal elements of the matrix are not */
+/*           referenced, but are assumed to be unity. */
+/*           Unchanged on exit. */
+
+/*  LDA    - INTEGER. */
+/*           On entry, LDA specifies the first dimension of A as declared */
+/*           in the calling (sub) program. LDA must be at least */
+/*           ( k + 1 ). */
+/*           Unchanged on exit. */
+
+/*  X      - COMPLEX*16       array of dimension at least */
+/*           ( 1 + ( n - 1 )*abs( INCX ) ). */
+/*           Before entry, the incremented array X must contain the n */
+/*           element vector x. On exit, X is overwritten with the */
+/*           tranformed vector x. */
+
+/*  INCX   - INTEGER. */
+/*           On entry, INCX specifies the increment for the elements of */
+/*           X. INCX must not be zero. */
+/*           Unchanged on exit. */
+
+
+/*  Level 2 Blas routine. */
+
+/*  -- Written on 22-October-1986. */
+/*     Jack Dongarra, Argonne National Lab. */
+/*     Jeremy Du Croz, Nag Central Office. */
+/*     Sven Hammarling, Nag Central Office. */
+/*     Richard Hanson, Sandia National Labs. */
+
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
     --x;
+
     /* Function Body */
     info = 0;
     if (! lsame_(uplo, "U") && ! lsame_(uplo, "L")) {
@@ -142,23 +195,32 @@
 	xerbla_("ZTBMV ", &info);
 	return 0;
     }
+
 /*     Quick return if possible. */
+
     if (*n == 0) {
 	return 0;
     }
+
     noconj = lsame_(trans, "T");
     nounit = lsame_(diag, "N");
-/*     Set up the start point in X if the increment is not unity. This   
-       will be  ( N - 1 )*INCX   too small for descending loops. */
+
+/*     Set up the start point in X if the increment is not unity. This */
+/*     will be  ( N - 1 )*INCX   too small for descending loops. */
+
     if (*incx <= 0) {
 	kx = 1 - (*n - 1) * *incx;
     } else if (*incx != 1) {
 	kx = 1;
     }
-/*     Start the operations. In this version the elements of A are   
-       accessed sequentially with one pass through A. */
+
+/*     Start the operations. In this version the elements of A are */
+/*     accessed sequentially with one pass through A. */
+
     if (lsame_(trans, "N")) {
+
 /*         Form  x := A*x. */
+
 	if (lsame_(uplo, "U")) {
 	    kplus1 = *k + 1;
 	    if (*incx == 1) {
@@ -319,7 +381,9 @@
 	    }
 	}
     } else {
+
 /*        Form  x := A'*x  or  x := conjg( A' )*x. */
+
 	if (lsame_(uplo, "U")) {
 	    kplus1 = *k + 1;
 	    if (*incx == 1) {
@@ -558,7 +622,9 @@
 	    }
 	}
     }
-    return 0;
-/*     End of ZTBMV . */
-} /* ztbmv_ */
 
+    return 0;
+
+/*     End of ZTBMV . */
+
+} /* ztbmv_ */
