@@ -1,120 +1,177 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {1.,0.};
 
 /* Subroutine */ int ztrsm_(char *side, char *uplo, char *transa, char *diag, 
 	integer *m, integer *n, doublecomplex *alpha, doublecomplex *a, 
 	integer *lda, doublecomplex *b, integer *ldb)
 {
-    /* Table of constant values */
-    static doublecomplex c_b1 = {1.,0.};
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, i__1, i__2, i__3, i__4, i__5, 
 	    i__6, i__7;
     doublecomplex z__1, z__2, z__3;
+
     /* Builtin functions */
     void z_div(doublecomplex *, doublecomplex *, doublecomplex *), d_cnjg(
 	    doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, k, info;
-    static doublecomplex temp;
-    static logical lside;
+    integer i__, j, k, info;
+    doublecomplex temp;
+    logical lside;
     extern logical lsame_(char *, char *);
-    static integer nrowa;
-    static logical upper;
+    integer nrowa;
+    logical upper;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static logical noconj, nounit;
-/*  Purpose   
-    =======   
-    ZTRSM  solves one of the matrix equations   
-       op( A )*X = alpha*B,   or   X*op( A ) = alpha*B,   
-    where alpha is a scalar, X and B are m by n matrices, A is a unit, or   
-    non-unit,  upper or lower triangular matrix  and  op( A )  is one  of   
-       op( A ) = A   or   op( A ) = A'   or   op( A ) = conjg( A' ).   
-    The matrix X is overwritten on B.   
-    Arguments   
-    ==========   
-    SIDE   - CHARACTER*1.   
-             On entry, SIDE specifies whether op( A ) appears on the left   
-             or right of X as follows:   
-                SIDE = 'L' or 'l'   op( A )*X = alpha*B.   
-                SIDE = 'R' or 'r'   X*op( A ) = alpha*B.   
-             Unchanged on exit.   
-    UPLO   - CHARACTER*1.   
-             On entry, UPLO specifies whether the matrix A is an upper or   
-             lower triangular matrix as follows:   
-                UPLO = 'U' or 'u'   A is an upper triangular matrix.   
-                UPLO = 'L' or 'l'   A is a lower triangular matrix.   
-             Unchanged on exit.   
-    TRANSA - CHARACTER*1.   
-             On entry, TRANSA specifies the form of op( A ) to be used in   
-             the matrix multiplication as follows:   
-                TRANSA = 'N' or 'n'   op( A ) = A.   
-                TRANSA = 'T' or 't'   op( A ) = A'.   
-                TRANSA = 'C' or 'c'   op( A ) = conjg( A' ).   
-             Unchanged on exit.   
-    DIAG   - CHARACTER*1.   
-             On entry, DIAG specifies whether or not A is unit triangular   
-             as follows:   
-                DIAG = 'U' or 'u'   A is assumed to be unit triangular.   
-                DIAG = 'N' or 'n'   A is not assumed to be unit   
-                                    triangular.   
-             Unchanged on exit.   
-    M      - INTEGER.   
-             On entry, M specifies the number of rows of B. M must be at   
-             least zero.   
-             Unchanged on exit.   
-    N      - INTEGER.   
-             On entry, N specifies the number of columns of B.  N must be   
-             at least zero.   
-             Unchanged on exit.   
-    ALPHA  - COMPLEX*16      .   
-             On entry,  ALPHA specifies the scalar  alpha. When  alpha is   
-             zero then  A is not referenced and  B need not be set before   
-             entry.   
-             Unchanged on exit.   
-    A      - COMPLEX*16       array of DIMENSION ( LDA, k ), where k is m   
-             when  SIDE = 'L' or 'l'  and is  n  when  SIDE = 'R' or 'r'.   
-             Before entry  with  UPLO = 'U' or 'u',  the  leading  k by k   
-             upper triangular part of the array  A must contain the upper   
-             triangular matrix  and the strictly lower triangular part of   
-             A is not referenced.   
-             Before entry  with  UPLO = 'L' or 'l',  the  leading  k by k   
-             lower triangular part of the array  A must contain the lower   
-             triangular matrix  and the strictly upper triangular part of   
-             A is not referenced.   
-             Note that when  DIAG = 'U' or 'u',  the diagonal elements of   
-             A  are not referenced either,  but are assumed to be  unity.   
-             Unchanged on exit.   
-    LDA    - INTEGER.   
-             On entry, LDA specifies the first dimension of A as declared   
-             in the calling (sub) program.  When  SIDE = 'L' or 'l'  then   
-             LDA  must be at least  max( 1, m ),  when  SIDE = 'R' or 'r'   
-             then LDA must be at least max( 1, n ).   
-             Unchanged on exit.   
-    B      - COMPLEX*16       array of DIMENSION ( LDB, n ).   
-             Before entry,  the leading  m by n part of the array  B must   
-             contain  the  right-hand  side  matrix  B,  and  on exit  is   
-             overwritten by the solution matrix  X.   
-    LDB    - INTEGER.   
-             On entry, LDB specifies the first dimension of B as declared   
-             in  the  calling  (sub)  program.   LDB  must  be  at  least   
-             max( 1, m ).   
-             Unchanged on exit.   
-    Level 3 Blas routine.   
-    -- Written on 8-February-1989.   
-       Jack Dongarra, Argonne National Laboratory.   
-       Iain Duff, AERE Harwell.   
-       Jeremy Du Croz, Numerical Algorithms Group Ltd.   
-       Sven Hammarling, Numerical Algorithms Group Ltd.   
-       Test the input parameters.   
-       Parameter adjustments */
+    logical noconj, nounit;
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZTRSM  solves one of the matrix equations */
+
+/*     op( A )*X = alpha*B,   or   X*op( A ) = alpha*B, */
+
+/*  where alpha is a scalar, X and B are m by n matrices, A is a unit, or */
+/*  non-unit,  upper or lower triangular matrix  and  op( A )  is one  of */
+
+/*     op( A ) = A   or   op( A ) = A'   or   op( A ) = conjg( A' ). */
+
+/*  The matrix X is overwritten on B. */
+
+/*  Arguments */
+/*  ========== */
+
+/*  SIDE   - CHARACTER*1. */
+/*           On entry, SIDE specifies whether op( A ) appears on the left */
+/*           or right of X as follows: */
+
+/*              SIDE = 'L' or 'l'   op( A )*X = alpha*B. */
+
+/*              SIDE = 'R' or 'r'   X*op( A ) = alpha*B. */
+
+/*           Unchanged on exit. */
+
+/*  UPLO   - CHARACTER*1. */
+/*           On entry, UPLO specifies whether the matrix A is an upper or */
+/*           lower triangular matrix as follows: */
+
+/*              UPLO = 'U' or 'u'   A is an upper triangular matrix. */
+
+/*              UPLO = 'L' or 'l'   A is a lower triangular matrix. */
+
+/*           Unchanged on exit. */
+
+/*  TRANSA - CHARACTER*1. */
+/*           On entry, TRANSA specifies the form of op( A ) to be used in */
+/*           the matrix multiplication as follows: */
+
+/*              TRANSA = 'N' or 'n'   op( A ) = A. */
+
+/*              TRANSA = 'T' or 't'   op( A ) = A'. */
+
+/*              TRANSA = 'C' or 'c'   op( A ) = conjg( A' ). */
+
+/*           Unchanged on exit. */
+
+/*  DIAG   - CHARACTER*1. */
+/*           On entry, DIAG specifies whether or not A is unit triangular */
+/*           as follows: */
+
+/*              DIAG = 'U' or 'u'   A is assumed to be unit triangular. */
+
+/*              DIAG = 'N' or 'n'   A is not assumed to be unit */
+/*                                  triangular. */
+
+/*           Unchanged on exit. */
+
+/*  M      - INTEGER. */
+/*           On entry, M specifies the number of rows of B. M must be at */
+/*           least zero. */
+/*           Unchanged on exit. */
+
+/*  N      - INTEGER. */
+/*           On entry, N specifies the number of columns of B.  N must be */
+/*           at least zero. */
+/*           Unchanged on exit. */
+
+/*  ALPHA  - COMPLEX*16      . */
+/*           On entry,  ALPHA specifies the scalar  alpha. When  alpha is */
+/*           zero then  A is not referenced and  B need not be set before */
+/*           entry. */
+/*           Unchanged on exit. */
+
+/*  A      - COMPLEX*16       array of DIMENSION ( LDA, k ), where k is m */
+/*           when  SIDE = 'L' or 'l'  and is  n  when  SIDE = 'R' or 'r'. */
+/*           Before entry  with  UPLO = 'U' or 'u',  the  leading  k by k */
+/*           upper triangular part of the array  A must contain the upper */
+/*           triangular matrix  and the strictly lower triangular part of */
+/*           A is not referenced. */
+/*           Before entry  with  UPLO = 'L' or 'l',  the  leading  k by k */
+/*           lower triangular part of the array  A must contain the lower */
+/*           triangular matrix  and the strictly upper triangular part of */
+/*           A is not referenced. */
+/*           Note that when  DIAG = 'U' or 'u',  the diagonal elements of */
+/*           A  are not referenced either,  but are assumed to be  unity. */
+/*           Unchanged on exit. */
+
+/*  LDA    - INTEGER. */
+/*           On entry, LDA specifies the first dimension of A as declared */
+/*           in the calling (sub) program.  When  SIDE = 'L' or 'l'  then */
+/*           LDA  must be at least  max( 1, m ),  when  SIDE = 'R' or 'r' */
+/*           then LDA must be at least max( 1, n ). */
+/*           Unchanged on exit. */
+
+/*  B      - COMPLEX*16       array of DIMENSION ( LDB, n ). */
+/*           Before entry,  the leading  m by n part of the array  B must */
+/*           contain  the  right-hand  side  matrix  B,  and  on exit  is */
+/*           overwritten by the solution matrix  X. */
+
+/*  LDB    - INTEGER. */
+/*           On entry, LDB specifies the first dimension of B as declared */
+/*           in  the  calling  (sub)  program.   LDB  must  be  at  least */
+/*           max( 1, m ). */
+/*           Unchanged on exit. */
+
+
+/*  Level 3 Blas routine. */
+
+/*  -- Written on 8-February-1989. */
+/*     Jack Dongarra, Argonne National Laboratory. */
+/*     Iain Duff, AERE Harwell. */
+/*     Jeremy Du Croz, Numerical Algorithms Group Ltd. */
+/*     Sven Hammarling, Numerical Algorithms Group Ltd. */
+
+
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Parameters .. */
+/*     .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
     b_dim1 = *ldb;
     b_offset = 1 + b_dim1;
     b -= b_offset;
+
     /* Function Body */
     lside = lsame_(side, "L");
     if (lside) {
@@ -125,6 +182,7 @@
     noconj = lsame_(transa, "T");
     nounit = lsame_(diag, "N");
     upper = lsame_(uplo, "U");
+
     info = 0;
     if (! lside && ! lsame_(side, "R")) {
 	info = 1;
@@ -149,11 +207,15 @@
 	xerbla_("ZTRSM ", &info);
 	return 0;
     }
+
 /*     Quick return if possible. */
+
     if (*n == 0) {
 	return 0;
     }
+
 /*     And when  alpha.eq.zero. */
+
     if (alpha->r == 0. && alpha->i == 0.) {
 	i__1 = *n;
 	for (j = 1; j <= i__1; ++j) {
@@ -167,10 +229,14 @@
 	}
 	return 0;
     }
+
 /*     Start the operations. */
+
     if (lside) {
 	if (lsame_(transa, "N")) {
+
 /*           Form  B := alpha*inv( A )*B. */
+
 	    if (upper) {
 		i__1 = *n;
 		for (j = 1; j <= i__1; ++j) {
@@ -260,8 +326,10 @@
 		}
 	    }
 	} else {
-/*           Form  B := alpha*inv( A' )*B   
-             or    B := alpha*inv( conjg( A' ) )*B. */
+
+/*           Form  B := alpha*inv( A' )*B */
+/*           or    B := alpha*inv( conjg( A' ) )*B. */
+
 	    if (upper) {
 		i__1 = *n;
 		for (j = 1; j <= i__1; ++j) {
@@ -369,7 +437,9 @@
 	}
     } else {
 	if (lsame_(transa, "N")) {
+
 /*           Form  B := alpha*B*inv( A ). */
+
 	    if (upper) {
 		i__1 = *n;
 		for (j = 1; j <= i__1; ++j) {
@@ -475,8 +545,10 @@
 		}
 	    }
 	} else {
-/*           Form  B := alpha*B*inv( A' )   
-             or    B := alpha*B*inv( conjg( A' ) ). */
+
+/*           Form  B := alpha*B*inv( A' ) */
+/*           or    B := alpha*B*inv( conjg( A' ) ). */
+
 	    if (upper) {
 		for (k = *n; k >= 1; --k) {
 		    if (nounit) {
@@ -607,8 +679,9 @@
 	    }
 	}
     }
+
     return 0;
+
 /*     End of ZTRSM . */
+
 } /* ztrsm_ */
-
-
