@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cblat1.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -46,7 +34,7 @@ static real c_b43 = 1.f;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer ic;
+    integer ic;
     extern /* Subroutine */ int check1_(real *), check2_(real *), header_(
 	    void);
 
@@ -55,19 +43,26 @@ static real c_b43 = 1.f;
     static cilist io___4 = { 0, 6, 0, fmt_99998, 0 };
 
 
-/*     Test program for the COMPLEX    Level 1 BLAS.   
-       Based upon the original BLAS test routine together with:   
-       F06GAF Example Program Text */
+/*     Test program for the COMPLEX    Level 1 BLAS. */
+/*     Based upon the original BLAS test routine together with: */
+/*     F06GAF Example Program Text */
+/*     .. Parameters .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. External Subroutines .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     s_wsfe(&io___2);
     e_wsfe();
     for (ic = 1; ic <= 10; ++ic) {
 	combla_1.icase = ic;
 	header_();
 
-/*        Initialize PASS, INCX, INCY, and MODE for a new case.   
-          The value 9999 for INCX, INCY or MODE will appear in the   
-          detailed  output, if any, for cases that do not involve   
-          these parameters. */
+/*        Initialize PASS, INCX, INCY, and MODE for a new case. */
+/*        The value 9999 for INCX, INCY or MODE will appear in the */
+/*        detailed  output, if any, for cases that do not involve */
+/*        these parameters. */
 
 	combla_1.pass = TRUE_;
 	combla_1.incx = 9999;
@@ -88,9 +83,9 @@ static real c_b43 = 1.f;
     s_stop("", (ftnlen)0);
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Subroutine */ int header_(void)
+/* Subroutine */ int header_(void)
 {
     /* Initialized data */
 
@@ -108,15 +103,21 @@ static real c_b43 = 1.f;
     static cilist io___6 = { 0, 6, 0, fmt_99999, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Arrays .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     s_wsfe(&io___6);
     do_fio(&c__1, (char *)&combla_1.icase, (ftnlen)sizeof(integer));
     do_fio(&c__1, l + (0 + (0 + (combla_1.icase - 1) * 6)), (ftnlen)6);
     e_wsfe();
     return 0;
 
-} /* header_   
+} /* header_ */
 
-   Subroutine */ int check1_(real *sfac)
+/* Subroutine */ int check1_(real *sfac)
 {
     /* Initialized data */
 
@@ -180,13 +181,13 @@ static real c_b43 = 1.f;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__;
-    static complex cx[8];
-    static integer np1, len;
+    integer i__;
+    complex cx[8];
+    integer np1, len;
     extern /* Subroutine */ int cscal_(integer *, complex *, complex *, 
 	    integer *), ctest_(integer *, complex *, complex *, complex *, 
 	    real *);
-    static complex mwpcs[5], mwpct[5];
+    complex mwpcs[5], mwpct[5];
     extern doublereal scnrm2_(integer *, complex *, integer *);
     extern /* Subroutine */ int itest1_(integer *, integer *), stest1_(real *,
 	     real *, real *, real *);
@@ -199,10 +200,22 @@ static real c_b43 = 1.f;
     static cilist io___19 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Functions .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     for (combla_1.incx = 1; combla_1.incx <= 2; ++combla_1.incx) {
 	for (np1 = 1; np1 <= 5; ++np1) {
 	    combla_1.n = np1 - 1;
 	    len = max(combla_1.n,1) << 1;
+/*           .. Set vector arguments .. */
 	    i__1 = len;
 	    for (i__ = 1; i__ <= i__1; ++i__) {
 		i__2 = i__ - 1;
@@ -211,20 +224,25 @@ static real c_b43 = 1.f;
 /* L20: */
 	    }
 	    if (combla_1.icase == 6) {
+/*              .. SCNRM2 .. */
 		r__1 = scnrm2_(&combla_1.n, cx, &combla_1.incx);
 		stest1_(&r__1, &strue2[np1 - 1], &strue2[np1 - 1], sfac);
 	    } else if (combla_1.icase == 7) {
+/*              .. SCASUM .. */
 		r__1 = scasum_(&combla_1.n, cx, &combla_1.incx);
 		stest1_(&r__1, &strue4[np1 - 1], &strue4[np1 - 1], sfac);
 	    } else if (combla_1.icase == 8) {
+/*              .. CSCAL .. */
 		cscal_(&combla_1.n, &ca, cx, &combla_1.incx);
 		ctest_(&len, cx, &ctrue5[(np1 + combla_1.incx * 5 << 3) - 48],
 			 &ctrue5[(np1 + combla_1.incx * 5 << 3) - 48], sfac);
 	    } else if (combla_1.icase == 9) {
+/*              .. CSSCAL .. */
 		csscal_(&combla_1.n, &sa, cx, &combla_1.incx);
 		ctest_(&len, cx, &ctrue6[(np1 + combla_1.incx * 5 << 3) - 48],
 			 &ctrue6[(np1 + combla_1.incx * 5 << 3) - 48], sfac);
 	    } else if (combla_1.icase == 10) {
+/*              .. ICAMAX .. */
 		i__1 = icamax_(&combla_1.n, cx, &combla_1.incx);
 		itest1_(&i__1, &itrue3[np1 - 1]);
 	    } else {
@@ -242,8 +260,8 @@ static real c_b43 = 1.f;
 
     combla_1.incx = 1;
     if (combla_1.icase == 8) {
-/*        CSCAL   
-          Add a test for alpha equal to zero. */
+/*        CSCAL */
+/*        Add a test for alpha equal to zero. */
 	ca.r = 0.f, ca.i = 0.f;
 	for (i__ = 1; i__ <= 5; ++i__) {
 	    i__1 = i__ - 1;
@@ -255,8 +273,8 @@ static real c_b43 = 1.f;
 	cscal_(&c__5, &ca, cx, &combla_1.incx);
 	ctest_(&c__5, cx, mwpct, mwpcs, sfac);
     } else if (combla_1.icase == 9) {
-/*        CSSCAL   
-          Add a test for alpha equal to zero. */
+/*        CSSCAL */
+/*        Add a test for alpha equal to zero. */
 	sa = 0.f;
 	for (i__ = 1; i__ <= 5; ++i__) {
 	    i__1 = i__ - 1;
@@ -297,9 +315,9 @@ static real c_b43 = 1.f;
 	ctest_(&c__5, cx, mwpct, mwpcs, sfac);
     }
     return 0;
-} /* check1_   
+} /* check1_ */
 
-   Subroutine */ int check2_(real *sfac)
+/* Subroutine */ int check2_(real *sfac)
 {
     /* Initialized data */
 
@@ -398,11 +416,11 @@ static real c_b43 = 1.f;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__, ki, kn;
-    static complex cx[7], cy[7];
-    static integer mx, my;
-    static complex cdot[1];
-    static integer lenx, leny;
+    integer i__, ki, kn;
+    complex cx[7], cy[7];
+    integer mx, my;
+    complex cdot[1];
+    integer lenx, leny;
     extern /* Complex */ VOID cdotc_(complex *, integer *, complex *, integer 
 	    *, complex *, integer *);
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
@@ -412,7 +430,7 @@ static real c_b43 = 1.f;
     extern /* Subroutine */ int cswap_(integer *, complex *, integer *, 
 	    complex *, integer *), ctest_(integer *, complex *, complex *, 
 	    complex *, real *);
-    static integer ksize;
+    integer ksize;
     extern /* Subroutine */ int caxpy_(integer *, complex *, complex *, 
 	    integer *, complex *, integer *);
 
@@ -420,6 +438,17 @@ static real c_b43 = 1.f;
     static cilist io___48 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Functions .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     for (ki = 1; ki <= 4; ++ki) {
 	combla_1.incx = incxs[ki - 1];
 	combla_1.incy = incys[ki - 1];
@@ -431,6 +460,7 @@ static real c_b43 = 1.f;
 	    ksize = min(2,kn);
 	    lenx = lens[kn + (mx << 2) - 5];
 	    leny = lens[kn + (my << 2) - 5];
+/*           .. initialize all argument arrays .. */
 	    for (i__ = 1; i__ <= 7; ++i__) {
 		i__1 = i__ - 1;
 		i__2 = i__ - 1;
@@ -441,27 +471,32 @@ static real c_b43 = 1.f;
 /* L20: */
 	    }
 	    if (combla_1.icase == 1) {
+/*              .. CDOTC .. */
 		cdotc_(&q__1, &combla_1.n, cx, &combla_1.incx, cy, &
 			combla_1.incy);
 		cdot[0].r = q__1.r, cdot[0].i = q__1.i;
 		ctest_(&c__1, cdot, &ct6[kn + (ki << 2) - 5], &csize1[kn - 1],
 			 sfac);
 	    } else if (combla_1.icase == 2) {
+/*              .. CDOTU .. */
 		cdotu_(&q__1, &combla_1.n, cx, &combla_1.incx, cy, &
 			combla_1.incy);
 		cdot[0].r = q__1.r, cdot[0].i = q__1.i;
 		ctest_(&c__1, cdot, &ct7[kn + (ki << 2) - 5], &csize1[kn - 1],
 			 sfac);
 	    } else if (combla_1.icase == 3) {
+/*              .. CAXPY .. */
 		caxpy_(&combla_1.n, &ca, cx, &combla_1.incx, cy, &
 			combla_1.incy);
 		ctest_(&leny, cy, &ct8[(kn + (ki << 2)) * 7 - 35], &csize2[
 			ksize * 7 - 7], sfac);
 	    } else if (combla_1.icase == 4) {
+/*              .. CCOPY .. */
 		ccopy_(&combla_1.n, cx, &combla_1.incx, cy, &combla_1.incy);
 		ctest_(&leny, cy, &ct10y[(kn + (ki << 2)) * 7 - 35], csize3, &
 			c_b43);
 	    } else if (combla_1.icase == 5) {
+/*              .. CSWAP .. */
 		cswap_(&combla_1.n, cx, &combla_1.incx, cy, &combla_1.incy);
 		ctest_(&lenx, cx, &ct10x[(kn + (ki << 2)) * 7 - 35], csize3, &
 			c_b43);
@@ -480,9 +515,9 @@ static real c_b43 = 1.f;
 /* L60: */
     }
     return 0;
-} /* check2_   
+} /* check2_ */
 
-   Subroutine */ int stest_(integer *len, real *scomp, real *strue, real *
+/* Subroutine */ int stest_(integer *len, real *scomp, real *strue, real *
 	ssize, real *sfac)
 {
     /* Format strings */
@@ -501,8 +536,8 @@ static real c_b43 = 1.f;
     integer s_wsfe(cilist *), e_wsfe(void), do_fio(integer *, char *, ftnlen);
 
     /* Local variables */
-    static integer i__;
-    static real sd;
+    integer i__;
+    real sd;
     extern doublereal sdiff_(real *, real *);
 
     /* Fortran I/O blocks */
@@ -511,16 +546,25 @@ static real c_b43 = 1.f;
     static cilist io___53 = { 0, 6, 0, fmt_99997, 0 };
 
 
-/*     ********************************* STEST **************************   
+/*     ********************************* STEST ************************** */
 
-       THIS SUBR COMPARES ARRAYS  SCOMP() AND STRUE() OF LENGTH LEN TO   
-       SEE IF THE TERM BY TERM DIFFERENCES, MULTIPLIED BY SFAC, ARE   
-       NEGLIGIBLE.   
+/*     THIS SUBR COMPARES ARRAYS  SCOMP() AND STRUE() OF LENGTH LEN TO */
+/*     SEE IF THE TERM BY TERM DIFFERENCES, MULTIPLIED BY SFAC, ARE */
+/*     NEGLIGIBLE. */
 
-       C. L. LAWSON, JPL, 1974 DEC 10   
+/*     C. L. LAWSON, JPL, 1974 DEC 10 */
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. External Functions .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ssize;
     --strue;
     --scomp;
@@ -565,25 +609,30 @@ L40:
     }
     return 0;
 
-} /* stest_   
+} /* stest_ */
 
-   Subroutine */ int stest1_(real *scomp1, real *strue1, real *ssize, real *
+/* Subroutine */ int stest1_(real *scomp1, real *strue1, real *ssize, real *
 	sfac)
 {
-    static real scomp[1], strue[1];
+    real scomp[1], strue[1];
     extern /* Subroutine */ int stest_(integer *, real *, real *, real *, 
 	    real *);
 
-/*     ************************* STEST1 *****************************   
+/*     ************************* STEST1 ***************************** */
 
-       THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN   
-       REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE   
-       ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT.   
+/*     THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN */
+/*     REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE */
+/*     ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT. */
 
-       C.L. LAWSON, JPL, 1978 DEC 6   
+/*     C.L. LAWSON, JPL, 1978 DEC 6 */
 
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ssize;
 
     /* Function Body */
@@ -599,14 +648,16 @@ doublereal sdiff_(real *sa, real *sb)
     /* System generated locals */
     real ret_val;
 
-/*     ********************************* SDIFF **************************   
-       COMPUTES DIFFERENCE OF TWO NUMBERS.  C. L. LAWSON, JPL 1974 FEB 15 */
+/*     ********************************* SDIFF ************************** */
+/*     COMPUTES DIFFERENCE OF TWO NUMBERS.  C. L. LAWSON, JPL 1974 FEB 15 */
 
+/*     .. Scalar Arguments .. */
+/*     .. Executable Statements .. */
     ret_val = *sa - *sb;
     return ret_val;
-} /* sdiff_   
+} /* sdiff_ */
 
-   Subroutine */ int ctest_(integer *len, complex *ccomp, complex *ctrue, 
+/* Subroutine */ int ctest_(integer *len, complex *ccomp, complex *ctrue, 
 	complex *csize, real *sfac)
 {
     /* System generated locals */
@@ -616,16 +667,23 @@ doublereal sdiff_(real *sa, real *sb)
     double r_imag(complex *);
 
     /* Local variables */
-    static integer i__;
-    static real scomp[20], ssize[20], strue[20];
+    integer i__;
+    real scomp[20], ssize[20], strue[20];
     extern /* Subroutine */ int stest_(integer *, real *, real *, real *, 
 	    real *);
 
-/*     **************************** CTEST *****************************   
+/*     **************************** CTEST ***************************** */
 
-       C.L. LAWSON, JPL, 1978 DEC 6   
+/*     C.L. LAWSON, JPL, 1978 DEC 6 */
 
-       Parameter adjustments */
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Executable Statements .. */
+    /* Parameter adjustments */
     --csize;
     --ctrue;
     --ccomp;
@@ -648,9 +706,9 @@ doublereal sdiff_(real *sa, real *sb)
     i__1 = *len << 1;
     stest_(&i__1, scomp, strue, ssize, sfac);
     return 0;
-} /* ctest_   
+} /* ctest_ */
 
-   Subroutine */ int itest1_(integer *icomp, integer *itrue)
+/* Subroutine */ int itest1_(integer *icomp, integer *itrue)
 {
     /* Format strings */
     static char fmt_99999[] = "(\002                                       F"
@@ -664,7 +722,7 @@ doublereal sdiff_(real *sa, real *sb)
     integer s_wsfe(cilist *), e_wsfe(void), do_fio(integer *, char *, ftnlen);
 
     /* Local variables */
-    static integer id;
+    integer id;
 
     /* Fortran I/O blocks */
     static cilist io___60 = { 0, 6, 0, fmt_99999, 0 };
@@ -672,12 +730,18 @@ doublereal sdiff_(real *sa, real *sb)
     static cilist io___63 = { 0, 6, 0, fmt_99997, 0 };
 
 
-/*     ********************************* ITEST1 *************************   
+/*     ********************************* ITEST1 ************************* */
 
-       THIS SUBROUTINE COMPARES THE VARIABLES ICOMP AND ITRUE FOR   
-       EQUALITY.   
-       C. L. LAWSON, JPL, 1974 DEC 10 */
+/*     THIS SUBROUTINE COMPARES THE VARIABLES ICOMP AND ITRUE FOR */
+/*     EQUALITY. */
+/*     C. L. LAWSON, JPL, 1974 DEC 10 */
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Common blocks .. */
+/*     .. Executable Statements .. */
     if (*icomp == *itrue) {
 	goto L40;
     }
@@ -708,6 +772,6 @@ L20:
 L40:
     return 0;
 
-} /* itest1_   
+} /* itest1_ */
 
-   Main program alias */ int cblat1_ () { MAIN__ (); return 0; }
+/* Main program alias */ int cblat1_ () { MAIN__ (); return 0; }
