@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dblat1.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -45,7 +33,7 @@ static integer c__5 = 5;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer ic;
+    integer ic;
     extern /* Subroutine */ int check0_(doublereal *), check1_(doublereal *), 
 	    check2_(doublereal *), check3_(doublereal *), header_(void);
 
@@ -54,15 +42,26 @@ static integer c__5 = 5;
     static cilist io___4 = { 0, 6, 0, fmt_99998, 0 };
 
 
-/*     Test program for the DOUBLE PRECISION Level 1 BLAS.   
-       Based upon the original BLAS test routine together with:   
-       F06EAF Example Program Text */
+/*     Test program for the DOUBLE PRECISION Level 1 BLAS. */
+/*     Based upon the original BLAS test routine together with: */
+/*     F06EAF Example Program Text */
+/*     .. Parameters .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. External Subroutines .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     s_wsfe(&io___2);
     e_wsfe();
     for (ic = 1; ic <= 10; ++ic) {
 	combla_1.icase = ic;
 	header_();
 
+/*        .. Initialize  PASS,  INCX,  INCY, and MODE for a new case. .. */
+/*        .. the value 9999 for INCX, INCY or MODE will appear in the .. */
+/*        .. detailed  output, if any, for cases  that do not involve .. */
+/*        .. these parameters .. */
 
 	combla_1.pass = TRUE_;
 	combla_1.incx = 9999;
@@ -89,9 +88,9 @@ static integer c__5 = 5;
     s_stop("", (ftnlen)0);
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Subroutine */ int header_(void)
+/* Subroutine */ int header_(void)
 {
     /* Initialized data */
 
@@ -109,15 +108,21 @@ static integer c__5 = 5;
     static cilist io___6 = { 0, 6, 0, fmt_99999, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Arrays .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     s_wsfe(&io___6);
     do_fio(&c__1, (char *)&combla_1.icase, (ftnlen)sizeof(integer));
     do_fio(&c__1, l + (0 + (0 + (combla_1.icase - 1) * 6)), (ftnlen)6);
     e_wsfe();
     return 0;
 
-} /* header_   
+} /* header_ */
 
-   Subroutine */ int check0_(doublereal *sfac)
+/* Subroutine */ int check0_(doublereal *sfac)
 {
     /* Initialized data */
 
@@ -134,8 +139,8 @@ static integer c__5 = 5;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer k;
-    static doublereal sa, sb, sc, ss;
+    integer k;
+    doublereal sa, sb, sc, ss;
     extern /* Subroutine */ int drotg_(doublereal *, doublereal *, doublereal 
 	    *, doublereal *), stest1_(doublereal *, doublereal *, doublereal *
 	    , doublereal *);
@@ -144,17 +149,28 @@ static integer c__5 = 5;
     static cilist io___19 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
 
-/*     Compute true values which cannot be prestored   
-       in decimal notation */
+/*     Compute true values which cannot be prestored */
+/*     in decimal notation */
 
     dbtrue[0] = 1.6666666666666667;
     dbtrue[2] = -1.6666666666666667;
     dbtrue[4] = 1.6666666666666667;
 
     for (k = 1; k <= 8; ++k) {
+/*        .. Set N=K for identification in output if any .. */
 	combla_1.n = k;
 	if (combla_1.icase == 3) {
+/*           .. DROTG .. */
 	    if (k > 8) {
 		goto L40;
 	    }
@@ -175,9 +191,9 @@ static integer c__5 = 5;
     }
 L40:
     return 0;
-} /* check0_   
+} /* check0_ */
 
-   Subroutine */ int check1_(doublereal *sfac)
+/* Subroutine */ int check1_(doublereal *sfac)
 {
     /* Initialized data */
 
@@ -206,14 +222,14 @@ L40:
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__;
-    static doublereal sx[8];
-    static integer np1, len;
+    integer i__;
+    doublereal sx[8];
+    integer np1, len;
     extern doublereal dnrm2_(integer *, doublereal *, integer *);
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
     extern doublereal dasum_(integer *, doublereal *, integer *);
-    static doublereal stemp[1], strue[8];
+    doublereal stemp[1], strue[8];
     extern /* Subroutine */ int stest_(integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *), itest1_(integer *, integer *), 
 	    stest1_(doublereal *, doublereal *, doublereal *, doublereal *);
@@ -223,10 +239,22 @@ L40:
     static cilist io___32 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Functions .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     for (combla_1.incx = 1; combla_1.incx <= 2; ++combla_1.incx) {
 	for (np1 = 1; np1 <= 5; ++np1) {
 	    combla_1.n = np1 - 1;
 	    len = max(combla_1.n,1) << 1;
+/*           .. Set vector arguments .. */
 	    i__1 = len;
 	    for (i__ = 1; i__ <= i__1; ++i__) {
 		sx[i__ - 1] = dv[i__ + (np1 + combla_1.incx * 5 << 3) - 49];
@@ -234,14 +262,17 @@ L40:
 	    }
 
 	    if (combla_1.icase == 7) {
+/*              .. DNRM2 .. */
 		stemp[0] = dtrue1[np1 - 1];
 		d__1 = dnrm2_(&combla_1.n, sx, &combla_1.incx);
 		stest1_(&d__1, stemp, stemp, sfac);
 	    } else if (combla_1.icase == 8) {
+/*              .. DASUM .. */
 		stemp[0] = dtrue3[np1 - 1];
 		d__1 = dasum_(&combla_1.n, sx, &combla_1.incx);
 		stest1_(&d__1, stemp, stemp, sfac);
 	    } else if (combla_1.icase == 9) {
+/*              .. DSCAL .. */
 		dscal_(&combla_1.n, &sa[(combla_1.incx - 1) * 5 + np1 - 1], 
 			sx, &combla_1.incx);
 		i__1 = len;
@@ -252,6 +283,7 @@ L40:
 		}
 		stest_(&len, sx, strue, strue, sfac);
 	    } else if (combla_1.icase == 10) {
+/*              .. IDAMAX .. */
 		i__1 = idamax_(&combla_1.n, sx, &combla_1.incx);
 		itest1_(&i__1, &itrue2[np1 - 1]);
 	    } else {
@@ -266,9 +298,9 @@ L40:
 /* L80: */
     }
     return 0;
-} /* check1_   
+} /* check1_ */
 
-   Subroutine */ int check2_(doublereal *sfac)
+/* Subroutine */ int check2_(doublereal *sfac)
 {
     /* Initialized data */
 
@@ -317,15 +349,15 @@ L40:
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__, j, ki, kn, mx, my;
-    static doublereal sx[7], sy[7], stx[7], sty[7];
+    integer i__, j, ki, kn, mx, my;
+    doublereal sx[7], sy[7], stx[7], sty[7];
     extern doublereal ddot_(integer *, doublereal *, integer *, doublereal *, 
 	    integer *);
-    static integer lenx, leny;
+    integer lenx, leny;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *), dswap_(integer *, doublereal *, integer 
 	    *, doublereal *, integer *);
-    static integer ksize;
+    integer ksize;
     extern /* Subroutine */ int daxpy_(integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *), stest_(integer *, doublereal 
 	    *, doublereal *, doublereal *, doublereal *), stest1_(doublereal *
@@ -335,6 +367,17 @@ L40:
     static cilist io___63 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Functions .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
 
     for (ki = 1; ki <= 4; ++ki) {
 	combla_1.incx = incxs[ki - 1];
@@ -347,6 +390,7 @@ L40:
 	    ksize = min(2,kn);
 	    lenx = lens[kn + (mx << 2) - 5];
 	    leny = lens[kn + (my << 2) - 5];
+/*           .. Initialize all argument arrays .. */
 	    for (i__ = 1; i__ <= 7; ++i__) {
 		sx[i__ - 1] = dx1[i__ - 1];
 		sy[i__ - 1] = dy1[i__ - 1];
@@ -354,11 +398,13 @@ L40:
 	    }
 
 	    if (combla_1.icase == 1) {
+/*              .. DDOT .. */
 		d__1 = ddot_(&combla_1.n, sx, &combla_1.incx, sy, &
 			combla_1.incy);
 		stest1_(&d__1, &dt7[kn + (ki << 2) - 5], &ssize1[kn - 1], 
 			sfac);
 	    } else if (combla_1.icase == 2) {
+/*              .. DAXPY .. */
 		daxpy_(&combla_1.n, &sa, sx, &combla_1.incx, sy, &
 			combla_1.incy);
 		i__1 = leny;
@@ -368,6 +414,7 @@ L40:
 		}
 		stest_(&leny, sy, sty, &ssize2[ksize * 14 - 14], sfac);
 	    } else if (combla_1.icase == 5) {
+/*              .. DCOPY .. */
 		for (i__ = 1; i__ <= 7; ++i__) {
 		    sty[i__ - 1] = dt10y[i__ + (kn + (ki << 2)) * 7 - 36];
 /* L60: */
@@ -375,6 +422,7 @@ L40:
 		dcopy_(&combla_1.n, sx, &combla_1.incx, sy, &combla_1.incy);
 		stest_(&leny, sy, sty, ssize2, &c_b34);
 	    } else if (combla_1.icase == 6) {
+/*              .. DSWAP .. */
 		dswap_(&combla_1.n, sx, &combla_1.incx, sy, &combla_1.incy);
 		for (i__ = 1; i__ <= 7; ++i__) {
 		    stx[i__ - 1] = dt10x[i__ + (kn + (ki << 2)) * 7 - 36];
@@ -395,9 +443,9 @@ L40:
 /* L120: */
     }
     return 0;
-} /* check2_   
+} /* check2_ */
 
-   Subroutine */ int check3_(doublereal *sfac)
+/* Subroutine */ int check3_(doublereal *sfac)
 {
     /* Initialized data */
 
@@ -433,27 +481,37 @@ L40:
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__, k, ki, kn, mx, my;
-    static doublereal sx[7], sy[7], stx[7], sty[7];
-    static integer lenx, leny;
-    static doublereal mwpc[11];
+    integer i__, k, ki, kn, mx, my;
+    doublereal sx[7], sy[7], stx[7], sty[7];
+    integer lenx, leny;
+    doublereal mwpc[11];
     extern /* Subroutine */ int drot_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *);
-    static integer mwpn[11];
-    static doublereal mwps[11], mwpx[5], mwpy[5];
-    static integer ksize;
-    static doublereal copyx[5], copyy[5];
+    integer mwpn[11];
+    doublereal mwps[11], mwpx[5], mwpy[5];
+    integer ksize;
+    doublereal copyx[5], copyy[5];
     extern /* Subroutine */ int stest_(integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *);
-    static doublereal mwptx[55]	/* was [11][5] */, mwpty[55]	/* was [11][5]
+    doublereal mwptx[55]	/* was [11][5] */, mwpty[55]	/* was [11][5]
 	     */;
-    static integer mwpinx[11], mwpiny[11];
-    static doublereal mwpstx[5], mwpsty[5];
+    integer mwpinx[11], mwpiny[11];
+    doublereal mwpstx[5], mwpsty[5];
 
     /* Fortran I/O blocks */
     static cilist io___88 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
 
     for (ki = 1; ki <= 4; ++ki) {
 	combla_1.incx = incxs[ki - 1];
@@ -468,6 +526,7 @@ L40:
 	    leny = lens[kn + (my << 2) - 5];
 
 	    if (combla_1.icase == 4) {
+/*              .. DROT .. */
 		for (i__ = 1; i__ <= 7; ++i__) {
 		    sx[i__ - 1] = dx1[i__ - 1];
 		    sy[i__ - 1] = dy1[i__ - 1];
@@ -593,9 +652,9 @@ L40:
 /* L200: */
     }
     return 0;
-} /* check3_   
+} /* check3_ */
 
-   Subroutine */ int stest_(integer *len, doublereal *scomp, doublereal *
+/* Subroutine */ int stest_(integer *len, doublereal *scomp, doublereal *
 	strue, doublereal *ssize, doublereal *sfac)
 {
     /* Format strings */
@@ -614,8 +673,8 @@ L40:
     integer s_wsfe(cilist *), e_wsfe(void), do_fio(integer *, char *, ftnlen);
 
     /* Local variables */
-    static integer i__;
-    static doublereal sd;
+    integer i__;
+    doublereal sd;
     extern doublereal sdiff_(doublereal *, doublereal *);
 
     /* Fortran I/O blocks */
@@ -624,16 +683,25 @@ L40:
     static cilist io___107 = { 0, 6, 0, fmt_99997, 0 };
 
 
-/*     ********************************* STEST **************************   
+/*     ********************************* STEST ************************** */
 
-       THIS SUBR COMPARES ARRAYS  SCOMP() AND STRUE() OF LENGTH LEN TO   
-       SEE IF THE TERM BY TERM DIFFERENCES, MULTIPLIED BY SFAC, ARE   
-       NEGLIGIBLE.   
+/*     THIS SUBR COMPARES ARRAYS  SCOMP() AND STRUE() OF LENGTH LEN TO */
+/*     SEE IF THE TERM BY TERM DIFFERENCES, MULTIPLIED BY SFAC, ARE */
+/*     NEGLIGIBLE. */
 
-       C. L. LAWSON, JPL, 1974 DEC 10   
+/*     C. L. LAWSON, JPL, 1974 DEC 10 */
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. External Functions .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ssize;
     --strue;
     --scomp;
@@ -678,25 +746,30 @@ L40:
     }
     return 0;
 
-} /* stest_   
+} /* stest_ */
 
-   Subroutine */ int stest1_(doublereal *scomp1, doublereal *strue1, 
+/* Subroutine */ int stest1_(doublereal *scomp1, doublereal *strue1, 
 	doublereal *ssize, doublereal *sfac)
 {
-    static doublereal scomp[1], strue[1];
+    doublereal scomp[1], strue[1];
     extern /* Subroutine */ int stest_(integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *);
 
-/*     ************************* STEST1 *****************************   
+/*     ************************* STEST1 ***************************** */
 
-       THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN   
-       REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE   
-       ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT.   
+/*     THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN */
+/*     REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE */
+/*     ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT. */
 
-       C.L. LAWSON, JPL, 1978 DEC 6   
+/*     C.L. LAWSON, JPL, 1978 DEC 6 */
 
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ssize;
 
     /* Function Body */
@@ -712,14 +785,16 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     /* System generated locals */
     doublereal ret_val;
 
-/*     ********************************* SDIFF **************************   
-       COMPUTES DIFFERENCE OF TWO NUMBERS.  C. L. LAWSON, JPL 1974 FEB 15 */
+/*     ********************************* SDIFF ************************** */
+/*     COMPUTES DIFFERENCE OF TWO NUMBERS.  C. L. LAWSON, JPL 1974 FEB 15 */
 
+/*     .. Scalar Arguments .. */
+/*     .. Executable Statements .. */
     ret_val = *sa - *sb;
     return ret_val;
-} /* sdiff_   
+} /* sdiff_ */
 
-   Subroutine */ int itest1_(integer *icomp, integer *itrue)
+/* Subroutine */ int itest1_(integer *icomp, integer *itrue)
 {
     /* Format strings */
     static char fmt_99999[] = "(\002                                       F"
@@ -733,7 +808,7 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     integer s_wsfe(cilist *), e_wsfe(void), do_fio(integer *, char *, ftnlen);
 
     /* Local variables */
-    static integer id;
+    integer id;
 
     /* Fortran I/O blocks */
     static cilist io___110 = { 0, 6, 0, fmt_99999, 0 };
@@ -741,12 +816,18 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     static cilist io___113 = { 0, 6, 0, fmt_99997, 0 };
 
 
-/*     ********************************* ITEST1 *************************   
+/*     ********************************* ITEST1 ************************* */
 
-       THIS SUBROUTINE COMPARES THE VARIABLES ICOMP AND ITRUE FOR   
-       EQUALITY.   
-       C. L. LAWSON, JPL, 1974 DEC 10 */
+/*     THIS SUBROUTINE COMPARES THE VARIABLES ICOMP AND ITRUE FOR */
+/*     EQUALITY. */
+/*     C. L. LAWSON, JPL, 1974 DEC 10 */
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Common blocks .. */
+/*     .. Executable Statements .. */
 
     if (*icomp == *itrue) {
 	goto L40;
@@ -778,6 +859,6 @@ L20:
 L40:
     return 0;
 
-} /* itest1_   
+} /* itest1_ */
 
-   Main program alias */ int dblat1_ () { MAIN__ (); return 0; }
+/* Main program alias */ int dblat1_ () { MAIN__ (); return 0; }
