@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zblat1.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -46,7 +34,7 @@ static doublereal c_b43 = 1.;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer ic;
+    integer ic;
     extern /* Subroutine */ int check1_(doublereal *), check2_(doublereal *), 
 	    header_(void);
 
@@ -55,19 +43,26 @@ static doublereal c_b43 = 1.;
     static cilist io___4 = { 0, 6, 0, fmt_99998, 0 };
 
 
-/*     Test program for the COMPLEX*16 Level 1 BLAS.   
-       Based upon the original BLAS test routine together with:   
-       F06GAF Example Program Text */
+/*     Test program for the COMPLEX*16 Level 1 BLAS. */
+/*     Based upon the original BLAS test routine together with: */
+/*     F06GAF Example Program Text */
+/*     .. Parameters .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. External Subroutines .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     s_wsfe(&io___2);
     e_wsfe();
     for (ic = 1; ic <= 10; ++ic) {
 	combla_1.icase = ic;
 	header_();
 
-/*        Initialize PASS, INCX, INCY, and MODE for a new case.   
-          The value 9999 for INCX, INCY or MODE will appear in the   
-          detailed  output, if any, for cases that do not involve   
-          these parameters. */
+/*        Initialize PASS, INCX, INCY, and MODE for a new case. */
+/*        The value 9999 for INCX, INCY or MODE will appear in the */
+/*        detailed  output, if any, for cases that do not involve */
+/*        these parameters. */
 
 	combla_1.pass = TRUE_;
 	combla_1.incx = 9999;
@@ -88,9 +83,9 @@ static doublereal c_b43 = 1.;
     s_stop("", (ftnlen)0);
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Subroutine */ int header_(void)
+/* Subroutine */ int header_(void)
 {
     /* Initialized data */
 
@@ -108,15 +103,21 @@ static doublereal c_b43 = 1.;
     static cilist io___6 = { 0, 6, 0, fmt_99999, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Arrays .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     s_wsfe(&io___6);
     do_fio(&c__1, (char *)&combla_1.icase, (ftnlen)sizeof(integer));
     do_fio(&c__1, l + (0 + (0 + (combla_1.icase - 1) * 6)), (ftnlen)6);
     e_wsfe();
     return 0;
 
-} /* header_   
+} /* header_ */
 
-   Subroutine */ int check1_(doublereal *sfac)
+/* Subroutine */ int check1_(doublereal *sfac)
 {
     /* Initialized data */
 
@@ -172,13 +173,13 @@ static doublereal c_b43 = 1.;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__;
-    static doublecomplex cx[8];
-    static integer np1, len;
+    integer i__;
+    doublecomplex cx[8];
+    integer np1, len;
     extern /* Subroutine */ int zscal_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *), ctest_(integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublereal *);
-    static doublecomplex mwpcs[5], mwpct[5];
+    doublecomplex mwpcs[5], mwpct[5];
     extern /* Subroutine */ int itest1_(integer *, integer *);
     extern doublereal dznrm2_(integer *, doublecomplex *, integer *);
     extern /* Subroutine */ int stest1_(doublereal *, doublereal *, 
@@ -191,10 +192,22 @@ static doublereal c_b43 = 1.;
     static cilist io___19 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Functions .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     for (combla_1.incx = 1; combla_1.incx <= 2; ++combla_1.incx) {
 	for (np1 = 1; np1 <= 5; ++np1) {
 	    combla_1.n = np1 - 1;
 	    len = max(combla_1.n,1) << 1;
+/*           .. Set vector arguments .. */
 	    i__1 = len;
 	    for (i__ = 1; i__ <= i__1; ++i__) {
 		i__2 = i__ - 1;
@@ -203,20 +216,25 @@ static doublereal c_b43 = 1.;
 /* L20: */
 	    }
 	    if (combla_1.icase == 6) {
+/*              .. DZNRM2 .. */
 		d__1 = dznrm2_(&combla_1.n, cx, &combla_1.incx);
 		stest1_(&d__1, &strue2[np1 - 1], &strue2[np1 - 1], sfac);
 	    } else if (combla_1.icase == 7) {
+/*              .. DZASUM .. */
 		d__1 = dzasum_(&combla_1.n, cx, &combla_1.incx);
 		stest1_(&d__1, &strue4[np1 - 1], &strue4[np1 - 1], sfac);
 	    } else if (combla_1.icase == 8) {
+/*              .. ZSCAL .. */
 		zscal_(&combla_1.n, &ca, cx, &combla_1.incx);
 		ctest_(&len, cx, &ctrue5[(np1 + combla_1.incx * 5 << 3) - 48],
 			 &ctrue5[(np1 + combla_1.incx * 5 << 3) - 48], sfac);
 	    } else if (combla_1.icase == 9) {
+/*              .. ZDSCAL .. */
 		zdscal_(&combla_1.n, &sa, cx, &combla_1.incx);
 		ctest_(&len, cx, &ctrue6[(np1 + combla_1.incx * 5 << 3) - 48],
 			 &ctrue6[(np1 + combla_1.incx * 5 << 3) - 48], sfac);
 	    } else if (combla_1.icase == 10) {
+/*              .. IZAMAX .. */
 		i__1 = izamax_(&combla_1.n, cx, &combla_1.incx);
 		itest1_(&i__1, &itrue3[np1 - 1]);
 	    } else {
@@ -234,8 +252,8 @@ static doublereal c_b43 = 1.;
 
     combla_1.incx = 1;
     if (combla_1.icase == 8) {
-/*        ZSCAL   
-          Add a test for alpha equal to zero. */
+/*        ZSCAL */
+/*        Add a test for alpha equal to zero. */
 	ca.r = 0., ca.i = 0.;
 	for (i__ = 1; i__ <= 5; ++i__) {
 	    i__1 = i__ - 1;
@@ -247,8 +265,8 @@ static doublereal c_b43 = 1.;
 	zscal_(&c__5, &ca, cx, &combla_1.incx);
 	ctest_(&c__5, cx, mwpct, mwpcs, sfac);
     } else if (combla_1.icase == 9) {
-/*        ZDSCAL   
-          Add a test for alpha equal to zero. */
+/*        ZDSCAL */
+/*        Add a test for alpha equal to zero. */
 	sa = 0.;
 	for (i__ = 1; i__ <= 5; ++i__) {
 	    i__1 = i__ - 1;
@@ -289,9 +307,9 @@ static doublereal c_b43 = 1.;
 	ctest_(&c__5, cx, mwpct, mwpcs, sfac);
     }
     return 0;
-} /* check1_   
+} /* check1_ */
 
-   Subroutine */ int check2_(doublereal *sfac)
+/* Subroutine */ int check2_(doublereal *sfac)
 {
     /* Initialized data */
 
@@ -380,16 +398,16 @@ static doublereal c_b43 = 1.;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static integer i__, ki, kn;
-    static doublecomplex cx[7], cy[7];
-    static integer mx, my;
-    static doublecomplex cdot[1];
-    static integer lenx, leny;
+    integer i__, ki, kn;
+    doublecomplex cx[7], cy[7];
+    integer mx, my;
+    doublecomplex cdot[1];
+    integer lenx, leny;
     extern /* Subroutine */ int ctest_(integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublereal *);
     extern /* Double Complex */ VOID zdotc_(doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
-    static integer ksize;
+    integer ksize;
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
     extern /* Double Complex */ VOID zdotu_(doublecomplex *, integer *, 
@@ -402,6 +420,17 @@ static doublereal c_b43 = 1.;
     static cilist io___48 = { 0, 6, 0, 0, 0 };
 
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Functions .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Data statements .. */
+/*     .. Executable Statements .. */
     for (ki = 1; ki <= 4; ++ki) {
 	combla_1.incx = incxs[ki - 1];
 	combla_1.incy = incys[ki - 1];
@@ -413,6 +442,7 @@ static doublereal c_b43 = 1.;
 	    ksize = min(2,kn);
 	    lenx = lens[kn + (mx << 2) - 5];
 	    leny = lens[kn + (my << 2) - 5];
+/*           .. initialize all argument arrays .. */
 	    for (i__ = 1; i__ <= 7; ++i__) {
 		i__1 = i__ - 1;
 		i__2 = i__ - 1;
@@ -423,27 +453,32 @@ static doublereal c_b43 = 1.;
 /* L20: */
 	    }
 	    if (combla_1.icase == 1) {
+/*              .. ZDOTC .. */
 		zdotc_(&z__1, &combla_1.n, cx, &combla_1.incx, cy, &
 			combla_1.incy);
 		cdot[0].r = z__1.r, cdot[0].i = z__1.i;
 		ctest_(&c__1, cdot, &ct6[kn + (ki << 2) - 5], &csize1[kn - 1],
 			 sfac);
 	    } else if (combla_1.icase == 2) {
+/*              .. ZDOTU .. */
 		zdotu_(&z__1, &combla_1.n, cx, &combla_1.incx, cy, &
 			combla_1.incy);
 		cdot[0].r = z__1.r, cdot[0].i = z__1.i;
 		ctest_(&c__1, cdot, &ct7[kn + (ki << 2) - 5], &csize1[kn - 1],
 			 sfac);
 	    } else if (combla_1.icase == 3) {
+/*              .. ZAXPY .. */
 		zaxpy_(&combla_1.n, &ca, cx, &combla_1.incx, cy, &
 			combla_1.incy);
 		ctest_(&leny, cy, &ct8[(kn + (ki << 2)) * 7 - 35], &csize2[
 			ksize * 7 - 7], sfac);
 	    } else if (combla_1.icase == 4) {
+/*              .. ZCOPY .. */
 		zcopy_(&combla_1.n, cx, &combla_1.incx, cy, &combla_1.incy);
 		ctest_(&leny, cy, &ct10y[(kn + (ki << 2)) * 7 - 35], csize3, &
 			c_b43);
 	    } else if (combla_1.icase == 5) {
+/*              .. ZSWAP .. */
 		zswap_(&combla_1.n, cx, &combla_1.incx, cy, &combla_1.incy);
 		ctest_(&lenx, cx, &ct10x[(kn + (ki << 2)) * 7 - 35], csize3, &
 			c_b43);
@@ -462,9 +497,9 @@ static doublereal c_b43 = 1.;
 /* L60: */
     }
     return 0;
-} /* check2_   
+} /* check2_ */
 
-   Subroutine */ int stest_(integer *len, doublereal *scomp, doublereal *
+/* Subroutine */ int stest_(integer *len, doublereal *scomp, doublereal *
 	strue, doublereal *ssize, doublereal *sfac)
 {
     /* Format strings */
@@ -483,8 +518,8 @@ static doublereal c_b43 = 1.;
     integer s_wsfe(cilist *), e_wsfe(void), do_fio(integer *, char *, ftnlen);
 
     /* Local variables */
-    static integer i__;
-    static doublereal sd;
+    integer i__;
+    doublereal sd;
     extern doublereal sdiff_(doublereal *, doublereal *);
 
     /* Fortran I/O blocks */
@@ -493,16 +528,25 @@ static doublereal c_b43 = 1.;
     static cilist io___53 = { 0, 6, 0, fmt_99997, 0 };
 
 
-/*     ********************************* STEST **************************   
+/*     ********************************* STEST ************************** */
 
-       THIS SUBR COMPARES ARRAYS  SCOMP() AND STRUE() OF LENGTH LEN TO   
-       SEE IF THE TERM BY TERM DIFFERENCES, MULTIPLIED BY SFAC, ARE   
-       NEGLIGIBLE.   
+/*     THIS SUBR COMPARES ARRAYS  SCOMP() AND STRUE() OF LENGTH LEN TO */
+/*     SEE IF THE TERM BY TERM DIFFERENCES, MULTIPLIED BY SFAC, ARE */
+/*     NEGLIGIBLE. */
 
-       C. L. LAWSON, JPL, 1974 DEC 10   
+/*     C. L. LAWSON, JPL, 1974 DEC 10 */
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. External Functions .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Common blocks .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ssize;
     --strue;
     --scomp;
@@ -547,25 +591,30 @@ L40:
     }
     return 0;
 
-} /* stest_   
+} /* stest_ */
 
-   Subroutine */ int stest1_(doublereal *scomp1, doublereal *strue1, 
+/* Subroutine */ int stest1_(doublereal *scomp1, doublereal *strue1, 
 	doublereal *ssize, doublereal *sfac)
 {
-    static doublereal scomp[1], strue[1];
+    doublereal scomp[1], strue[1];
     extern /* Subroutine */ int stest_(integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *);
 
-/*     ************************* STEST1 *****************************   
+/*     ************************* STEST1 ***************************** */
 
-       THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN   
-       REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE   
-       ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT.   
+/*     THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN */
+/*     REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE */
+/*     ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT. */
 
-       C.L. LAWSON, JPL, 1978 DEC 6   
+/*     C.L. LAWSON, JPL, 1978 DEC 6 */
 
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ssize;
 
     /* Function Body */
@@ -581,14 +630,16 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     /* System generated locals */
     doublereal ret_val;
 
-/*     ********************************* SDIFF **************************   
-       COMPUTES DIFFERENCE OF TWO NUMBERS.  C. L. LAWSON, JPL 1974 FEB 15 */
+/*     ********************************* SDIFF ************************** */
+/*     COMPUTES DIFFERENCE OF TWO NUMBERS.  C. L. LAWSON, JPL 1974 FEB 15 */
 
+/*     .. Scalar Arguments .. */
+/*     .. Executable Statements .. */
     ret_val = *sa - *sb;
     return ret_val;
-} /* sdiff_   
+} /* sdiff_ */
 
-   Subroutine */ int ctest_(integer *len, doublecomplex *ccomp, doublecomplex 
+/* Subroutine */ int ctest_(integer *len, doublecomplex *ccomp, doublecomplex 
 	*ctrue, doublecomplex *csize, doublereal *sfac)
 {
     /* System generated locals */
@@ -598,16 +649,23 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     double d_imag(doublecomplex *);
 
     /* Local variables */
-    static integer i__;
-    static doublereal scomp[20], ssize[20], strue[20];
+    integer i__;
+    doublereal scomp[20], ssize[20], strue[20];
     extern /* Subroutine */ int stest_(integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *);
 
-/*     **************************** CTEST *****************************   
+/*     **************************** CTEST ***************************** */
 
-       C.L. LAWSON, JPL, 1978 DEC 6   
+/*     C.L. LAWSON, JPL, 1978 DEC 6 */
 
-       Parameter adjustments */
+/*     .. Scalar Arguments .. */
+/*     .. Array Arguments .. */
+/*     .. Local Scalars .. */
+/*     .. Local Arrays .. */
+/*     .. External Subroutines .. */
+/*     .. Intrinsic Functions .. */
+/*     .. Executable Statements .. */
+    /* Parameter adjustments */
     --csize;
     --ctrue;
     --ccomp;
@@ -630,9 +688,9 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     i__1 = *len << 1;
     stest_(&i__1, scomp, strue, ssize, sfac);
     return 0;
-} /* ctest_   
+} /* ctest_ */
 
-   Subroutine */ int itest1_(integer *icomp, integer *itrue)
+/* Subroutine */ int itest1_(integer *icomp, integer *itrue)
 {
     /* Format strings */
     static char fmt_99999[] = "(\002                                       F"
@@ -646,7 +704,7 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     integer s_wsfe(cilist *), e_wsfe(void), do_fio(integer *, char *, ftnlen);
 
     /* Local variables */
-    static integer id;
+    integer id;
 
     /* Fortran I/O blocks */
     static cilist io___60 = { 0, 6, 0, fmt_99999, 0 };
@@ -654,12 +712,18 @@ doublereal sdiff_(doublereal *sa, doublereal *sb)
     static cilist io___63 = { 0, 6, 0, fmt_99997, 0 };
 
 
-/*     ********************************* ITEST1 *************************   
+/*     ********************************* ITEST1 ************************* */
 
-       THIS SUBROUTINE COMPARES THE VARIABLES ICOMP AND ITRUE FOR   
-       EQUALITY.   
-       C. L. LAWSON, JPL, 1974 DEC 10 */
+/*     THIS SUBROUTINE COMPARES THE VARIABLES ICOMP AND ITRUE FOR */
+/*     EQUALITY. */
+/*     C. L. LAWSON, JPL, 1974 DEC 10 */
 
+/*     .. Parameters .. */
+/*     .. Scalar Arguments .. */
+/*     .. Scalars in Common .. */
+/*     .. Local Scalars .. */
+/*     .. Common blocks .. */
+/*     .. Executable Statements .. */
     if (*icomp == *itrue) {
 	goto L40;
     }
@@ -690,6 +754,6 @@ L20:
 L40:
     return 0;
 
-} /* itest1_   
+} /* itest1_ */
 
-   Main program alias */ int zblat1_ () { MAIN__ (); return 0; }
+/* Main program alias */ int zblat1_ () { MAIN__ (); return 0; }
