@@ -1,225 +1,40 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static complex c_b2 = {1.f,0.f};
+static integer c__1 = 1;
+static integer c_n1 = -1;
+static real c_b29 = 1.f;
 
 /* Subroutine */ int cgegv_(char *jobvl, char *jobvr, integer *n, complex *a, 
-	integer *lda, complex *b, integer *ldb, complex *alpha, complex *beta,
+	integer *lda, complex *b, integer *ldb, complex *alpha, complex *beta, 
 	 complex *vl, integer *ldvl, complex *vr, integer *ldvr, complex *
 	work, integer *lwork, real *rwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    This routine is deprecated and has been replaced by routine CGGEV.   
-
-    CGEGV computes the eigenvalues and, optionally, the left and/or right   
-    eigenvectors of a complex matrix pair (A,B).   
-    Given two square matrices A and B,   
-    the generalized nonsymmetric eigenvalue problem (GNEP) is to find the   
-    eigenvalues lambda and corresponding (non-zero) eigenvectors x such   
-    that   
-       A*x = lambda*B*x.   
-
-    An alternate form is to find the eigenvalues mu and corresponding   
-    eigenvectors y such that   
-       mu*A*y = B*y.   
-
-    These two forms are equivalent with mu = 1/lambda and x = y if   
-    neither lambda nor mu is zero.  In order to deal with the case that   
-    lambda or mu is zero or small, two values alpha and beta are returned   
-    for each eigenvalue, such that lambda = alpha/beta and   
-    mu = beta/alpha.   
-
-    The vectors x and y in the above equations are right eigenvectors of   
-    the matrix pair (A,B).  Vectors u and v satisfying   
-       u**H*A = lambda*u**H*B  or  mu*v**H*A = v**H*B   
-    are left eigenvectors of (A,B).   
-
-    Note: this routine performs "full balancing" on A and B -- see   
-    "Further Details", below.   
-
-    Arguments   
-    =========   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N':  do not compute the left generalized eigenvectors;   
-            = 'V':  compute the left generalized eigenvectors (returned   
-                    in VL).   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N':  do not compute the right generalized eigenvectors;   
-            = 'V':  compute the right generalized eigenvectors (returned   
-                    in VR).   
-
-    N       (input) INTEGER   
-            The order of the matrices A, B, VL, and VR.  N >= 0.   
-
-    A       (input/output) COMPLEX array, dimension (LDA, N)   
-            On entry, the matrix A.   
-            If JOBVL = 'V' or JOBVR = 'V', then on exit A   
-            contains the Schur form of A from the generalized Schur   
-            factorization of the pair (A,B) after balancing.  If no   
-            eigenvectors were computed, then only the diagonal elements   
-            of the Schur form will be correct.  See CGGHRD and CHGEQZ   
-            for details.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A.  LDA >= max(1,N).   
-
-    B       (input/output) COMPLEX array, dimension (LDB, N)   
-            On entry, the matrix B.   
-            If JOBVL = 'V' or JOBVR = 'V', then on exit B contains the   
-            upper triangular matrix obtained from B in the generalized   
-            Schur factorization of the pair (A,B) after balancing.   
-            If no eigenvectors were computed, then only the diagonal   
-            elements of B will be correct.  See CGGHRD and CHGEQZ for   
-            details.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of B.  LDB >= max(1,N).   
-
-    ALPHA   (output) COMPLEX array, dimension (N)   
-            The complex scalars alpha that define the eigenvalues of   
-            GNEP.   
-
-    BETA    (output) COMPLEX array, dimension (N)   
-            The complex scalars beta that define the eigenvalues of GNEP.   
-
-            Together, the quantities alpha = ALPHA(j) and beta = BETA(j)   
-            represent the j-th eigenvalue of the matrix pair (A,B), in   
-            one of the forms lambda = alpha/beta or mu = beta/alpha.   
-            Since either lambda or mu may overflow, they should not,   
-            in general, be computed.   
-
-    VL      (output) COMPLEX array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left eigenvectors u(j) are stored   
-            in the columns of VL, in the same order as their eigenvalues.   
-            Each eigenvector is scaled so that its largest component has   
-            abs(real part) + abs(imag. part) = 1, except for eigenvectors   
-            corresponding to an eigenvalue with alpha = beta = 0, which   
-            are set to zero.   
-            Not referenced if JOBVL = 'N'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the matrix VL. LDVL >= 1, and   
-            if JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) COMPLEX array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right eigenvectors x(j) are stored   
-            in the columns of VR, in the same order as their eigenvalues.   
-            Each eigenvector is scaled so that its largest component has   
-            abs(real part) + abs(imag. part) = 1, except for eigenvectors   
-            corresponding to an eigenvalue with alpha = beta = 0, which   
-            are set to zero.   
-            Not referenced if JOBVR = 'N'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the matrix VR. LDVR >= 1, and   
-            if JOBVR = 'V', LDVR >= N.   
-
-    WORK    (workspace/output) COMPLEX array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,2*N).   
-            For good performance, LWORK must generally be larger.   
-            To compute the optimal value of LWORK, call ILAENV to get   
-            blocksizes (for CGEQRF, CUNMQR, and CUNGQR.)  Then compute:   
-            NB  -- MAX of the blocksizes for CGEQRF, CUNMQR, and CUNGQR;   
-            The optimal LWORK is  MAX( 2*N, N*(NB+1) ).   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    RWORK   (workspace/output) REAL array, dimension (8*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            =1,...,N:   
-                  The QZ iteration failed.  No eigenvectors have been   
-                  calculated, but ALPHA(j) and BETA(j) should be   
-                  correct for j=INFO+1,...,N.   
-            > N:  errors that usually indicate LAPACK problems:   
-                  =N+1: error return from CGGBAL   
-                  =N+2: error return from CGEQRF   
-                  =N+3: error return from CUNMQR   
-                  =N+4: error return from CUNGQR   
-                  =N+5: error return from CGGHRD   
-                  =N+6: error return from CHGEQZ (other than failed   
-                                                 iteration)   
-                  =N+7: error return from CTGEVC   
-                  =N+8: error return from CGGBAK (computing VL)   
-                  =N+9: error return from CGGBAK (computing VR)   
-                  =N+10: error return from CLASCL (various calls)   
-
-    Further Details   
-    ===============   
-
-    Balancing   
-    ---------   
-
-    This driver calls CGGBAL to both permute and scale rows and columns   
-    of A and B.  The permutations PL and PR are chosen so that PL*A*PR   
-    and PL*B*R will be upper triangular except for the diagonal blocks   
-    A(i:j,i:j) and B(i:j,i:j), with i and j as close together as   
-    possible.  The diagonal scaling matrices DL and DR are chosen so   
-    that the pair  DL*PL*A*PR*DR, DL*PL*B*PR*DR have elements close to   
-    one (except for the elements that start out zero.)   
-
-    After the eigenvalues and eigenvectors of the balanced matrices   
-    have been computed, CGGBAK transforms the eigenvectors back to what   
-    they would have been (in perfect arithmetic) if they had not been   
-    balanced.   
-
-    Contents of A and B on Exit   
-    -------- -- - --- - -- ----   
-
-    If any eigenvectors are computed (either JOBVL='V' or JOBVR='V' or   
-    both), then on exit the arrays A and B will contain the complex Schur   
-    form[*] of the "balanced" versions of A and B.  If no eigenvectors   
-    are computed, then only the diagonal blocks will be correct.   
-
-    [*] In other words, upper triangular form.   
-
-    =====================================================================   
-
-
-       Decode the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static complex c_b2 = {1.f,0.f};
-    static integer c__1 = 1;
-    static integer c_n1 = -1;
-    static real c_b29 = 1.f;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2, i__3, i__4;
     real r__1, r__2, r__3, r__4;
     complex q__1, q__2;
+
     /* Builtin functions */
     double r_imag(complex *);
+
     /* Local variables */
-    static integer jc, nb, in, jr, nb1, nb2, nb3, ihi, ilo;
-    static real eps;
-    static logical ilv;
-    static real absb, anrm, bnrm;
-    static integer itau;
-    static real temp;
-    static logical ilvl, ilvr;
-    static integer lopt;
-    static real anrm1, anrm2, bnrm1, bnrm2, absai, scale, absar, sbeta;
+    integer jc, nb, in, jr, nb1, nb2, nb3, ihi, ilo;
+    real eps;
+    logical ilv;
+    real absb, anrm, bnrm;
+    integer itau;
+    real temp;
+    logical ilvl, ilvr;
+    integer lopt;
+    real anrm1, anrm2, bnrm1, bnrm2, absai, scale, absar, sbeta;
     extern logical lsame_(char *, char *);
-    static integer ileft, iinfo, icols, iwork, irows;
+    integer ileft, iinfo, icols, iwork, irows;
     extern /* Subroutine */ int cggbak_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, complex *, integer *, 
 	    integer *), cggbal_(char *, integer *, complex *, 
@@ -230,43 +45,252 @@
     extern /* Subroutine */ int cgghrd_(char *, char *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, complex *, integer *, integer *);
-    static real salfai;
+    real salfai;
     extern /* Subroutine */ int clascl_(char *, integer *, integer *, real *, 
 	    real *, integer *, integer *, complex *, integer *, integer *), cgeqrf_(integer *, integer *, complex *, integer *, 
 	    complex *, complex *, integer *, integer *);
-    static real salfar;
+    real salfar;
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), claset_(char *, 
 	    integer *, integer *, complex *, complex *, complex *, integer *);
-    static real safmin;
+    real safmin;
     extern /* Subroutine */ int ctgevc_(char *, char *, logical *, integer *, 
 	    complex *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, integer *, integer *, complex *, real *, 
 	    integer *);
-    static real safmax;
-    static char chtemp[1];
-    static logical ldumma[1];
+    real safmax;
+    char chtemp[1];
+    logical ldumma[1];
     extern /* Subroutine */ int chgeqz_(char *, char *, char *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, complex *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, real *, integer *), 
 	    xerbla_(char *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static integer ijobvl, iright;
-    static logical ilimit;
-    static integer ijobvr;
+	    integer *, integer *);
+    integer ijobvl, iright;
+    logical ilimit;
+    integer ijobvr;
     extern /* Subroutine */ int cungqr_(integer *, integer *, integer *, 
 	    complex *, integer *, complex *, complex *, integer *, integer *);
-    static integer lwkmin;
+    integer lwkmin;
     extern /* Subroutine */ int cunmqr_(char *, char *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, complex *, integer *, 
 	    complex *, integer *, integer *);
-    static integer irwork, lwkopt;
-    static logical lquery;
+    integer irwork, lwkopt;
+    logical lquery;
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  This routine is deprecated and has been replaced by routine CGGEV. */
+
+/*  CGEGV computes the eigenvalues and, optionally, the left and/or right */
+/*  eigenvectors of a complex matrix pair (A,B). */
+/*  Given two square matrices A and B, */
+/*  the generalized nonsymmetric eigenvalue problem (GNEP) is to find the */
+/*  eigenvalues lambda and corresponding (non-zero) eigenvectors x such */
+/*  that */
+/*     A*x = lambda*B*x. */
+
+/*  An alternate form is to find the eigenvalues mu and corresponding */
+/*  eigenvectors y such that */
+/*     mu*A*y = B*y. */
+
+/*  These two forms are equivalent with mu = 1/lambda and x = y if */
+/*  neither lambda nor mu is zero.  In order to deal with the case that */
+/*  lambda or mu is zero or small, two values alpha and beta are returned */
+/*  for each eigenvalue, such that lambda = alpha/beta and */
+/*  mu = beta/alpha. */
+
+/*  The vectors x and y in the above equations are right eigenvectors of */
+/*  the matrix pair (A,B).  Vectors u and v satisfying */
+/*     u**H*A = lambda*u**H*B  or  mu*v**H*A = v**H*B */
+/*  are left eigenvectors of (A,B). */
+
+/*  Note: this routine performs "full balancing" on A and B -- see */
+/*  "Further Details", below. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the left generalized eigenvectors; */
+/*          = 'V':  compute the left generalized eigenvectors (returned */
+/*                  in VL). */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the right generalized eigenvectors; */
+/*          = 'V':  compute the right generalized eigenvectors (returned */
+/*                  in VR). */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A, B, VL, and VR.  N >= 0. */
+
+/*  A       (input/output) COMPLEX array, dimension (LDA, N) */
+/*          On entry, the matrix A. */
+/*          If JOBVL = 'V' or JOBVR = 'V', then on exit A */
+/*          contains the Schur form of A from the generalized Schur */
+/*          factorization of the pair (A,B) after balancing.  If no */
+/*          eigenvectors were computed, then only the diagonal elements */
+/*          of the Schur form will be correct.  See CGGHRD and CHGEQZ */
+/*          for details. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A.  LDA >= max(1,N). */
+
+/*  B       (input/output) COMPLEX array, dimension (LDB, N) */
+/*          On entry, the matrix B. */
+/*          If JOBVL = 'V' or JOBVR = 'V', then on exit B contains the */
+/*          upper triangular matrix obtained from B in the generalized */
+/*          Schur factorization of the pair (A,B) after balancing. */
+/*          If no eigenvectors were computed, then only the diagonal */
+/*          elements of B will be correct.  See CGGHRD and CHGEQZ for */
+/*          details. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B.  LDB >= max(1,N). */
+
+/*  ALPHA   (output) COMPLEX array, dimension (N) */
+/*          The complex scalars alpha that define the eigenvalues of */
+/*          GNEP. */
+
+/*  BETA    (output) COMPLEX array, dimension (N) */
+/*          The complex scalars beta that define the eigenvalues of GNEP. */
+
+/*          Together, the quantities alpha = ALPHA(j) and beta = BETA(j) */
+/*          represent the j-th eigenvalue of the matrix pair (A,B), in */
+/*          one of the forms lambda = alpha/beta or mu = beta/alpha. */
+/*          Since either lambda or mu may overflow, they should not, */
+/*          in general, be computed. */
+
+/*  VL      (output) COMPLEX array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left eigenvectors u(j) are stored */
+/*          in the columns of VL, in the same order as their eigenvalues. */
+/*          Each eigenvector is scaled so that its largest component has */
+/*          abs(real part) + abs(imag. part) = 1, except for eigenvectors */
+/*          corresponding to an eigenvalue with alpha = beta = 0, which */
+/*          are set to zero. */
+/*          Not referenced if JOBVL = 'N'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the matrix VL. LDVL >= 1, and */
+/*          if JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) COMPLEX array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right eigenvectors x(j) are stored */
+/*          in the columns of VR, in the same order as their eigenvalues. */
+/*          Each eigenvector is scaled so that its largest component has */
+/*          abs(real part) + abs(imag. part) = 1, except for eigenvectors */
+/*          corresponding to an eigenvalue with alpha = beta = 0, which */
+/*          are set to zero. */
+/*          Not referenced if JOBVR = 'N'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the matrix VR. LDVR >= 1, and */
+/*          if JOBVR = 'V', LDVR >= N. */
+
+/*  WORK    (workspace/output) COMPLEX array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,2*N). */
+/*          For good performance, LWORK must generally be larger. */
+/*          To compute the optimal value of LWORK, call ILAENV to get */
+/*          blocksizes (for CGEQRF, CUNMQR, and CUNGQR.)  Then compute: */
+/*          NB  -- MAX of the blocksizes for CGEQRF, CUNMQR, and CUNGQR; */
+/*          The optimal LWORK is  MAX( 2*N, N*(NB+1) ). */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  RWORK   (workspace/output) REAL array, dimension (8*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          =1,...,N: */
+/*                The QZ iteration failed.  No eigenvectors have been */
+/*                calculated, but ALPHA(j) and BETA(j) should be */
+/*                correct for j=INFO+1,...,N. */
+/*          > N:  errors that usually indicate LAPACK problems: */
+/*                =N+1: error return from CGGBAL */
+/*                =N+2: error return from CGEQRF */
+/*                =N+3: error return from CUNMQR */
+/*                =N+4: error return from CUNGQR */
+/*                =N+5: error return from CGGHRD */
+/*                =N+6: error return from CHGEQZ (other than failed */
+/*                                               iteration) */
+/*                =N+7: error return from CTGEVC */
+/*                =N+8: error return from CGGBAK (computing VL) */
+/*                =N+9: error return from CGGBAK (computing VR) */
+/*                =N+10: error return from CLASCL (various calls) */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Balancing */
+/*  --------- */
+
+/*  This driver calls CGGBAL to both permute and scale rows and columns */
+/*  of A and B.  The permutations PL and PR are chosen so that PL*A*PR */
+/*  and PL*B*R will be upper triangular except for the diagonal blocks */
+/*  A(i:j,i:j) and B(i:j,i:j), with i and j as close together as */
+/*  possible.  The diagonal scaling matrices DL and DR are chosen so */
+/*  that the pair  DL*PL*A*PR*DR, DL*PL*B*PR*DR have elements close to */
+/*  one (except for the elements that start out zero.) */
+
+/*  After the eigenvalues and eigenvectors of the balanced matrices */
+/*  have been computed, CGGBAK transforms the eigenvectors back to what */
+/*  they would have been (in perfect arithmetic) if they had not been */
+/*  balanced. */
+
+/*  Contents of A and B on Exit */
+/*  -------- -- - --- - -- ---- */
+
+/*  If any eigenvectors are computed (either JOBVL='V' or JOBVR='V' or */
+/*  both), then on exit the arrays A and B will contain the complex Schur */
+/*  form[*] of the "balanced" versions of A and B.  If no eigenvectors */
+/*  are computed, then only the diagonal blocks will be correct. */
+
+/*  [*] In other words, upper triangular form. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -308,9 +332,9 @@
     }
     ilv = ilvl || ilvr;
 
-/*     Test the input arguments   
+/*     Test the input arguments */
 
-   Computing MAX */
+/* Computing MAX */
     i__1 = *n << 1;
     lwkmin = max(i__1,1);
     lwkopt = lwkmin;
@@ -336,12 +360,9 @@
     }
 
     if (*info == 0) {
-	nb1 = ilaenv_(&c__1, "CGEQRF", " ", n, n, &c_n1, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-	nb2 = ilaenv_(&c__1, "CUNMQR", " ", n, n, n, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-	nb3 = ilaenv_(&c__1, "CUNGQR", " ", n, n, n, &c_n1, (ftnlen)6, (
-		ftnlen)1);
+	nb1 = ilaenv_(&c__1, "CGEQRF", " ", n, n, &c_n1, &c_n1);
+	nb2 = ilaenv_(&c__1, "CUNMQR", " ", n, n, n, &c_n1);
+	nb3 = ilaenv_(&c__1, "CUNGQR", " ", n, n, n, &c_n1);
 /* Computing MAX */
 	i__1 = max(nb1,nb2);
 	nb = max(i__1,nb3);
@@ -414,8 +435,8 @@
 	}
     }
 
-/*     Permute the matrix to make it more nearly triangular   
-       Also "balance" the matrix. */
+/*     Permute the matrix to make it more nearly triangular */
+/*     Also "balance" the matrix. */
 
     ileft = 1;
     iright = *n + 1;
@@ -563,7 +584,7 @@
 /*        Undo balancing on VL and VR, rescale */
 
 	if (ilvl) {
-	    cggbak_("P", "L", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n,
+	    cggbak_("P", "L", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n, 
 		     &vl[vl_offset], ldvl, &iinfo);
 	    if (iinfo != 0) {
 		*info = *n + 8;
@@ -599,7 +620,7 @@ L30:
 	    }
 	}
 	if (ilvr) {
-	    cggbak_("P", "R", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n,
+	    cggbak_("P", "R", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n, 
 		     &vr[vr_offset], ldvr, &iinfo);
 	    if (iinfo != 0) {
 		*info = *n + 9;
@@ -639,13 +660,13 @@ L60:
 
     }
 
-/*     Undo scaling in alpha, beta   
+/*     Undo scaling in alpha, beta */
 
-       Note: this does not give the alpha and beta for the unscaled   
-       problem.   
+/*     Note: this does not give the alpha and beta for the unscaled */
+/*     problem. */
 
-       Un-scaling is limited to avoid underflow in alpha and beta   
-       if they are significant. */
+/*     Un-scaling is limited to avoid underflow in alpha and beta */
+/*     if they are significant. */
 
     i__1 = *n;
     for (jc = 1; jc <= i__1; ++jc) {
@@ -662,9 +683,9 @@ L60:
 	ilimit = FALSE_;
 	scale = 1.f;
 
-/*        Check for significant underflow in imaginary part of ALPHA   
+/*        Check for significant underflow in imaginary part of ALPHA */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = safmin, r__2 = eps * absar, r__1 = max(r__1,r__2), r__2 = eps *
 		 absb;
 	if (dabs(salfai) < safmin && absai >= dmax(r__1,r__2)) {
@@ -674,29 +695,29 @@ L60:
 	    scale = safmin / anrm1 / dmax(r__1,r__2);
 	}
 
-/*        Check for significant underflow in real part of ALPHA   
+/*        Check for significant underflow in real part of ALPHA */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = safmin, r__2 = eps * absai, r__1 = max(r__1,r__2), r__2 = eps *
 		 absb;
 	if (dabs(salfar) < safmin && absar >= dmax(r__1,r__2)) {
 	    ilimit = TRUE_;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    r__3 = safmin, r__4 = anrm2 * absar;
 	    r__1 = scale, r__2 = safmin / anrm1 / dmax(r__3,r__4);
 	    scale = dmax(r__1,r__2);
 	}
 
-/*        Check for significant underflow in BETA   
+/*        Check for significant underflow in BETA */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = safmin, r__2 = eps * absar, r__1 = max(r__1,r__2), r__2 = eps *
 		 absai;
 	if (dabs(sbeta) < safmin && absb >= dmax(r__1,r__2)) {
 	    ilimit = TRUE_;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    r__3 = safmin, r__4 = bnrm2 * absb;
 	    r__1 = scale, r__2 = safmin / bnrm1 / dmax(r__3,r__4);
 	    scale = dmax(r__1,r__2);
