@@ -1,160 +1,39 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static complex c_b2 = {1.f,0.f};
+static integer c__1 = 1;
+static integer c__0 = 0;
+static integer c_n1 = -1;
 
 /* Subroutine */ int cggev_(char *jobvl, char *jobvr, integer *n, complex *a, 
-	integer *lda, complex *b, integer *ldb, complex *alpha, complex *beta,
+	integer *lda, complex *b, integer *ldb, complex *alpha, complex *beta, 
 	 complex *vl, integer *ldvl, complex *vr, integer *ldvr, complex *
 	work, integer *lwork, real *rwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CGGEV computes for a pair of N-by-N complex nonsymmetric matrices   
-    (A,B), the generalized eigenvalues, and optionally, the left and/or   
-    right generalized eigenvectors.   
-
-    A generalized eigenvalue for a pair of matrices (A,B) is a scalar   
-    lambda or a ratio alpha/beta = lambda, such that A - lambda*B is   
-    singular. It is usually represented as the pair (alpha,beta), as   
-    there is a reasonable interpretation for beta=0, and even for both   
-    being zero.   
-
-    The right generalized eigenvector v(j) corresponding to the   
-    generalized eigenvalue lambda(j) of (A,B) satisfies   
-
-                 A * v(j) = lambda(j) * B * v(j).   
-
-    The left generalized eigenvector u(j) corresponding to the   
-    generalized eigenvalues lambda(j) of (A,B) satisfies   
-
-                 u(j)**H * A = lambda(j) * u(j)**H * B   
-
-    where u(j)**H is the conjugate-transpose of u(j).   
-
-    Arguments   
-    =========   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N':  do not compute the left generalized eigenvectors;   
-            = 'V':  compute the left generalized eigenvectors.   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N':  do not compute the right generalized eigenvectors;   
-            = 'V':  compute the right generalized eigenvectors.   
-
-    N       (input) INTEGER   
-            The order of the matrices A, B, VL, and VR.  N >= 0.   
-
-    A       (input/output) COMPLEX array, dimension (LDA, N)   
-            On entry, the matrix A in the pair (A,B).   
-            On exit, A has been overwritten.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A.  LDA >= max(1,N).   
-
-    B       (input/output) COMPLEX array, dimension (LDB, N)   
-            On entry, the matrix B in the pair (A,B).   
-            On exit, B has been overwritten.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of B.  LDB >= max(1,N).   
-
-    ALPHA   (output) COMPLEX array, dimension (N)   
-    BETA    (output) COMPLEX array, dimension (N)   
-            On exit, ALPHA(j)/BETA(j), j=1,...,N, will be the   
-            generalized eigenvalues.   
-
-            Note: the quotients ALPHA(j)/BETA(j) may easily over- or   
-            underflow, and BETA(j) may even be zero.  Thus, the user   
-            should avoid naively computing the ratio alpha/beta.   
-            However, ALPHA will be always less than and usually   
-            comparable with norm(A) in magnitude, and BETA always less   
-            than and usually comparable with norm(B).   
-
-    VL      (output) COMPLEX array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left generalized eigenvectors u(j) are   
-            stored one after another in the columns of VL, in the same   
-            order as their eigenvalues.   
-            Each eigenvector is scaled so the largest component has   
-            abs(real part) + abs(imag. part) = 1.   
-            Not referenced if JOBVL = 'N'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the matrix VL. LDVL >= 1, and   
-            if JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) COMPLEX array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right generalized eigenvectors v(j) are   
-            stored one after another in the columns of VR, in the same   
-            order as their eigenvalues.   
-            Each eigenvector is scaled so the largest component has   
-            abs(real part) + abs(imag. part) = 1.   
-            Not referenced if JOBVR = 'N'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the matrix VR. LDVR >= 1, and   
-            if JOBVR = 'V', LDVR >= N.   
-
-    WORK    (workspace/output) COMPLEX array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,2*N).   
-            For good performance, LWORK must generally be larger.   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    RWORK   (workspace/output) REAL array, dimension (8*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            =1,...,N:   
-                  The QZ iteration failed.  No eigenvectors have been   
-                  calculated, but ALPHA(j) and BETA(j) should be   
-                  correct for j=INFO+1,...,N.   
-            > N:  =N+1: other then QZ iteration failed in SHGEQZ,   
-                  =N+2: error return from STGEVC.   
-
-    =====================================================================   
-
-
-       Decode the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static complex c_b2 = {1.f,0.f};
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static integer c_n1 = -1;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2, i__3, i__4;
     real r__1, r__2, r__3, r__4;
     complex q__1;
+
     /* Builtin functions */
     double sqrt(doublereal), r_imag(complex *);
+
     /* Local variables */
-    static integer jc, in, jr, ihi, ilo;
-    static real eps;
-    static logical ilv;
-    static real anrm, bnrm;
-    static integer ierr, itau;
-    static real temp;
-    static logical ilvl, ilvr;
-    static integer iwrk;
+    integer jc, in, jr, ihi, ilo;
+    real eps;
+    logical ilv;
+    real anrm, bnrm;
+    integer ierr, itau;
+    real temp;
+    logical ilvl, ilvr;
+    integer iwrk;
     extern logical lsame_(char *, char *);
-    static integer ileft, icols, irwrk, irows;
+    integer ileft, icols, irwrk, irows;
     extern /* Subroutine */ int cggbak_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, complex *, integer *, 
 	    integer *), cggbal_(char *, integer *, complex *, 
@@ -167,7 +46,7 @@
 	    integer *, complex *, integer *, integer *), 
 	    clascl_(char *, integer *, integer *, real *, real *, integer *, 
 	    integer *, complex *, integer *, integer *);
-    static logical ilascl, ilbscl;
+    logical ilascl, ilbscl;
     extern /* Subroutine */ int cgeqrf_(integer *, integer *, complex *, 
 	    integer *, complex *, complex *, integer *, integer *);
     extern doublereal slamch_(char *);
@@ -176,29 +55,174 @@
 	    integer *, integer *, complex *, complex *, complex *, integer *), ctgevc_(char *, char *, logical *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, integer *, integer *, complex *, real *, integer *), xerbla_(char *, integer *);
-    static logical ldumma[1];
-    static char chtemp[1];
-    static real bignum;
+    logical ldumma[1];
+    char chtemp[1];
+    real bignum;
     extern /* Subroutine */ int chgeqz_(char *, char *, char *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, complex *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, real *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static integer ijobvl, iright, ijobvr;
+	    integer *, integer *);
+    integer ijobvl, iright, ijobvr;
     extern /* Subroutine */ int cungqr_(integer *, integer *, integer *, 
 	    complex *, integer *, complex *, complex *, integer *, integer *);
-    static real anrmto;
-    static integer lwkmin;
-    static real bnrmto;
+    real anrmto;
+    integer lwkmin;
+    real bnrmto;
     extern /* Subroutine */ int cunmqr_(char *, char *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, complex *, integer *, 
 	    complex *, integer *, integer *);
-    static real smlnum;
-    static integer lwkopt;
-    static logical lquery;
+    real smlnum;
+    integer lwkopt;
+    logical lquery;
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CGGEV computes for a pair of N-by-N complex nonsymmetric matrices */
+/*  (A,B), the generalized eigenvalues, and optionally, the left and/or */
+/*  right generalized eigenvectors. */
+
+/*  A generalized eigenvalue for a pair of matrices (A,B) is a scalar */
+/*  lambda or a ratio alpha/beta = lambda, such that A - lambda*B is */
+/*  singular. It is usually represented as the pair (alpha,beta), as */
+/*  there is a reasonable interpretation for beta=0, and even for both */
+/*  being zero. */
+
+/*  The right generalized eigenvector v(j) corresponding to the */
+/*  generalized eigenvalue lambda(j) of (A,B) satisfies */
+
+/*               A * v(j) = lambda(j) * B * v(j). */
+
+/*  The left generalized eigenvector u(j) corresponding to the */
+/*  generalized eigenvalues lambda(j) of (A,B) satisfies */
+
+/*               u(j)**H * A = lambda(j) * u(j)**H * B */
+
+/*  where u(j)**H is the conjugate-transpose of u(j). */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the left generalized eigenvectors; */
+/*          = 'V':  compute the left generalized eigenvectors. */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the right generalized eigenvectors; */
+/*          = 'V':  compute the right generalized eigenvectors. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A, B, VL, and VR.  N >= 0. */
+
+/*  A       (input/output) COMPLEX array, dimension (LDA, N) */
+/*          On entry, the matrix A in the pair (A,B). */
+/*          On exit, A has been overwritten. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A.  LDA >= max(1,N). */
+
+/*  B       (input/output) COMPLEX array, dimension (LDB, N) */
+/*          On entry, the matrix B in the pair (A,B). */
+/*          On exit, B has been overwritten. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B.  LDB >= max(1,N). */
+
+/*  ALPHA   (output) COMPLEX array, dimension (N) */
+/*  BETA    (output) COMPLEX array, dimension (N) */
+/*          On exit, ALPHA(j)/BETA(j), j=1,...,N, will be the */
+/*          generalized eigenvalues. */
+
+/*          Note: the quotients ALPHA(j)/BETA(j) may easily over- or */
+/*          underflow, and BETA(j) may even be zero.  Thus, the user */
+/*          should avoid naively computing the ratio alpha/beta. */
+/*          However, ALPHA will be always less than and usually */
+/*          comparable with norm(A) in magnitude, and BETA always less */
+/*          than and usually comparable with norm(B). */
+
+/*  VL      (output) COMPLEX array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left generalized eigenvectors u(j) are */
+/*          stored one after another in the columns of VL, in the same */
+/*          order as their eigenvalues. */
+/*          Each eigenvector is scaled so the largest component has */
+/*          abs(real part) + abs(imag. part) = 1. */
+/*          Not referenced if JOBVL = 'N'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the matrix VL. LDVL >= 1, and */
+/*          if JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) COMPLEX array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right generalized eigenvectors v(j) are */
+/*          stored one after another in the columns of VR, in the same */
+/*          order as their eigenvalues. */
+/*          Each eigenvector is scaled so the largest component has */
+/*          abs(real part) + abs(imag. part) = 1. */
+/*          Not referenced if JOBVR = 'N'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the matrix VR. LDVR >= 1, and */
+/*          if JOBVR = 'V', LDVR >= N. */
+
+/*  WORK    (workspace/output) COMPLEX array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,2*N). */
+/*          For good performance, LWORK must generally be larger. */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  RWORK   (workspace/output) REAL array, dimension (8*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          =1,...,N: */
+/*                The QZ iteration failed.  No eigenvectors have been */
+/*                calculated, but ALPHA(j) and BETA(j) should be */
+/*                correct for j=INFO+1,...,N. */
+/*          > N:  =N+1: other then QZ iteration failed in SHGEQZ, */
+/*                =N+2: error return from STGEVC. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -260,13 +284,13 @@
 	*info = -13;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV. The workspace is   
-         computed assuming ILO = 1 and IHI = N, the worst case.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. The workspace is */
+/*       computed assuming ILO = 1 and IHI = N, the worst case.) */
 
     if (*info == 0) {
 /* Computing MAX */
@@ -274,16 +298,16 @@
 	lwkmin = max(i__1,i__2);
 /* Computing MAX */
 	i__1 = 1, i__2 = *n + *n * ilaenv_(&c__1, "CGEQRF", " ", n, &c__1, n, 
-		&c__0, (ftnlen)6, (ftnlen)1);
+		&c__0);
 	lwkopt = max(i__1,i__2);
 /* Computing MAX */
 	i__1 = lwkopt, i__2 = *n + *n * ilaenv_(&c__1, "CUNMQR", " ", n, &
-		c__1, n, &c__0, (ftnlen)6, (ftnlen)1);
+		c__1, n, &c__0);
 	lwkopt = max(i__1,i__2);
 	if (ilvl) {
 /* Computing MAX */
 	    i__1 = lwkopt, i__2 = *n + *n * ilaenv_(&c__1, "CUNGQR", " ", n, &
-		    c__1, n, &c_n1, (ftnlen)6, (ftnlen)1);
+		    c__1, n, &c_n1);
 	    lwkopt = max(i__1,i__2);
 	}
 	work[1].r = (real) lwkopt, work[1].i = 0.f;
@@ -348,8 +372,8 @@
 		ierr);
     }
 
-/*     Permute the matrices A, B to isolate eigenvalues if possible   
-       (Real Workspace: need 6*N) */
+/*     Permute the matrices A, B to isolate eigenvalues if possible */
+/*     (Real Workspace: need 6*N) */
 
     ileft = 1;
     iright = *n + 1;
@@ -357,8 +381,8 @@
     cggbal_("P", n, &a[a_offset], lda, &b[b_offset], ldb, &ilo, &ihi, &rwork[
 	    ileft], &rwork[iright], &rwork[irwrk], &ierr);
 
-/*     Reduce B to triangular form (QR decomposition of B)   
-       (Complex Workspace: need N, prefer N*NB) */
+/*     Reduce B to triangular form (QR decomposition of B) */
+/*     (Complex Workspace: need N, prefer N*NB) */
 
     irows = ihi + 1 - ilo;
     if (ilv) {
@@ -372,16 +396,16 @@
     cgeqrf_(&irows, &icols, &b[ilo + ilo * b_dim1], ldb, &work[itau], &work[
 	    iwrk], &i__1, &ierr);
 
-/*     Apply the orthogonal transformation to matrix A   
-       (Complex Workspace: need N, prefer N*NB) */
+/*     Apply the orthogonal transformation to matrix A */
+/*     (Complex Workspace: need N, prefer N*NB) */
 
     i__1 = *lwork + 1 - iwrk;
     cunmqr_("L", "C", &irows, &icols, &irows, &b[ilo + ilo * b_dim1], ldb, &
 	    work[itau], &a[ilo + ilo * a_dim1], lda, &work[iwrk], &i__1, &
 	    ierr);
 
-/*     Initialize VL   
-       (Complex Workspace: need N, prefer N*NB) */
+/*     Initialize VL */
+/*     (Complex Workspace: need N, prefer N*NB) */
 
     if (ilvl) {
 	claset_("Full", n, n, &c_b1, &c_b2, &vl[vl_offset], ldvl);
@@ -416,10 +440,10 @@
 		vr_offset], ldvr, &ierr);
     }
 
-/*     Perform QZ algorithm (Compute eigenvalues, and optionally, the   
-       Schur form and Schur vectors)   
-       (Complex Workspace: need N)   
-       (Real Workspace: need N) */
+/*     Perform QZ algorithm (Compute eigenvalues, and optionally, the */
+/*     Schur form and Schur vectors) */
+/*     (Complex Workspace: need N) */
+/*     (Real Workspace: need N) */
 
     iwrk = itau;
     if (ilv) {
@@ -442,9 +466,9 @@
 	goto L70;
     }
 
-/*     Compute Eigenvectors   
-       (Real Workspace: need 2*N)   
-       (Complex Workspace: need 2*N) */
+/*     Compute Eigenvectors */
+/*     (Real Workspace: need 2*N) */
+/*     (Complex Workspace: need 2*N) */
 
     if (ilv) {
 	if (ilvl) {
@@ -465,11 +489,11 @@
 	    goto L70;
 	}
 
-/*        Undo balancing on VL and VR and normalization   
-          (Workspace: none needed) */
+/*        Undo balancing on VL and VR and normalization */
+/*        (Workspace: none needed) */
 
 	if (ilvl) {
-	    cggbak_("P", "L", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n,
+	    cggbak_("P", "L", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n, 
 		     &vl[vl_offset], ldvl, &ierr);
 	    i__1 = *n;
 	    for (jc = 1; jc <= i__1; ++jc) {
@@ -501,7 +525,7 @@ L30:
 	    }
 	}
 	if (ilvr) {
-	    cggbak_("P", "R", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n,
+	    cggbak_("P", "R", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n, 
 		     &vr[vr_offset], ldvr, &ierr);
 	    i__1 = *n;
 	    for (jc = 1; jc <= i__1; ++jc) {
