@@ -1,81 +1,93 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int cgtts2_(integer *itrans, integer *n, integer *nrhs, 
 	complex *dl, complex *d__, complex *du, complex *du2, integer *ipiv, 
 	complex *b, integer *ldb)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CGTTS2 solves one of the systems of equations   
-       A * X = B,  A**T * X = B,  or  A**H * X = B,   
-    with a tridiagonal matrix A using the LU factorization computed   
-    by CGTTRF.   
-
-    Arguments   
-    =========   
-
-    ITRANS  (input) INTEGER   
-            Specifies the form of the system of equations.   
-            = 0:  A * X = B     (No transpose)   
-            = 1:  A**T * X = B  (Transpose)   
-            = 2:  A**H * X = B  (Conjugate transpose)   
-
-    N       (input) INTEGER   
-            The order of the matrix A.   
-
-    NRHS    (input) INTEGER   
-            The number of right hand sides, i.e., the number of columns   
-            of the matrix B.  NRHS >= 0.   
-
-    DL      (input) COMPLEX array, dimension (N-1)   
-            The (n-1) multipliers that define the matrix L from the   
-            LU factorization of A.   
-
-    D       (input) COMPLEX array, dimension (N)   
-            The n diagonal elements of the upper triangular matrix U from   
-            the LU factorization of A.   
-
-    DU      (input) COMPLEX array, dimension (N-1)   
-            The (n-1) elements of the first super-diagonal of U.   
-
-    DU2     (input) COMPLEX array, dimension (N-2)   
-            The (n-2) elements of the second super-diagonal of U.   
-
-    IPIV    (input) INTEGER array, dimension (N)   
-            The pivot indices; for 1 <= i <= n, row i of the matrix was   
-            interchanged with row IPIV(i).  IPIV(i) will always be either   
-            i or i+1; IPIV(i) = i indicates a row interchange was not   
-            required.   
-
-    B       (input/output) COMPLEX array, dimension (LDB,NRHS)   
-            On entry, the matrix of right hand side vectors B.   
-            On exit, B is overwritten by the solution vectors X.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B.  LDB >= max(1,N).   
-
-    =====================================================================   
-
-
-       Quick return if possible   
-
-       Parameter adjustments */
     /* System generated locals */
     integer b_dim1, b_offset, i__1, i__2, i__3, i__4, i__5, i__6, i__7, i__8;
     complex q__1, q__2, q__3, q__4, q__5, q__6, q__7, q__8;
+
     /* Builtin functions */
     void c_div(complex *, complex *, complex *), r_cnjg(complex *, complex *);
-    /* Local variables */
-    static integer i__, j;
-    static complex temp;
 
+    /* Local variables */
+    integer i__, j;
+    complex temp;
+
+
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CGTTS2 solves one of the systems of equations */
+/*     A * X = B,  A**T * X = B,  or  A**H * X = B, */
+/*  with a tridiagonal matrix A using the LU factorization computed */
+/*  by CGTTRF. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  ITRANS  (input) INTEGER */
+/*          Specifies the form of the system of equations. */
+/*          = 0:  A * X = B     (No transpose) */
+/*          = 1:  A**T * X = B  (Transpose) */
+/*          = 2:  A**H * X = B  (Conjugate transpose) */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A. */
+
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand sides, i.e., the number of columns */
+/*          of the matrix B.  NRHS >= 0. */
+
+/*  DL      (input) COMPLEX array, dimension (N-1) */
+/*          The (n-1) multipliers that define the matrix L from the */
+/*          LU factorization of A. */
+
+/*  D       (input) COMPLEX array, dimension (N) */
+/*          The n diagonal elements of the upper triangular matrix U from */
+/*          the LU factorization of A. */
+
+/*  DU      (input) COMPLEX array, dimension (N-1) */
+/*          The (n-1) elements of the first super-diagonal of U. */
+
+/*  DU2     (input) COMPLEX array, dimension (N-2) */
+/*          The (n-2) elements of the second super-diagonal of U. */
+
+/*  IPIV    (input) INTEGER array, dimension (N) */
+/*          The pivot indices; for 1 <= i <= n, row i of the matrix was */
+/*          interchanged with row IPIV(i).  IPIV(i) will always be either */
+/*          i or i+1; IPIV(i) = i indicates a row interchange was not */
+/*          required. */
+
+/*  B       (input/output) COMPLEX array, dimension (LDB,NRHS) */
+/*          On entry, the matrix of right hand side vectors B. */
+/*          On exit, B is overwritten by the solution vectors X. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B.  LDB >= max(1,N). */
+
+/*  ===================================================================== */
+
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Quick return if possible */
+
+    /* Parameter adjustments */
     --dl;
     --d__;
     --du;
@@ -92,8 +104,8 @@
 
     if (*itrans == 0) {
 
-/*        Solve A*X = B using the LU factorization of A,   
-          overwriting each right hand side vector with its solution. */
+/*        Solve A*X = B using the LU factorization of A, */
+/*        overwriting each right hand side vector with its solution. */
 
 	if (*nrhs <= 1) {
 	    j = 1;
