@@ -1,252 +1,274 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static complex c_b2 = {1.f,0.f};
+static integer c__1 = 1;
+static integer c__2 = 2;
 
 /* Subroutine */ int chgeqz_(char *job, char *compq, char *compz, integer *n, 
 	integer *ilo, integer *ihi, complex *h__, integer *ldh, complex *t, 
-	integer *ldt, complex *alpha, complex *beta, complex *q, integer *ldq,
+	integer *ldt, complex *alpha, complex *beta, complex *q, integer *ldq, 
 	 complex *z__, integer *ldz, complex *work, integer *lwork, real *
-	rwork, integer *info  	)
+	rwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CHGEQZ computes the eigenvalues of a complex matrix pair (H,T),   
-    where H is an upper Hessenberg matrix and T is upper triangular,   
-    using the single-shift QZ method.   
-    Matrix pairs of this type are produced by the reduction to   
-    generalized upper Hessenberg form of a complex matrix pair (A,B):   
-
-       A = Q1*H*Z1**H,  B = Q1*T*Z1**H,   
-
-    as computed by CGGHRD.   
-
-    If JOB='S', then the Hessenberg-triangular pair (H,T) is   
-    also reduced to generalized Schur form,   
-
-       H = Q*S*Z**H,  T = Q*P*Z**H,   
-
-    where Q and Z are unitary matrices and S and P are upper triangular.   
-
-    Optionally, the unitary matrix Q from the generalized Schur   
-    factorization may be postmultiplied into an input matrix Q1, and the   
-    unitary matrix Z may be postmultiplied into an input matrix Z1.   
-    If Q1 and Z1 are the unitary matrices from CGGHRD that reduced   
-    the matrix pair (A,B) to generalized Hessenberg form, then the output   
-    matrices Q1*Q and Z1*Z are the unitary factors from the generalized   
-    Schur factorization of (A,B):   
-
-       A = (Q1*Q)*S*(Z1*Z)**H,  B = (Q1*Q)*P*(Z1*Z)**H.   
-
-    To avoid overflow, eigenvalues of the matrix pair (H,T)   
-    (equivalently, of (A,B)) are computed as a pair of complex values   
-    (alpha,beta).  If beta is nonzero, lambda = alpha / beta is an   
-    eigenvalue of the generalized nonsymmetric eigenvalue problem (GNEP)   
-       A*x = lambda*B*x   
-    and if alpha is nonzero, mu = beta / alpha is an eigenvalue of the   
-    alternate form of the GNEP   
-       mu*A*y = B*y.   
-    The values of alpha and beta for the i-th eigenvalue can be read   
-    directly from the generalized Schur form:  alpha = S(i,i),   
-    beta = P(i,i).   
-
-    Ref: C.B. Moler & G.W. Stewart, "An Algorithm for Generalized Matrix   
-         Eigenvalue Problems", SIAM J. Numer. Anal., 10(1973),   
-         pp. 241--256.   
-
-    Arguments   
-    =========   
-
-    JOB     (input) CHARACTER*1   
-            = 'E': Compute eigenvalues only;   
-            = 'S': Computer eigenvalues and the Schur form.   
-
-    COMPQ   (input) CHARACTER*1   
-            = 'N': Left Schur vectors (Q) are not computed;   
-            = 'I': Q is initialized to the unit matrix and the matrix Q   
-                   of left Schur vectors of (H,T) is returned;   
-            = 'V': Q must contain a unitary matrix Q1 on entry and   
-                   the product Q1*Q is returned.   
-
-    COMPZ   (input) CHARACTER*1   
-            = 'N': Right Schur vectors (Z) are not computed;   
-            = 'I': Q is initialized to the unit matrix and the matrix Z   
-                   of right Schur vectors of (H,T) is returned;   
-            = 'V': Z must contain a unitary matrix Z1 on entry and   
-                   the product Z1*Z is returned.   
-
-    N       (input) INTEGER   
-            The order of the matrices H, T, Q, and Z.  N >= 0.   
-
-    ILO     (input) INTEGER   
-    IHI     (input) INTEGER   
-            ILO and IHI mark the rows and columns of H which are in   
-            Hessenberg form.  It is assumed that A is already upper   
-            triangular in rows and columns 1:ILO-1 and IHI+1:N.   
-            If N > 0, 1 <= ILO <= IHI <= N; if N = 0, ILO=1 and IHI=0.   
-
-    H       (input/output) COMPLEX array, dimension (LDH, N)   
-            On entry, the N-by-N upper Hessenberg matrix H.   
-            On exit, if JOB = 'S', H contains the upper triangular   
-            matrix S from the generalized Schur factorization.   
-            If JOB = 'E', the diagonal of H matches that of S, but   
-            the rest of H is unspecified.   
-
-    LDH     (input) INTEGER   
-            The leading dimension of the array H.  LDH >= max( 1, N ).   
-
-    T       (input/output) COMPLEX array, dimension (LDT, N)   
-            On entry, the N-by-N upper triangular matrix T.   
-            On exit, if JOB = 'S', T contains the upper triangular   
-            matrix P from the generalized Schur factorization.   
-            If JOB = 'E', the diagonal of T matches that of P, but   
-            the rest of T is unspecified.   
-
-    LDT     (input) INTEGER   
-            The leading dimension of the array T.  LDT >= max( 1, N ).   
-
-    ALPHA   (output) COMPLEX array, dimension (N)   
-            The complex scalars alpha that define the eigenvalues of   
-            GNEP.  ALPHA(i) = S(i,i) in the generalized Schur   
-            factorization.   
-
-    BETA    (output) COMPLEX array, dimension (N)   
-            The real non-negative scalars beta that define the   
-            eigenvalues of GNEP.  BETA(i) = P(i,i) in the generalized   
-            Schur factorization.   
-
-            Together, the quantities alpha = ALPHA(j) and beta = BETA(j)   
-            represent the j-th eigenvalue of the matrix pair (A,B), in   
-            one of the forms lambda = alpha/beta or mu = beta/alpha.   
-            Since either lambda or mu may overflow, they should not,   
-            in general, be computed.   
-
-    Q       (input/output) COMPLEX array, dimension (LDQ, N)   
-            On entry, if COMPZ = 'V', the unitary matrix Q1 used in the   
-            reduction of (A,B) to generalized Hessenberg form.   
-            On exit, if COMPZ = 'I', the unitary matrix of left Schur   
-            vectors of (H,T), and if COMPZ = 'V', the unitary matrix of   
-            left Schur vectors of (A,B).   
-            Not referenced if COMPZ = 'N'.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of the array Q.  LDQ >= 1.   
-            If COMPQ='V' or 'I', then LDQ >= N.   
-
-    Z       (input/output) COMPLEX array, dimension (LDZ, N)   
-            On entry, if COMPZ = 'V', the unitary matrix Z1 used in the   
-            reduction of (A,B) to generalized Hessenberg form.   
-            On exit, if COMPZ = 'I', the unitary matrix of right Schur   
-            vectors of (H,T), and if COMPZ = 'V', the unitary matrix of   
-            right Schur vectors of (A,B).   
-            Not referenced if COMPZ = 'N'.   
-
-    LDZ     (input) INTEGER   
-            The leading dimension of the array Z.  LDZ >= 1.   
-            If COMPZ='V' or 'I', then LDZ >= N.   
-
-    WORK    (workspace/output) COMPLEX array, dimension (MAX(1,LWORK))   
-            On exit, if INFO >= 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,N).   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    RWORK   (workspace) REAL array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            < 0: if INFO = -i, the i-th argument had an illegal value   
-            = 1,...,N: the QZ iteration did not converge.  (H,T) is not   
-                       in Schur form, but ALPHA(i) and BETA(i),   
-                       i=INFO+1,...,N should be correct.   
-            = N+1,...,2*N: the shift calculation failed.  (H,T) is not   
-                       in Schur form, but ALPHA(i) and BETA(i),   
-                       i=INFO-N+1,...,N should be correct.   
-
-    Further Details   
-    ===============   
-
-    We assume that complex ABS works as long as its value is less than   
-    overflow.   
-
-    =====================================================================   
-
-
-       Decode JOB, COMPQ, COMPZ   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static complex c_b2 = {1.f,0.f};
-    static integer c__1 = 1;
-    static integer c__2 = 2;
-    
     /* System generated locals */
     integer h_dim1, h_offset, q_dim1, q_offset, t_dim1, t_offset, z_dim1, 
 	    z_offset, i__1, i__2, i__3, i__4, i__5, i__6;
     real r__1, r__2, r__3, r__4, r__5, r__6;
     complex q__1, q__2, q__3, q__4, q__5, q__6;
+
     /* Builtin functions */
     double c_abs(complex *);
     void r_cnjg(complex *, complex *);
     double r_imag(complex *);
     void c_div(complex *, complex *, complex *), pow_ci(complex *, complex *, 
 	    integer *), c_sqrt(complex *, complex *);
+
     /* Local variables */
-    static real c__;
-    static integer j;
-    static complex s, t1;
-    static integer jc, in;
-    static complex u12;
-    static integer jr;
-    static complex ad11, ad12, ad21, ad22;
-    static integer jch;
-    static logical ilq, ilz;
-    static real ulp;
-    static complex abi22;
-    static real absb, atol, btol, temp;
+    real c__;
+    integer j;
+    complex s, t1;
+    integer jc, in;
+    complex u12;
+    integer jr;
+    complex ad11, ad12, ad21, ad22;
+    integer jch;
+    logical ilq, ilz;
+    real ulp;
+    complex abi22;
+    real absb, atol, btol, temp;
     extern /* Subroutine */ int crot_(integer *, complex *, integer *, 
 	    complex *, integer *, real *, complex *);
-    static real temp2;
+    real temp2;
     extern /* Subroutine */ int cscal_(integer *, complex *, complex *, 
 	    integer *);
     extern logical lsame_(char *, char *);
-    static complex ctemp;
-    static integer iiter, ilast, jiter;
-    static real anorm, bnorm;
-    static integer maxit;
-    static complex shift;
-    static real tempr;
-    static complex ctemp2, ctemp3;
-    static logical ilazr2;
-    static real ascale, bscale;
-    static complex signbc;
+    complex ctemp;
+    integer iiter, ilast, jiter;
+    real anorm, bnorm;
+    integer maxit;
+    complex shift;
+    real tempr;
+    complex ctemp2, ctemp3;
+    logical ilazr2;
+    real ascale, bscale;
+    complex signbc;
     extern doublereal slamch_(char *), clanhs_(char *, integer *, 
 	    complex *, integer *, real *);
     extern /* Subroutine */ int claset_(char *, integer *, integer *, complex 
 	    *, complex *, complex *, integer *), clartg_(complex *, 
 	    complex *, real *, complex *, complex *);
-    static real safmin;
+    real safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static complex eshift;
-    static logical ilschr;
-    static integer icompq, ilastm;
-    static complex rtdisc;
-    static integer ischur;
-    static logical ilazro;
-    static integer icompz, ifirst, ifrstm, istart;
-    static logical lquery;
+    complex eshift;
+    logical ilschr;
+    integer icompq, ilastm;
+    complex rtdisc;
+    integer ischur;
+    logical ilazro;
+    integer icompz, ifirst, ifrstm, istart;
+    logical lquery;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CHGEQZ computes the eigenvalues of a complex matrix pair (H,T), */
+/*  where H is an upper Hessenberg matrix and T is upper triangular, */
+/*  using the single-shift QZ method. */
+/*  Matrix pairs of this type are produced by the reduction to */
+/*  generalized upper Hessenberg form of a complex matrix pair (A,B): */
+
+/*     A = Q1*H*Z1**H,  B = Q1*T*Z1**H, */
+
+/*  as computed by CGGHRD. */
+
+/*  If JOB='S', then the Hessenberg-triangular pair (H,T) is */
+/*  also reduced to generalized Schur form, */
+
+/*     H = Q*S*Z**H,  T = Q*P*Z**H, */
+
+/*  where Q and Z are unitary matrices and S and P are upper triangular. */
+
+/*  Optionally, the unitary matrix Q from the generalized Schur */
+/*  factorization may be postmultiplied into an input matrix Q1, and the */
+/*  unitary matrix Z may be postmultiplied into an input matrix Z1. */
+/*  If Q1 and Z1 are the unitary matrices from CGGHRD that reduced */
+/*  the matrix pair (A,B) to generalized Hessenberg form, then the output */
+/*  matrices Q1*Q and Z1*Z are the unitary factors from the generalized */
+/*  Schur factorization of (A,B): */
+
+/*     A = (Q1*Q)*S*(Z1*Z)**H,  B = (Q1*Q)*P*(Z1*Z)**H. */
+
+/*  To avoid overflow, eigenvalues of the matrix pair (H,T) */
+/*  (equivalently, of (A,B)) are computed as a pair of complex values */
+/*  (alpha,beta).  If beta is nonzero, lambda = alpha / beta is an */
+/*  eigenvalue of the generalized nonsymmetric eigenvalue problem (GNEP) */
+/*     A*x = lambda*B*x */
+/*  and if alpha is nonzero, mu = beta / alpha is an eigenvalue of the */
+/*  alternate form of the GNEP */
+/*     mu*A*y = B*y. */
+/*  The values of alpha and beta for the i-th eigenvalue can be read */
+/*  directly from the generalized Schur form:  alpha = S(i,i), */
+/*  beta = P(i,i). */
+
+/*  Ref: C.B. Moler & G.W. Stewart, "An Algorithm for Generalized Matrix */
+/*       Eigenvalue Problems", SIAM J. Numer. Anal., 10(1973), */
+/*       pp. 241--256. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOB     (input) CHARACTER*1 */
+/*          = 'E': Compute eigenvalues only; */
+/*          = 'S': Computer eigenvalues and the Schur form. */
+
+/*  COMPQ   (input) CHARACTER*1 */
+/*          = 'N': Left Schur vectors (Q) are not computed; */
+/*          = 'I': Q is initialized to the unit matrix and the matrix Q */
+/*                 of left Schur vectors of (H,T) is returned; */
+/*          = 'V': Q must contain a unitary matrix Q1 on entry and */
+/*                 the product Q1*Q is returned. */
+
+/*  COMPZ   (input) CHARACTER*1 */
+/*          = 'N': Right Schur vectors (Z) are not computed; */
+/*          = 'I': Q is initialized to the unit matrix and the matrix Z */
+/*                 of right Schur vectors of (H,T) is returned; */
+/*          = 'V': Z must contain a unitary matrix Z1 on entry and */
+/*                 the product Z1*Z is returned. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices H, T, Q, and Z.  N >= 0. */
+
+/*  ILO     (input) INTEGER */
+/*  IHI     (input) INTEGER */
+/*          ILO and IHI mark the rows and columns of H which are in */
+/*          Hessenberg form.  It is assumed that A is already upper */
+/*          triangular in rows and columns 1:ILO-1 and IHI+1:N. */
+/*          If N > 0, 1 <= ILO <= IHI <= N; if N = 0, ILO=1 and IHI=0. */
+
+/*  H       (input/output) COMPLEX array, dimension (LDH, N) */
+/*          On entry, the N-by-N upper Hessenberg matrix H. */
+/*          On exit, if JOB = 'S', H contains the upper triangular */
+/*          matrix S from the generalized Schur factorization. */
+/*          If JOB = 'E', the diagonal of H matches that of S, but */
+/*          the rest of H is unspecified. */
+
+/*  LDH     (input) INTEGER */
+/*          The leading dimension of the array H.  LDH >= max( 1, N ). */
+
+/*  T       (input/output) COMPLEX array, dimension (LDT, N) */
+/*          On entry, the N-by-N upper triangular matrix T. */
+/*          On exit, if JOB = 'S', T contains the upper triangular */
+/*          matrix P from the generalized Schur factorization. */
+/*          If JOB = 'E', the diagonal of T matches that of P, but */
+/*          the rest of T is unspecified. */
+
+/*  LDT     (input) INTEGER */
+/*          The leading dimension of the array T.  LDT >= max( 1, N ). */
+
+/*  ALPHA   (output) COMPLEX array, dimension (N) */
+/*          The complex scalars alpha that define the eigenvalues of */
+/*          GNEP.  ALPHA(i) = S(i,i) in the generalized Schur */
+/*          factorization. */
+
+/*  BETA    (output) COMPLEX array, dimension (N) */
+/*          The real non-negative scalars beta that define the */
+/*          eigenvalues of GNEP.  BETA(i) = P(i,i) in the generalized */
+/*          Schur factorization. */
+
+/*          Together, the quantities alpha = ALPHA(j) and beta = BETA(j) */
+/*          represent the j-th eigenvalue of the matrix pair (A,B), in */
+/*          one of the forms lambda = alpha/beta or mu = beta/alpha. */
+/*          Since either lambda or mu may overflow, they should not, */
+/*          in general, be computed. */
+
+/*  Q       (input/output) COMPLEX array, dimension (LDQ, N) */
+/*          On entry, if COMPZ = 'V', the unitary matrix Q1 used in the */
+/*          reduction of (A,B) to generalized Hessenberg form. */
+/*          On exit, if COMPZ = 'I', the unitary matrix of left Schur */
+/*          vectors of (H,T), and if COMPZ = 'V', the unitary matrix of */
+/*          left Schur vectors of (A,B). */
+/*          Not referenced if COMPZ = 'N'. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of the array Q.  LDQ >= 1. */
+/*          If COMPQ='V' or 'I', then LDQ >= N. */
+
+/*  Z       (input/output) COMPLEX array, dimension (LDZ, N) */
+/*          On entry, if COMPZ = 'V', the unitary matrix Z1 used in the */
+/*          reduction of (A,B) to generalized Hessenberg form. */
+/*          On exit, if COMPZ = 'I', the unitary matrix of right Schur */
+/*          vectors of (H,T), and if COMPZ = 'V', the unitary matrix of */
+/*          right Schur vectors of (A,B). */
+/*          Not referenced if COMPZ = 'N'. */
+
+/*  LDZ     (input) INTEGER */
+/*          The leading dimension of the array Z.  LDZ >= 1. */
+/*          If COMPZ='V' or 'I', then LDZ >= N. */
+
+/*  WORK    (workspace/output) COMPLEX array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO >= 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,N). */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  RWORK   (workspace) REAL array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          < 0: if INFO = -i, the i-th argument had an illegal value */
+/*          = 1,...,N: the QZ iteration did not converge.  (H,T) is not */
+/*                     in Schur form, but ALPHA(i) and BETA(i), */
+/*                     i=INFO+1,...,N should be correct. */
+/*          = N+1,...,2*N: the shift calculation failed.  (H,T) is not */
+/*                     in Schur form, but ALPHA(i) and BETA(i), */
+/*                     i=INFO-N+1,...,N should be correct. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  We assume that complex ABS works as long as its value is less than */
+/*  overflow. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode JOB, COMPQ, COMPZ */
+
+    /* Parameter adjustments */
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
     h__ -= h_offset;
@@ -338,9 +360,9 @@
 	return 0;
     }
 
-/*     Quick return if possible   
+/*     Quick return if possible */
 
-       WORK( 1 ) = CMPLX( 1 ) */
+/*     WORK( 1 ) = CMPLX( 1 ) */
     if (*n <= 0) {
 	work[1].r = 1.f, work[1].i = 0.f;
 	return 0;
@@ -418,20 +440,20 @@
 	goto L190;
     }
 
-/*     MAIN QZ ITERATION LOOP   
+/*     MAIN QZ ITERATION LOOP */
 
-       Initialize dynamic indices   
+/*     Initialize dynamic indices */
 
-       Eigenvalues ILAST+1:N have been found.   
-          Column operations modify rows IFRSTM:whatever   
-          Row operations modify columns whatever:ILASTM   
+/*     Eigenvalues ILAST+1:N have been found. */
+/*        Column operations modify rows IFRSTM:whatever */
+/*        Row operations modify columns whatever:ILASTM */
 
-       If only eigenvalues are being computed, then   
-          IFRSTM is the row of the last splitting row above row ILAST;   
-          this is always at least ILO.   
-       IITER counts iterations since the last eigenvalue was found,   
-          to tell when to use an extraordinary shift.   
-       MAXIT is the maximum number of QZ sweeps allowed. */
+/*     If only eigenvalues are being computed, then */
+/*        IFRSTM is the row of the last splitting row above row ILAST; */
+/*        this is always at least ILO. */
+/*     IITER counts iterations since the last eigenvalue was found, */
+/*        to tell when to use an extraordinary shift. */
+/*     MAXIT is the maximum number of QZ sweeps allowed. */
 
     ilast = *ihi;
     if (ilschr) {
@@ -454,13 +476,13 @@
 	    goto L180;
 	}
 
-/*        Split the matrix if possible.   
+/*        Split the matrix if possible. */
 
-          Two tests:   
-             1: H(j,j-1)=0  or  j=ILO   
-             2: T(j,j)=0   
+/*        Two tests: */
+/*           1: H(j,j-1)=0  or  j=ILO */
+/*           2: T(j,j)=0 */
 
-          Special case: j=ILAST */
+/*        Special case: j=ILAST */
 
 	if (ilast == *ilo) {
 	    goto L60;
@@ -525,11 +547,11 @@
 		    }
 		}
 
-/*              If both tests pass (1 & 2), i.e., the leading diagonal   
-                element of B in the block is zero, split a 1x1 block off   
-                at the top. (I.e., at the J-th row/column) The leading   
-                diagonal element of the remainder can also be zero, so   
-                this may have to be done repeatedly. */
+/*              If both tests pass (1 & 2), i.e., the leading diagonal */
+/*              element of B in the block is zero, split a 1x1 block off */
+/*              at the top. (I.e., at the J-th row/column) The leading */
+/*              diagonal element of the remainder can also be zero, so */
+/*              this may have to be done repeatedly. */
 
 		if (ilazro || ilazr2) {
 		    i__3 = ilast - 1;
@@ -578,8 +600,8 @@
 		    goto L50;
 		} else {
 
-/*                 Only test 2 passed -- chase the zero to T(ILAST,ILAST)   
-                   Then process as in the case T(ILAST,ILAST)=0 */
+/*                 Only test 2 passed -- chase the zero to T(ILAST,ILAST) */
+/*                 Then process as in the case T(ILAST,ILAST)=0 */
 
 		    i__3 = ilast - 1;
 		    for (jch = j; jch <= i__3; ++jch) {
@@ -634,9 +656,9 @@
 		goto L70;
 	    }
 
-/*           Neither test passed -- try next J   
+/*           Neither test passed -- try next J */
 
-   L40: */
+/* L40: */
 	}
 
 /*        (Drop-through is "impossible") */
@@ -644,8 +666,8 @@
 	*info = (*n << 1) + 1;
 	goto L210;
 
-/*        T(ILAST,ILAST)=0 -- clear H(ILAST,ILAST-1) to split off a   
-          1x1 block. */
+/*        T(ILAST,ILAST)=0 -- clear H(ILAST,ILAST-1) to split off a */
+/*        1x1 block. */
 
 L50:
 	i__2 = ilast + ilast * h_dim1;
@@ -722,10 +744,10 @@ L60:
 	}
 	goto L160;
 
-/*        QZ step   
+/*        QZ step */
 
-          This iteration only involves rows/columns IFIRST:ILAST.  We   
-          assume IFIRST < ILAST, and that the diagonal of B is non-zero. */
+/*        This iteration only involves rows/columns IFIRST:ILAST.  We */
+/*        assume IFIRST < ILAST, and that the diagonal of B is non-zero. */
 
 L70:
 	++iiter;
@@ -733,20 +755,20 @@ L70:
 	    ifrstm = ifirst;
 	}
 
-/*        Compute the Shift.   
+/*        Compute the Shift. */
 
-          At this point, IFIRST < ILAST, and the diagonal elements of   
-          T(IFIRST:ILAST,IFIRST,ILAST) are larger than BTOL (in   
-          magnitude) */
+/*        At this point, IFIRST < ILAST, and the diagonal elements of */
+/*        T(IFIRST:ILAST,IFIRST,ILAST) are larger than BTOL (in */
+/*        magnitude) */
 
 	if (iiter / 10 * 10 != iiter) {
 
-/*           The Wilkinson shift (AEP p.512), i.e., the eigenvalue of   
-             the bottom-right 2x2 block of A inv(B) which is nearest to   
-             the bottom-right element.   
+/*           The Wilkinson shift (AEP p.512), i.e., the eigenvalue of */
+/*           the bottom-right 2x2 block of A inv(B) which is nearest to */
+/*           the bottom-right element. */
 
-             We factor B as U*D, where U has unit diagonals, and   
-             compute (A*inv(D))*inv(U). */
+/*           We factor B as U*D, where U has unit diagonals, and */
+/*           compute (A*inv(D))*inv(U). */
 
 	    i__2 = ilast - 1 + ilast * t_dim1;
 	    q__2.r = bscale * t[i__2].r, q__2.i = bscale * t[i__2].i;
@@ -862,9 +884,9 @@ L70:
 	ctemp.r = q__1.r, ctemp.i = q__1.i;
 L90:
 
-/*        Do an implicit-shift QZ sweep.   
+/*        Do an implicit-shift QZ sweep. */
 
-          Initial Q */
+/*        Initial Q */
 
 	i__2 = istart + 1 + istart * h_dim1;
 	q__1.r = ascale * h__[i__2].r, q__1.i = ascale * h__[i__2].i;
