@@ -1,152 +1,174 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
 
 /* Subroutine */ int chptrf_(char *uplo, integer *n, complex *ap, integer *
 	ipiv, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CHPTRF computes the factorization of a complex Hermitian packed   
-    matrix A using the Bunch-Kaufman diagonal pivoting method:   
-
-       A = U*D*U**H  or  A = L*D*L**H   
-
-    where U (or L) is a product of permutation and unit upper (lower)   
-    triangular matrices, and D is Hermitian and block diagonal with   
-    1-by-1 and 2-by-2 diagonal blocks.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            = 'U':  Upper triangle of A is stored;   
-            = 'L':  Lower triangle of A is stored.   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    AP      (input/output) COMPLEX array, dimension (N*(N+1)/2)   
-            On entry, the upper or lower triangle of the Hermitian matrix   
-            A, packed columnwise in a linear array.  The j-th column of A   
-            is stored in the array AP as follows:   
-            if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;   
-            if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.   
-
-            On exit, the block diagonal matrix D and the multipliers used   
-            to obtain the factor U or L, stored as a packed triangular   
-            matrix overwriting A (see below for further details).   
-
-    IPIV    (output) INTEGER array, dimension (N)   
-            Details of the interchanges and the block structure of D.   
-            If IPIV(k) > 0, then rows and columns k and IPIV(k) were   
-            interchanged and D(k,k) is a 1-by-1 diagonal block.   
-            If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and   
-            columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)   
-            is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =   
-            IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were   
-            interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            < 0: if INFO = -i, the i-th argument had an illegal value   
-            > 0: if INFO = i, D(i,i) is exactly zero.  The factorization   
-                 has been completed, but the block diagonal matrix D is   
-                 exactly singular, and division by zero will occur if it   
-                 is used to solve a system of equations.   
-
-    Further Details   
-    ===============   
-
-    5-96 - Based on modifications by J. Lewis, Boeing Computer Services   
-           Company   
-
-    If UPLO = 'U', then A = U*D*U', where   
-       U = P(n)*U(n)* ... *P(k)U(k)* ...,   
-    i.e., U is a product of terms P(k)*U(k), where k decreases from n to   
-    1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1   
-    and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as   
-    defined by IPIV(k), and U(k) is a unit upper triangular matrix, such   
-    that if the diagonal block D(k) is of order s (s = 1 or 2), then   
-
-               (   I    v    0   )   k-s   
-       U(k) =  (   0    I    0   )   s   
-               (   0    0    I   )   n-k   
-                  k-s   s   n-k   
-
-    If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).   
-    If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),   
-    and A(k,k), and v overwrites A(1:k-2,k-1:k).   
-
-    If UPLO = 'L', then A = L*D*L', where   
-       L = P(1)*L(1)* ... *P(k)*L(k)* ...,   
-    i.e., L is a product of terms P(k)*L(k), where k increases from 1 to   
-    n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1   
-    and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as   
-    defined by IPIV(k), and L(k) is a unit lower triangular matrix, such   
-    that if the diagonal block D(k) is of order s (s = 1 or 2), then   
-
-               (   I    0     0   )  k-1   
-       L(k) =  (   0    I     0   )  s   
-               (   0    v     I   )  n-k-s+1   
-                  k-1   s  n-k-s+1   
-
-    If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).   
-    If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),   
-    and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer i__1, i__2, i__3, i__4, i__5, i__6;
     real r__1, r__2, r__3, r__4;
     complex q__1, q__2, q__3, q__4, q__5, q__6;
+
     /* Builtin functions */
     double sqrt(doublereal), r_imag(complex *);
     void r_cnjg(complex *, complex *);
+
     /* Local variables */
-    static real d__;
-    static integer i__, j, k;
-    static complex t;
-    static real r1, d11;
-    static complex d12;
-    static real d22;
-    static complex d21;
-    static integer kc, kk, kp;
-    static complex wk;
-    static integer kx;
-    static real tt;
-    static integer knc, kpc, npp;
-    static complex wkm1, wkp1;
+    real d__;
+    integer i__, j, k;
+    complex t;
+    real r1, d11;
+    complex d12;
+    real d22;
+    complex d21;
+    integer kc, kk, kp;
+    complex wk;
+    integer kx;
+    real tt;
+    integer knc, kpc, npp;
+    complex wkm1, wkp1;
     extern /* Subroutine */ int chpr_(char *, integer *, real *, complex *, 
 	    integer *, complex *);
-    static integer imax, jmax;
-    static real alpha;
+    integer imax, jmax;
+    real alpha;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int cswap_(integer *, complex *, integer *, 
 	    complex *, integer *);
-    static integer kstep;
-    static logical upper;
+    integer kstep;
+    logical upper;
     extern doublereal slapy2_(real *, real *);
-    static real absakk;
+    real absakk;
     extern integer icamax_(integer *, complex *, integer *);
     extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
 	    *), xerbla_(char *, integer *);
-    static real colmax, rowmax;
+    real colmax, rowmax;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CHPTRF computes the factorization of a complex Hermitian packed */
+/*  matrix A using the Bunch-Kaufman diagonal pivoting method: */
+
+/*     A = U*D*U**H  or  A = L*D*L**H */
+
+/*  where U (or L) is a product of permutation and unit upper (lower) */
+/*  triangular matrices, and D is Hermitian and block diagonal with */
+/*  1-by-1 and 2-by-2 diagonal blocks. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          = 'U':  Upper triangle of A is stored; */
+/*          = 'L':  Lower triangle of A is stored. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  AP      (input/output) COMPLEX array, dimension (N*(N+1)/2) */
+/*          On entry, the upper or lower triangle of the Hermitian matrix */
+/*          A, packed columnwise in a linear array.  The j-th column of A */
+/*          is stored in the array AP as follows: */
+/*          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j; */
+/*          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n. */
+
+/*          On exit, the block diagonal matrix D and the multipliers used */
+/*          to obtain the factor U or L, stored as a packed triangular */
+/*          matrix overwriting A (see below for further details). */
+
+/*  IPIV    (output) INTEGER array, dimension (N) */
+/*          Details of the interchanges and the block structure of D. */
+/*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were */
+/*          interchanged and D(k,k) is a 1-by-1 diagonal block. */
+/*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and */
+/*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k) */
+/*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) = */
+/*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were */
+/*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          < 0: if INFO = -i, the i-th argument had an illegal value */
+/*          > 0: if INFO = i, D(i,i) is exactly zero.  The factorization */
+/*               has been completed, but the block diagonal matrix D is */
+/*               exactly singular, and division by zero will occur if it */
+/*               is used to solve a system of equations. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  5-96 - Based on modifications by J. Lewis, Boeing Computer Services */
+/*         Company */
+
+/*  If UPLO = 'U', then A = U*D*U', where */
+/*     U = P(n)*U(n)* ... *P(k)U(k)* ..., */
+/*  i.e., U is a product of terms P(k)*U(k), where k decreases from n to */
+/*  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1 */
+/*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as */
+/*  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such */
+/*  that if the diagonal block D(k) is of order s (s = 1 or 2), then */
+
+/*             (   I    v    0   )   k-s */
+/*     U(k) =  (   0    I    0   )   s */
+/*             (   0    0    I   )   n-k */
+/*                k-s   s   n-k */
+
+/*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k). */
+/*  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k), */
+/*  and A(k,k), and v overwrites A(1:k-2,k-1:k). */
+
+/*  If UPLO = 'L', then A = L*D*L', where */
+/*     L = P(1)*L(1)* ... *P(k)*L(k)* ..., */
+/*  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to */
+/*  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1 */
+/*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as */
+/*  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such */
+/*  that if the diagonal block D(k) is of order s (s = 1 or 2), then */
+
+/*             (   I    0     0   )  k-1 */
+/*     L(k) =  (   0    I     0   )  s */
+/*             (   0    v     I   )  n-k-s+1 */
+/*                k-1   s  n-k-s+1 */
+
+/*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k). */
+/*  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k), */
+/*  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     --ipiv;
     --ap;
 
@@ -170,10 +192,10 @@
 
     if (upper) {
 
-/*        Factorize A as U*D*U' using the upper triangle of A   
+/*        Factorize A as U*D*U' using the upper triangle of A */
 
-          K is the main loop index, decreasing from N to 1 in steps of   
-          1 or 2 */
+/*        K is the main loop index, decreasing from N to 1 in steps of */
+/*        1 or 2 */
 
 	k = *n;
 	kc = (*n - 1) * *n / 2 + 1;
@@ -187,14 +209,14 @@ L10:
 	}
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	i__1 = kc + k - 1;
 	absakk = (r__1 = ap[i__1].r, dabs(r__1));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k > 1) {
 	    i__1 = k - 1;
@@ -226,8 +248,8 @@ L10:
 		kp = k;
 	    } else {
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		rowmax = 0.f;
 		jmax = imax;
@@ -265,14 +287,14 @@ L10:
 		    i__1 = kpc + imax - 1;
 		    if ((r__1 = ap[i__1].r, dabs(r__1)) >= alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 			kp = imax;
 		    } else {
 
-/*                 interchange rows and columns K-1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K-1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 			kp = imax;
 			kstep = 2;
@@ -286,8 +308,8 @@ L10:
 	    }
 	    if (kp != kk) {
 
-/*              Interchange rows and columns KK and KP in the leading   
-                submatrix A(1:k,1:k) */
+/*              Interchange rows and columns KK and KP in the leading */
+/*              submatrix A(1:k,1:k) */
 
 		i__1 = kp - 1;
 		cswap_(&i__1, &ap[knc], &c__1, &ap[kpc], &c__1);
@@ -345,15 +367,15 @@ L10:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k now holds   
+/*              1-by-1 pivot block D(k): column k now holds */
 
-                W(k) = U(k)*D(k)   
+/*              W(k) = U(k)*D(k) */
 
-                where U(k) is the k-th column of U   
+/*              where U(k) is the k-th column of U */
 
-                Perform a rank-1 update of A(1:k-1,1:k-1) as   
+/*              Perform a rank-1 update of A(1:k-1,1:k-1) as */
 
-                A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)' */
+/*              A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)' */
 
 		i__1 = kc + k - 1;
 		r1 = 1.f / ap[i__1].r;
@@ -367,17 +389,17 @@ L10:
 		csscal_(&i__1, &r1, &ap[kc], &c__1);
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns k and k-1 now hold   
+/*              2-by-2 pivot block D(k): columns k and k-1 now hold */
 
-                ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k)   
+/*              ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k) */
 
-                where U(k) and U(k-1) are the k-th and (k-1)-th columns   
-                of U   
+/*              where U(k) and U(k-1) are the k-th and (k-1)-th columns */
+/*              of U */
 
-                Perform a rank-2 update of A(1:k-2,1:k-2) as   
+/*              Perform a rank-2 update of A(1:k-2,1:k-2) as */
 
-                A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )'   
-                   = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )' */
+/*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )' */
+/*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )' */
 
 		if (k > 2) {
 
@@ -469,10 +491,10 @@ L10:
 
     } else {
 
-/*        Factorize A as L*D*L' using the lower triangle of A   
+/*        Factorize A as L*D*L' using the lower triangle of A */
 
-          K is the main loop index, increasing from 1 to N in steps of   
-          1 or 2 */
+/*        K is the main loop index, increasing from 1 to N in steps of */
+/*        1 or 2 */
 
 	k = 1;
 	kc = 1;
@@ -487,14 +509,14 @@ L60:
 	}
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	i__1 = kc;
 	absakk = (r__1 = ap[i__1].r, dabs(r__1));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k < *n) {
 	    i__1 = *n - k;
@@ -526,8 +548,8 @@ L60:
 		kp = k;
 	    } else {
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		rowmax = 0.f;
 		kx = kc + imax - k;
@@ -565,14 +587,14 @@ L60:
 		    i__1 = kpc;
 		    if ((r__1 = ap[i__1].r, dabs(r__1)) >= alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 			kp = imax;
 		    } else {
 
-/*                 interchange rows and columns K+1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K+1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 			kp = imax;
 			kstep = 2;
@@ -586,8 +608,8 @@ L60:
 	    }
 	    if (kp != kk) {
 
-/*              Interchange rows and columns KK and KP in the trailing   
-                submatrix A(k:n,k:n) */
+/*              Interchange rows and columns KK and KP in the trailing */
+/*              submatrix A(k:n,k:n) */
 
 		if (kp < *n) {
 		    i__1 = *n - kp;
@@ -648,17 +670,17 @@ L60:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k now holds   
+/*              1-by-1 pivot block D(k): column k now holds */
 
-                W(k) = L(k)*D(k)   
+/*              W(k) = L(k)*D(k) */
 
-                where L(k) is the k-th column of L */
+/*              where L(k) is the k-th column of L */
 
 		if (k < *n) {
 
-/*                 Perform a rank-1 update of A(k+1:n,k+1:n) as   
+/*                 Perform a rank-1 update of A(k+1:n,k+1:n) as */
 
-                   A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)' */
+/*                 A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)' */
 
 		    i__1 = kc;
 		    r1 = 1.f / ap[i__1].r;
@@ -674,22 +696,22 @@ L60:
 		}
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns K and K+1 now hold   
+/*              2-by-2 pivot block D(k): columns K and K+1 now hold */
 
-                ( W(k) W(k+1) ) = ( L(k) L(k+1) )*D(k)   
+/*              ( W(k) W(k+1) ) = ( L(k) L(k+1) )*D(k) */
 
-                where L(k) and L(k+1) are the k-th and (k+1)-th columns   
-                of L */
+/*              where L(k) and L(k+1) are the k-th and (k+1)-th columns */
+/*              of L */
 
 		if (k < *n - 1) {
 
-/*                 Perform a rank-2 update of A(k+2:n,k+2:n) as   
+/*                 Perform a rank-2 update of A(k+2:n,k+2:n) as */
 
-                   A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )'   
-                      = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )'   
+/*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )' */
+/*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )' */
 
-                   where L(k) and L(k+1) are the k-th and (k+1)-th   
-                   columns of L */
+/*                 where L(k) and L(k+1) are the k-th and (k+1)-th */
+/*                 columns of L */
 
 		    i__1 = k + 1 + (k - 1) * ((*n << 1) - k) / 2;
 		    r__1 = ap[i__1].r;
