@@ -1,169 +1,193 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static integer c__2 = 2;
 
 /* Subroutine */ int clahqr_(logical *wantt, logical *wantz, integer *n, 
 	integer *ilo, integer *ihi, complex *h__, integer *ldh, complex *w, 
 	integer *iloz, integer *ihiz, complex *z__, integer *ldz, integer *
 	info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-       Purpose   
-       =======   
-
-       CLAHQR is an auxiliary routine called by CHSEQR to update the   
-       eigenvalues and Schur decomposition already computed by CHSEQR, by   
-       dealing with the Hessenberg submatrix in rows and columns ILO to   
-       IHI.   
-
-       Arguments   
-       =========   
-
-       WANTT   (input) LOGICAL   
-            = .TRUE. : the full Schur form T is required;   
-            = .FALSE.: only eigenvalues are required.   
-
-       WANTZ   (input) LOGICAL   
-            = .TRUE. : the matrix of Schur vectors Z is required;   
-            = .FALSE.: Schur vectors are not required.   
-
-       N       (input) INTEGER   
-            The order of the matrix H.  N >= 0.   
-
-       ILO     (input) INTEGER   
-       IHI     (input) INTEGER   
-            It is assumed that H is already upper triangular in rows and   
-            columns IHI+1:N, and that H(ILO,ILO-1) = 0 (unless ILO = 1).   
-            CLAHQR works primarily with the Hessenberg submatrix in rows   
-            and columns ILO to IHI, but applies transformations to all of   
-            H if WANTT is .TRUE..   
-            1 <= ILO <= max(1,IHI); IHI <= N.   
-
-       H       (input/output) COMPLEX array, dimension (LDH,N)   
-            On entry, the upper Hessenberg matrix H.   
-            On exit, if INFO is zero and if WANTT is .TRUE., then H   
-            is upper triangular in rows and columns ILO:IHI.  If INFO   
-            is zero and if WANTT is .FALSE., then the contents of H   
-            are unspecified on exit.  The output state of H in case   
-            INF is positive is below under the description of INFO.   
-
-       LDH     (input) INTEGER   
-            The leading dimension of the array H. LDH >= max(1,N).   
-
-       W       (output) COMPLEX array, dimension (N)   
-            The computed eigenvalues ILO to IHI are stored in the   
-            corresponding elements of W. If WANTT is .TRUE., the   
-            eigenvalues are stored in the same order as on the diagonal   
-            of the Schur form returned in H, with W(i) = H(i,i).   
-
-       ILOZ    (input) INTEGER   
-       IHIZ    (input) INTEGER   
-            Specify the rows of Z to which transformations must be   
-            applied if WANTZ is .TRUE..   
-            1 <= ILOZ <= ILO; IHI <= IHIZ <= N.   
-
-       Z       (input/output) COMPLEX array, dimension (LDZ,N)   
-            If WANTZ is .TRUE., on entry Z must contain the current   
-            matrix Z of transformations accumulated by CHSEQR, and on   
-            exit Z has been updated; transformations are applied only to   
-            the submatrix Z(ILOZ:IHIZ,ILO:IHI).   
-            If WANTZ is .FALSE., Z is not referenced.   
-
-       LDZ     (input) INTEGER   
-            The leading dimension of the array Z. LDZ >= max(1,N).   
-
-       INFO    (output) INTEGER   
-             =   0: successful exit   
-            .GT. 0: if INFO = i, CLAHQR failed to compute all the   
-                    eigenvalues ILO to IHI in a total of 30 iterations   
-                    per eigenvalue; elements i+1:ihi of W contain   
-                    those eigenvalues which have been successfully   
-                    computed.   
-
-                    If INFO .GT. 0 and WANTT is .FALSE., then on exit,   
-                    the remaining unconverged eigenvalues are the   
-                    eigenvalues of the upper Hessenberg matrix   
-                    rows and columns ILO thorugh INFO of the final,   
-                    output value of H.   
-
-                    If INFO .GT. 0 and WANTT is .TRUE., then on exit   
-            (*)       (initial value of H)*U  = U*(final value of H)   
-                    where U is an orthognal matrix.    The final   
-                    value of H is upper Hessenberg and triangular in   
-                    rows and columns INFO+1 through IHI.   
-
-                    If INFO .GT. 0 and WANTZ is .TRUE., then on exit   
-                        (final value of Z)  = (initial value of Z)*U   
-                    where U is the orthogonal matrix in (*)   
-                    (regardless of the value of WANTT.)   
-
-       Further Details   
-       ===============   
-
-       02-96 Based on modifications by   
-       David Day, Sandia National Laboratory, USA   
-
-       12-04 Further modifications by   
-       Ralph Byers, University of Kansas, USA   
-
-         This is a modified version of CLAHQR from LAPACK version 3.0.   
-         It is (1) more robust against overflow and underflow and   
-         (2) adopts the more conservative Ahues & Tisseur stopping   
-         criterion (LAWN 122, 1997).   
-
-       =========================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static integer c__2 = 2;
-    
     /* System generated locals */
     integer h_dim1, h_offset, z_dim1, z_offset, i__1, i__2, i__3, i__4;
     real r__1, r__2, r__3, r__4, r__5, r__6;
     complex q__1, q__2, q__3, q__4, q__5, q__6, q__7;
+
     /* Builtin functions */
     double r_imag(complex *);
     void r_cnjg(complex *, complex *);
     double c_abs(complex *);
     void c_sqrt(complex *, complex *), pow_ci(complex *, complex *, integer *)
 	    ;
+
     /* Local variables */
-    static integer i__, j, k, l, m;
-    static real s;
-    static complex t, u, v[2], x, y;
-    static integer i1, i2;
-    static complex t1;
-    static real t2;
-    static complex v2;
-    static real aa, ab, ba, bb, h10;
-    static complex h11;
-    static real h21;
-    static complex h22, sc;
-    static integer nh, nz;
-    static real sx;
-    static integer jhi;
-    static complex h11s;
-    static integer jlo, its;
-    static real ulp;
-    static complex sum;
-    static real tst;
-    static complex temp;
+    integer i__, j, k, l, m;
+    real s;
+    complex t, u, v[2], x, y;
+    integer i1, i2;
+    complex t1;
+    real t2;
+    complex v2;
+    real aa, ab, ba, bb, h10;
+    complex h11;
+    real h21;
+    complex h22, sc;
+    integer nh, nz;
+    real sx;
+    integer jhi;
+    complex h11s;
+    integer jlo, its;
+    real ulp;
+    complex sum;
+    real tst;
+    complex temp;
     extern /* Subroutine */ int cscal_(integer *, complex *, complex *, 
 	    integer *), ccopy_(integer *, complex *, integer *, complex *, 
 	    integer *);
-    static real rtemp;
+    real rtemp;
     extern /* Subroutine */ int slabad_(real *, real *), clarfg_(integer *, 
 	    complex *, complex *, integer *, complex *);
     extern /* Complex */ VOID cladiv_(complex *, complex *, complex *);
     extern doublereal slamch_(char *);
-    static real safmin, safmax, smlnum;
+    real safmin, safmax, smlnum;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*     Purpose */
+/*     ======= */
+
+/*     CLAHQR is an auxiliary routine called by CHSEQR to update the */
+/*     eigenvalues and Schur decomposition already computed by CHSEQR, by */
+/*     dealing with the Hessenberg submatrix in rows and columns ILO to */
+/*     IHI. */
+
+/*     Arguments */
+/*     ========= */
+
+/*     WANTT   (input) LOGICAL */
+/*          = .TRUE. : the full Schur form T is required; */
+/*          = .FALSE.: only eigenvalues are required. */
+
+/*     WANTZ   (input) LOGICAL */
+/*          = .TRUE. : the matrix of Schur vectors Z is required; */
+/*          = .FALSE.: Schur vectors are not required. */
+
+/*     N       (input) INTEGER */
+/*          The order of the matrix H.  N >= 0. */
+
+/*     ILO     (input) INTEGER */
+/*     IHI     (input) INTEGER */
+/*          It is assumed that H is already upper triangular in rows and */
+/*          columns IHI+1:N, and that H(ILO,ILO-1) = 0 (unless ILO = 1). */
+/*          CLAHQR works primarily with the Hessenberg submatrix in rows */
+/*          and columns ILO to IHI, but applies transformations to all of */
+/*          H if WANTT is .TRUE.. */
+/*          1 <= ILO <= max(1,IHI); IHI <= N. */
+
+/*     H       (input/output) COMPLEX array, dimension (LDH,N) */
+/*          On entry, the upper Hessenberg matrix H. */
+/*          On exit, if INFO is zero and if WANTT is .TRUE., then H */
+/*          is upper triangular in rows and columns ILO:IHI.  If INFO */
+/*          is zero and if WANTT is .FALSE., then the contents of H */
+/*          are unspecified on exit.  The output state of H in case */
+/*          INF is positive is below under the description of INFO. */
+
+/*     LDH     (input) INTEGER */
+/*          The leading dimension of the array H. LDH >= max(1,N). */
+
+/*     W       (output) COMPLEX array, dimension (N) */
+/*          The computed eigenvalues ILO to IHI are stored in the */
+/*          corresponding elements of W. If WANTT is .TRUE., the */
+/*          eigenvalues are stored in the same order as on the diagonal */
+/*          of the Schur form returned in H, with W(i) = H(i,i). */
+
+/*     ILOZ    (input) INTEGER */
+/*     IHIZ    (input) INTEGER */
+/*          Specify the rows of Z to which transformations must be */
+/*          applied if WANTZ is .TRUE.. */
+/*          1 <= ILOZ <= ILO; IHI <= IHIZ <= N. */
+
+/*     Z       (input/output) COMPLEX array, dimension (LDZ,N) */
+/*          If WANTZ is .TRUE., on entry Z must contain the current */
+/*          matrix Z of transformations accumulated by CHSEQR, and on */
+/*          exit Z has been updated; transformations are applied only to */
+/*          the submatrix Z(ILOZ:IHIZ,ILO:IHI). */
+/*          If WANTZ is .FALSE., Z is not referenced. */
+
+/*     LDZ     (input) INTEGER */
+/*          The leading dimension of the array Z. LDZ >= max(1,N). */
+
+/*     INFO    (output) INTEGER */
+/*           =   0: successful exit */
+/*          .GT. 0: if INFO = i, CLAHQR failed to compute all the */
+/*                  eigenvalues ILO to IHI in a total of 30 iterations */
+/*                  per eigenvalue; elements i+1:ihi of W contain */
+/*                  those eigenvalues which have been successfully */
+/*                  computed. */
+
+/*                  If INFO .GT. 0 and WANTT is .FALSE., then on exit, */
+/*                  the remaining unconverged eigenvalues are the */
+/*                  eigenvalues of the upper Hessenberg matrix */
+/*                  rows and columns ILO thorugh INFO of the final, */
+/*                  output value of H. */
+
+/*                  If INFO .GT. 0 and WANTT is .TRUE., then on exit */
+/*          (*)       (initial value of H)*U  = U*(final value of H) */
+/*                  where U is an orthognal matrix.    The final */
+/*                  value of H is upper Hessenberg and triangular in */
+/*                  rows and columns INFO+1 through IHI. */
+
+/*                  If INFO .GT. 0 and WANTZ is .TRUE., then on exit */
+/*                      (final value of Z)  = (initial value of Z)*U */
+/*                  where U is the orthogonal matrix in (*) */
+/*                  (regardless of the value of WANTT.) */
+
+/*     Further Details */
+/*     =============== */
+
+/*     02-96 Based on modifications by */
+/*     David Day, Sandia National Laboratory, USA */
+
+/*     12-04 Further modifications by */
+/*     Ralph Byers, University of Kansas, USA */
+
+/*       This is a modified version of CLAHQR from LAPACK version 3.0. */
+/*       It is (1) more robust against overflow and underflow and */
+/*       (2) adopts the more conservative Ahues & Tisseur stopping */
+/*       criterion (LAWN 122, 1997). */
+
+/*     ========================================================= */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
     h__ -= h_offset;
@@ -204,9 +228,9 @@
     i__1 = *ihi;
     for (i__ = *ilo + 1; i__ <= i__1; ++i__) {
 	if (r_imag(&h__[i__ + (i__ - 1) * h_dim1]) != 0.f) {
-/*           ==== The following redundant normalization   
-             .    avoids problems with both gradual and   
-             .    sudden underflow in ABS(H(I,I-1)) ==== */
+/*           ==== The following redundant normalization */
+/*           .    avoids problems with both gradual and */
+/*           .    sudden underflow in ABS(H(I,I-1)) ==== */
 	    i__2 = i__ + (i__ - 1) * h_dim1;
 	    i__3 = i__ + (i__ - 1) * h_dim1;
 	    r__3 = (r__1 = h__[i__3].r, dabs(r__1)) + (r__2 = r_imag(&h__[i__ 
@@ -254,20 +278,20 @@
     ulp = slamch_("PRECISION");
     smlnum = safmin * ((real) nh / ulp);
 
-/*     I1 and I2 are the indices of the first row and last column of H   
-       to which transformations must be applied. If eigenvalues only are   
-       being computed, I1 and I2 are set inside the main loop. */
+/*     I1 and I2 are the indices of the first row and last column of H */
+/*     to which transformations must be applied. If eigenvalues only are */
+/*     being computed, I1 and I2 are set inside the main loop. */
 
     if (*wantt) {
 	i1 = 1;
 	i2 = *n;
     }
 
-/*     The main loop begins here. I is the loop index and decreases from   
-       IHI to ILO in steps of 1. Each iteration of the loop works   
-       with the active submatrix in rows and columns L to I.   
-       Eigenvalues I+1 to IHI have already converged. Either L = ILO, or   
-       H(L,L-1) is negligible so that the matrix splits. */
+/*     The main loop begins here. I is the loop index and decreases from */
+/*     IHI to ILO in steps of 1. Each iteration of the loop works */
+/*     with the active submatrix in rows and columns L to I. */
+/*     Eigenvalues I+1 to IHI have already converged. Either L = ILO, or */
+/*     H(L,L-1) is negligible so that the matrix splits. */
 
     i__ = *ihi;
 L30:
@@ -275,9 +299,9 @@ L30:
 	goto L150;
     }
 
-/*     Perform QR iterations on rows and columns ILO to I until a   
-       submatrix of order 1 splits off at the bottom because a   
-       subdiagonal element has become negligible. */
+/*     Perform QR iterations on rows and columns ILO to I until a */
+/*     submatrix of order 1 splits off at the bottom because a */
+/*     subdiagonal element has become negligible. */
 
     l = *ilo;
     for (its = 0; its <= 30; ++its) {
@@ -307,10 +331,10 @@ L30:
 		    tst += (r__1 = h__[i__2].r, dabs(r__1));
 		}
 	    }
-/*           ==== The following is a conservative small subdiagonal   
-             .    deflation criterion due to Ahues & Tisseur (LAWN 122,   
-             .    1997). It has better mathematical foundation and   
-             .    improves accuracy in some examples.  ==== */
+/*           ==== The following is a conservative small subdiagonal */
+/*           .    deflation criterion due to Ahues & Tisseur (LAWN 122, */
+/*           .    1997). It has better mathematical foundation and */
+/*           .    improves accuracy in some examples.  ==== */
 	    i__2 = k + (k - 1) * h_dim1;
 	    if ((r__1 = h__[i__2].r, dabs(r__1)) <= ulp * tst) {
 /* Computing MAX */
@@ -376,9 +400,9 @@ L50:
 	    goto L140;
 	}
 
-/*        Now the active submatrix is in rows and columns L to I. If   
-          eigenvalues only are being computed, only the active submatrix   
-          need be transformed. */
+/*        Now the active submatrix is in rows and columns L to I. If */
+/*        eigenvalues only are being computed, only the active submatrix */
+/*        need be transformed. */
 
 	if (! (*wantt)) {
 	    i1 = l;
@@ -411,7 +435,8 @@ L50:
 		q__2.r = h__[i__1].r - t.r, q__2.i = h__[i__1].i - t.i;
 		q__1.r = q__2.r * .5f, q__1.i = q__2.i * .5f;
 		x.r = q__1.r, x.i = q__1.i;
-		sx = (r__1 = x.r, dabs(r__1)) + (r__2 = r_imag(&x), dabs(r__2) );
+		sx = (r__1 = x.r, dabs(r__1)) + (r__2 = r_imag(&x), dabs(r__2)
+			);
 /* Computing MAX */
 		r__3 = s, r__4 = (r__1 = x.r, dabs(r__1)) + (r__2 = r_imag(&x)
 			, dabs(r__2));
@@ -446,9 +471,9 @@ L50:
 	i__1 = l + 1;
 	for (m = i__ - 1; m >= i__1; --m) {
 
-/*           Determine the effect of starting the single-shift QR   
-             iteration at row M, and see if this would make H(M,M-1)   
-             negligible. */
+/*           Determine the effect of starting the single-shift QR */
+/*           iteration at row M, and see if this would make H(M,M-1) */
+/*           negligible. */
 
 	    i__2 = m + m * h_dim1;
 	    h11.r = h__[i__2].r, h11.i = h__[i__2].i;
@@ -470,7 +495,8 @@ L50:
 	    if (dabs(h10) * dabs(h21) <= ulp * (((r__1 = h11s.r, dabs(r__1)) 
 		    + (r__2 = r_imag(&h11s), dabs(r__2))) * ((r__3 = h11.r, 
 		    dabs(r__3)) + (r__4 = r_imag(&h11), dabs(r__4)) + ((r__5 =
-		     h22.r, dabs(r__5)) + (r__6 = r_imag(&h22), dabs(r__6))))) 		    ) {
+		     h22.r, dabs(r__5)) + (r__6 = r_imag(&h22), dabs(r__6)))))
+		    ) {
 		goto L70;
 	    }
 /* L60: */
@@ -497,17 +523,17 @@ L70:
 	i__1 = i__ - 1;
 	for (k = m; k <= i__1; ++k) {
 
-/*           The first iteration of this loop determines a reflection G   
-             from the vector V and applies it from left and right to H,   
-             thus creating a nonzero bulge below the subdiagonal.   
+/*           The first iteration of this loop determines a reflection G */
+/*           from the vector V and applies it from left and right to H, */
+/*           thus creating a nonzero bulge below the subdiagonal. */
 
-             Each subsequent iteration determines a reflection G to   
-             restore the Hessenberg form in the (K-1)th column, and thus   
-             chases the bulge one step toward the bottom of the active   
-             submatrix.   
+/*           Each subsequent iteration determines a reflection G to */
+/*           restore the Hessenberg form in the (K-1)th column, and thus */
+/*           chases the bulge one step toward the bottom of the active */
+/*           submatrix. */
 
-             V(2) is always real before the call to CLARFG, and hence   
-             after the call T2 ( = T1*V(2) ) is also real. */
+/*           V(2) is always real before the call to CLARFG, and hence */
+/*           after the call T2 ( = T1*V(2) ) is also real. */
 
 	    if (k > m) {
 		ccopy_(&c__2, &h__[k + (k - 1) * h_dim1], &c__1, v, &c__1);
@@ -524,8 +550,8 @@ L70:
 		    v2.r;
 	    t2 = q__1.r;
 
-/*           Apply G from the left to transform the rows of the matrix   
-             in columns K to I2. */
+/*           Apply G from the left to transform the rows of the matrix */
+/*           in columns K to I2. */
 
 	    i__2 = i2;
 	    for (j = k; j <= i__2; ++j) {
@@ -550,10 +576,10 @@ L70:
 /* L80: */
 	    }
 
-/*           Apply G from the right to transform the columns of the   
-             matrix in rows I1 to min(K+2,I).   
+/*           Apply G from the right to transform the columns of the */
+/*           matrix in rows I1 to min(K+2,I). */
 
-   Computing MIN */
+/* Computing MIN */
 	    i__3 = k + 2;
 	    i__2 = min(i__3,i__);
 	    for (j = i1; j <= i__2; ++j) {
@@ -610,10 +636,10 @@ L70:
 
 	    if (k == m && m > l) {
 
-/*              If the QR step was started at row M > L because two   
-                consecutive small subdiagonals were found, then extra   
-                scaling must be performed to ensure that H(M,M-1) remains   
-                real. */
+/*              If the QR step was started at row M > L because two */
+/*              consecutive small subdiagonals were found, then extra */
+/*              scaling must be performed to ensure that H(M,M-1) remains */
+/*              real. */
 
 		q__1.r = 1.f - t1.r, q__1.i = 0.f - t1.i;
 		temp.r = q__1.r, temp.i = q__1.i;
