@@ -1,5 +1,11 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static real c_b9 = 1.f;
+static real c_b10 = 0.f;
+static integer c__2 = 2;
 
 /* Subroutine */ int clalsa_(integer *icompq, integer *smlsiz, integer *n, 
 	integer *nrhs, complex *b, integer *ldb, complex *bx, integer *ldbx, 
@@ -8,155 +14,6 @@
 	ldgcol, integer *perm, real *givnum, real *c__, real *s, real *rwork, 
 	integer *iwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CLALSA is an itermediate step in solving the least squares problem   
-    by computing the SVD of the coefficient matrix in compact form (The   
-    singular vectors are computed as products of simple orthorgonal   
-    matrices.).   
-
-    If ICOMPQ = 0, CLALSA applies the inverse of the left singular vector   
-    matrix of an upper bidiagonal matrix to the right hand side; and if   
-    ICOMPQ = 1, CLALSA applies the right singular vector matrix to the   
-    right hand side. The singular vector matrices were generated in   
-    compact form by CLALSA.   
-
-    Arguments   
-    =========   
-
-    ICOMPQ (input) INTEGER   
-           Specifies whether the left or the right singular vector   
-           matrix is involved.   
-           = 0: Left singular vector matrix   
-           = 1: Right singular vector matrix   
-
-    SMLSIZ (input) INTEGER   
-           The maximum size of the subproblems at the bottom of the   
-           computation tree.   
-
-    N      (input) INTEGER   
-           The row and column dimensions of the upper bidiagonal matrix.   
-
-    NRHS   (input) INTEGER   
-           The number of columns of B and BX. NRHS must be at least 1.   
-
-    B      (input/output) COMPLEX array, dimension ( LDB, NRHS )   
-           On input, B contains the right hand sides of the least   
-           squares problem in rows 1 through M.   
-           On output, B contains the solution X in rows 1 through N.   
-
-    LDB    (input) INTEGER   
-           The leading dimension of B in the calling subprogram.   
-           LDB must be at least max(1,MAX( M, N ) ).   
-
-    BX     (output) COMPLEX array, dimension ( LDBX, NRHS )   
-           On exit, the result of applying the left or right singular   
-           vector matrix to B.   
-
-    LDBX   (input) INTEGER   
-           The leading dimension of BX.   
-
-    U      (input) REAL array, dimension ( LDU, SMLSIZ ).   
-           On entry, U contains the left singular vector matrices of all   
-           subproblems at the bottom level.   
-
-    LDU    (input) INTEGER, LDU = > N.   
-           The leading dimension of arrays U, VT, DIFL, DIFR,   
-           POLES, GIVNUM, and Z.   
-
-    VT     (input) REAL array, dimension ( LDU, SMLSIZ+1 ).   
-           On entry, VT' contains the right singular vector matrices of   
-           all subproblems at the bottom level.   
-
-    K      (input) INTEGER array, dimension ( N ).   
-
-    DIFL   (input) REAL array, dimension ( LDU, NLVL ).   
-           where NLVL = INT(log_2 (N/(SMLSIZ+1))) + 1.   
-
-    DIFR   (input) REAL array, dimension ( LDU, 2 * NLVL ).   
-           On entry, DIFL(*, I) and DIFR(*, 2 * I -1) record   
-           distances between singular values on the I-th level and   
-           singular values on the (I -1)-th level, and DIFR(*, 2 * I)   
-           record the normalizing factors of the right singular vectors   
-           matrices of subproblems on I-th level.   
-
-    Z      (input) REAL array, dimension ( LDU, NLVL ).   
-           On entry, Z(1, I) contains the components of the deflation-   
-           adjusted updating row vector for subproblems on the I-th   
-           level.   
-
-    POLES  (input) REAL array, dimension ( LDU, 2 * NLVL ).   
-           On entry, POLES(*, 2 * I -1: 2 * I) contains the new and old   
-           singular values involved in the secular equations on the I-th   
-           level.   
-
-    GIVPTR (input) INTEGER array, dimension ( N ).   
-           On entry, GIVPTR( I ) records the number of Givens   
-           rotations performed on the I-th problem on the computation   
-           tree.   
-
-    GIVCOL (input) INTEGER array, dimension ( LDGCOL, 2 * NLVL ).   
-           On entry, for each I, GIVCOL(*, 2 * I - 1: 2 * I) records the   
-           locations of Givens rotations performed on the I-th level on   
-           the computation tree.   
-
-    LDGCOL (input) INTEGER, LDGCOL = > N.   
-           The leading dimension of arrays GIVCOL and PERM.   
-
-    PERM   (input) INTEGER array, dimension ( LDGCOL, NLVL ).   
-           On entry, PERM(*, I) records permutations done on the I-th   
-           level of the computation tree.   
-
-    GIVNUM (input) REAL array, dimension ( LDU, 2 * NLVL ).   
-           On entry, GIVNUM(*, 2 *I -1 : 2 * I) records the C- and S-   
-           values of Givens rotations performed on the I-th level on the   
-           computation tree.   
-
-    C      (input) REAL array, dimension ( N ).   
-           On entry, if the I-th subproblem is not square,   
-           C( I ) contains the C-value of a Givens rotation related to   
-           the right null space of the I-th subproblem.   
-
-    S      (input) REAL array, dimension ( N ).   
-           On entry, if the I-th subproblem is not square,   
-           S( I ) contains the S-value of a Givens rotation related to   
-           the right null space of the I-th subproblem.   
-
-    RWORK  (workspace) REAL array, dimension at least   
-           max ( N, (SMLSZ+1)*NRHS*3 ).   
-
-    IWORK  (workspace) INTEGER array.   
-           The dimension must be at least 3 * N   
-
-    INFO   (output) INTEGER   
-            = 0:  successful exit.   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-
-    Further Details   
-    ===============   
-
-    Based on contributions by   
-       Ming Gu and Ren-Cang Li, Computer Science Division, University of   
-         California at Berkeley, USA   
-       Osni Marques, LBNL/NERSC, USA   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static real c_b9 = 1.f;
-    static real c_b10 = 0.f;
-    static integer c__2 = 2;
-    
     /* System generated locals */
     integer givcol_dim1, givcol_offset, perm_dim1, perm_offset, difl_dim1, 
 	    difl_offset, difr_dim1, difr_offset, givnum_dim1, givnum_offset, 
@@ -164,26 +21,186 @@
 	    z_dim1, z_offset, b_dim1, b_offset, bx_dim1, bx_offset, i__1, 
 	    i__2, i__3, i__4, i__5, i__6;
     complex q__1;
+
     /* Builtin functions */
     double r_imag(complex *);
     integer pow_ii(integer *, integer *);
+
     /* Local variables */
-    static integer i__, j, i1, ic, lf, nd, ll, nl, nr, im1, nlf, nrf, lvl, 
-	    ndb1, nlp1, lvl2, nrp1, jcol, nlvl, sqre, jrow, jimag, jreal, 
-	    inode, ndiml;
+    integer i__, j, i1, ic, lf, nd, ll, nl, nr, im1, nlf, nrf, lvl, ndb1, 
+	    nlp1, lvl2, nrp1, jcol, nlvl, sqre, jrow, jimag, jreal, inode, 
+	    ndiml;
     extern /* Subroutine */ int sgemm_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *);
-    static integer ndimr;
+    integer ndimr;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), clals0_(integer *, integer *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    integer *, integer *, integer *, integer *, real *, integer *, 
-	    real *, real *, real *, real *, integer *, real *, real *, real *,
+	    real *, real *, real *, real *, integer *, real *, real *, real *, 
 	     integer *), xerbla_(char *, integer *), slasdt_(integer *
-	    , integer *, integer *, integer *, integer *, integer *, integer * );
+, integer *, integer *, integer *, integer *, integer *, integer *
+);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CLALSA is an itermediate step in solving the least squares problem */
+/*  by computing the SVD of the coefficient matrix in compact form (The */
+/*  singular vectors are computed as products of simple orthorgonal */
+/*  matrices.). */
+
+/*  If ICOMPQ = 0, CLALSA applies the inverse of the left singular vector */
+/*  matrix of an upper bidiagonal matrix to the right hand side; and if */
+/*  ICOMPQ = 1, CLALSA applies the right singular vector matrix to the */
+/*  right hand side. The singular vector matrices were generated in */
+/*  compact form by CLALSA. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  ICOMPQ (input) INTEGER */
+/*         Specifies whether the left or the right singular vector */
+/*         matrix is involved. */
+/*         = 0: Left singular vector matrix */
+/*         = 1: Right singular vector matrix */
+
+/*  SMLSIZ (input) INTEGER */
+/*         The maximum size of the subproblems at the bottom of the */
+/*         computation tree. */
+
+/*  N      (input) INTEGER */
+/*         The row and column dimensions of the upper bidiagonal matrix. */
+
+/*  NRHS   (input) INTEGER */
+/*         The number of columns of B and BX. NRHS must be at least 1. */
+
+/*  B      (input/output) COMPLEX array, dimension ( LDB, NRHS ) */
+/*         On input, B contains the right hand sides of the least */
+/*         squares problem in rows 1 through M. */
+/*         On output, B contains the solution X in rows 1 through N. */
+
+/*  LDB    (input) INTEGER */
+/*         The leading dimension of B in the calling subprogram. */
+/*         LDB must be at least max(1,MAX( M, N ) ). */
+
+/*  BX     (output) COMPLEX array, dimension ( LDBX, NRHS ) */
+/*         On exit, the result of applying the left or right singular */
+/*         vector matrix to B. */
+
+/*  LDBX   (input) INTEGER */
+/*         The leading dimension of BX. */
+
+/*  U      (input) REAL array, dimension ( LDU, SMLSIZ ). */
+/*         On entry, U contains the left singular vector matrices of all */
+/*         subproblems at the bottom level. */
+
+/*  LDU    (input) INTEGER, LDU = > N. */
+/*         The leading dimension of arrays U, VT, DIFL, DIFR, */
+/*         POLES, GIVNUM, and Z. */
+
+/*  VT     (input) REAL array, dimension ( LDU, SMLSIZ+1 ). */
+/*         On entry, VT' contains the right singular vector matrices of */
+/*         all subproblems at the bottom level. */
+
+/*  K      (input) INTEGER array, dimension ( N ). */
+
+/*  DIFL   (input) REAL array, dimension ( LDU, NLVL ). */
+/*         where NLVL = INT(log_2 (N/(SMLSIZ+1))) + 1. */
+
+/*  DIFR   (input) REAL array, dimension ( LDU, 2 * NLVL ). */
+/*         On entry, DIFL(*, I) and DIFR(*, 2 * I -1) record */
+/*         distances between singular values on the I-th level and */
+/*         singular values on the (I -1)-th level, and DIFR(*, 2 * I) */
+/*         record the normalizing factors of the right singular vectors */
+/*         matrices of subproblems on I-th level. */
+
+/*  Z      (input) REAL array, dimension ( LDU, NLVL ). */
+/*         On entry, Z(1, I) contains the components of the deflation- */
+/*         adjusted updating row vector for subproblems on the I-th */
+/*         level. */
+
+/*  POLES  (input) REAL array, dimension ( LDU, 2 * NLVL ). */
+/*         On entry, POLES(*, 2 * I -1: 2 * I) contains the new and old */
+/*         singular values involved in the secular equations on the I-th */
+/*         level. */
+
+/*  GIVPTR (input) INTEGER array, dimension ( N ). */
+/*         On entry, GIVPTR( I ) records the number of Givens */
+/*         rotations performed on the I-th problem on the computation */
+/*         tree. */
+
+/*  GIVCOL (input) INTEGER array, dimension ( LDGCOL, 2 * NLVL ). */
+/*         On entry, for each I, GIVCOL(*, 2 * I - 1: 2 * I) records the */
+/*         locations of Givens rotations performed on the I-th level on */
+/*         the computation tree. */
+
+/*  LDGCOL (input) INTEGER, LDGCOL = > N. */
+/*         The leading dimension of arrays GIVCOL and PERM. */
+
+/*  PERM   (input) INTEGER array, dimension ( LDGCOL, NLVL ). */
+/*         On entry, PERM(*, I) records permutations done on the I-th */
+/*         level of the computation tree. */
+
+/*  GIVNUM (input) REAL array, dimension ( LDU, 2 * NLVL ). */
+/*         On entry, GIVNUM(*, 2 *I -1 : 2 * I) records the C- and S- */
+/*         values of Givens rotations performed on the I-th level on the */
+/*         computation tree. */
+
+/*  C      (input) REAL array, dimension ( N ). */
+/*         On entry, if the I-th subproblem is not square, */
+/*         C( I ) contains the C-value of a Givens rotation related to */
+/*         the right null space of the I-th subproblem. */
+
+/*  S      (input) REAL array, dimension ( N ). */
+/*         On entry, if the I-th subproblem is not square, */
+/*         S( I ) contains the S-value of a Givens rotation related to */
+/*         the right null space of the I-th subproblem. */
+
+/*  RWORK  (workspace) REAL array, dimension at least */
+/*         max ( N, (SMLSZ+1)*NRHS*3 ). */
+
+/*  IWORK  (workspace) INTEGER array. */
+/*         The dimension must be at least 3 * N */
+
+/*  INFO   (output) INTEGER */
+/*          = 0:  successful exit. */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Based on contributions by */
+/*     Ming Gu and Ren-Cang Li, Computer Science Division, University of */
+/*       California at Berkeley, USA */
+/*     Osni Marques, LBNL/NERSC, USA */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     b_dim1 = *ldb;
     b_offset = 1 + b_dim1;
     b -= b_offset;
@@ -259,27 +276,27 @@
     slasdt_(n, &nlvl, &nd, &iwork[inode], &iwork[ndiml], &iwork[ndimr], 
 	    smlsiz);
 
-/*     The following code applies back the left singular vector factors.   
-       For applying back the right singular vector factors, go to 170. */
+/*     The following code applies back the left singular vector factors. */
+/*     For applying back the right singular vector factors, go to 170. */
 
     if (*icompq == 1) {
 	goto L170;
     }
 
-/*     The nodes on the bottom level of the tree were solved   
-       by SLASDQ. The corresponding left and right singular vector   
-       matrices are in explicit form. First apply back the left   
-       singular vector matrices. */
+/*     The nodes on the bottom level of the tree were solved */
+/*     by SLASDQ. The corresponding left and right singular vector */
+/*     matrices are in explicit form. First apply back the left */
+/*     singular vector matrices. */
 
     ndb1 = (nd + 1) / 2;
     i__1 = nd;
     for (i__ = ndb1; i__ <= i__1; ++i__) {
 
-/*        IC : center row of each node   
-          NL : number of rows of left  subproblem   
-          NR : number of rows of right subproblem   
-          NLF: starting row of the left   subproblem   
-          NRF: starting row of the right  subproblem */
+/*        IC : center row of each node */
+/*        NL : number of rows of left  subproblem */
+/*        NR : number of rows of right subproblem */
+/*        NLF: starting row of the left   subproblem */
+/*        NRF: starting row of the right  subproblem */
 
 	i1 = i__ - 1;
 	ic = iwork[inode + i1];
@@ -288,11 +305,11 @@
 	nlf = ic - nl;
 	nrf = ic + 1;
 
-/*        Since B and BX are complex, the following call to SGEMM   
-          is performed in two steps (real and imaginary parts).   
+/*        Since B and BX are complex, the following call to SGEMM */
+/*        is performed in two steps (real and imaginary parts). */
 
-          CALL SGEMM( 'T', 'N', NL, NRHS, NL, ONE, U( NLF, 1 ), LDU,   
-       $               B( NLF, 1 ), LDB, ZERO, BX( NLF, 1 ), LDBX ) */
+/*        CALL SGEMM( 'T', 'N', NL, NRHS, NL, ONE, U( NLF, 1 ), LDU, */
+/*     $               B( NLF, 1 ), LDB, ZERO, BX( NLF, 1 ), LDBX ) */
 
 	j = nl * *nrhs << 1;
 	i__2 = *nrhs;
@@ -340,11 +357,11 @@
 /* L60: */
 	}
 
-/*        Since B and BX are complex, the following call to SGEMM   
-          is performed in two steps (real and imaginary parts).   
+/*        Since B and BX are complex, the following call to SGEMM */
+/*        is performed in two steps (real and imaginary parts). */
 
-          CALL SGEMM( 'T', 'N', NR, NRHS, NR, ONE, U( NRF, 1 ), LDU,   
-      $               B( NRF, 1 ), LDB, ZERO, BX( NRF, 1 ), LDBX ) */
+/*        CALL SGEMM( 'T', 'N', NR, NRHS, NR, ONE, U( NRF, 1 ), LDU, */
+/*    $               B( NRF, 1 ), LDB, ZERO, BX( NRF, 1 ), LDBX ) */
 
 	j = nr * *nrhs << 1;
 	i__2 = *nrhs;
@@ -395,8 +412,8 @@
 /* L130: */
     }
 
-/*     Next copy the rows of B that correspond to unchanged rows   
-       in the bidiagonal matrix to BX. */
+/*     Next copy the rows of B that correspond to unchanged rows */
+/*     in the bidiagonal matrix to BX. */
 
     i__1 = nd;
     for (i__ = 1; i__ <= i__1; ++i__) {
@@ -405,8 +422,8 @@
 /* L140: */
     }
 
-/*     Finally go through the left singular vector matrices of all   
-       the other subproblems bottom-up on the tree. */
+/*     Finally go through the left singular vector matrices of all */
+/*     the other subproblems bottom-up on the tree. */
 
     j = pow_ii(&c__2, &nlvl);
     sqre = 0;
@@ -414,8 +431,8 @@
     for (lvl = nlvl; lvl >= 1; --lvl) {
 	lvl2 = (lvl << 1) - 1;
 
-/*        find the first node LF and last node LL on   
-          the current level LVL */
+/*        find the first node LF and last node LL on */
+/*        the current level LVL */
 
 	if (lvl == 1) {
 	    lf = 1;
@@ -451,16 +468,16 @@
 
 L170:
 
-/*     First now go through the right singular vector matrices of all   
-       the tree nodes top-down. */
+/*     First now go through the right singular vector matrices of all */
+/*     the tree nodes top-down. */
 
     j = 0;
     i__1 = nlvl;
     for (lvl = 1; lvl <= i__1; ++lvl) {
 	lvl2 = (lvl << 1) - 1;
 
-/*        Find the first node LF and last node LL on   
-          the current level LVL. */
+/*        Find the first node LF and last node LL on */
+/*        the current level LVL. */
 
 	if (lvl == 1) {
 	    lf = 1;
@@ -496,9 +513,9 @@ L170:
 /* L190: */
     }
 
-/*     The nodes on the bottom level of the tree were solved   
-       by SLASDQ. The corresponding right singular vector   
-       matrices are in explicit form. Apply them back. */
+/*     The nodes on the bottom level of the tree were solved */
+/*     by SLASDQ. The corresponding right singular vector */
+/*     matrices are in explicit form. Apply them back. */
 
     ndb1 = (nd + 1) / 2;
     i__1 = nd;
@@ -516,11 +533,11 @@ L170:
 	nlf = ic - nl;
 	nrf = ic + 1;
 
-/*        Since B and BX are complex, the following call to SGEMM is   
-          performed in two steps (real and imaginary parts).   
+/*        Since B and BX are complex, the following call to SGEMM is */
+/*        performed in two steps (real and imaginary parts). */
 
-          CALL SGEMM( 'T', 'N', NLP1, NRHS, NLP1, ONE, VT( NLF, 1 ), LDU,   
-      $               B( NLF, 1 ), LDB, ZERO, BX( NLF, 1 ), LDBX ) */
+/*        CALL SGEMM( 'T', 'N', NLP1, NRHS, NLP1, ONE, VT( NLF, 1 ), LDU, */
+/*    $               B( NLF, 1 ), LDB, ZERO, BX( NLF, 1 ), LDBX ) */
 
 	j = nlp1 * *nrhs << 1;
 	i__2 = *nrhs;
@@ -569,11 +586,11 @@ L170:
 /* L250: */
 	}
 
-/*        Since B and BX are complex, the following call to SGEMM is   
-          performed in two steps (real and imaginary parts).   
+/*        Since B and BX are complex, the following call to SGEMM is */
+/*        performed in two steps (real and imaginary parts). */
 
-          CALL SGEMM( 'T', 'N', NRP1, NRHS, NRP1, ONE, VT( NRF, 1 ), LDU,   
-      $               B( NRF, 1 ), LDB, ZERO, BX( NRF, 1 ), LDBX ) */
+/*        CALL SGEMM( 'T', 'N', NRP1, NRHS, NRP1, ONE, VT( NRF, 1 ), LDU, */
+/*    $               B( NRF, 1 ), LDB, ZERO, BX( NRF, 1 ), LDBX ) */
 
 	j = nrp1 * *nrhs << 1;
 	i__2 = *nrhs;
