@@ -1,157 +1,57 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static integer c__1 = 1;
+static integer c__0 = 0;
+static real c_b10 = 1.f;
+static real c_b35 = 0.f;
 
 /* Subroutine */ int clalsd_(char *uplo, integer *smlsiz, integer *n, integer 
 	*nrhs, real *d__, real *e, complex *b, integer *ldb, real *rcond, 
 	integer *rank, complex *work, real *rwork, integer *iwork, integer *
 	info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CLALSD uses the singular value decomposition of A to solve the least   
-    squares problem of finding X to minimize the Euclidean norm of each   
-    column of A*X-B, where A is N-by-N upper bidiagonal, and X and B   
-    are N-by-NRHS. The solution X overwrites B.   
-
-    The singular values of A smaller than RCOND times the largest   
-    singular value are treated as zero in solving the least squares   
-    problem; in this case a minimum norm solution is returned.   
-    The actual singular values are returned in D in ascending order.   
-
-    This code makes very mild assumptions about floating point   
-    arithmetic. It will work on machines with a guard digit in   
-    add/subtract, or on those binary machines without guard digits   
-    which subtract like the Cray XMP, Cray YMP, Cray C 90, or Cray 2.   
-    It could conceivably fail on hexadecimal or decimal machines   
-    without guard digits, but we know of none.   
-
-    Arguments   
-    =========   
-
-    UPLO   (input) CHARACTER*1   
-           = 'U': D and E define an upper bidiagonal matrix.   
-           = 'L': D and E define a  lower bidiagonal matrix.   
-
-    SMLSIZ (input) INTEGER   
-           The maximum size of the subproblems at the bottom of the   
-           computation tree.   
-
-    N      (input) INTEGER   
-           The dimension of the  bidiagonal matrix.  N >= 0.   
-
-    NRHS   (input) INTEGER   
-           The number of columns of B. NRHS must be at least 1.   
-
-    D      (input/output) REAL array, dimension (N)   
-           On entry D contains the main diagonal of the bidiagonal   
-           matrix. On exit, if INFO = 0, D contains its singular values.   
-
-    E      (input/output) REAL array, dimension (N-1)   
-           Contains the super-diagonal entries of the bidiagonal matrix.   
-           On exit, E has been destroyed.   
-
-    B      (input/output) COMPLEX array, dimension (LDB,NRHS)   
-           On input, B contains the right hand sides of the least   
-           squares problem. On output, B contains the solution X.   
-
-    LDB    (input) INTEGER   
-           The leading dimension of B in the calling subprogram.   
-           LDB must be at least max(1,N).   
-
-    RCOND  (input) REAL   
-           The singular values of A less than or equal to RCOND times   
-           the largest singular value are treated as zero in solving   
-           the least squares problem. If RCOND is negative,   
-           machine precision is used instead.   
-           For example, if diag(S)*X=B were the least squares problem,   
-           where diag(S) is a diagonal matrix of singular values, the   
-           solution would be X(i) = B(i) / S(i) if S(i) is greater than   
-           RCOND*max(S), and X(i) = 0 if S(i) is less than or equal to   
-           RCOND*max(S).   
-
-    RANK   (output) INTEGER   
-           The number of singular values of A greater than RCOND times   
-           the largest singular value.   
-
-    WORK   (workspace) COMPLEX array, dimension (N * NRHS).   
-
-    RWORK  (workspace) REAL array, dimension at least   
-           (9*N + 2*N*SMLSIZ + 8*N*NLVL + 3*SMLSIZ*NRHS + (SMLSIZ+1)**2),   
-           where   
-           NLVL = MAX( 0, INT( LOG_2( MIN( M,N )/(SMLSIZ+1) ) ) + 1 )   
-
-    IWORK  (workspace) INTEGER array, dimension (3*N*NLVL + 11*N).   
-
-    INFO   (output) INTEGER   
-           = 0:  successful exit.   
-           < 0:  if INFO = -i, the i-th argument had an illegal value.   
-           > 0:  The algorithm failed to compute an singular value while   
-                 working on the submatrix lying in rows and columns   
-                 INFO/(N+1) through MOD(INFO,N+1).   
-
-    Further Details   
-    ===============   
-
-    Based on contributions by   
-       Ming Gu and Ren-Cang Li, Computer Science Division, University of   
-         California at Berkeley, USA   
-       Osni Marques, LBNL/NERSC, USA   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static real c_b10 = 1.f;
-    static real c_b35 = 0.f;
-    
     /* System generated locals */
     integer b_dim1, b_offset, i__1, i__2, i__3, i__4, i__5, i__6;
     real r__1;
     complex q__1;
+
     /* Builtin functions */
     double r_imag(complex *), log(doublereal), r_sign(real *, real *);
+
     /* Local variables */
-    static integer c__, i__, j, k;
-    static real r__;
-    static integer s, u, z__;
-    static real cs;
-    static integer bx;
-    static real sn;
-    static integer st, vt, nm1, st1;
-    static real eps;
-    static integer iwk;
-    static real tol;
-    static integer difl, difr;
-    static real rcnd;
-    static integer jcol, irwb, perm, nsub, nlvl, sqre, bxst, jrow, irwu, 
-	    jimag, jreal;
+    integer c__, i__, j, k;
+    real r__;
+    integer s, u, z__;
+    real cs;
+    integer bx;
+    real sn;
+    integer st, vt, nm1, st1;
+    real eps;
+    integer iwk;
+    real tol;
+    integer difl, difr;
+    real rcnd;
+    integer jcol, irwb, perm, nsub, nlvl, sqre, bxst, jrow, irwu, jimag, 
+	    jreal;
     extern /* Subroutine */ int sgemm_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *);
-    static integer irwib;
+    integer irwib;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *);
-    static integer poles, sizei, irwrb, nsize;
+    integer poles, sizei, irwrb, nsize;
     extern /* Subroutine */ int csrot_(integer *, complex *, integer *, 
 	    complex *, integer *, real *, real *);
-    static integer irwvt, icmpq1, icmpq2;
+    integer irwvt, icmpq1, icmpq2;
     extern /* Subroutine */ int clalsa_(integer *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
 	    integer *, real *, integer *, real *, real *, real *, real *, 
 	    integer *, integer *, integer *, integer *, real *, real *, real *
-	    , real *, integer *, integer *), clascl_(char *, integer *, 
+, real *, integer *, integer *), clascl_(char *, integer *, 
 	    integer *, real *, real *, integer *, integer *, complex *, 
 	    integer *, integer *);
     extern doublereal slamch_(char *);
@@ -163,21 +63,141 @@
 	    complex *, integer *), claset_(char *, integer *, integer 
 	    *, complex *, complex *, complex *, integer *), xerbla_(
 	    char *, integer *), slascl_(char *, integer *, integer *, 
-	    real *, real *, integer *, integer *, real *, integer *, integer * );
+	    real *, real *, integer *, integer *, real *, integer *, integer *
+);
     extern integer isamax_(integer *, real *, integer *);
-    static integer givcol;
+    integer givcol;
     extern /* Subroutine */ int slasdq_(char *, integer *, integer *, integer 
 	    *, integer *, integer *, real *, real *, real *, integer *, real *
-	    , integer *, real *, integer *, real *, integer *), 
+, integer *, real *, integer *, real *, integer *), 
 	    slaset_(char *, integer *, integer *, real *, real *, real *, 
-	    integer *), slartg_(real *, real *, real *, real *, real * );
-    static real orgnrm;
-    static integer givnum;
+	    integer *), slartg_(real *, real *, real *, real *, real *
+);
+    real orgnrm;
+    integer givnum;
     extern doublereal slanst_(char *, integer *, real *, real *);
     extern /* Subroutine */ int slasrt_(char *, integer *, real *, integer *);
-    static integer givptr, nrwork, irwwrk, smlszp;
+    integer givptr, nrwork, irwwrk, smlszp;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CLALSD uses the singular value decomposition of A to solve the least */
+/*  squares problem of finding X to minimize the Euclidean norm of each */
+/*  column of A*X-B, where A is N-by-N upper bidiagonal, and X and B */
+/*  are N-by-NRHS. The solution X overwrites B. */
+
+/*  The singular values of A smaller than RCOND times the largest */
+/*  singular value are treated as zero in solving the least squares */
+/*  problem; in this case a minimum norm solution is returned. */
+/*  The actual singular values are returned in D in ascending order. */
+
+/*  This code makes very mild assumptions about floating point */
+/*  arithmetic. It will work on machines with a guard digit in */
+/*  add/subtract, or on those binary machines without guard digits */
+/*  which subtract like the Cray XMP, Cray YMP, Cray C 90, or Cray 2. */
+/*  It could conceivably fail on hexadecimal or decimal machines */
+/*  without guard digits, but we know of none. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO   (input) CHARACTER*1 */
+/*         = 'U': D and E define an upper bidiagonal matrix. */
+/*         = 'L': D and E define a  lower bidiagonal matrix. */
+
+/*  SMLSIZ (input) INTEGER */
+/*         The maximum size of the subproblems at the bottom of the */
+/*         computation tree. */
+
+/*  N      (input) INTEGER */
+/*         The dimension of the  bidiagonal matrix.  N >= 0. */
+
+/*  NRHS   (input) INTEGER */
+/*         The number of columns of B. NRHS must be at least 1. */
+
+/*  D      (input/output) REAL array, dimension (N) */
+/*         On entry D contains the main diagonal of the bidiagonal */
+/*         matrix. On exit, if INFO = 0, D contains its singular values. */
+
+/*  E      (input/output) REAL array, dimension (N-1) */
+/*         Contains the super-diagonal entries of the bidiagonal matrix. */
+/*         On exit, E has been destroyed. */
+
+/*  B      (input/output) COMPLEX array, dimension (LDB,NRHS) */
+/*         On input, B contains the right hand sides of the least */
+/*         squares problem. On output, B contains the solution X. */
+
+/*  LDB    (input) INTEGER */
+/*         The leading dimension of B in the calling subprogram. */
+/*         LDB must be at least max(1,N). */
+
+/*  RCOND  (input) REAL */
+/*         The singular values of A less than or equal to RCOND times */
+/*         the largest singular value are treated as zero in solving */
+/*         the least squares problem. If RCOND is negative, */
+/*         machine precision is used instead. */
+/*         For example, if diag(S)*X=B were the least squares problem, */
+/*         where diag(S) is a diagonal matrix of singular values, the */
+/*         solution would be X(i) = B(i) / S(i) if S(i) is greater than */
+/*         RCOND*max(S), and X(i) = 0 if S(i) is less than or equal to */
+/*         RCOND*max(S). */
+
+/*  RANK   (output) INTEGER */
+/*         The number of singular values of A greater than RCOND times */
+/*         the largest singular value. */
+
+/*  WORK   (workspace) COMPLEX array, dimension (N * NRHS). */
+
+/*  RWORK  (workspace) REAL array, dimension at least */
+/*         (9*N + 2*N*SMLSIZ + 8*N*NLVL + 3*SMLSIZ*NRHS + (SMLSIZ+1)**2), */
+/*         where */
+/*         NLVL = MAX( 0, INT( LOG_2( MIN( M,N )/(SMLSIZ+1) ) ) + 1 ) */
+
+/*  IWORK  (workspace) INTEGER array, dimension (3*N*NLVL + 11*N). */
+
+/*  INFO   (output) INTEGER */
+/*         = 0:  successful exit. */
+/*         < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*         > 0:  The algorithm failed to compute an singular value while */
+/*               working on the submatrix lying in rows and columns */
+/*               INFO/(N+1) through MOD(INFO,N+1). */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Based on contributions by */
+/*     Ming Gu and Ren-Cang Li, Computer Science Division, University of */
+/*       California at Berkeley, USA */
+/*     Osni Marques, LBNL/NERSC, USA */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     --d__;
     --e;
     b_dim1 = *ldb;
@@ -278,8 +298,8 @@
     slascl_("G", &c__0, &c__0, &orgnrm, &c_b10, &nm1, &c__1, &e[1], &nm1, 
 	    info);
 
-/*     If N is smaller than the minimum divide size SMLSIZ, then solve   
-       the problem with another solver. */
+/*     If N is smaller than the minimum divide size SMLSIZ, then solve */
+/*     the problem with another solver. */
 
     if (*n <= *smlsiz) {
 	irwu = 1;
@@ -296,9 +316,9 @@
 	    return 0;
 	}
 
-/*        In the real version, B is passed to SLASDQ and multiplied   
-          internally by Q'. Here B is complex and that product is   
-          computed below in two steps (real and imaginary parts). */
+/*        In the real version, B is passed to SLASDQ and multiplied */
+/*        internally by Q'. Here B is complex and that product is */
+/*        computed below in two steps (real and imaginary parts). */
 
 	j = irwb - 1;
 	i__1 = *nrhs;
@@ -358,12 +378,12 @@
 /* L100: */
 	}
 
-/*        Since B is complex, the following call to SGEMM is performed   
-          in two steps (real and imaginary parts). That is for V * B   
-          (in the real version of the code V' is stored in WORK).   
+/*        Since B is complex, the following call to SGEMM is performed */
+/*        in two steps (real and imaginary parts). That is for V * B */
+/*        (in the real version of the code V' is stored in WORK). */
 
-          CALL SGEMM( 'T', 'N', N, NRHS, N, ONE, WORK, N, B, LDB, ZERO,   
-      $               WORK( NWORK ), N ) */
+/*        CALL SGEMM( 'T', 'N', N, NRHS, N, ONE, WORK, N, B, LDB, ZERO, */
+/*    $               WORK( NWORK ), N ) */
 
 	j = irwb - 1;
 	i__1 = *nrhs;
@@ -470,8 +490,8 @@
 	    ++nsub;
 	    iwork[nsub] = st;
 
-/*           Subproblem found. First determine its size and then   
-             apply divide and conquer on it. */
+/*           Subproblem found. First determine its size and then */
+/*           apply divide and conquer on it. */
 
 	    if (i__ < nm1) {
 
@@ -487,9 +507,9 @@
 		iwork[sizei + nsub - 1] = nsize;
 	    } else {
 
-/*              A subproblem with E(NM1) small. This implies an   
-                1-by-1 subproblem at D(N), which is not solved   
-                explicitly. */
+/*              A subproblem with E(NM1) small. This implies an */
+/*              1-by-1 subproblem at D(N), which is not solved */
+/*              explicitly. */
 
 		nsize = i__ - st + 1;
 		iwork[sizei + nsub - 1] = nsize;
@@ -501,15 +521,15 @@
 	    st1 = st - 1;
 	    if (nsize == 1) {
 
-/*              This is a 1-by-1 subproblem and is not solved   
-                explicitly. */
+/*              This is a 1-by-1 subproblem and is not solved */
+/*              explicitly. */
 
 		ccopy_(nrhs, &b[st + b_dim1], ldb, &work[bx + st1], n);
 	    } else if (nsize <= *smlsiz) {
 
 /*              This is a small subproblem and is solved by SLASDQ. */
 
-		slaset_("A", &nsize, &nsize, &c_b35, &c_b10, &rwork[vt + st1],
+		slaset_("A", &nsize, &nsize, &c_b35, &c_b10, &rwork[vt + st1], 
 			 n);
 		slaset_("A", &nsize, &nsize, &c_b35, &c_b10, &rwork[u + st1], 
 			n);
@@ -521,9 +541,9 @@
 		    return 0;
 		}
 
-/*              In the real version, B is passed to SLASDQ and multiplied   
-                internally by Q'. Here B is complex and that product is   
-                computed below in two steps (real and imaginary parts). */
+/*              In the real version, B is passed to SLASDQ and multiplied */
+/*              internally by Q'. Here B is complex and that product is */
+/*              computed below in two steps (real and imaginary parts). */
 
 		j = irwb - 1;
 		i__2 = *nrhs;
@@ -592,7 +612,7 @@
 		clalsa_(&icmpq2, smlsiz, &nsize, nrhs, &b[st + b_dim1], ldb, &
 			work[bxst], n, &rwork[u + st1], n, &rwork[vt + st1], &
 			iwork[k + st1], &rwork[difl + st1], &rwork[difr + st1]
-			, &rwork[z__ + st1], &rwork[poles + st1], &iwork[
+, &rwork[z__ + st1], &rwork[poles + st1], &iwork[
 			givptr + st1], &iwork[givcol + st1], n, &iwork[perm + 
 			st1], &rwork[givnum + st1], &rwork[c__ + st1], &rwork[
 			s + st1], &rwork[nrwork], &iwork[iwk], info);
@@ -612,8 +632,8 @@
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
 
-/*        Some of the elements in D can be negative because 1-by-1   
-          subproblems were not solved explicitly. */
+/*        Some of the elements in D can be negative because 1-by-1 */
+/*        subproblems were not solved explicitly. */
 
 	if ((r__1 = d__[i__], dabs(r__1)) <= tol) {
 	    claset_("A", &c__1, nrhs, &c_b1, &c_b1, &work[bx + i__ - 1], n);
@@ -639,12 +659,12 @@
 	    ccopy_(nrhs, &work[bxst], n, &b[st + b_dim1], ldb);
 	} else if (nsize <= *smlsiz) {
 
-/*           Since B and BX are complex, the following call to SGEMM   
-             is performed in two steps (real and imaginary parts).   
+/*           Since B and BX are complex, the following call to SGEMM */
+/*           is performed in two steps (real and imaginary parts). */
 
-             CALL SGEMM( 'T', 'N', NSIZE, NRHS, NSIZE, ONE,   
-      $                  RWORK( VT+ST1 ), N, RWORK( BXST ), N, ZERO,   
-      $                  B( ST, 1 ), LDB ) */
+/*           CALL SGEMM( 'T', 'N', NSIZE, NRHS, NSIZE, ONE, */
+/*    $                  RWORK( VT+ST1 ), N, RWORK( BXST ), N, ZERO, */
+/*    $                  B( ST, 1 ), LDB ) */
 
 	    j = bxst - *n - 1;
 	    jreal = irwb - 1;
