@@ -1,149 +1,21 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static complex c_b2 = {1.f,0.f};
+static integer c__3 = 3;
+static integer c__1 = 1;
+static integer c__2 = 2;
 
 /* Subroutine */ int claqr5_(logical *wantt, logical *wantz, integer *kacc22, 
-	integer *n, integer *ktop, integer *kbot, integer *nshfts, complex *s,
+	integer *n, integer *ktop, integer *kbot, integer *nshfts, complex *s, 
 	 complex *h__, integer *ldh, integer *iloz, integer *ihiz, complex *
-	z__, integer *ldz, complex *v, integer *ldv, complex *u, integer *ldu,
+	z__, integer *ldz, complex *v, integer *ldv, complex *u, integer *ldu, 
 	 integer *nv, complex *wv, integer *ldwv, integer *nh, complex *wh, 
 	integer *ldwh)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-       This auxiliary subroutine called by CLAQR0 performs a   
-       single small-bulge multi-shift QR sweep.   
-
-        WANTT  (input) logical scalar   
-               WANTT = .true. if the triangular Schur factor   
-               is being computed.  WANTT is set to .false. otherwise.   
-
-        WANTZ  (input) logical scalar   
-               WANTZ = .true. if the unitary Schur factor is being   
-               computed.  WANTZ is set to .false. otherwise.   
-
-        KACC22 (input) integer with value 0, 1, or 2.   
-               Specifies the computation mode of far-from-diagonal   
-               orthogonal updates.   
-          = 0: CLAQR5 does not accumulate reflections and does not   
-               use matrix-matrix multiply to update far-from-diagonal   
-               matrix entries.   
-          = 1: CLAQR5 accumulates reflections and uses matrix-matrix   
-               multiply to update the far-from-diagonal matrix entries.   
-          = 2: CLAQR5 accumulates reflections, uses matrix-matrix   
-               multiply to update the far-from-diagonal matrix entries,   
-               and takes advantage of 2-by-2 block structure during   
-               matrix multiplies.   
-
-        N      (input) integer scalar   
-               N is the order of the Hessenberg matrix H upon which this   
-               subroutine operates.   
-
-        KTOP   (input) integer scalar   
-        KBOT   (input) integer scalar   
-               These are the first and last rows and columns of an   
-               isolated diagonal block upon which the QR sweep is to be   
-               applied. It is assumed without a check that   
-                         either KTOP = 1  or   H(KTOP,KTOP-1) = 0   
-               and   
-                         either KBOT = N  or   H(KBOT+1,KBOT) = 0.   
-
-        NSHFTS (input) integer scalar   
-               NSHFTS gives the number of simultaneous shifts.  NSHFTS   
-               must be positive and even.   
-
-        S      (input) COMPLEX array of size (NSHFTS)   
-               S contains the shifts of origin that define the multi-   
-               shift QR sweep.   
-
-        H      (input/output) COMPLEX array of size (LDH,N)   
-               On input H contains a Hessenberg matrix.  On output a   
-               multi-shift QR sweep with shifts SR(J)+i*SI(J) is applied   
-               to the isolated diagonal block in rows and columns KTOP   
-               through KBOT.   
-
-        LDH    (input) integer scalar   
-               LDH is the leading dimension of H just as declared in the   
-               calling procedure.  LDH.GE.MAX(1,N).   
-
-        ILOZ   (input) INTEGER   
-        IHIZ   (input) INTEGER   
-               Specify the rows of Z to which transformations must be   
-               applied if WANTZ is .TRUE.. 1 .LE. ILOZ .LE. IHIZ .LE. N   
-
-        Z      (input/output) COMPLEX array of size (LDZ,IHI)   
-               If WANTZ = .TRUE., then the QR Sweep unitary   
-               similarity transformation is accumulated into   
-               Z(ILOZ:IHIZ,ILO:IHI) from the right.   
-               If WANTZ = .FALSE., then Z is unreferenced.   
-
-        LDZ    (input) integer scalar   
-               LDA is the leading dimension of Z just as declared in   
-               the calling procedure. LDZ.GE.N.   
-
-        V      (workspace) COMPLEX array of size (LDV,NSHFTS/2)   
-
-        LDV    (input) integer scalar   
-               LDV is the leading dimension of V as declared in the   
-               calling procedure.  LDV.GE.3.   
-
-        U      (workspace) COMPLEX array of size   
-               (LDU,3*NSHFTS-3)   
-
-        LDU    (input) integer scalar   
-               LDU is the leading dimension of U just as declared in the   
-               in the calling subroutine.  LDU.GE.3*NSHFTS-3.   
-
-        NH     (input) integer scalar   
-               NH is the number of columns in array WH available for   
-               workspace. NH.GE.1.   
-
-        WH     (workspace) COMPLEX array of size (LDWH,NH)   
-
-        LDWH   (input) integer scalar   
-               Leading dimension of WH just as declared in the   
-               calling procedure.  LDWH.GE.3*NSHFTS-3.   
-
-        NV     (input) integer scalar   
-               NV is the number of rows in WV agailable for workspace.   
-               NV.GE.1.   
-
-        WV     (workspace) COMPLEX array of size   
-               (LDWV,3*NSHFTS-3)   
-
-        LDWV   (input) integer scalar   
-               LDWV is the leading dimension of WV as declared in the   
-               in the calling subroutine.  LDWV.GE.NV.   
-
-
-       ================================================================   
-       Based on contributions by   
-          Karen Braman and Ralph Byers, Department of Mathematics,   
-          University of Kansas, USA   
-
-       ============================================================   
-       Reference:   
-
-       K. Braman, R. Byers and R. Mathias, The Multi-Shift QR   
-       Algorithm Part I: Maintaining Well Focused Shifts, and   
-       Level 3 Performance, SIAM Journal of Matrix Analysis,   
-       volume 23, pages 929--947, 2002.   
-
-       ============================================================   
-
-
-       ==== If there are no shifts, then there is nothing to do. ====   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static complex c_b2 = {1.f,0.f};
-    static integer c__3 = 3;
-    static integer c__1 = 1;
-    static integer c__2 = 2;
-    
     /* System generated locals */
     integer h_dim1, h_offset, u_dim1, u_offset, v_dim1, v_offset, wh_dim1, 
 	    wh_offset, wv_dim1, wv_offset, z_dim1, z_offset, i__1, i__2, i__3,
@@ -151,28 +23,30 @@
     real r__1, r__2, r__3, r__4, r__5, r__6, r__7, r__8, r__9, r__10, r__11, 
 	    r__12, r__13, r__14;
     complex q__1, q__2, q__3, q__4, q__5, q__6, q__7, q__8;
+
     /* Builtin functions */
     double r_imag(complex *);
     void r_cnjg(complex *, complex *);
+
     /* Local variables */
-    static integer j, k, m, i2, j2, i4, j4, k1;
-    static real h11, h12, h21, h22;
-    static integer m22, ns, nu;
-    static complex vt[3];
-    static real scl;
-    static integer kdu, kms;
-    static real ulp;
-    static integer knz, kzs;
-    static real tst1, tst2;
-    static complex beta;
-    static logical blk22, bmp22;
-    static integer mend, jcol, jlen, jbot, mbot, jtop, jrow, mtop;
-    static complex alpha;
-    static logical accum;
+    integer j, k, m, i2, j2, i4, j4, k1;
+    real h11, h12, h21, h22;
+    integer m22, ns, nu;
+    complex vt[3];
+    real scl;
+    integer kdu, kms;
+    real ulp;
+    integer knz, kzs;
+    real tst1, tst2;
+    complex beta;
+    logical blk22, bmp22;
+    integer mend, jcol, jlen, jbot, mbot, jtop, jrow, mtop;
+    complex alpha;
+    logical accum;
     extern /* Subroutine */ int cgemm_(char *, char *, integer *, integer *, 
 	    integer *, complex *, complex *, integer *, complex *, integer *, 
 	    complex *, complex *, integer *);
-    static integer ndcol, incol, krcol, nbmps;
+    integer ndcol, incol, krcol, nbmps;
     extern /* Subroutine */ int ctrmm_(char *, char *, char *, char *, 
 	    integer *, integer *, complex *, complex *, integer *, complex *, 
 	    integer *), claqr1_(integer *, 
@@ -183,12 +57,162 @@
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), claset_(char *, 
 	    integer *, integer *, complex *, complex *, complex *, integer *);
-    static real safmin, safmax;
-    static complex refsum;
-    static integer mstart;
-    static real smlnum;
+    real safmin, safmax;
+    complex refsum;
+    integer mstart;
+    real smlnum;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*     This auxiliary subroutine called by CLAQR0 performs a */
+/*     single small-bulge multi-shift QR sweep. */
+
+/*      WANTT  (input) logical scalar */
+/*             WANTT = .true. if the triangular Schur factor */
+/*             is being computed.  WANTT is set to .false. otherwise. */
+
+/*      WANTZ  (input) logical scalar */
+/*             WANTZ = .true. if the unitary Schur factor is being */
+/*             computed.  WANTZ is set to .false. otherwise. */
+
+/*      KACC22 (input) integer with value 0, 1, or 2. */
+/*             Specifies the computation mode of far-from-diagonal */
+/*             orthogonal updates. */
+/*        = 0: CLAQR5 does not accumulate reflections and does not */
+/*             use matrix-matrix multiply to update far-from-diagonal */
+/*             matrix entries. */
+/*        = 1: CLAQR5 accumulates reflections and uses matrix-matrix */
+/*             multiply to update the far-from-diagonal matrix entries. */
+/*        = 2: CLAQR5 accumulates reflections, uses matrix-matrix */
+/*             multiply to update the far-from-diagonal matrix entries, */
+/*             and takes advantage of 2-by-2 block structure during */
+/*             matrix multiplies. */
+
+/*      N      (input) integer scalar */
+/*             N is the order of the Hessenberg matrix H upon which this */
+/*             subroutine operates. */
+
+/*      KTOP   (input) integer scalar */
+/*      KBOT   (input) integer scalar */
+/*             These are the first and last rows and columns of an */
+/*             isolated diagonal block upon which the QR sweep is to be */
+/*             applied. It is assumed without a check that */
+/*                       either KTOP = 1  or   H(KTOP,KTOP-1) = 0 */
+/*             and */
+/*                       either KBOT = N  or   H(KBOT+1,KBOT) = 0. */
+
+/*      NSHFTS (input) integer scalar */
+/*             NSHFTS gives the number of simultaneous shifts.  NSHFTS */
+/*             must be positive and even. */
+
+/*      S      (input) COMPLEX array of size (NSHFTS) */
+/*             S contains the shifts of origin that define the multi- */
+/*             shift QR sweep. */
+
+/*      H      (input/output) COMPLEX array of size (LDH,N) */
+/*             On input H contains a Hessenberg matrix.  On output a */
+/*             multi-shift QR sweep with shifts SR(J)+i*SI(J) is applied */
+/*             to the isolated diagonal block in rows and columns KTOP */
+/*             through KBOT. */
+
+/*      LDH    (input) integer scalar */
+/*             LDH is the leading dimension of H just as declared in the */
+/*             calling procedure.  LDH.GE.MAX(1,N). */
+
+/*      ILOZ   (input) INTEGER */
+/*      IHIZ   (input) INTEGER */
+/*             Specify the rows of Z to which transformations must be */
+/*             applied if WANTZ is .TRUE.. 1 .LE. ILOZ .LE. IHIZ .LE. N */
+
+/*      Z      (input/output) COMPLEX array of size (LDZ,IHI) */
+/*             If WANTZ = .TRUE., then the QR Sweep unitary */
+/*             similarity transformation is accumulated into */
+/*             Z(ILOZ:IHIZ,ILO:IHI) from the right. */
+/*             If WANTZ = .FALSE., then Z is unreferenced. */
+
+/*      LDZ    (input) integer scalar */
+/*             LDA is the leading dimension of Z just as declared in */
+/*             the calling procedure. LDZ.GE.N. */
+
+/*      V      (workspace) COMPLEX array of size (LDV,NSHFTS/2) */
+
+/*      LDV    (input) integer scalar */
+/*             LDV is the leading dimension of V as declared in the */
+/*             calling procedure.  LDV.GE.3. */
+
+/*      U      (workspace) COMPLEX array of size */
+/*             (LDU,3*NSHFTS-3) */
+
+/*      LDU    (input) integer scalar */
+/*             LDU is the leading dimension of U just as declared in the */
+/*             in the calling subroutine.  LDU.GE.3*NSHFTS-3. */
+
+/*      NH     (input) integer scalar */
+/*             NH is the number of columns in array WH available for */
+/*             workspace. NH.GE.1. */
+
+/*      WH     (workspace) COMPLEX array of size (LDWH,NH) */
+
+/*      LDWH   (input) integer scalar */
+/*             Leading dimension of WH just as declared in the */
+/*             calling procedure.  LDWH.GE.3*NSHFTS-3. */
+
+/*      NV     (input) integer scalar */
+/*             NV is the number of rows in WV agailable for workspace. */
+/*             NV.GE.1. */
+
+/*      WV     (workspace) COMPLEX array of size */
+/*             (LDWV,3*NSHFTS-3) */
+
+/*      LDWV   (input) integer scalar */
+/*             LDWV is the leading dimension of WV as declared in the */
+/*             in the calling subroutine.  LDWV.GE.NV. */
+
+
+/*     ================================================================ */
+/*     Based on contributions by */
+/*        Karen Braman and Ralph Byers, Department of Mathematics, */
+/*        University of Kansas, USA */
+
+/*     ============================================================ */
+/*     Reference: */
+
+/*     K. Braman, R. Byers and R. Mathias, The Multi-Shift QR */
+/*     Algorithm Part I: Maintaining Well Focused Shifts, and */
+/*     Level 3 Performance, SIAM Journal of Matrix Analysis, */
+/*     volume 23, pages 929--947, 2002. */
+
+/*     ============================================================ */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     ==== If there are no shifts, then there is nothing to do. ==== */
+
+    /* Parameter adjustments */
     --s;
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
@@ -214,15 +238,15 @@
 	return 0;
     }
 
-/*     ==== If the active block is empty or 1-by-1, then there   
-       .    is nothing to do. ==== */
+/*     ==== If the active block is empty or 1-by-1, then there */
+/*     .    is nothing to do. ==== */
 
     if (*ktop >= *kbot) {
 	return 0;
     }
 
-/*     ==== NSHFTS is supposed to be even, but if is odd,   
-       .    then simply reduce it by one.  ==== */
+/*     ==== NSHFTS is supposed to be even, but if is odd, */
+/*     .    then simply reduce it by one.  ==== */
 
     ns = *nshfts - *nshfts % 2;
 
@@ -234,8 +258,8 @@
     ulp = slamch_("PRECISION");
     smlnum = safmin * ((real) (*n) / ulp);
 
-/*     ==== Use accumulated reflections to update far-from-diagonal   
-       .    entries ? ==== */
+/*     ==== Use accumulated reflections to update far-from-diagonal */
+/*     .    entries ? ==== */
 
     accum = *kacc22 == 1 || *kacc22 == 2;
 
@@ -269,31 +293,31 @@
 	    claset_("ALL", &kdu, &kdu, &c_b1, &c_b2, &u[u_offset], ldu);
 	}
 
-/*        ==== Near-the-diagonal bulge chase.  The following loop   
-          .    performs the near-the-diagonal part of a small bulge   
-          .    multi-shift QR sweep.  Each 6*NBMPS-2 column diagonal   
-          .    chunk extends from column INCOL to column NDCOL   
-          .    (including both column INCOL and column NDCOL). The   
-          .    following loop chases a 3*NBMPS column long chain of   
-          .    NBMPS bulges 3*NBMPS-2 columns to the right.  (INCOL   
-          .    may be less than KTOP and and NDCOL may be greater than   
-          .    KBOT indicating phantom columns from which to chase   
-          .    bulges before they are actually introduced or to which   
-          .    to chase bulges beyond column KBOT.)  ====   
+/*        ==== Near-the-diagonal bulge chase.  The following loop */
+/*        .    performs the near-the-diagonal part of a small bulge */
+/*        .    multi-shift QR sweep.  Each 6*NBMPS-2 column diagonal */
+/*        .    chunk extends from column INCOL to column NDCOL */
+/*        .    (including both column INCOL and column NDCOL). The */
+/*        .    following loop chases a 3*NBMPS column long chain of */
+/*        .    NBMPS bulges 3*NBMPS-2 columns to the right.  (INCOL */
+/*        .    may be less than KTOP and and NDCOL may be greater than */
+/*        .    KBOT indicating phantom columns from which to chase */
+/*        .    bulges before they are actually introduced or to which */
+/*        .    to chase bulges beyond column KBOT.)  ==== */
 
-   Computing MIN */
+/* Computing MIN */
 	i__4 = incol + nbmps * 3 - 3, i__5 = *kbot - 2;
 	i__3 = min(i__4,i__5);
 	for (krcol = incol; krcol <= i__3; ++krcol) {
 
-/*           ==== Bulges number MTOP to MBOT are active double implicit   
-             .    shift bulges.  There may or may not also be small   
-             .    2-by-2 bulge, if there is room.  The inactive bulges   
-             .    (if any) must wait until the active bulges have moved   
-             .    down the diagonal to make room.  The phantom matrix   
-             .    paradigm described above helps keep track.  ====   
+/*           ==== Bulges number MTOP to MBOT are active double implicit */
+/*           .    shift bulges.  There may or may not also be small */
+/*           .    2-by-2 bulge, if there is room.  The inactive bulges */
+/*           .    (if any) must wait until the active bulges have moved */
+/*           .    down the diagonal to make room.  The phantom matrix */
+/*           .    paradigm described above helps keep track.  ==== */
 
-   Computing MAX */
+/* Computing MAX */
 	    i__4 = 1, i__5 = (*ktop - 1 - krcol + 2) / 3 + 1;
 	    mtop = max(i__4,i__5);
 /* Computing MIN */
@@ -302,8 +326,8 @@
 	    m22 = mbot + 1;
 	    bmp22 = mbot < nbmps && krcol + (m22 - 1) * 3 == *kbot - 2;
 
-/*           ==== Generate reflections to chase the chain right   
-             .    one column.  (The minimum value of K is KTOP-1.) ==== */
+/*           ==== Generate reflections to chase the chain right */
+/*           .    one column.  (The minimum value of K is KTOP-1.) ==== */
 
 	    i__4 = mbot;
 	    for (m = mtop; m <= i__4; ++m) {
@@ -327,15 +351,15 @@
 		    clarfg_(&c__3, &beta, &v[m * v_dim1 + 2], &c__1, &v[m * 
 			    v_dim1 + 1]);
 
-/*                 ==== A Bulge may collapse because of vigilant   
-                   .    deflation or destructive underflow.  (The   
-                   .    initial bulge is always collapsed.) Use   
-                   .    the two-small-subdiagonals trick to try   
-                   .    to get it started again. If V(2,M).NE.0 and   
-                   .    V(3,M) = H(K+3,K+1) = H(K+3,K+2) = 0, then   
-                   .    this bulge is collapsing into a zero   
-                   .    subdiagonal.  It will be restarted next   
-                   .    trip through the loop.) */
+/*                 ==== A Bulge may collapse because of vigilant */
+/*                 .    deflation or destructive underflow.  (The */
+/*                 .    initial bulge is always collapsed.) Use */
+/*                 .    the two-small-subdiagonals trick to try */
+/*                 .    to get it started again. If V(2,M).NE.0 and */
+/*                 .    V(3,M) = H(K+3,K+1) = H(K+3,K+2) = 0, then */
+/*                 .    this bulge is collapsing into a zero */
+/*                 .    subdiagonal.  It will be restarted next */
+/*                 .    trip through the loop.) */
 
 		    i__5 = m * v_dim1 + 1;
 		    i__6 = m * v_dim1 + 3;
@@ -356,11 +380,11 @@
 			h__[i__5].r = 0.f, h__[i__5].i = 0.f;
 		    } else {
 
-/*                    ==== Atypical case: collapsed.  Attempt to   
-                      .    reintroduce ignoring H(K+1,K).  If the   
-                      .    fill resulting from the new reflector   
-                      .    is too large, then abandon it.   
-                      .    Otherwise, use the new one. ==== */
+/*                    ==== Atypical case: collapsed.  Attempt to */
+/*                    .    reintroduce ignoring H(K+1,K).  If the */
+/*                    .    fill resulting from the new reflector */
+/*                    .    is too large, then abandon it. */
+/*                    .    Otherwise, use the new one. ==== */
 
 			claqr1_(&c__3, &h__[k + 1 + (k + 1) * h_dim1], ldh, &
 				s[(m << 1) - 1], &s[m * 2], vt);
@@ -378,10 +402,10 @@
 			    vt[2].r = q__1.r, vt[2].i = q__1.i;
 			}
 
-/*                    ==== The following is the traditional and   
-                      .    conservative two-small-subdiagonals   
-                      .    test.  ====   
-                      . */
+/*                    ==== The following is the traditional and */
+/*                    .    conservative two-small-subdiagonals */
+/*                    .    test.  ==== */
+/*                    . */
 			i__5 = k + 1 + k * h_dim1;
 			i__6 = k + k * h_dim1;
 			i__7 = k + 1 + (k + 1) * h_dim1;
@@ -401,12 +425,12 @@
 				 + (r__14 = r_imag(&h__[k + 2 + (k + 2) * 
 				h_dim1]), dabs(r__14))))) {
 
-/*                       ==== Starting a new bulge here would   
-                         .    create non-negligible fill.   If   
-                         .    the old reflector is diagonal (only   
-                         .    possible with underflows), then   
-                         .    change it to I.  Otherwise, use   
-                         .    it with trepidation. ==== */
+/*                       ==== Starting a new bulge here would */
+/*                       .    create non-negligible fill.   If */
+/*                       .    the old reflector is diagonal (only */
+/*                       .    possible with underflows), then */
+/*                       .    change it to I.  Otherwise, use */
+/*                       .    it with trepidation. ==== */
 
 			    i__5 = m * v_dim1 + 2;
 			    i__6 = m * v_dim1 + 3;
@@ -424,10 +448,10 @@
 			    }
 			} else {
 
-/*                       ==== Stating a new bulge here would   
-                         .    create only negligible fill.   
-                         .    Replace the old reflector with   
-                         .    the new one. ==== */
+/*                       ==== Stating a new bulge here would */
+/*                       .    create only negligible fill. */
+/*                       .    Replace the old reflector with */
+/*                       .    the new one. ==== */
 
 			    alpha.r = vt[0].r, alpha.i = vt[0].i;
 			    clarfg_(&c__3, &alpha, &vt[1], &c__1, vt);
@@ -499,8 +523,8 @@
 		}
 	    } else {
 
-/*              ==== Initialize V(1,M22) here to avoid possible undefined   
-                .    variable problems later. ==== */
+/*              ==== Initialize V(1,M22) here to avoid possible undefined */
+/*              .    variable problems later. ==== */
 
 		i__4 = m22 * v_dim1 + 1;
 		v[i__4].r = 0.f, v[i__4].i = 0.f;
@@ -604,9 +628,9 @@
 		}
 	    }
 
-/*           ==== Multiply H by reflections from the right.   
-             .    Delay filling in the last row until the   
-             .    vigilant deflation check is complete. ==== */
+/*           ==== Multiply H by reflections from the right. */
+/*           .    Delay filling in the last row until the */
+/*           .    vigilant deflation check is complete. ==== */
 
 	    if (accum) {
 		jtop = max(*ktop,incol);
@@ -671,9 +695,9 @@
 
 		    if (accum) {
 
-/*                    ==== Accumulate U. (If necessary, update Z later   
-                      .    with with an efficient matrix-matrix   
-                      .    multiply.) ==== */
+/*                    ==== Accumulate U. (If necessary, update Z later */
+/*                    .    with with an efficient matrix-matrix */
+/*                    .    multiply.) ==== */
 
 			kms = k - incol;
 /* Computing MAX */
@@ -727,9 +751,9 @@
 			}
 		    } else if (*wantz) {
 
-/*                    ==== U is not accumulated, so update Z   
-                      .    now by multiplying by reflections   
-                      .    from the right. ==== */
+/*                    ==== U is not accumulated, so update Z */
+/*                    .    now by multiplying by reflections */
+/*                    .    from the right. ==== */
 
 			i__7 = *ihiz;
 			for (j = *iloz; j <= i__7; ++j) {
@@ -909,14 +933,14 @@
 		i__5 = *kbot - 1, i__7 = krcol + (m - 1) * 3;
 		k = min(i__5,i__7);
 
-/*              ==== The following convergence test requires that   
-                .    the tradition small-compared-to-nearby-diagonals   
-                .    criterion and the Ahues & Tisseur (LAWN 122, 1997)   
-                .    criteria both be satisfied.  The latter improves   
-                .    accuracy in some examples. Falling back on an   
-                .    alternate convergence criterion when TST1 or TST2   
-                .    is zero (as done here) is traditional but probably   
-                .    unnecessary. ==== */
+/*              ==== The following convergence test requires that */
+/*              .    the tradition small-compared-to-nearby-diagonals */
+/*              .    criterion and the Ahues & Tisseur (LAWN 122, 1997) */
+/*              .    criteria both be satisfied.  The latter improves */
+/*              .    accuracy in some examples. Falling back on an */
+/*              .    alternate convergence criterion when TST1 or TST2 */
+/*              .    is zero (as done here) is traditional but probably */
+/*              .    unnecessary. ==== */
 
 		i__5 = k + 1 + k * h_dim1;
 		if (h__[i__5].r != 0.f || h__[i__5].i != 0.f) {
@@ -1027,9 +1051,9 @@
 /* L120: */
 	    }
 
-/*           ==== Fill in the last row of each bulge. ====   
+/*           ==== Fill in the last row of each bulge. ==== */
 
-   Computing MIN */
+/* Computing MIN */
 	    i__4 = nbmps, i__5 = (*kbot - krcol - 1) / 3;
 	    mend = min(i__4,i__5);
 	    i__4 = mend;
@@ -1063,14 +1087,14 @@
 /* L130: */
 	    }
 
-/*           ==== End of near-the-diagonal bulge chase. ====   
+/*           ==== End of near-the-diagonal bulge chase. ==== */
 
-   L140: */
+/* L140: */
 	}
 
-/*        ==== Use U (if accumulated) to update far-from-diagonal   
-          .    entries in H.  If required, use U to update Z as   
-          .    well. ==== */
+/*        ==== Use U (if accumulated) to update far-from-diagonal */
+/*        .    entries in H.  If required, use U to update Z as */
+/*        .    well. ==== */
 
 	if (accum) {
 	    if (*wantt) {
@@ -1082,16 +1106,16 @@
 	    }
 	    if (! blk22 || incol < *ktop || ndcol > *kbot || ns <= 2) {
 
-/*              ==== Updates not exploiting the 2-by-2 block   
-                .    structure of U.  K1 and NU keep track of   
-                .    the location and size of U in the special   
-                .    cases of introducing bulges and chasing   
-                .    bulges off the bottom.  In these special   
-                .    cases and in case the number of shifts   
-                .    is NS = 2, there is no 2-by-2 block   
-                .    structure to exploit.  ====   
+/*              ==== Updates not exploiting the 2-by-2 block */
+/*              .    structure of U.  K1 and NU keep track of */
+/*              .    the location and size of U in the special */
+/*              .    cases of introducing bulges and chasing */
+/*              .    bulges off the bottom.  In these special */
+/*              .    cases and in case the number of shifts */
+/*              .    is NS = 2, there is no 2-by-2 block */
+/*              .    structure to exploit.  ==== */
 
-   Computing MAX */
+/* Computing MAX */
 		i__3 = 1, i__4 = *ktop - incol;
 		k1 = max(i__3,i__4);
 /* Computing MAX */
@@ -1153,18 +1177,18 @@
 		}
 	    } else {
 
-/*              ==== Updates exploiting U's 2-by-2 block structure.   
-                .    (I2, I4, J2, J4 are the last rows and columns   
-                .    of the blocks.) ==== */
+/*              ==== Updates exploiting U's 2-by-2 block structure. */
+/*              .    (I2, I4, J2, J4 are the last rows and columns */
+/*              .    of the blocks.) ==== */
 
 		i2 = (kdu + 1) / 2;
 		i4 = kdu;
 		j2 = i4 - i2;
 		j4 = kdu;
 
-/*              ==== KZS and KNZ deal with the band of zeros   
-                .    along the diagonal of one of the triangular   
-                .    blocks. ==== */
+/*              ==== KZS and KNZ deal with the band of zeros */
+/*              .    along the diagonal of one of the triangular */
+/*              .    blocks. ==== */
 
 		kzs = j4 - j2 - (ns + 1);
 		knz = ns + 1;
@@ -1179,8 +1203,8 @@
 		    i__5 = *nh, i__7 = jbot - jcol + 1;
 		    jlen = min(i__5,i__7);
 
-/*                 ==== Copy bottom of H to top+KZS of scratch ====   
-                    (The first KZS rows get multiplied by zero.) ==== */
+/*                 ==== Copy bottom of H to top+KZS of scratch ==== */
+/*                  (The first KZS rows get multiplied by zero.) ==== */
 
 		    clacpy_("ALL", &knz, &jlen, &h__[incol + 1 + j2 + jcol * 
 			    h_dim1], ldh, &wh[kzs + 1 + wh_dim1], ldwh);
@@ -1202,7 +1226,7 @@
 /*                 ==== Copy top of H bottom of WH ==== */
 
 		    clacpy_("ALL", &j2, &jlen, &h__[incol + 1 + jcol * h_dim1]
-			    , ldh, &wh[i2 + 1 + wh_dim1], ldwh);
+, ldh, &wh[i2 + 1 + wh_dim1], ldwh);
 
 /*                 ==== Multiply by U21' ==== */
 
@@ -1235,8 +1259,8 @@
 		    i__5 = *nv, i__7 = max(incol,*ktop) - jrow;
 		    jlen = min(i__5,i__7);
 
-/*                 ==== Copy right of H to scratch (the first KZS   
-                   .    columns get multiplied by zero) ==== */
+/*                 ==== Copy right of H to scratch (the first KZS */
+/*                 .    columns get multiplied by zero) ==== */
 
 		    clacpy_("ALL", &jlen, &knz, &h__[jrow + (incol + 1 + j2) *
 			     h_dim1], ldh, &wv[(kzs + 1) * wv_dim1 + 1], ldwv);
@@ -1294,8 +1318,8 @@
 			i__5 = *nv, i__7 = *ihiz - jrow + 1;
 			jlen = min(i__5,i__7);
 
-/*                    ==== Copy right of Z to left of scratch (first   
-                      .     KZS columns get multiplied by zero) ==== */
+/*                    ==== Copy right of Z to left of scratch (first */
+/*                    .     KZS columns get multiplied by zero) ==== */
 
 			clacpy_("ALL", &jlen, &knz, &z__[jrow + (incol + 1 + 
 				j2) * z_dim1], ldz, &wv[(kzs + 1) * wv_dim1 + 
