@@ -1,81 +1,28 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static complex c_b2 = {1.f,0.f};
+static integer c__1 = 1;
 
 /* Subroutine */ int clarfx_(char *side, integer *m, integer *n, complex *v, 
-	complex *tau, complex *c__, integer *ldc, complex *work  	)
+	complex *tau, complex *c__, integer *ldc, complex *work)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CLARFX applies a complex elementary reflector H to a complex m by n   
-    matrix C, from either the left or the right. H is represented in the   
-    form   
-
-          H = I - tau * v * v'   
-
-    where tau is a complex scalar and v is a complex vector.   
-
-    If tau = 0, then H is taken to be the unit matrix   
-
-    This version uses inline code if H has order < 11.   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'L': form  H * C   
-            = 'R': form  C * H   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix C.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix C.   
-
-    V       (input) COMPLEX array, dimension (M) if SIDE = 'L'   
-                                          or (N) if SIDE = 'R'   
-            The vector v in the representation of H.   
-
-    TAU     (input) COMPLEX   
-            The value tau in the representation of H.   
-
-    C       (input/output) COMPLEX array, dimension (LDC,N)   
-            On entry, the m by n matrix C.   
-            On exit, C is overwritten by the matrix H * C if SIDE = 'L',   
-            or C * H if SIDE = 'R'.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C. LDA >= max(1,M).   
-
-    WORK    (workspace) COMPLEX array, dimension (N) if SIDE = 'L'   
-                                              or (M) if SIDE = 'R'   
-            WORK is not referenced if H has order < 11.   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static complex c_b2 = {1.f,0.f};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer c_dim1, c_offset, i__1, i__2, i__3, i__4, i__5, i__6, i__7, i__8, 
 	    i__9, i__10, i__11;
     complex q__1, q__2, q__3, q__4, q__5, q__6, q__7, q__8, q__9, q__10, 
 	    q__11, q__12, q__13, q__14, q__15, q__16, q__17, q__18, q__19;
+
     /* Builtin functions */
     void r_cnjg(complex *, complex *);
+
     /* Local variables */
-    static integer j;
-    static complex t1, t2, t3, t4, t5, t6, t7, t8, t9, v1, v2, v3, v4, v5, v6,
-	     v7, v8, v9, t10, v10, sum;
+    integer j;
+    complex t1, t2, t3, t4, t5, t6, t7, t8, t9, v1, v2, v3, v4, v5, v6, v7, 
+	    v8, v9, t10, v10, sum;
     extern /* Subroutine */ int cgerc_(integer *, integer *, complex *, 
 	    complex *, integer *, complex *, integer *, complex *, integer *);
     extern logical lsame_(char *, char *);
@@ -84,6 +31,77 @@
 , integer *);
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CLARFX applies a complex elementary reflector H to a complex m by n */
+/*  matrix C, from either the left or the right. H is represented in the */
+/*  form */
+
+/*        H = I - tau * v * v' */
+
+/*  where tau is a complex scalar and v is a complex vector. */
+
+/*  If tau = 0, then H is taken to be the unit matrix */
+
+/*  This version uses inline code if H has order < 11. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'L': form  H * C */
+/*          = 'R': form  C * H */
+
+/*  M       (input) INTEGER */
+/*          The number of rows of the matrix C. */
+
+/*  N       (input) INTEGER */
+/*          The number of columns of the matrix C. */
+
+/*  V       (input) COMPLEX array, dimension (M) if SIDE = 'L' */
+/*                                        or (N) if SIDE = 'R' */
+/*          The vector v in the representation of H. */
+
+/*  TAU     (input) COMPLEX */
+/*          The value tau in the representation of H. */
+
+/*  C       (input/output) COMPLEX array, dimension (LDC,N) */
+/*          On entry, the m by n matrix C. */
+/*          On exit, C is overwritten by the matrix H * C if SIDE = 'L', */
+/*          or C * H if SIDE = 'R'. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. LDA >= max(1,M). */
+
+/*  WORK    (workspace) COMPLEX array, dimension (N) if SIDE = 'L' */
+/*                                            or (M) if SIDE = 'R' */
+/*          WORK is not referenced if H has order < 11. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     --v;
     c_dim1 = *ldc;
     c_offset = 1 + c_dim1;
@@ -111,9 +129,9 @@
 	    case 10:  goto L190;
 	}
 
-/*        Code for general M   
+/*        Code for general M */
 
-          w := C'*v */
+/*        w := C'*v */
 
 	cgemv_("Conjugate transpose", m, n, &c_b2, &c__[c_offset], ldc, &v[1], 
 		 &c__1, &c_b1, &work[1], &c__1);
@@ -1107,9 +1125,9 @@ L190:
 	    case 10:  goto L390;
 	}
 
-/*        Code for general N   
+/*        Code for general N */
 
-          w := C * v */
+/*        w := C * v */
 
 	cgemv_("No transpose", m, n, &c_b2, &c__[c_offset], ldc, &v[1], &c__1, 
 		 &c_b1, &work[1], &c__1);
