@@ -1,204 +1,46 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static real c_b36 = .5f;
 
 /* Subroutine */ int clatrs_(char *uplo, char *trans, char *diag, char *
-	normin, integer *n, complex *a, integer *lda, complex *x, real *scale,
+	normin, integer *n, complex *a, integer *lda, complex *x, real *scale, 
 	 real *cnorm, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CLATRS solves one of the triangular systems   
-
-       A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b,   
-
-    with scaling to prevent overflow.  Here A is an upper or lower   
-    triangular matrix, A**T denotes the transpose of A, A**H denotes the   
-    conjugate transpose of A, x and b are n-element vectors, and s is a   
-    scaling factor, usually less than or equal to 1, chosen so that the   
-    components of x will be less than the overflow threshold.  If the   
-    unscaled problem will not cause overflow, the Level 2 BLAS routine   
-    CTRSV is called. If the matrix A is singular (A(j,j) = 0 for some j),   
-    then s is set to 0 and a non-trivial solution to A*x = 0 is returned.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A is upper or lower triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
-
-    TRANS   (input) CHARACTER*1   
-            Specifies the operation applied to A.   
-            = 'N':  Solve A * x = s*b     (No transpose)   
-            = 'T':  Solve A**T * x = s*b  (Transpose)   
-            = 'C':  Solve A**H * x = s*b  (Conjugate transpose)   
-
-    DIAG    (input) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
-
-    NORMIN  (input) CHARACTER*1   
-            Specifies whether CNORM has been set or not.   
-            = 'Y':  CNORM contains the column norms on entry   
-            = 'N':  CNORM is not set on entry.  On exit, the norms will   
-                    be computed and stored in CNORM.   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    A       (input) COMPLEX array, dimension (LDA,N)   
-            The triangular matrix A.  If UPLO = 'U', the leading n by n   
-            upper triangular part of the array A contains the upper   
-            triangular matrix, and the strictly lower triangular part of   
-            A is not referenced.  If UPLO = 'L', the leading n by n lower   
-            triangular part of the array A contains the lower triangular   
-            matrix, and the strictly upper triangular part of A is not   
-            referenced.  If DIAG = 'U', the diagonal elements of A are   
-            also not referenced and are assumed to be 1.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max (1,N).   
-
-    X       (input/output) COMPLEX array, dimension (N)   
-            On entry, the right hand side b of the triangular system.   
-            On exit, X is overwritten by the solution vector x.   
-
-    SCALE   (output) REAL   
-            The scaling factor s for the triangular system   
-               A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b.   
-            If SCALE = 0, the matrix A is singular or badly scaled, and   
-            the vector x is an exact or approximate solution to A*x = 0.   
-
-    CNORM   (input or output) REAL array, dimension (N)   
-
-            If NORMIN = 'Y', CNORM is an input argument and CNORM(j)   
-            contains the norm of the off-diagonal part of the j-th column   
-            of A.  If TRANS = 'N', CNORM(j) must be greater than or equal   
-            to the infinity-norm, and if TRANS = 'T' or 'C', CNORM(j)   
-            must be greater than or equal to the 1-norm.   
-
-            If NORMIN = 'N', CNORM is an output argument and CNORM(j)   
-            returns the 1-norm of the offdiagonal part of the j-th column   
-            of A.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -k, the k-th argument had an illegal value   
-
-    Further Details   
-    ======= =======   
-
-    A rough bound on x is computed; if that is less than overflow, CTRSV   
-    is called, otherwise, specific code is used which checks for possible   
-    overflow or divide-by-zero at every operation.   
-
-    A columnwise scheme is used for solving A*x = b.  The basic algorithm   
-    if A is lower triangular is   
-
-         x[1:n] := b[1:n]   
-         for j = 1, ..., n   
-              x(j) := x(j) / A(j,j)   
-              x[j+1:n] := x[j+1:n] - x(j) * A[j+1:n,j]   
-         end   
-
-    Define bounds on the components of x after j iterations of the loop:   
-       M(j) = bound on x[1:j]   
-       G(j) = bound on x[j+1:n]   
-    Initially, let M(0) = 0 and G(0) = max{x(i), i=1,...,n}.   
-
-    Then for iteration j+1 we have   
-       M(j+1) <= G(j) / | A(j+1,j+1) |   
-       G(j+1) <= G(j) + M(j+1) * | A[j+2:n,j+1] |   
-              <= G(j) ( 1 + CNORM(j+1) / | A(j+1,j+1) | )   
-
-    where CNORM(j+1) is greater than or equal to the infinity-norm of   
-    column j+1 of A, not counting the diagonal.  Hence   
-
-       G(j) <= G(0) product ( 1 + CNORM(i) / | A(i,i) | )   
-                    1<=i<=j   
-    and   
-
-       |x(j)| <= ( G(0) / |A(j,j)| ) product ( 1 + CNORM(i) / |A(i,i)| )   
-                                     1<=i< j   
-
-    Since |x(j)| <= M(j), we use the Level 2 BLAS routine CTRSV if the   
-    reciprocal of the largest M(j), j=1,..,n, is larger than   
-    max(underflow, 1/overflow).   
-
-    The bound on x(j) is also used to determine when a step in the   
-    columnwise method can be performed without fear of overflow.  If   
-    the computed bound is greater than a large constant, x is scaled to   
-    prevent overflow, but if the bound overflows, x is set to 0, x(j) to   
-    1, and scale to 0, and a non-trivial solution to A*x = 0 is found.   
-
-    Similarly, a row-wise scheme is used to solve A**T *x = b  or   
-    A**H *x = b.  The basic algorithm for A upper triangular is   
-
-         for j = 1, ..., n   
-              x(j) := ( b(j) - A[1:j-1,j]' * x[1:j-1] ) / A(j,j)   
-         end   
-
-    We simultaneously compute two bounds   
-         G(j) = bound on ( b(i) - A[1:i-1,i]' * x[1:i-1] ), 1<=i<=j   
-         M(j) = bound on x(i), 1<=i<=j   
-
-    The initial values are G(0) = 0, M(0) = max{b(i), i=1,..,n}, and we   
-    add the constraint G(j) >= G(j-1) and M(j) >= M(j-1) for j >= 1.   
-    Then the bound on x(j) is   
-
-         M(j) <= M(j-1) * ( 1 + CNORM(j) ) / | A(j,j) |   
-
-              <= M(0) * product ( ( 1 + CNORM(i) ) / |A(i,i)| )   
-                        1<=i<=j   
-
-    and we can safely call CTRSV if 1/M(n) and 1/G(n) are both greater   
-    than max(underflow, 1/overflow).   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static real c_b36 = .5f;
-    
     /* System generated locals */
     integer a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2, r__3, r__4;
     complex q__1, q__2, q__3, q__4;
+
     /* Builtin functions */
     double r_imag(complex *);
     void r_cnjg(complex *, complex *);
+
     /* Local variables */
-    static integer i__, j;
-    static real xj, rec, tjj;
-    static integer jinc;
-    static real xbnd;
-    static integer imax;
-    static real tmax;
-    static complex tjjs;
-    static real xmax, grow;
+    integer i__, j;
+    real xj, rec, tjj;
+    integer jinc;
+    real xbnd;
+    integer imax;
+    real tmax;
+    complex tjjs;
+    real xmax, grow;
     extern /* Complex */ VOID cdotc_(complex *, integer *, complex *, integer 
 	    *, complex *, integer *);
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static real tscal;
-    static complex uscal;
-    static integer jlast;
+    real tscal;
+    complex uscal;
+    integer jlast;
     extern /* Complex */ VOID cdotu_(complex *, integer *, complex *, integer 
 	    *, complex *, integer *);
-    static complex csumj;
+    complex csumj;
     extern /* Subroutine */ int caxpy_(integer *, complex *, complex *, 
 	    integer *, complex *, integer *);
-    static logical upper;
+    logical upper;
     extern /* Subroutine */ int ctrsv_(char *, char *, char *, integer *, 
 	    complex *, integer *, complex *, integer *), slabad_(real *, real *);
     extern integer icamax_(integer *, complex *, integer *);
@@ -206,15 +48,195 @@
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
 	    *), xerbla_(char *, integer *);
-    static real bignum;
+    real bignum;
     extern integer isamax_(integer *, real *, integer *);
     extern doublereal scasum_(integer *, complex *, integer *);
-    static logical notran;
-    static integer jfirst;
-    static real smlnum;
-    static logical nounit;
+    logical notran;
+    integer jfirst;
+    real smlnum;
+    logical nounit;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CLATRS solves one of the triangular systems */
+
+/*     A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b, */
+
+/*  with scaling to prevent overflow.  Here A is an upper or lower */
+/*  triangular matrix, A**T denotes the transpose of A, A**H denotes the */
+/*  conjugate transpose of A, x and b are n-element vectors, and s is a */
+/*  scaling factor, usually less than or equal to 1, chosen so that the */
+/*  components of x will be less than the overflow threshold.  If the */
+/*  unscaled problem will not cause overflow, the Level 2 BLAS routine */
+/*  CTRSV is called. If the matrix A is singular (A(j,j) = 0 for some j), */
+/*  then s is set to 0 and a non-trivial solution to A*x = 0 is returned. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A is upper or lower triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies the operation applied to A. */
+/*          = 'N':  Solve A * x = s*b     (No transpose) */
+/*          = 'T':  Solve A**T * x = s*b  (Transpose) */
+/*          = 'C':  Solve A**H * x = s*b  (Conjugate transpose) */
+
+/*  DIAG    (input) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
+
+/*  NORMIN  (input) CHARACTER*1 */
+/*          Specifies whether CNORM has been set or not. */
+/*          = 'Y':  CNORM contains the column norms on entry */
+/*          = 'N':  CNORM is not set on entry.  On exit, the norms will */
+/*                  be computed and stored in CNORM. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  A       (input) COMPLEX array, dimension (LDA,N) */
+/*          The triangular matrix A.  If UPLO = 'U', the leading n by n */
+/*          upper triangular part of the array A contains the upper */
+/*          triangular matrix, and the strictly lower triangular part of */
+/*          A is not referenced.  If UPLO = 'L', the leading n by n lower */
+/*          triangular part of the array A contains the lower triangular */
+/*          matrix, and the strictly upper triangular part of A is not */
+/*          referenced.  If DIAG = 'U', the diagonal elements of A are */
+/*          also not referenced and are assumed to be 1. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max (1,N). */
+
+/*  X       (input/output) COMPLEX array, dimension (N) */
+/*          On entry, the right hand side b of the triangular system. */
+/*          On exit, X is overwritten by the solution vector x. */
+
+/*  SCALE   (output) REAL */
+/*          The scaling factor s for the triangular system */
+/*             A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b. */
+/*          If SCALE = 0, the matrix A is singular or badly scaled, and */
+/*          the vector x is an exact or approximate solution to A*x = 0. */
+
+/*  CNORM   (input or output) REAL array, dimension (N) */
+
+/*          If NORMIN = 'Y', CNORM is an input argument and CNORM(j) */
+/*          contains the norm of the off-diagonal part of the j-th column */
+/*          of A.  If TRANS = 'N', CNORM(j) must be greater than or equal */
+/*          to the infinity-norm, and if TRANS = 'T' or 'C', CNORM(j) */
+/*          must be greater than or equal to the 1-norm. */
+
+/*          If NORMIN = 'N', CNORM is an output argument and CNORM(j) */
+/*          returns the 1-norm of the offdiagonal part of the j-th column */
+/*          of A. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -k, the k-th argument had an illegal value */
+
+/*  Further Details */
+/*  ======= ======= */
+
+/*  A rough bound on x is computed; if that is less than overflow, CTRSV */
+/*  is called, otherwise, specific code is used which checks for possible */
+/*  overflow or divide-by-zero at every operation. */
+
+/*  A columnwise scheme is used for solving A*x = b.  The basic algorithm */
+/*  if A is lower triangular is */
+
+/*       x[1:n] := b[1:n] */
+/*       for j = 1, ..., n */
+/*            x(j) := x(j) / A(j,j) */
+/*            x[j+1:n] := x[j+1:n] - x(j) * A[j+1:n,j] */
+/*       end */
+
+/*  Define bounds on the components of x after j iterations of the loop: */
+/*     M(j) = bound on x[1:j] */
+/*     G(j) = bound on x[j+1:n] */
+/*  Initially, let M(0) = 0 and G(0) = max{x(i), i=1,...,n}. */
+
+/*  Then for iteration j+1 we have */
+/*     M(j+1) <= G(j) / | A(j+1,j+1) | */
+/*     G(j+1) <= G(j) + M(j+1) * | A[j+2:n,j+1] | */
+/*            <= G(j) ( 1 + CNORM(j+1) / | A(j+1,j+1) | ) */
+
+/*  where CNORM(j+1) is greater than or equal to the infinity-norm of */
+/*  column j+1 of A, not counting the diagonal.  Hence */
+
+/*     G(j) <= G(0) product ( 1 + CNORM(i) / | A(i,i) | ) */
+/*                  1<=i<=j */
+/*  and */
+
+/*     |x(j)| <= ( G(0) / |A(j,j)| ) product ( 1 + CNORM(i) / |A(i,i)| ) */
+/*                                   1<=i< j */
+
+/*  Since |x(j)| <= M(j), we use the Level 2 BLAS routine CTRSV if the */
+/*  reciprocal of the largest M(j), j=1,..,n, is larger than */
+/*  max(underflow, 1/overflow). */
+
+/*  The bound on x(j) is also used to determine when a step in the */
+/*  columnwise method can be performed without fear of overflow.  If */
+/*  the computed bound is greater than a large constant, x is scaled to */
+/*  prevent overflow, but if the bound overflows, x is set to 0, x(j) to */
+/*  1, and scale to 0, and a non-trivial solution to A*x = 0 is found. */
+
+/*  Similarly, a row-wise scheme is used to solve A**T *x = b  or */
+/*  A**H *x = b.  The basic algorithm for A upper triangular is */
+
+/*       for j = 1, ..., n */
+/*            x(j) := ( b(j) - A[1:j-1,j]' * x[1:j-1] ) / A(j,j) */
+/*       end */
+
+/*  We simultaneously compute two bounds */
+/*       G(j) = bound on ( b(i) - A[1:i-1,i]' * x[1:i-1] ), 1<=i<=j */
+/*       M(j) = bound on x(i), 1<=i<=j */
+
+/*  The initial values are G(0) = 0, M(0) = max{b(i), i=1,..,n}, and we */
+/*  add the constraint G(j) >= G(j-1) and M(j) >= M(j-1) for j >= 1. */
+/*  Then the bound on x(j) is */
+
+/*       M(j) <= M(j-1) * ( 1 + CNORM(j) ) / | A(j,j) | */
+
+/*            <= M(0) * product ( ( 1 + CNORM(i) ) / |A(i,i)| ) */
+/*                      1<=i<=j */
+
+/*  and we can safely call CTRSV if 1/M(n) and 1/G(n) are both greater */
+/*  than max(underflow, 1/overflow). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -293,8 +315,8 @@
 	}
     }
 
-/*     Scale the column norms by TSCAL if the maximum element in CNORM is   
-       greater than BIGNUM/2. */
+/*     Scale the column norms by TSCAL if the maximum element in CNORM is */
+/*     greater than BIGNUM/2. */
 
     imax = isamax_(n, &cnorm[1], &c__1);
     tmax = cnorm[imax];
@@ -305,8 +327,8 @@
 	sscal_(n, &tscal, &cnorm[1], &c__1);
     }
 
-/*     Compute a bound on the computed solution vector to see if the   
-       Level 2 BLAS routine CTRSV can be used. */
+/*     Compute a bound on the computed solution vector to see if the */
+/*     Level 2 BLAS routine CTRSV can be used. */
 
     xmax = 0.f;
     i__1 = *n;
@@ -341,10 +363,10 @@
 
 	if (nounit) {
 
-/*           A is non-unit triangular.   
+/*           A is non-unit triangular. */
 
-             Compute GROW = 1/G(j) and XBND = 1/M(j).   
-             Initially, G(0) = max{x(i), i=1,...,n}. */
+/*           Compute GROW = 1/G(j) and XBND = 1/M(j). */
+/*           Initially, G(0) = max{x(i), i=1,...,n}. */
 
 	    grow = .5f / dmax(xbnd,smlnum);
 	    xbnd = grow;
@@ -365,9 +387,9 @@
 
 		if (tjj >= smlnum) {
 
-/*                 M(j) = G(j-1) / abs(A(j,j))   
+/*                 M(j) = G(j-1) / abs(A(j,j)) */
 
-   Computing MIN */
+/* Computing MIN */
 		    r__1 = xbnd, r__2 = dmin(1.f,tjj) * grow;
 		    xbnd = dmin(r__1,r__2);
 		} else {
@@ -393,11 +415,11 @@
 	    grow = xbnd;
 	} else {
 
-/*           A is unit triangular.   
+/*           A is unit triangular. */
 
-             Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}.   
+/*           Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}. */
 
-   Computing MIN */
+/* Computing MIN */
 	    r__1 = 1.f, r__2 = .5f / dmax(xbnd,smlnum);
 	    grow = dmin(r__1,r__2);
 	    i__2 = jlast;
@@ -440,10 +462,10 @@ L60:
 
 	if (nounit) {
 
-/*           A is non-unit triangular.   
+/*           A is non-unit triangular. */
 
-             Compute GROW = 1/G(j) and XBND = 1/M(j).   
-             Initially, M(0) = max{x(i), i=1,...,n}. */
+/*           Compute GROW = 1/G(j) and XBND = 1/M(j). */
+/*           Initially, M(0) = max{x(i), i=1,...,n}. */
 
 	    grow = .5f / dmax(xbnd,smlnum);
 	    xbnd = grow;
@@ -487,11 +509,11 @@ L60:
 	    grow = dmin(grow,xbnd);
 	} else {
 
-/*           A is unit triangular.   
+/*           A is unit triangular. */
 
-             Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}.   
+/*           Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}. */
 
-   Computing MIN */
+/* Computing MIN */
 	    r__1 = 1.f, r__2 = .5f / dmax(xbnd,smlnum);
 	    grow = dmin(r__1,r__2);
 	    i__2 = jlast;
@@ -517,8 +539,8 @@ L90:
 
     if (grow * tscal > smlnum) {
 
-/*        Use the Level 2 BLAS solve if the reciprocal of the bound on   
-          elements of X is not too small. */
+/*        Use the Level 2 BLAS solve if the reciprocal of the bound on */
+/*        elements of X is not too small. */
 
 	ctrsv_(uplo, trans, diag, n, &a[a_offset], lda, &x[1], &c__1);
     } else {
@@ -527,8 +549,8 @@ L90:
 
 	if (xmax > bignum * .5f) {
 
-/*           Scale X so that its components are less than or equal to   
-             BIGNUM in absolute value. */
+/*           Scale X so that its components are less than or equal to */
+/*           BIGNUM in absolute value. */
 
 	    *scale = bignum * .5f / xmax;
 	    csscal_(n, scale, &x[1], &c__1);
@@ -581,21 +603,22 @@ L90:
 		    cladiv_(&q__1, &x[j], &tjjs);
 		    x[i__3].r = q__1.r, x[i__3].i = q__1.i;
 		    i__3 = j;
-		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j] 			    ), dabs(r__2));
+		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j]
+			    ), dabs(r__2));
 		} else if (tjj > 0.f) {
 
 /*                    0 < abs(A(j,j)) <= SMLNUM: */
 
 		    if (xj > tjj * bignum) {
 
-/*                       Scale x by (1/abs(x(j)))*abs(A(j,j))*BIGNUM   
-                         to avoid overflow when dividing by A(j,j). */
+/*                       Scale x by (1/abs(x(j)))*abs(A(j,j))*BIGNUM */
+/*                       to avoid overflow when dividing by A(j,j). */
 
 			rec = tjj * bignum / xj;
 			if (cnorm[j] > 1.f) {
 
-/*                          Scale by 1/CNORM(j) to avoid overflow when   
-                            multiplying x(j) times column j. */
+/*                          Scale by 1/CNORM(j) to avoid overflow when */
+/*                          multiplying x(j) times column j. */
 
 			    rec /= cnorm[j];
 			}
@@ -607,11 +630,12 @@ L90:
 		    cladiv_(&q__1, &x[j], &tjjs);
 		    x[i__3].r = q__1.r, x[i__3].i = q__1.i;
 		    i__3 = j;
-		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j] 			    ), dabs(r__2));
+		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j]
+			    ), dabs(r__2));
 		} else {
 
-/*                    A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                      scale = 0, and compute a solution to A*x = 0. */
+/*                    A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                    scale = 0, and compute a solution to A*x = 0. */
 
 		    i__3 = *n;
 		    for (i__ = 1; i__ <= i__3; ++i__) {
@@ -627,8 +651,8 @@ L90:
 		}
 L105:
 
-/*              Scale x if necessary to avoid overflow when adding a   
-                multiple of column j of A. */
+/*              Scale x if necessary to avoid overflow when adding a */
+/*              multiple of column j of A. */
 
 		if (xj > 1.f) {
 		    rec = 1.f / xj;
@@ -651,8 +675,8 @@ L105:
 		if (upper) {
 		    if (j > 1) {
 
-/*                    Compute the update   
-                         x(1:j-1) := x(1:j-1) - x(j) * A(1:j-1,j) */
+/*                    Compute the update */
+/*                       x(1:j-1) := x(1:j-1) - x(j) * A(1:j-1,j) */
 
 			i__3 = j - 1;
 			i__4 = j;
@@ -669,8 +693,8 @@ L105:
 		} else {
 		    if (j < *n) {
 
-/*                    Compute the update   
-                         x(j+1:n) := x(j+1:n) - x(j) * A(j+1:n,j) */
+/*                    Compute the update */
+/*                       x(j+1:n) := x(j+1:n) - x(j) * A(j+1:n,j) */
 
 			i__3 = *n - j;
 			i__4 = j;
@@ -696,8 +720,8 @@ L105:
 	    i__1 = jinc;
 	    for (j = jfirst; i__1 < 0 ? j >= i__2 : j <= i__2; j += i__1) {
 
-/*              Compute x(j) = b(j) - sum A(k,j)*x(k).   
-                                      k<>j */
+/*              Compute x(j) = b(j) - sum A(k,j)*x(k). */
+/*                                    k<>j */
 
 		i__3 = j;
 		xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j]), 
@@ -721,9 +745,9 @@ L105:
 			     dabs(r__2));
 		    if (tjj > 1.f) {
 
-/*                       Divide by A(j,j) when scaling x if A(j,j) > 1.   
+/*                       Divide by A(j,j) when scaling x if A(j,j) > 1. */
 
-   Computing MIN */
+/* Computing MIN */
 			r__1 = 1.f, r__2 = rec * tjj;
 			rec = dmin(r__1,r__2);
 			cladiv_(&q__1, &uscal, &tjjs);
@@ -739,8 +763,8 @@ L105:
 		csumj.r = 0.f, csumj.i = 0.f;
 		if (uscal.r == 1.f && uscal.i == 0.f) {
 
-/*                 If the scaling needed for A in the dot product is 1,   
-                   call CDOTU to perform the dot product. */
+/*                 If the scaling needed for A in the dot product is 1, */
+/*                 call CDOTU to perform the dot product. */
 
 		    if (upper) {
 			i__3 = j - 1;
@@ -795,8 +819,8 @@ L105:
 		q__1.r = tscal, q__1.i = 0.f;
 		if (uscal.r == q__1.r && uscal.i == q__1.i) {
 
-/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j)   
-                   was not used to scale the dotproduct. */
+/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j) */
+/*                 was not used to scale the dotproduct. */
 
 		    i__3 = j;
 		    i__4 = j;
@@ -804,7 +828,8 @@ L105:
 			    csumj.i;
 		    x[i__3].r = q__1.r, x[i__3].i = q__1.i;
 		    i__3 = j;
-		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j] 			    ), dabs(r__2));
+		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j]
+			    ), dabs(r__2));
 		    if (nounit) {
 			i__3 = j + j * a_dim1;
 			q__1.r = tscal * a[i__3].r, q__1.i = tscal * a[i__3]
@@ -857,8 +882,8 @@ L105:
 			x[i__3].r = q__1.r, x[i__3].i = q__1.i;
 		    } else {
 
-/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                         scale = 0 and compute a solution to A**T *x = 0. */
+/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                       scale = 0 and compute a solution to A**T *x = 0. */
 
 			i__3 = *n;
 			for (i__ = 1; i__ <= i__3; ++i__) {
@@ -875,8 +900,8 @@ L145:
 		    ;
 		} else {
 
-/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot   
-                   product has already been divided by 1/A(j,j). */
+/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot */
+/*                 product has already been divided by 1/A(j,j). */
 
 		    i__3 = j;
 		    cladiv_(&q__2, &x[j], &tjjs);
@@ -899,8 +924,8 @@ L145:
 	    i__2 = jinc;
 	    for (j = jfirst; i__2 < 0 ? j >= i__1 : j <= i__1; j += i__2) {
 
-/*              Compute x(j) = b(j) - sum A(k,j)*x(k).   
-                                      k<>j */
+/*              Compute x(j) = b(j) - sum A(k,j)*x(k). */
+/*                                    k<>j */
 
 		i__3 = j;
 		xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j]), 
@@ -923,9 +948,9 @@ L145:
 			     dabs(r__2));
 		    if (tjj > 1.f) {
 
-/*                       Divide by A(j,j) when scaling x if A(j,j) > 1.   
+/*                       Divide by A(j,j) when scaling x if A(j,j) > 1. */
 
-   Computing MIN */
+/* Computing MIN */
 			r__1 = 1.f, r__2 = rec * tjj;
 			rec = dmin(r__1,r__2);
 			cladiv_(&q__1, &uscal, &tjjs);
@@ -941,8 +966,8 @@ L145:
 		csumj.r = 0.f, csumj.i = 0.f;
 		if (uscal.r == 1.f && uscal.i == 0.f) {
 
-/*                 If the scaling needed for A in the dot product is 1,   
-                   call CDOTC to perform the dot product. */
+/*                 If the scaling needed for A in the dot product is 1, */
+/*                 call CDOTC to perform the dot product. */
 
 		    if (upper) {
 			i__3 = j - 1;
@@ -997,8 +1022,8 @@ L145:
 		q__1.r = tscal, q__1.i = 0.f;
 		if (uscal.r == q__1.r && uscal.i == q__1.i) {
 
-/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j)   
-                   was not used to scale the dotproduct. */
+/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j) */
+/*                 was not used to scale the dotproduct. */
 
 		    i__3 = j;
 		    i__4 = j;
@@ -1006,7 +1031,8 @@ L145:
 			    csumj.i;
 		    x[i__3].r = q__1.r, x[i__3].i = q__1.i;
 		    i__3 = j;
-		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j] 			    ), dabs(r__2));
+		    xj = (r__1 = x[i__3].r, dabs(r__1)) + (r__2 = r_imag(&x[j]
+			    ), dabs(r__2));
 		    if (nounit) {
 			r_cnjg(&q__2, &a[j + j * a_dim1]);
 			q__1.r = tscal * q__2.r, q__1.i = tscal * q__2.i;
@@ -1058,8 +1084,8 @@ L145:
 			x[i__3].r = q__1.r, x[i__3].i = q__1.i;
 		    } else {
 
-/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                         scale = 0 and compute a solution to A**H *x = 0. */
+/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                       scale = 0 and compute a solution to A**H *x = 0. */
 
 			i__3 = *n;
 			for (i__ = 1; i__ <= i__3; ++i__) {
@@ -1076,8 +1102,8 @@ L185:
 		    ;
 		} else {
 
-/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot   
-                   product has already been divided by 1/A(j,j). */
+/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot */
+/*                 product has already been divided by 1/A(j,j). */
 
 		    i__3 = j;
 		    cladiv_(&q__2, &x[j], &tjjs);
