@@ -1,137 +1,159 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
-/* Subroutine */ int cptrfs_(char *uplo, integer *n, integer *nrhs, real *d__,
+/* Table of constant values */
+
+static integer c__1 = 1;
+static complex c_b16 = {1.f,0.f};
+
+/* Subroutine */ int cptrfs_(char *uplo, integer *n, integer *nrhs, real *d__, 
 	 complex *e, real *df, complex *ef, complex *b, integer *ldb, complex 
 	*x, integer *ldx, real *ferr, real *berr, complex *work, real *rwork, 
 	integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CPTRFS improves the computed solution to a system of linear   
-    equations when the coefficient matrix is Hermitian positive definite   
-    and tridiagonal, and provides error bounds and backward error   
-    estimates for the solution.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the superdiagonal or the subdiagonal of the   
-            tridiagonal matrix A is stored and the form of the   
-            factorization:   
-            = 'U':  E is the superdiagonal of A, and A = U**H*D*U;   
-            = 'L':  E is the subdiagonal of A, and A = L*D*L**H.   
-            (The two forms are equivalent if A is real.)   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    NRHS    (input) INTEGER   
-            The number of right hand sides, i.e., the number of columns   
-            of the matrix B.  NRHS >= 0.   
-
-    D       (input) REAL array, dimension (N)   
-            The n real diagonal elements of the tridiagonal matrix A.   
-
-    E       (input) COMPLEX array, dimension (N-1)   
-            The (n-1) off-diagonal elements of the tridiagonal matrix A   
-            (see UPLO).   
-
-    DF      (input) REAL array, dimension (N)   
-            The n diagonal elements of the diagonal matrix D from   
-            the factorization computed by CPTTRF.   
-
-    EF      (input) COMPLEX array, dimension (N-1)   
-            The (n-1) off-diagonal elements of the unit bidiagonal   
-            factor U or L from the factorization computed by CPTTRF   
-            (see UPLO).   
-
-    B       (input) COMPLEX array, dimension (LDB,NRHS)   
-            The right hand side matrix B.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B.  LDB >= max(1,N).   
-
-    X       (input/output) COMPLEX array, dimension (LDX,NRHS)   
-            On entry, the solution matrix X, as computed by CPTTRS.   
-            On exit, the improved solution matrix X.   
-
-    LDX     (input) INTEGER   
-            The leading dimension of the array X.  LDX >= max(1,N).   
-
-    FERR    (output) REAL array, dimension (NRHS)   
-            The forward error bound for each solution vector   
-            X(j) (the j-th column of the solution matrix X).   
-            If XTRUE is the true solution corresponding to X(j), FERR(j)   
-            is an estimated upper bound for the magnitude of the largest   
-            element in (X(j) - XTRUE) divided by the magnitude of the   
-            largest element in X(j).   
-
-    BERR    (output) REAL array, dimension (NRHS)   
-            The componentwise relative backward error of each solution   
-            vector X(j) (i.e., the smallest relative change in   
-            any element of A or B that makes X(j) an exact solution).   
-
-    WORK    (workspace) COMPLEX array, dimension (N)   
-
-    RWORK   (workspace) REAL array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value   
-
-    Internal Parameters   
-    ===================   
-
-    ITMAX is the maximum number of steps of iterative refinement.   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static complex c_b16 = {1.f,0.f};
-    
     /* System generated locals */
     integer b_dim1, b_offset, x_dim1, x_offset, i__1, i__2, i__3, i__4, i__5, 
 	    i__6;
     real r__1, r__2, r__3, r__4, r__5, r__6, r__7, r__8, r__9, r__10, r__11, 
 	    r__12;
     complex q__1, q__2, q__3;
+
     /* Builtin functions */
     double r_imag(complex *);
     void r_cnjg(complex *, complex *);
     double c_abs(complex *);
+
     /* Local variables */
-    static integer i__, j;
-    static real s;
-    static complex bi, cx, dx, ex;
-    static integer ix, nz;
-    static real eps, safe1, safe2;
+    integer i__, j;
+    real s;
+    complex bi, cx, dx, ex;
+    integer ix, nz;
+    real eps, safe1, safe2;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int caxpy_(integer *, complex *, complex *, 
 	    integer *, complex *, integer *);
-    static integer count;
-    static logical upper;
+    integer count;
+    logical upper;
     extern doublereal slamch_(char *);
-    static real safmin;
+    real safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *);
     extern integer isamax_(integer *, real *, integer *);
-    static real lstres;
+    real lstres;
     extern /* Subroutine */ int cpttrs_(char *, integer *, integer *, real *, 
 	    complex *, complex *, integer *, integer *);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CPTRFS improves the computed solution to a system of linear */
+/*  equations when the coefficient matrix is Hermitian positive definite */
+/*  and tridiagonal, and provides error bounds and backward error */
+/*  estimates for the solution. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the superdiagonal or the subdiagonal of the */
+/*          tridiagonal matrix A is stored and the form of the */
+/*          factorization: */
+/*          = 'U':  E is the superdiagonal of A, and A = U**H*D*U; */
+/*          = 'L':  E is the subdiagonal of A, and A = L*D*L**H. */
+/*          (The two forms are equivalent if A is real.) */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand sides, i.e., the number of columns */
+/*          of the matrix B.  NRHS >= 0. */
+
+/*  D       (input) REAL array, dimension (N) */
+/*          The n real diagonal elements of the tridiagonal matrix A. */
+
+/*  E       (input) COMPLEX array, dimension (N-1) */
+/*          The (n-1) off-diagonal elements of the tridiagonal matrix A */
+/*          (see UPLO). */
+
+/*  DF      (input) REAL array, dimension (N) */
+/*          The n diagonal elements of the diagonal matrix D from */
+/*          the factorization computed by CPTTRF. */
+
+/*  EF      (input) COMPLEX array, dimension (N-1) */
+/*          The (n-1) off-diagonal elements of the unit bidiagonal */
+/*          factor U or L from the factorization computed by CPTTRF */
+/*          (see UPLO). */
+
+/*  B       (input) COMPLEX array, dimension (LDB,NRHS) */
+/*          The right hand side matrix B. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B.  LDB >= max(1,N). */
+
+/*  X       (input/output) COMPLEX array, dimension (LDX,NRHS) */
+/*          On entry, the solution matrix X, as computed by CPTTRS. */
+/*          On exit, the improved solution matrix X. */
+
+/*  LDX     (input) INTEGER */
+/*          The leading dimension of the array X.  LDX >= max(1,N). */
+
+/*  FERR    (output) REAL array, dimension (NRHS) */
+/*          The forward error bound for each solution vector */
+/*          X(j) (the j-th column of the solution matrix X). */
+/*          If XTRUE is the true solution corresponding to X(j), FERR(j) */
+/*          is an estimated upper bound for the magnitude of the largest */
+/*          element in (X(j) - XTRUE) divided by the magnitude of the */
+/*          largest element in X(j). */
+
+/*  BERR    (output) REAL array, dimension (NRHS) */
+/*          The componentwise relative backward error of each solution */
+/*          vector X(j) (i.e., the smallest relative change in */
+/*          any element of A or B that makes X(j) an exact solution). */
+
+/*  WORK    (workspace) COMPLEX array, dimension (N) */
+
+/*  RWORK   (workspace) REAL array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
+
+/*  Internal Parameters */
+/*  =================== */
+
+/*  ITMAX is the maximum number of steps of iterative refinement. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     --d__;
     --e;
     --df;
@@ -196,10 +218,10 @@
 	lstres = 3.f;
 L20:
 
-/*        Loop until stopping criterion is satisfied.   
+/*        Loop until stopping criterion is satisfied. */
 
-          Compute residual R = B - A * X.  Also compute   
-          abs(A)*abs(x) + abs(b) for use in the backward error bound. */
+/*        Compute residual R = B - A * X.  Also compute */
+/*        abs(A)*abs(x) + abs(b) for use in the backward error bound. */
 
 	if (upper) {
 	    if (*n == 1) {
@@ -401,14 +423,14 @@ L20:
 	    }
 	}
 
-/*        Compute componentwise relative backward error from formula   
+/*        Compute componentwise relative backward error from formula */
 
-          max(i) ( abs(R(i)) / ( abs(A)*abs(X) + abs(B) )(i) )   
+/*        max(i) ( abs(R(i)) / ( abs(A)*abs(X) + abs(B) )(i) ) */
 
-          where abs(Z) is the componentwise absolute value of the matrix   
-          or vector Z.  If the i-th component of the denominator is less   
-          than SAFE2, then SAFE1 is added to the i-th components of the   
-          numerator and denominator before dividing. */
+/*        where abs(Z) is the componentwise absolute value of the matrix */
+/*        or vector Z.  If the i-th component of the denominator is less */
+/*        than SAFE2, then SAFE1 is added to the i-th components of the */
+/*        numerator and denominator before dividing. */
 
 	s = 0.f;
 	i__2 = *n;
@@ -431,11 +453,11 @@ L20:
 	}
 	berr[j] = s;
 
-/*        Test stopping criterion. Continue iterating if   
-             1) The residual BERR(J) is larger than machine epsilon, and   
-             2) BERR(J) decreased by at least a factor of 2 during the   
-                last iteration, and   
-             3) At most ITMAX iterations tried. */
+/*        Test stopping criterion. Continue iterating if */
+/*           1) The residual BERR(J) is larger than machine epsilon, and */
+/*           2) BERR(J) decreased by at least a factor of 2 during the */
+/*              last iteration, and */
+/*           3) At most ITMAX iterations tried. */
 
 	if (berr[j] > eps && berr[j] * 2.f <= lstres && count <= 5) {
 
@@ -448,23 +470,23 @@ L20:
 	    goto L20;
 	}
 
-/*        Bound error from formula   
+/*        Bound error from formula */
 
-          norm(X - XTRUE) / norm(X) .le. FERR =   
-          norm( abs(inv(A))*   
-             ( abs(R) + NZ*EPS*( abs(A)*abs(X)+abs(B) ))) / norm(X)   
+/*        norm(X - XTRUE) / norm(X) .le. FERR = */
+/*        norm( abs(inv(A))* */
+/*           ( abs(R) + NZ*EPS*( abs(A)*abs(X)+abs(B) ))) / norm(X) */
 
-          where   
-            norm(Z) is the magnitude of the largest component of Z   
-            inv(A) is the inverse of A   
-            abs(Z) is the componentwise absolute value of the matrix or   
-               vector Z   
-            NZ is the maximum number of nonzeros in any row of A, plus 1   
-            EPS is machine epsilon   
+/*        where */
+/*          norm(Z) is the magnitude of the largest component of Z */
+/*          inv(A) is the inverse of A */
+/*          abs(Z) is the componentwise absolute value of the matrix or */
+/*             vector Z */
+/*          NZ is the maximum number of nonzeros in any row of A, plus 1 */
+/*          EPS is machine epsilon */
 
-          The i-th component of abs(R)+NZ*EPS*(abs(A)*abs(X)+abs(B))   
-          is incremented by SAFE1 if the i-th component of   
-          abs(A)*abs(X) + abs(B) is less than SAFE2. */
+/*        The i-th component of abs(R)+NZ*EPS*(abs(A)*abs(X)+abs(B)) */
+/*        is incremented by SAFE1 if the i-th component of */
+/*        abs(A)*abs(X) + abs(B) is less than SAFE2. */
 
 	i__2 = *n;
 	for (i__ = 1; i__ <= i__2; ++i__) {
@@ -484,16 +506,16 @@ L20:
 	ix = isamax_(n, &rwork[1], &c__1);
 	ferr[j] = rwork[ix];
 
-/*        Estimate the norm of inv(A).   
+/*        Estimate the norm of inv(A). */
 
-          Solve M(A) * x = e, where M(A) = (m(i,j)) is given by   
+/*        Solve M(A) * x = e, where M(A) = (m(i,j)) is given by */
 
-             m(i,j) =  abs(A(i,j)), i = j,   
-             m(i,j) = -abs(A(i,j)), i .ne. j,   
+/*           m(i,j) =  abs(A(i,j)), i = j, */
+/*           m(i,j) = -abs(A(i,j)), i .ne. j, */
 
-          and e = [ 1, 1, ..., 1 ]'.  Note M(A) = M(L)*D*M(L)'.   
+/*        and e = [ 1, 1, ..., 1 ]'.  Note M(A) = M(L)*D*M(L)'. */
 
-          Solve M(L) * x = e. */
+/*        Solve M(L) * x = e. */
 
 	rwork[1] = 1.f;
 	i__2 = *n;
