@@ -1,147 +1,169 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {1.f,0.f};
+static integer c__1 = 1;
 
 /* Subroutine */ int csptrf_(char *uplo, integer *n, complex *ap, integer *
 	ipiv, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    CSPTRF computes the factorization of a complex symmetric matrix A   
-    stored in packed format using the Bunch-Kaufman diagonal pivoting   
-    method:   
-
-       A = U*D*U**T  or  A = L*D*L**T   
-
-    where U (or L) is a product of permutation and unit upper (lower)   
-    triangular matrices, and D is symmetric and block diagonal with   
-    1-by-1 and 2-by-2 diagonal blocks.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            = 'U':  Upper triangle of A is stored;   
-            = 'L':  Lower triangle of A is stored.   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    AP      (input/output) COMPLEX array, dimension (N*(N+1)/2)   
-            On entry, the upper or lower triangle of the symmetric matrix   
-            A, packed columnwise in a linear array.  The j-th column of A   
-            is stored in the array AP as follows:   
-            if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;   
-            if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.   
-
-            On exit, the block diagonal matrix D and the multipliers used   
-            to obtain the factor U or L, stored as a packed triangular   
-            matrix overwriting A (see below for further details).   
-
-    IPIV    (output) INTEGER array, dimension (N)   
-            Details of the interchanges and the block structure of D.   
-            If IPIV(k) > 0, then rows and columns k and IPIV(k) were   
-            interchanged and D(k,k) is a 1-by-1 diagonal block.   
-            If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and   
-            columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)   
-            is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =   
-            IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were   
-            interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            < 0: if INFO = -i, the i-th argument had an illegal value   
-            > 0: if INFO = i, D(i,i) is exactly zero.  The factorization   
-                 has been completed, but the block diagonal matrix D is   
-                 exactly singular, and division by zero will occur if it   
-                 is used to solve a system of equations.   
-
-    Further Details   
-    ===============   
-
-    5-96 - Based on modifications by J. Lewis, Boeing Computer Services   
-           Company   
-
-    If UPLO = 'U', then A = U*D*U', where   
-       U = P(n)*U(n)* ... *P(k)U(k)* ...,   
-    i.e., U is a product of terms P(k)*U(k), where k decreases from n to   
-    1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1   
-    and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as   
-    defined by IPIV(k), and U(k) is a unit upper triangular matrix, such   
-    that if the diagonal block D(k) is of order s (s = 1 or 2), then   
-
-               (   I    v    0   )   k-s   
-       U(k) =  (   0    I    0   )   s   
-               (   0    0    I   )   n-k   
-                  k-s   s   n-k   
-
-    If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).   
-    If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),   
-    and A(k,k), and v overwrites A(1:k-2,k-1:k).   
-
-    If UPLO = 'L', then A = L*D*L', where   
-       L = P(1)*L(1)* ... *P(k)*L(k)* ...,   
-    i.e., L is a product of terms P(k)*L(k), where k increases from 1 to   
-    n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1   
-    and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as   
-    defined by IPIV(k), and L(k) is a unit lower triangular matrix, such   
-    that if the diagonal block D(k) is of order s (s = 1 or 2), then   
-
-               (   I    0     0   )  k-1   
-       L(k) =  (   0    I     0   )  s   
-               (   0    v     I   )  n-k-s+1   
-                  k-1   s  n-k-s+1   
-
-    If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).   
-    If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),   
-    and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {1.f,0.f};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer i__1, i__2, i__3, i__4, i__5, i__6;
     real r__1, r__2, r__3, r__4;
     complex q__1, q__2, q__3, q__4;
+
     /* Builtin functions */
     double sqrt(doublereal), r_imag(complex *);
     void c_div(complex *, complex *, complex *);
+
     /* Local variables */
-    static integer i__, j, k;
-    static complex t, r1, d11, d12, d21, d22;
-    static integer kc, kk, kp;
-    static complex wk;
-    static integer kx, knc, kpc, npp;
-    static complex wkm1, wkp1;
-    static integer imax, jmax;
-    extern /* Subroutine */ int cspr_(char *, integer *, complex *, complex *,
+    integer i__, j, k;
+    complex t, r1, d11, d12, d21, d22;
+    integer kc, kk, kp;
+    complex wk;
+    integer kx, knc, kpc, npp;
+    complex wkm1, wkp1;
+    integer imax, jmax;
+    extern /* Subroutine */ int cspr_(char *, integer *, complex *, complex *, 
 	     integer *, complex *);
-    static real alpha;
+    real alpha;
     extern /* Subroutine */ int cscal_(integer *, complex *, complex *, 
 	    integer *);
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int cswap_(integer *, complex *, integer *, 
 	    complex *, integer *);
-    static integer kstep;
-    static logical upper;
-    static real absakk;
+    integer kstep;
+    logical upper;
+    real absakk;
     extern integer icamax_(integer *, complex *, integer *);
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static real colmax, rowmax;
+    real colmax, rowmax;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CSPTRF computes the factorization of a complex symmetric matrix A */
+/*  stored in packed format using the Bunch-Kaufman diagonal pivoting */
+/*  method: */
+
+/*     A = U*D*U**T  or  A = L*D*L**T */
+
+/*  where U (or L) is a product of permutation and unit upper (lower) */
+/*  triangular matrices, and D is symmetric and block diagonal with */
+/*  1-by-1 and 2-by-2 diagonal blocks. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          = 'U':  Upper triangle of A is stored; */
+/*          = 'L':  Lower triangle of A is stored. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  AP      (input/output) COMPLEX array, dimension (N*(N+1)/2) */
+/*          On entry, the upper or lower triangle of the symmetric matrix */
+/*          A, packed columnwise in a linear array.  The j-th column of A */
+/*          is stored in the array AP as follows: */
+/*          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j; */
+/*          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n. */
+
+/*          On exit, the block diagonal matrix D and the multipliers used */
+/*          to obtain the factor U or L, stored as a packed triangular */
+/*          matrix overwriting A (see below for further details). */
+
+/*  IPIV    (output) INTEGER array, dimension (N) */
+/*          Details of the interchanges and the block structure of D. */
+/*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were */
+/*          interchanged and D(k,k) is a 1-by-1 diagonal block. */
+/*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and */
+/*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k) */
+/*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) = */
+/*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were */
+/*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          < 0: if INFO = -i, the i-th argument had an illegal value */
+/*          > 0: if INFO = i, D(i,i) is exactly zero.  The factorization */
+/*               has been completed, but the block diagonal matrix D is */
+/*               exactly singular, and division by zero will occur if it */
+/*               is used to solve a system of equations. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  5-96 - Based on modifications by J. Lewis, Boeing Computer Services */
+/*         Company */
+
+/*  If UPLO = 'U', then A = U*D*U', where */
+/*     U = P(n)*U(n)* ... *P(k)U(k)* ..., */
+/*  i.e., U is a product of terms P(k)*U(k), where k decreases from n to */
+/*  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1 */
+/*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as */
+/*  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such */
+/*  that if the diagonal block D(k) is of order s (s = 1 or 2), then */
+
+/*             (   I    v    0   )   k-s */
+/*     U(k) =  (   0    I    0   )   s */
+/*             (   0    0    I   )   n-k */
+/*                k-s   s   n-k */
+
+/*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k). */
+/*  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k), */
+/*  and A(k,k), and v overwrites A(1:k-2,k-1:k). */
+
+/*  If UPLO = 'L', then A = L*D*L', where */
+/*     L = P(1)*L(1)* ... *P(k)*L(k)* ..., */
+/*  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to */
+/*  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1 */
+/*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as */
+/*  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such */
+/*  that if the diagonal block D(k) is of order s (s = 1 or 2), then */
+
+/*             (   I    0     0   )  k-1 */
+/*     L(k) =  (   0    I     0   )  s */
+/*             (   0    v     I   )  n-k-s+1 */
+/*                k-1   s  n-k-s+1 */
+
+/*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k). */
+/*  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k), */
+/*  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     --ipiv;
     --ap;
 
@@ -165,10 +187,10 @@
 
     if (upper) {
 
-/*        Factorize A as U*D*U' using the upper triangle of A   
+/*        Factorize A as U*D*U' using the upper triangle of A */
 
-          K is the main loop index, decreasing from N to 1 in steps of   
-          1 or 2 */
+/*        K is the main loop index, decreasing from N to 1 in steps of */
+/*        1 or 2 */
 
 	k = *n;
 	kc = (*n - 1) * *n / 2 + 1;
@@ -182,15 +204,15 @@ L10:
 	}
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	i__1 = kc + k - 1;
 	absakk = (r__1 = ap[i__1].r, dabs(r__1)) + (r__2 = r_imag(&ap[kc + k 
 		- 1]), dabs(r__2));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k > 1) {
 	    i__1 = k - 1;
@@ -218,8 +240,8 @@ L10:
 		kp = k;
 	    } else {
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		rowmax = 0.f;
 		jmax = imax;
@@ -258,14 +280,14 @@ L10:
 		    if ((r__1 = ap[i__1].r, dabs(r__1)) + (r__2 = r_imag(&ap[
 			    kpc + imax - 1]), dabs(r__2)) >= alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 			kp = imax;
 		    } else {
 
-/*                 interchange rows and columns K-1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K-1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 			kp = imax;
 			kstep = 2;
@@ -279,8 +301,8 @@ L10:
 	    }
 	    if (kp != kk) {
 
-/*              Interchange rows and columns KK and KP in the leading   
-                submatrix A(1:k,1:k) */
+/*              Interchange rows and columns KK and KP in the leading */
+/*              submatrix A(1:k,1:k) */
 
 		i__1 = kp - 1;
 		cswap_(&i__1, &ap[knc], &c__1, &ap[kpc], &c__1);
@@ -319,15 +341,15 @@ L10:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k now holds   
+/*              1-by-1 pivot block D(k): column k now holds */
 
-                W(k) = U(k)*D(k)   
+/*              W(k) = U(k)*D(k) */
 
-                where U(k) is the k-th column of U   
+/*              where U(k) is the k-th column of U */
 
-                Perform a rank-1 update of A(1:k-1,1:k-1) as   
+/*              Perform a rank-1 update of A(1:k-1,1:k-1) as */
 
-                A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)' */
+/*              A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)' */
 
 		c_div(&q__1, &c_b1, &ap[kc + k - 1]);
 		r1.r = q__1.r, r1.i = q__1.i;
@@ -341,17 +363,17 @@ L10:
 		cscal_(&i__1, &r1, &ap[kc], &c__1);
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns k and k-1 now hold   
+/*              2-by-2 pivot block D(k): columns k and k-1 now hold */
 
-                ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k)   
+/*              ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k) */
 
-                where U(k) and U(k-1) are the k-th and (k-1)-th columns   
-                of U   
+/*              where U(k) and U(k-1) are the k-th and (k-1)-th columns */
+/*              of U */
 
-                Perform a rank-2 update of A(1:k-2,1:k-2) as   
+/*              Perform a rank-2 update of A(1:k-2,1:k-2) as */
 
-                A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )'   
-                   = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )' */
+/*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )' */
+/*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )' */
 
 		if (k > 2) {
 
@@ -436,10 +458,10 @@ L10:
 
     } else {
 
-/*        Factorize A as L*D*L' using the lower triangle of A   
+/*        Factorize A as L*D*L' using the lower triangle of A */
 
-          K is the main loop index, increasing from 1 to N in steps of   
-          1 or 2 */
+/*        K is the main loop index, increasing from 1 to N in steps of */
+/*        1 or 2 */
 
 	k = 1;
 	kc = 1;
@@ -454,15 +476,15 @@ L60:
 	}
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	i__1 = kc;
 	absakk = (r__1 = ap[i__1].r, dabs(r__1)) + (r__2 = r_imag(&ap[kc]), 
 		dabs(r__2));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k < *n) {
 	    i__1 = *n - k;
@@ -490,8 +512,8 @@ L60:
 		kp = k;
 	    } else {
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		rowmax = 0.f;
 		kx = kc + imax - k;
@@ -530,14 +552,14 @@ L60:
 		    if ((r__1 = ap[i__1].r, dabs(r__1)) + (r__2 = r_imag(&ap[
 			    kpc]), dabs(r__2)) >= alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 			kp = imax;
 		    } else {
 
-/*                 interchange rows and columns K+1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K+1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 			kp = imax;
 			kstep = 2;
@@ -551,8 +573,8 @@ L60:
 	    }
 	    if (kp != kk) {
 
-/*              Interchange rows and columns KK and KP in the trailing   
-                submatrix A(k:n,k:n) */
+/*              Interchange rows and columns KK and KP in the trailing */
+/*              submatrix A(k:n,k:n) */
 
 		if (kp < *n) {
 		    i__1 = *n - kp;
@@ -594,17 +616,17 @@ L60:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k now holds   
+/*              1-by-1 pivot block D(k): column k now holds */
 
-                W(k) = L(k)*D(k)   
+/*              W(k) = L(k)*D(k) */
 
-                where L(k) is the k-th column of L */
+/*              where L(k) is the k-th column of L */
 
 		if (k < *n) {
 
-/*                 Perform a rank-1 update of A(k+1:n,k+1:n) as   
+/*                 Perform a rank-1 update of A(k+1:n,k+1:n) as */
 
-                   A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)' */
+/*                 A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)' */
 
 		    c_div(&q__1, &c_b1, &ap[kc]);
 		    r1.r = q__1.r, r1.i = q__1.i;
@@ -620,22 +642,22 @@ L60:
 		}
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns K and K+1 now hold   
+/*              2-by-2 pivot block D(k): columns K and K+1 now hold */
 
-                ( W(k) W(k+1) ) = ( L(k) L(k+1) )*D(k)   
+/*              ( W(k) W(k+1) ) = ( L(k) L(k+1) )*D(k) */
 
-                where L(k) and L(k+1) are the k-th and (k+1)-th columns   
-                of L */
+/*              where L(k) and L(k+1) are the k-th and (k+1)-th columns */
+/*              of L */
 
 		if (k < *n - 1) {
 
-/*                 Perform a rank-2 update of A(k+2:n,k+2:n) as   
+/*                 Perform a rank-2 update of A(k+2:n,k+2:n) as */
 
-                   A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )'   
-                      = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )'   
+/*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )' */
+/*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )' */
 
-                   where L(k) and L(k+1) are the k-th and (k+1)-th   
-                   columns of L */
+/*                 where L(k) and L(k+1) are the k-th and (k+1)-th */
+/*                 columns of L */
 
 		    i__1 = k + 1 + (k - 1) * ((*n << 1) - k) / 2;
 		    d21.r = ap[i__1].r, d21.i = ap[i__1].i;
