@@ -1,192 +1,214 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static complex c_b1 = {0.f,0.f};
+static complex c_b2 = {1.f,0.f};
+static integer c__1 = 1;
 
 /* Subroutine */ int ctgevc_(char *side, char *howmny, logical *select, 
 	integer *n, complex *s, integer *lds, complex *p, integer *ldp, 
 	complex *vl, integer *ldvl, complex *vr, integer *ldvr, integer *mm, 
-	integer *m, complex *work, real *rwork, integer *info  	)
+	integer *m, complex *work, real *rwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-
-    Purpose   
-    =======   
-
-    CTGEVC computes some or all of the right and/or left eigenvectors of   
-    a pair of complex matrices (S,P), where S and P are upper triangular.   
-    Matrix pairs of this type are produced by the generalized Schur   
-    factorization of a complex matrix pair (A,B):   
-
-       A = Q*S*Z**H,  B = Q*P*Z**H   
-
-    as computed by CGGHRD + CHGEQZ.   
-
-    The right eigenvector x and the left eigenvector y of (S,P)   
-    corresponding to an eigenvalue w are defined by:   
-
-       S*x = w*P*x,  (y**H)*S = w*(y**H)*P,   
-
-    where y**H denotes the conjugate tranpose of y.   
-    The eigenvalues are not input to this routine, but are computed   
-    directly from the diagonal elements of S and P.   
-
-    This routine returns the matrices X and/or Y of right and left   
-    eigenvectors of (S,P), or the products Z*X and/or Q*Y,   
-    where Z and Q are input matrices.   
-    If Q and Z are the unitary factors from the generalized Schur   
-    factorization of a matrix pair (A,B), then Z*X and Q*Y   
-    are the matrices of right and left eigenvectors of (A,B).   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'R': compute right eigenvectors only;   
-            = 'L': compute left eigenvectors only;   
-            = 'B': compute both right and left eigenvectors.   
-
-    HOWMNY  (input) CHARACTER*1   
-            = 'A': compute all right and/or left eigenvectors;   
-            = 'B': compute all right and/or left eigenvectors,   
-                   backtransformed by the matrices in VR and/or VL;   
-            = 'S': compute selected right and/or left eigenvectors,   
-                   specified by the logical array SELECT.   
-
-    SELECT  (input) LOGICAL array, dimension (N)   
-            If HOWMNY='S', SELECT specifies the eigenvectors to be   
-            computed.  The eigenvector corresponding to the j-th   
-            eigenvalue is computed if SELECT(j) = .TRUE..   
-            Not referenced if HOWMNY = 'A' or 'B'.   
-
-    N       (input) INTEGER   
-            The order of the matrices S and P.  N >= 0.   
-
-    S       (input) COMPLEX array, dimension (LDS,N)   
-            The upper triangular matrix S from a generalized Schur   
-            factorization, as computed by CHGEQZ.   
-
-    LDS     (input) INTEGER   
-            The leading dimension of array S.  LDS >= max(1,N).   
-
-    P       (input) COMPLEX array, dimension (LDP,N)   
-            The upper triangular matrix P from a generalized Schur   
-            factorization, as computed by CHGEQZ.  P must have real   
-            diagonal elements.   
-
-    LDP     (input) INTEGER   
-            The leading dimension of array P.  LDP >= max(1,N).   
-
-    VL      (input/output) COMPLEX array, dimension (LDVL,MM)   
-            On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must   
-            contain an N-by-N matrix Q (usually the unitary matrix Q   
-            of left Schur vectors returned by CHGEQZ).   
-            On exit, if SIDE = 'L' or 'B', VL contains:   
-            if HOWMNY = 'A', the matrix Y of left eigenvectors of (S,P);   
-            if HOWMNY = 'B', the matrix Q*Y;   
-            if HOWMNY = 'S', the left eigenvectors of (S,P) specified by   
-                        SELECT, stored consecutively in the columns of   
-                        VL, in the same order as their eigenvalues.   
-            Not referenced if SIDE = 'R'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of array VL.  LDVL >= 1, and if   
-            SIDE = 'L' or 'l' or 'B' or 'b', LDVL >= N.   
-
-    VR      (input/output) COMPLEX array, dimension (LDVR,MM)   
-            On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must   
-            contain an N-by-N matrix Q (usually the unitary matrix Z   
-            of right Schur vectors returned by CHGEQZ).   
-            On exit, if SIDE = 'R' or 'B', VR contains:   
-            if HOWMNY = 'A', the matrix X of right eigenvectors of (S,P);   
-            if HOWMNY = 'B', the matrix Z*X;   
-            if HOWMNY = 'S', the right eigenvectors of (S,P) specified by   
-                        SELECT, stored consecutively in the columns of   
-                        VR, in the same order as their eigenvalues.   
-            Not referenced if SIDE = 'L'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the array VR.  LDVR >= 1, and if   
-            SIDE = 'R' or 'B', LDVR >= N.   
-
-    MM      (input) INTEGER   
-            The number of columns in the arrays VL and/or VR. MM >= M.   
-
-    M       (output) INTEGER   
-            The number of columns in the arrays VL and/or VR actually   
-            used to store the eigenvectors.  If HOWMNY = 'A' or 'B', M   
-            is set to N.  Each selected eigenvector occupies one column.   
-
-    WORK    (workspace) COMPLEX array, dimension (2*N)   
-
-    RWORK   (workspace) REAL array, dimension (2*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit.   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-
-    =====================================================================   
-
-
-       Decode and Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static complex c_b1 = {0.f,0.f};
-    static complex c_b2 = {1.f,0.f};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer p_dim1, p_offset, s_dim1, s_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2, r__3, r__4, r__5, r__6;
     complex q__1, q__2, q__3, q__4;
+
     /* Builtin functions */
     double r_imag(complex *);
     void r_cnjg(complex *, complex *);
+
     /* Local variables */
-    static complex d__;
-    static integer i__, j;
-    static complex ca, cb;
-    static integer je, im, jr;
-    static real big;
-    static logical lsa, lsb;
-    static real ulp;
-    static complex sum;
-    static integer ibeg, ieig, iend;
-    static real dmin__;
-    static integer isrc;
-    static real temp;
-    static complex suma, sumb;
-    static real xmax, scale;
-    static logical ilall;
-    static integer iside;
-    static real sbeta;
+    complex d__;
+    integer i__, j;
+    complex ca, cb;
+    integer je, im, jr;
+    real big;
+    logical lsa, lsb;
+    real ulp;
+    complex sum;
+    integer ibeg, ieig, iend;
+    real dmin__;
+    integer isrc;
+    real temp;
+    complex suma, sumb;
+    real xmax, scale;
+    logical ilall;
+    integer iside;
+    real sbeta;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int cgemv_(char *, integer *, integer *, complex *
 , complex *, integer *, complex *, integer *, complex *, complex *
 , integer *);
-    static real small;
-    static logical compl;
-    static real anorm, bnorm;
-    static logical compr, ilbbad;
-    static real acoefa, bcoefa, acoeff;
-    static complex bcoeff;
-    static logical ilback;
+    real small;
+    logical compl;
+    real anorm, bnorm;
+    logical compr, ilbbad;
+    real acoefa, bcoefa, acoeff;
+    complex bcoeff;
+    logical ilback;
     extern /* Subroutine */ int slabad_(real *, real *);
-    static real ascale, bscale;
+    real ascale, bscale;
     extern /* Complex */ VOID cladiv_(complex *, complex *, complex *);
     extern doublereal slamch_(char *);
-    static complex salpha;
-    static real safmin;
+    complex salpha;
+    real safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static real bignum;
-    static logical ilcomp;
-    static integer ihwmny;
+    real bignum;
+    logical ilcomp;
+    integer ihwmny;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+
+/*  Purpose */
+/*  ======= */
+
+/*  CTGEVC computes some or all of the right and/or left eigenvectors of */
+/*  a pair of complex matrices (S,P), where S and P are upper triangular. */
+/*  Matrix pairs of this type are produced by the generalized Schur */
+/*  factorization of a complex matrix pair (A,B): */
+
+/*     A = Q*S*Z**H,  B = Q*P*Z**H */
+
+/*  as computed by CGGHRD + CHGEQZ. */
+
+/*  The right eigenvector x and the left eigenvector y of (S,P) */
+/*  corresponding to an eigenvalue w are defined by: */
+
+/*     S*x = w*P*x,  (y**H)*S = w*(y**H)*P, */
+
+/*  where y**H denotes the conjugate tranpose of y. */
+/*  The eigenvalues are not input to this routine, but are computed */
+/*  directly from the diagonal elements of S and P. */
+
+/*  This routine returns the matrices X and/or Y of right and left */
+/*  eigenvectors of (S,P), or the products Z*X and/or Q*Y, */
+/*  where Z and Q are input matrices. */
+/*  If Q and Z are the unitary factors from the generalized Schur */
+/*  factorization of a matrix pair (A,B), then Z*X and Q*Y */
+/*  are the matrices of right and left eigenvectors of (A,B). */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'R': compute right eigenvectors only; */
+/*          = 'L': compute left eigenvectors only; */
+/*          = 'B': compute both right and left eigenvectors. */
+
+/*  HOWMNY  (input) CHARACTER*1 */
+/*          = 'A': compute all right and/or left eigenvectors; */
+/*          = 'B': compute all right and/or left eigenvectors, */
+/*                 backtransformed by the matrices in VR and/or VL; */
+/*          = 'S': compute selected right and/or left eigenvectors, */
+/*                 specified by the logical array SELECT. */
+
+/*  SELECT  (input) LOGICAL array, dimension (N) */
+/*          If HOWMNY='S', SELECT specifies the eigenvectors to be */
+/*          computed.  The eigenvector corresponding to the j-th */
+/*          eigenvalue is computed if SELECT(j) = .TRUE.. */
+/*          Not referenced if HOWMNY = 'A' or 'B'. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices S and P.  N >= 0. */
+
+/*  S       (input) COMPLEX array, dimension (LDS,N) */
+/*          The upper triangular matrix S from a generalized Schur */
+/*          factorization, as computed by CHGEQZ. */
+
+/*  LDS     (input) INTEGER */
+/*          The leading dimension of array S.  LDS >= max(1,N). */
+
+/*  P       (input) COMPLEX array, dimension (LDP,N) */
+/*          The upper triangular matrix P from a generalized Schur */
+/*          factorization, as computed by CHGEQZ.  P must have real */
+/*          diagonal elements. */
+
+/*  LDP     (input) INTEGER */
+/*          The leading dimension of array P.  LDP >= max(1,N). */
+
+/*  VL      (input/output) COMPLEX array, dimension (LDVL,MM) */
+/*          On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must */
+/*          contain an N-by-N matrix Q (usually the unitary matrix Q */
+/*          of left Schur vectors returned by CHGEQZ). */
+/*          On exit, if SIDE = 'L' or 'B', VL contains: */
+/*          if HOWMNY = 'A', the matrix Y of left eigenvectors of (S,P); */
+/*          if HOWMNY = 'B', the matrix Q*Y; */
+/*          if HOWMNY = 'S', the left eigenvectors of (S,P) specified by */
+/*                      SELECT, stored consecutively in the columns of */
+/*                      VL, in the same order as their eigenvalues. */
+/*          Not referenced if SIDE = 'R'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of array VL.  LDVL >= 1, and if */
+/*          SIDE = 'L' or 'l' or 'B' or 'b', LDVL >= N. */
+
+/*  VR      (input/output) COMPLEX array, dimension (LDVR,MM) */
+/*          On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must */
+/*          contain an N-by-N matrix Q (usually the unitary matrix Z */
+/*          of right Schur vectors returned by CHGEQZ). */
+/*          On exit, if SIDE = 'R' or 'B', VR contains: */
+/*          if HOWMNY = 'A', the matrix X of right eigenvectors of (S,P); */
+/*          if HOWMNY = 'B', the matrix Z*X; */
+/*          if HOWMNY = 'S', the right eigenvectors of (S,P) specified by */
+/*                      SELECT, stored consecutively in the columns of */
+/*                      VR, in the same order as their eigenvalues. */
+/*          Not referenced if SIDE = 'L'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the array VR.  LDVR >= 1, and if */
+/*          SIDE = 'R' or 'B', LDVR >= N. */
+
+/*  MM      (input) INTEGER */
+/*          The number of columns in the arrays VL and/or VR. MM >= M. */
+
+/*  M       (output) INTEGER */
+/*          The number of columns in the arrays VL and/or VR actually */
+/*          used to store the eigenvectors.  If HOWMNY = 'A' or 'B', M */
+/*          is set to N.  Each selected eigenvector occupies one column. */
+
+/*  WORK    (workspace) COMPLEX array, dimension (2*N) */
+
+/*  RWORK   (workspace) REAL array, dimension (2*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit. */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and Test the input parameters */
+
+    /* Parameter adjustments */
     --select;
     s_dim1 = *lds;
     s_offset = 1 + s_dim1;
@@ -312,9 +334,9 @@
     big = 1.f / small;
     bignum = 1.f / (safmin * *n);
 
-/*     Compute the 1-norm of each column of the strictly upper triangular   
-       part of A and B to check for possible overflow in the triangular   
-       solver. */
+/*     Compute the 1-norm of each column of the strictly upper triangular */
+/*     part of A and B to check for possible overflow in the triangular */
+/*     solver. */
 
     i__1 = s_dim1 + 1;
     anorm = (r__1 = s[i__1].r, dabs(r__1)) + (r__2 = r_imag(&s[s_dim1 + 1]), 
@@ -390,12 +412,12 @@
 		    goto L140;
 		}
 
-/*              Non-singular eigenvalue:   
-                Compute coefficients  a  and  b  in   
-                     H   
-                   y  ( a A - b B ) = 0   
+/*              Non-singular eigenvalue: */
+/*              Compute coefficients  a  and  b  in */
+/*                   H */
+/*                 y  ( a A - b B ) = 0 */
 
-   Computing MAX */
+/* Computing MAX */
 		i__2 = je + je * s_dim1;
 		i__3 = je + je * p_dim1;
 		r__4 = ((r__2 = s[i__2].r, dabs(r__2)) + (r__3 = r_imag(&s[je 
@@ -417,7 +439,8 @@
 
 		lsa = dabs(sbeta) >= safmin && dabs(acoeff) < small;
 		lsb = (r__1 = salpha.r, dabs(r__1)) + (r__2 = r_imag(&salpha),
-			 dabs(r__2)) >= safmin && (r__3 = bcoeff.r, dabs(r__3) 			) + (r__4 = r_imag(&bcoeff), dabs(r__4)) < small;
+			 dabs(r__2)) >= safmin && (r__3 = bcoeff.r, dabs(r__3)
+			) + (r__4 = r_imag(&bcoeff), dabs(r__4)) < small;
 
 		scale = 1.f;
 		if (lsa) {
@@ -425,13 +448,14 @@
 		}
 		if (lsb) {
 /* Computing MAX */
-		    r__3 = scale, r__4 = small / ((r__1 = salpha.r, dabs(r__1) 			    ) + (r__2 = r_imag(&salpha), dabs(r__2))) * dmin(
+		    r__3 = scale, r__4 = small / ((r__1 = salpha.r, dabs(r__1)
+			    ) + (r__2 = r_imag(&salpha), dabs(r__2))) * dmin(
 			    bnorm,big);
 		    scale = dmax(r__3,r__4);
 		}
 		if (lsa || lsb) {
-/* Computing MIN   
-   Computing MAX */
+/* Computing MIN */
+/* Computing MAX */
 		    r__5 = 1.f, r__6 = dabs(acoeff), r__5 = max(r__5,r__6), 
 			    r__6 = (r__1 = bcoeff.r, dabs(r__1)) + (r__2 = 
 			    r_imag(&bcoeff), dabs(r__2));
@@ -469,20 +493,20 @@
 			r__1 = max(r__1,r__2);
 		dmin__ = dmax(r__1,safmin);
 
-/*                                              H   
-                Triangular solve of  (a A - b B)  y = 0   
+/*                                              H */
+/*              Triangular solve of  (a A - b B)  y = 0 */
 
-                                        H   
-                (rowwise in  (a A - b B) , or columnwise in a A - b B) */
+/*                                      H */
+/*              (rowwise in  (a A - b B) , or columnwise in a A - b B) */
 
 		i__2 = *n;
 		for (j = je + 1; j <= i__2; ++j) {
 
-/*                 Compute   
-                         j-1   
-                   SUM = sum  conjg( a*S(k,j) - b*P(k,j) )*x(k)   
-                         k=je   
-                   (Scale if necessary) */
+/*                 Compute */
+/*                       j-1 */
+/*                 SUM = sum  conjg( a*S(k,j) - b*P(k,j) )*x(k) */
+/*                       k=je */
+/*                 (Scale if necessary) */
 
 		    temp = 1.f / xmax;
 		    if (acoefa * rwork[j] + bcoefa * rwork[*n + j] > bignum * 
@@ -526,9 +550,9 @@
 		    q__1.r = q__2.r - q__3.r, q__1.i = q__2.i - q__3.i;
 		    sum.r = q__1.r, sum.i = q__1.i;
 
-/*                 Form x(j) = - SUM / conjg( a*S(j,j) - b*P(j,j) )   
+/*                 Form x(j) = - SUM / conjg( a*S(j,j) - b*P(j,j) ) */
 
-                   with scaling and perturbation of the denominator */
+/*                 with scaling and perturbation of the denominator */
 
 		    i__3 = j + j * s_dim1;
 		    q__3.r = acoeff * s[i__3].r, q__3.i = acoeff * s[i__3].i;
@@ -668,12 +692,12 @@ L140:
 		    goto L250;
 		}
 
-/*              Non-singular eigenvalue:   
-                Compute coefficients  a  and  b  in   
+/*              Non-singular eigenvalue: */
+/*              Compute coefficients  a  and  b  in */
 
-                ( a A - b B ) x  = 0   
+/*              ( a A - b B ) x  = 0 */
 
-   Computing MAX */
+/* Computing MAX */
 		i__1 = je + je * s_dim1;
 		i__2 = je + je * p_dim1;
 		r__4 = ((r__2 = s[i__1].r, dabs(r__2)) + (r__3 = r_imag(&s[je 
@@ -695,7 +719,8 @@ L140:
 
 		lsa = dabs(sbeta) >= safmin && dabs(acoeff) < small;
 		lsb = (r__1 = salpha.r, dabs(r__1)) + (r__2 = r_imag(&salpha),
-			 dabs(r__2)) >= safmin && (r__3 = bcoeff.r, dabs(r__3) 			) + (r__4 = r_imag(&bcoeff), dabs(r__4)) < small;
+			 dabs(r__2)) >= safmin && (r__3 = bcoeff.r, dabs(r__3)
+			) + (r__4 = r_imag(&bcoeff), dabs(r__4)) < small;
 
 		scale = 1.f;
 		if (lsa) {
@@ -703,13 +728,14 @@ L140:
 		}
 		if (lsb) {
 /* Computing MAX */
-		    r__3 = scale, r__4 = small / ((r__1 = salpha.r, dabs(r__1) 			    ) + (r__2 = r_imag(&salpha), dabs(r__2))) * dmin(
+		    r__3 = scale, r__4 = small / ((r__1 = salpha.r, dabs(r__1)
+			    ) + (r__2 = r_imag(&salpha), dabs(r__2))) * dmin(
 			    bnorm,big);
 		    scale = dmax(r__3,r__4);
 		}
 		if (lsa || lsb) {
-/* Computing MIN   
-   Computing MAX */
+/* Computing MIN */
+/* Computing MAX */
 		    r__5 = 1.f, r__6 = dabs(acoeff), r__5 = max(r__5,r__6), 
 			    r__6 = (r__1 = bcoeff.r, dabs(r__1)) + (r__2 = 
 			    r_imag(&bcoeff), dabs(r__2));
@@ -747,10 +773,10 @@ L140:
 			r__1 = max(r__1,r__2);
 		dmin__ = dmax(r__1,safmin);
 
-/*              Triangular solve of  (a A - b B) x = 0  (columnwise)   
+/*              Triangular solve of  (a A - b B) x = 0  (columnwise) */
 
-                WORK(1:j-1) contains sums w,   
-                WORK(j+1:JE) contains x */
+/*              WORK(1:j-1) contains sums w, */
+/*              WORK(j+1:JE) contains x */
 
 		i__1 = je - 1;
 		for (jr = 1; jr <= i__1; ++jr) {
@@ -770,8 +796,8 @@ L140:
 
 		for (j = je - 1; j >= 1; --j) {
 
-/*                 Form x(j) := - w(j) / d   
-                   with scaling and perturbation of the denominator */
+/*                 Form x(j) := - w(j) / d */
+/*                 with scaling and perturbation of the denominator */
 
 		    i__1 = j + j * s_dim1;
 		    q__2.r = acoeff * s[i__1].r, q__2.i = acoeff * s[i__1].i;
