@@ -1,149 +1,56 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__6 = 6;
+static integer c_n1 = -1;
+static integer c__1 = 1;
+static integer c__0 = 0;
+static doublereal c_b74 = 0.;
+static doublereal c_b108 = 1.;
 
 /* Subroutine */ int dgelss_(integer *m, integer *n, integer *nrhs, 
 	doublereal *a, integer *lda, doublereal *b, integer *ldb, doublereal *
-	s, doublereal *rcond, integer *rank, doublereal *work, integer *lwork,
+	s, doublereal *rcond, integer *rank, doublereal *work, integer *lwork, 
 	 integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    DGELSS computes the minimum norm solution to a real linear least   
-    squares problem:   
-
-    Minimize 2-norm(| b - A*x |).   
-
-    using the singular value decomposition (SVD) of A. A is an M-by-N   
-    matrix which may be rank-deficient.   
-
-    Several right hand side vectors b and solution vectors x can be   
-    handled in a single call; they are stored as the columns of the   
-    M-by-NRHS right hand side matrix B and the N-by-NRHS solution matrix   
-    X.   
-
-    The effective rank of A is determined by treating as zero those   
-    singular values which are less than RCOND times the largest singular   
-    value.   
-
-    Arguments   
-    =========   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix A. M >= 0.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix A. N >= 0.   
-
-    NRHS    (input) INTEGER   
-            The number of right hand sides, i.e., the number of columns   
-            of the matrices B and X. NRHS >= 0.   
-
-    A       (input/output) DOUBLE PRECISION array, dimension (LDA,N)   
-            On entry, the M-by-N matrix A.   
-            On exit, the first min(m,n) rows of A are overwritten with   
-            its right singular vectors, stored rowwise.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,M).   
-
-    B       (input/output) DOUBLE PRECISION array, dimension (LDB,NRHS)   
-            On entry, the M-by-NRHS right hand side matrix B.   
-            On exit, B is overwritten by the N-by-NRHS solution   
-            matrix X.  If m >= n and RANK = n, the residual   
-            sum-of-squares for the solution in the i-th column is given   
-            by the sum of squares of elements n+1:m in that column.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B. LDB >= max(1,max(M,N)).   
-
-    S       (output) DOUBLE PRECISION array, dimension (min(M,N))   
-            The singular values of A in decreasing order.   
-            The condition number of A in the 2-norm = S(1)/S(min(m,n)).   
-
-    RCOND   (input) DOUBLE PRECISION   
-            RCOND is used to determine the effective rank of A.   
-            Singular values S(i) <= RCOND*S(1) are treated as zero.   
-            If RCOND < 0, machine precision is used instead.   
-
-    RANK    (output) INTEGER   
-            The effective rank of A, i.e., the number of singular values   
-            which are greater than RCOND*S(1).   
-
-    WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK. LWORK >= 1, and also:   
-            LWORK >= 3*min(M,N) + max( 2*min(M,N), max(M,N), NRHS )   
-            For good performance, LWORK should generally be larger.   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  the algorithm for computing the SVD failed to converge;   
-                  if INFO = i, i off-diagonal elements of an intermediate   
-                  bidiagonal form did not converge to zero.   
-
-    =====================================================================   
-
-
-       Test the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__6 = 6;
-    static integer c_n1 = -1;
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static doublereal c_b74 = 0.;
-    static doublereal c_b108 = 1.;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, i__1, i__2, i__3, i__4;
     doublereal d__1;
+
     /* Local variables */
-    static integer i__, bl, ie, il, mm;
-    static doublereal eps, thr, anrm, bnrm;
-    static integer itau;
-    static doublereal vdum[1];
+    integer i__, bl, ie, il, mm;
+    doublereal eps, thr, anrm, bnrm;
+    integer itau;
+    doublereal vdum[1];
     extern /* Subroutine */ int dgemm_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *);
-    static integer iascl, ibscl;
+    integer iascl, ibscl;
     extern /* Subroutine */ int dgemv_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *), drscl_(integer *, 
 	    doublereal *, doublereal *, integer *);
-    static integer chunk;
-    static doublereal sfmin;
-    static integer minmn;
+    integer chunk;
+    doublereal sfmin;
+    integer minmn;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static integer maxmn, itaup, itauq, mnthr, iwork;
+    integer maxmn, itaup, itauq, mnthr, iwork;
     extern /* Subroutine */ int dlabad_(doublereal *, doublereal *), dgebrd_(
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *);
     extern doublereal dlamch_(char *), dlange_(char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *);
-    static integer bdspac;
+    integer bdspac;
     extern /* Subroutine */ int dgelqf_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *, integer *), 
 	    dlascl_(char *, integer *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, doublereal *, integer *, integer *),
 	     dgeqrf_(integer *, integer *, doublereal *, integer *, 
-	    doublereal *, doublereal *, integer *, integer *), dlacpy_(char *,
+	    doublereal *, doublereal *, integer *, integer *), dlacpy_(char *, 
 	     integer *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *), dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *), 
@@ -153,23 +60,135 @@
 	    integer *, doublereal *, integer *), dorgbr_(char *, 
 	    integer *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *, integer *);
-    static doublereal bignum;
+    doublereal bignum;
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int dormbr_(char *, char *, char *, integer *, 
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *), dormlq_(char *, char *, integer *, 
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *);
-    static integer ldwork;
+    integer ldwork;
     extern /* Subroutine */ int dormqr_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *);
-    static integer minwrk, maxwrk;
-    static doublereal smlnum;
-    static logical lquery;
+    integer minwrk, maxwrk;
+    doublereal smlnum;
+    logical lquery;
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  DGELSS computes the minimum norm solution to a real linear least */
+/*  squares problem: */
+
+/*  Minimize 2-norm(| b - A*x |). */
+
+/*  using the singular value decomposition (SVD) of A. A is an M-by-N */
+/*  matrix which may be rank-deficient. */
+
+/*  Several right hand side vectors b and solution vectors x can be */
+/*  handled in a single call; they are stored as the columns of the */
+/*  M-by-NRHS right hand side matrix B and the N-by-NRHS solution matrix */
+/*  X. */
+
+/*  The effective rank of A is determined by treating as zero those */
+/*  singular values which are less than RCOND times the largest singular */
+/*  value. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  M       (input) INTEGER */
+/*          The number of rows of the matrix A. M >= 0. */
+
+/*  N       (input) INTEGER */
+/*          The number of columns of the matrix A. N >= 0. */
+
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand sides, i.e., the number of columns */
+/*          of the matrices B and X. NRHS >= 0. */
+
+/*  A       (input/output) DOUBLE PRECISION array, dimension (LDA,N) */
+/*          On entry, the M-by-N matrix A. */
+/*          On exit, the first min(m,n) rows of A are overwritten with */
+/*          its right singular vectors, stored rowwise. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,M). */
+
+/*  B       (input/output) DOUBLE PRECISION array, dimension (LDB,NRHS) */
+/*          On entry, the M-by-NRHS right hand side matrix B. */
+/*          On exit, B is overwritten by the N-by-NRHS solution */
+/*          matrix X.  If m >= n and RANK = n, the residual */
+/*          sum-of-squares for the solution in the i-th column is given */
+/*          by the sum of squares of elements n+1:m in that column. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B. LDB >= max(1,max(M,N)). */
+
+/*  S       (output) DOUBLE PRECISION array, dimension (min(M,N)) */
+/*          The singular values of A in decreasing order. */
+/*          The condition number of A in the 2-norm = S(1)/S(min(m,n)). */
+
+/*  RCOND   (input) DOUBLE PRECISION */
+/*          RCOND is used to determine the effective rank of A. */
+/*          Singular values S(i) <= RCOND*S(1) are treated as zero. */
+/*          If RCOND < 0, machine precision is used instead. */
+
+/*  RANK    (output) INTEGER */
+/*          The effective rank of A, i.e., the number of singular values */
+/*          which are greater than RCOND*S(1). */
+
+/*  WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK. LWORK >= 1, and also: */
+/*          LWORK >= 3*min(M,N) + max( 2*min(M,N), max(M,N), NRHS ) */
+/*          For good performance, LWORK should generally be larger. */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  the algorithm for computing the SVD failed to converge; */
+/*                if INFO = i, i off-diagonal elements of an intermediate */
+/*                bidiagonal form did not converge to zero. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -196,55 +215,54 @@
 	*info = -7;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV.) */
 
     if (*info == 0) {
 	minwrk = 1;
 	maxwrk = 1;
 	if (minmn > 0) {
 	    mm = *m;
-	    mnthr = ilaenv_(&c__6, "DGELSS", " ", m, n, nrhs, &c_n1, (ftnlen)
-		    6, (ftnlen)1);
+	    mnthr = ilaenv_(&c__6, "DGELSS", " ", m, n, nrhs, &c_n1);
 	    if (*m >= *n && *m >= mnthr) {
 
-/*              Path 1a - overdetermined, with many more rows than   
-                          columns */
+/*              Path 1a - overdetermined, with many more rows than */
+/*                        columns */
 
 		mm = *n;
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = *n + *n * ilaenv_(&c__1, "DGEQRF", 
-			" ", m, n, &c_n1, &c_n1, (ftnlen)6, (ftnlen)1);
+			" ", m, n, &c_n1, &c_n1);
 		maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = *n + *nrhs * ilaenv_(&c__1, "DORMQR", 
-			"LT", m, nrhs, n, &c_n1, (ftnlen)6, (ftnlen)2);
+			"LT", m, nrhs, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 	    }
 	    if (*m >= *n) {
 
-/*              Path 1 - overdetermined or exactly determined   
+/*              Path 1 - overdetermined or exactly determined */
 
-                Compute workspace needed for DBDSQR   
+/*              Compute workspace needed for DBDSQR */
 
-   Computing MAX */
+/* Computing MAX */
 		i__1 = 1, i__2 = *n * 5;
 		bdspac = max(i__1,i__2);
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = *n * 3 + (mm + *n) * ilaenv_(&c__1, 
-			"DGEBRD", " ", &mm, n, &c_n1, &c_n1, (ftnlen)6, (ftnlen)1);
+			"DGEBRD", " ", &mm, n, &c_n1, &c_n1);
 		maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = *n * 3 + *nrhs * ilaenv_(&c__1, "DORMBR"
-			, "QLT", &mm, nrhs, n, &c_n1, (ftnlen)6, (ftnlen)3);
+, "QLT", &mm, nrhs, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = *n * 3 + (*n - 1) * ilaenv_(&c__1, 
-			"DORGBR", "P", n, n, n, &c_n1, (ftnlen)6, (ftnlen)1);
+			"DORGBR", "P", n, n, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 		maxwrk = max(maxwrk,bdspac);
 /* Computing MAX */
@@ -258,9 +276,9 @@
 	    }
 	    if (*n > *m) {
 
-/*              Compute workspace needed for DBDSQR   
+/*              Compute workspace needed for DBDSQR */
 
-   Computing MAX */
+/* Computing MAX */
 		i__1 = 1, i__2 = *m * 5;
 		bdspac = max(i__1,i__2);
 /* Computing MAX */
@@ -269,25 +287,22 @@
 		minwrk = max(i__1,bdspac);
 		if (*n >= mnthr) {
 
-/*                 Path 2a - underdetermined, with many more columns   
-                   than rows */
+/*                 Path 2a - underdetermined, with many more columns */
+/*                 than rows */
 
 		    maxwrk = *m + *m * ilaenv_(&c__1, "DGELQF", " ", m, n, &
-			    c_n1, &c_n1, (ftnlen)6, (ftnlen)1);
+			    c_n1, &c_n1);
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m * *m + (*m << 2) + (*m << 1) * 
-			    ilaenv_(&c__1, "DGEBRD", " ", m, m, &c_n1, &c_n1, 
-			    (ftnlen)6, (ftnlen)1);
+			    ilaenv_(&c__1, "DGEBRD", " ", m, m, &c_n1, &c_n1);
 		    maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m * *m + (*m << 2) + *nrhs * 
-			    ilaenv_(&c__1, "DORMBR", "QLT", m, nrhs, m, &c_n1,
-			     (ftnlen)6, (ftnlen)3);
+			    ilaenv_(&c__1, "DORMBR", "QLT", m, nrhs, m, &c_n1);
 		    maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m * *m + (*m << 2) + (*m - 1) * 
-			    ilaenv_(&c__1, "DORGBR", "P", m, m, m, &c_n1, (
-			    ftnlen)6, (ftnlen)1);
+			    ilaenv_(&c__1, "DORGBR", "P", m, m, m, &c_n1);
 		    maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m * *m + *m + bdspac;
@@ -303,21 +318,21 @@
 		    }
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m + *nrhs * ilaenv_(&c__1, "DORMLQ"
-			    , "LT", n, nrhs, m, &c_n1, (ftnlen)6, (ftnlen)2);
+, "LT", n, nrhs, m, &c_n1);
 		    maxwrk = max(i__1,i__2);
 		} else {
 
 /*                 Path 2 - underdetermined */
 
 		    maxwrk = *m * 3 + (*n + *m) * ilaenv_(&c__1, "DGEBRD", 
-			    " ", m, n, &c_n1, &c_n1, (ftnlen)6, (ftnlen)1);
+			    " ", m, n, &c_n1, &c_n1);
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m * 3 + *nrhs * ilaenv_(&c__1, 
-			    "DORMBR", "QLT", m, nrhs, m, &c_n1, (ftnlen)6, (ftnlen)3);
+			    "DORMBR", "QLT", m, nrhs, m, &c_n1);
 		    maxwrk = max(i__1,i__2);
 /* Computing MAX */
 		    i__1 = maxwrk, i__2 = *m * 3 + *m * ilaenv_(&c__1, "DORG"
-			    "BR", "P", m, n, m, &c_n1, (ftnlen)6, (ftnlen)1);
+			    "BR", "P", m, n, m, &c_n1);
 		    maxwrk = max(i__1,i__2);
 		    maxwrk = max(maxwrk,bdspac);
 /* Computing MAX */
@@ -394,14 +409,14 @@
 
 /*        Scale matrix norm up to SMLNUM */
 
-	dlascl_("G", &c__0, &c__0, &bnrm, &smlnum, m, nrhs, &b[b_offset], ldb,
+	dlascl_("G", &c__0, &c__0, &bnrm, &smlnum, m, nrhs, &b[b_offset], ldb, 
 		 info);
 	ibscl = 1;
     } else if (bnrm > bignum) {
 
 /*        Scale matrix norm down to BIGNUM */
 
-	dlascl_("G", &c__0, &c__0, &bnrm, &bignum, m, nrhs, &b[b_offset], ldb,
+	dlascl_("G", &c__0, &c__0, &bnrm, &bignum, m, nrhs, &b[b_offset], ldb, 
 		 info);
 	ibscl = 2;
     }
@@ -421,15 +436,15 @@
 	    itau = 1;
 	    iwork = itau + *n;
 
-/*           Compute A=Q*R   
-             (Workspace: need 2*N, prefer N+N*NB) */
+/*           Compute A=Q*R */
+/*           (Workspace: need 2*N, prefer N+N*NB) */
 
 	    i__1 = *lwork - iwork + 1;
-	    dgeqrf_(m, n, &a[a_offset], lda, &work[itau], &work[iwork], &i__1,
+	    dgeqrf_(m, n, &a[a_offset], lda, &work[itau], &work[iwork], &i__1, 
 		     info);
 
-/*           Multiply B by transpose(Q)   
-             (Workspace: need N+NRHS, prefer N+NRHS*NB) */
+/*           Multiply B by transpose(Q) */
+/*           (Workspace: need N+NRHS, prefer N+NRHS*NB) */
 
 	    i__1 = *lwork - iwork + 1;
 	    dormqr_("L", "T", m, nrhs, n, &a[a_offset], lda, &work[itau], &b[
@@ -450,32 +465,32 @@
 	itaup = itauq + *n;
 	iwork = itaup + *n;
 
-/*        Bidiagonalize R in A   
-          (Workspace: need 3*N+MM, prefer 3*N+(MM+N)*NB) */
+/*        Bidiagonalize R in A */
+/*        (Workspace: need 3*N+MM, prefer 3*N+(MM+N)*NB) */
 
 	i__1 = *lwork - iwork + 1;
 	dgebrd_(&mm, n, &a[a_offset], lda, &s[1], &work[ie], &work[itauq], &
 		work[itaup], &work[iwork], &i__1, info);
 
-/*        Multiply B by transpose of left bidiagonalizing vectors of R   
-          (Workspace: need 3*N+NRHS, prefer 3*N+NRHS*NB) */
+/*        Multiply B by transpose of left bidiagonalizing vectors of R */
+/*        (Workspace: need 3*N+NRHS, prefer 3*N+NRHS*NB) */
 
 	i__1 = *lwork - iwork + 1;
 	dormbr_("Q", "L", "T", &mm, nrhs, n, &a[a_offset], lda, &work[itauq], 
 		&b[b_offset], ldb, &work[iwork], &i__1, info);
 
-/*        Generate right bidiagonalizing vectors of R in A   
-          (Workspace: need 4*N-1, prefer 3*N+(N-1)*NB) */
+/*        Generate right bidiagonalizing vectors of R in A */
+/*        (Workspace: need 4*N-1, prefer 3*N+(N-1)*NB) */
 
 	i__1 = *lwork - iwork + 1;
 	dorgbr_("P", n, n, n, &a[a_offset], lda, &work[itaup], &work[iwork], &
 		i__1, info);
 	iwork = ie + *n;
 
-/*        Perform bidiagonal QR iteration   
-            multiply B by transpose of left singular vectors   
-            compute right singular vectors in A   
-          (Workspace: need BDSPAC) */
+/*        Perform bidiagonal QR iteration */
+/*          multiply B by transpose of left singular vectors */
+/*          compute right singular vectors in A */
+/*        (Workspace: need BDSPAC) */
 
 	dbdsqr_("U", n, n, &c__0, nrhs, &s[1], &work[ie], &a[a_offset], lda, 
 		vdum, &c__1, &b[b_offset], ldb, &work[iwork], info)
@@ -484,9 +499,9 @@
 	    goto L70;
 	}
 
-/*        Multiply B by reciprocals of singular values   
+/*        Multiply B by reciprocals of singular values */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = *rcond * s[1];
 	thr = max(d__1,sfmin);
 	if (*rcond < 0.) {
@@ -507,8 +522,8 @@
 /* L10: */
 	}
 
-/*        Multiply B by right singular vectors   
-          (Workspace: need N, prefer N*NRHS) */
+/*        Multiply B by right singular vectors */
+/*        (Workspace: need N, prefer N*NRHS) */
 
 	if (*lwork >= *ldb * *nrhs && *nrhs > 1) {
 	    dgemm_("T", "N", n, nrhs, n, &c_b108, &a[a_offset], lda, &b[
@@ -540,12 +555,12 @@
 		i__2,*nrhs), i__1 = *n - *m * 3;
 	if (*n >= mnthr && *lwork >= (*m << 2) + *m * *m + max(i__2,i__1)) {
 
-/*        Path 2a - underdetermined, with many more columns than rows   
-          and sufficient workspace for an efficient algorithm */
+/*        Path 2a - underdetermined, with many more columns than rows */
+/*        and sufficient workspace for an efficient algorithm */
 
 	    ldwork = *m;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    i__3 = *m, i__4 = (*m << 1) - 4, i__3 = max(i__3,i__4), i__3 = 
 		    max(i__3,*nrhs), i__4 = *n - *m * 3;
 	    i__2 = (*m << 2) + *m * *lda + max(i__3,i__4), i__1 = *m * *lda + 
@@ -556,11 +571,11 @@
 	    itau = 1;
 	    iwork = *m + 1;
 
-/*        Compute A=L*Q   
-          (Workspace: need 2*M, prefer M+M*NB) */
+/*        Compute A=L*Q */
+/*        (Workspace: need 2*M, prefer M+M*NB) */
 
 	    i__2 = *lwork - iwork + 1;
-	    dgelqf_(m, n, &a[a_offset], lda, &work[itau], &work[iwork], &i__2,
+	    dgelqf_(m, n, &a[a_offset], lda, &work[itau], &work[iwork], &i__2, 
 		     info);
 	    il = iwork;
 
@@ -576,43 +591,43 @@
 	    itaup = itauq + *m;
 	    iwork = itaup + *m;
 
-/*        Bidiagonalize L in WORK(IL)   
-          (Workspace: need M*M+5*M, prefer M*M+4*M+2*M*NB) */
+/*        Bidiagonalize L in WORK(IL) */
+/*        (Workspace: need M*M+5*M, prefer M*M+4*M+2*M*NB) */
 
 	    i__2 = *lwork - iwork + 1;
 	    dgebrd_(m, m, &work[il], &ldwork, &s[1], &work[ie], &work[itauq], 
 		    &work[itaup], &work[iwork], &i__2, info);
 
-/*        Multiply B by transpose of left bidiagonalizing vectors of L   
-          (Workspace: need M*M+4*M+NRHS, prefer M*M+4*M+NRHS*NB) */
+/*        Multiply B by transpose of left bidiagonalizing vectors of L */
+/*        (Workspace: need M*M+4*M+NRHS, prefer M*M+4*M+NRHS*NB) */
 
 	    i__2 = *lwork - iwork + 1;
 	    dormbr_("Q", "L", "T", m, nrhs, m, &work[il], &ldwork, &work[
 		    itauq], &b[b_offset], ldb, &work[iwork], &i__2, info);
 
-/*        Generate right bidiagonalizing vectors of R in WORK(IL)   
-          (Workspace: need M*M+5*M-1, prefer M*M+4*M+(M-1)*NB) */
+/*        Generate right bidiagonalizing vectors of R in WORK(IL) */
+/*        (Workspace: need M*M+5*M-1, prefer M*M+4*M+(M-1)*NB) */
 
 	    i__2 = *lwork - iwork + 1;
 	    dorgbr_("P", m, m, m, &work[il], &ldwork, &work[itaup], &work[
 		    iwork], &i__2, info);
 	    iwork = ie + *m;
 
-/*        Perform bidiagonal QR iteration,   
-             computing right singular vectors of L in WORK(IL) and   
-             multiplying B by transpose of left singular vectors   
-          (Workspace: need M*M+M+BDSPAC) */
+/*        Perform bidiagonal QR iteration, */
+/*           computing right singular vectors of L in WORK(IL) and */
+/*           multiplying B by transpose of left singular vectors */
+/*        (Workspace: need M*M+M+BDSPAC) */
 
 	    dbdsqr_("U", m, m, &c__0, nrhs, &s[1], &work[ie], &work[il], &
 		    ldwork, &a[a_offset], lda, &b[b_offset], ldb, &work[iwork]
-		    , info);
+, info);
 	    if (*info != 0) {
 		goto L70;
 	    }
 
-/*        Multiply B by reciprocals of singular values   
+/*        Multiply B by reciprocals of singular values */
 
-   Computing MAX */
+/* Computing MAX */
 	    d__1 = *rcond * s[1];
 	    thr = max(d__1,sfmin);
 	    if (*rcond < 0.) {
@@ -628,14 +643,14 @@
 		    ++(*rank);
 		} else {
 		    dlaset_("F", &c__1, nrhs, &c_b74, &c_b74, &b[i__ + b_dim1]
-			    , ldb);
+, ldb);
 		}
 /* L30: */
 	    }
 	    iwork = ie;
 
-/*        Multiply B by right singular vectors of L in WORK(IL)   
-          (Workspace: need M*M+2*M, prefer M*M+M+M*NRHS) */
+/*        Multiply B by right singular vectors of L in WORK(IL) */
+/*        (Workspace: need M*M+2*M, prefer M*M+M+M*NRHS) */
 
 	    if (*lwork >= *ldb * *nrhs + iwork - 1 && *nrhs > 1) {
 		dgemm_("T", "N", m, nrhs, m, &c_b108, &work[il], &ldwork, &b[
@@ -653,7 +668,7 @@
 		    dgemm_("T", "N", m, &bl, m, &c_b108, &work[il], &ldwork, &
 			    b[i__ * b_dim1 + 1], ldb, &c_b74, &work[iwork], m);
 		    dlacpy_("G", m, &bl, &work[iwork], m, &b[i__ * b_dim1 + 1]
-			    , ldb);
+, ldb);
 /* L40: */
 		}
 	    } else {
@@ -669,8 +684,8 @@
 		    ldb);
 	    iwork = itau + *m;
 
-/*        Multiply transpose(Q) by B   
-          (Workspace: need M+NRHS, prefer M+NRHS*NB) */
+/*        Multiply transpose(Q) by B */
+/*        (Workspace: need M+NRHS, prefer M+NRHS*NB) */
 
 	    i__1 = *lwork - iwork + 1;
 	    dormlq_("L", "T", n, nrhs, m, &a[a_offset], lda, &work[itau], &b[
@@ -685,32 +700,32 @@
 	    itaup = itauq + *m;
 	    iwork = itaup + *m;
 
-/*        Bidiagonalize A   
-          (Workspace: need 3*M+N, prefer 3*M+(M+N)*NB) */
+/*        Bidiagonalize A */
+/*        (Workspace: need 3*M+N, prefer 3*M+(M+N)*NB) */
 
 	    i__1 = *lwork - iwork + 1;
 	    dgebrd_(m, n, &a[a_offset], lda, &s[1], &work[ie], &work[itauq], &
 		    work[itaup], &work[iwork], &i__1, info);
 
-/*        Multiply B by transpose of left bidiagonalizing vectors   
-          (Workspace: need 3*M+NRHS, prefer 3*M+NRHS*NB) */
+/*        Multiply B by transpose of left bidiagonalizing vectors */
+/*        (Workspace: need 3*M+NRHS, prefer 3*M+NRHS*NB) */
 
 	    i__1 = *lwork - iwork + 1;
 	    dormbr_("Q", "L", "T", m, nrhs, n, &a[a_offset], lda, &work[itauq]
-		    , &b[b_offset], ldb, &work[iwork], &i__1, info);
+, &b[b_offset], ldb, &work[iwork], &i__1, info);
 
-/*        Generate right bidiagonalizing vectors in A   
-          (Workspace: need 4*M, prefer 3*M+M*NB) */
+/*        Generate right bidiagonalizing vectors in A */
+/*        (Workspace: need 4*M, prefer 3*M+M*NB) */
 
 	    i__1 = *lwork - iwork + 1;
 	    dorgbr_("P", m, n, m, &a[a_offset], lda, &work[itaup], &work[
 		    iwork], &i__1, info);
 	    iwork = ie + *m;
 
-/*        Perform bidiagonal QR iteration,   
-             computing right singular vectors of A in A and   
-             multiplying B by transpose of left singular vectors   
-          (Workspace: need BDSPAC) */
+/*        Perform bidiagonal QR iteration, */
+/*           computing right singular vectors of A in A and */
+/*           multiplying B by transpose of left singular vectors */
+/*        (Workspace: need BDSPAC) */
 
 	    dbdsqr_("L", m, n, &c__0, nrhs, &s[1], &work[ie], &a[a_offset], 
 		    lda, vdum, &c__1, &b[b_offset], ldb, &work[iwork], info);
@@ -718,9 +733,9 @@
 		goto L70;
 	    }
 
-/*        Multiply B by reciprocals of singular values   
+/*        Multiply B by reciprocals of singular values */
 
-   Computing MAX */
+/* Computing MAX */
 	    d__1 = *rcond * s[1];
 	    thr = max(d__1,sfmin);
 	    if (*rcond < 0.) {
@@ -736,13 +751,13 @@
 		    ++(*rank);
 		} else {
 		    dlaset_("F", &c__1, nrhs, &c_b74, &c_b74, &b[i__ + b_dim1]
-			    , ldb);
+, ldb);
 		}
 /* L50: */
 	    }
 
-/*        Multiply B by right singular vectors of A   
-          (Workspace: need N, prefer N*NRHS) */
+/*        Multiply B by right singular vectors of A */
+/*        (Workspace: need N, prefer N*NRHS) */
 
 	    if (*lwork >= *ldb * *nrhs && *nrhs > 1) {
 		dgemm_("T", "N", n, nrhs, m, &c_b108, &a[a_offset], lda, &b[
@@ -774,21 +789,21 @@
 /*     Undo scaling */
 
     if (iascl == 1) {
-	dlascl_("G", &c__0, &c__0, &anrm, &smlnum, n, nrhs, &b[b_offset], ldb,
+	dlascl_("G", &c__0, &c__0, &anrm, &smlnum, n, nrhs, &b[b_offset], ldb, 
 		 info);
 	dlascl_("G", &c__0, &c__0, &smlnum, &anrm, &minmn, &c__1, &s[1], &
 		minmn, info);
     } else if (iascl == 2) {
-	dlascl_("G", &c__0, &c__0, &anrm, &bignum, n, nrhs, &b[b_offset], ldb,
+	dlascl_("G", &c__0, &c__0, &anrm, &bignum, n, nrhs, &b[b_offset], ldb, 
 		 info);
 	dlascl_("G", &c__0, &c__0, &bignum, &anrm, &minmn, &c__1, &s[1], &
 		minmn, info);
     }
     if (ibscl == 1) {
-	dlascl_("G", &c__0, &c__0, &smlnum, &bnrm, n, nrhs, &b[b_offset], ldb,
+	dlascl_("G", &c__0, &c__0, &smlnum, &bnrm, n, nrhs, &b[b_offset], ldb, 
 		 info);
     } else if (ibscl == 2) {
-	dlascl_("G", &c__0, &c__0, &bignum, &bnrm, n, nrhs, &b[b_offset], ldb,
+	dlascl_("G", &c__0, &c__0, &bignum, &bnrm, n, nrhs, &b[b_offset], ldb, 
 		 info);
     }
 
