@@ -1,5 +1,13 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static integer c__0 = 0;
+static integer c_n1 = -1;
+static doublereal c_b38 = 0.;
+static doublereal c_b39 = 1.;
 
 /* Subroutine */ int dgges_(char *jobvsl, char *jobvsr, char *sort, L_fp 
 	selctg, integer *n, doublereal *a, integer *lda, doublereal *b, 
@@ -8,208 +16,31 @@
 	integer *ldvsr, doublereal *work, integer *lwork, logical *bwork, 
 	integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    DGGES computes for a pair of N-by-N real nonsymmetric matrices (A,B),   
-    the generalized eigenvalues, the generalized real Schur form (S,T),   
-    optionally, the left and/or right matrices of Schur vectors (VSL and   
-    VSR). This gives the generalized Schur factorization   
-
-             (A,B) = ( (VSL)*S*(VSR)**T, (VSL)*T*(VSR)**T )   
-
-    Optionally, it also orders the eigenvalues so that a selected cluster   
-    of eigenvalues appears in the leading diagonal blocks of the upper   
-    quasi-triangular matrix S and the upper triangular matrix T.The   
-    leading columns of VSL and VSR then form an orthonormal basis for the   
-    corresponding left and right eigenspaces (deflating subspaces).   
-
-    (If only the generalized eigenvalues are needed, use the driver   
-    DGGEV instead, which is faster.)   
-
-    A generalized eigenvalue for a pair of matrices (A,B) is a scalar w   
-    or a ratio alpha/beta = w, such that  A - w*B is singular.  It is   
-    usually represented as the pair (alpha,beta), as there is a   
-    reasonable interpretation for beta=0 or both being zero.   
-
-    A pair of matrices (S,T) is in generalized real Schur form if T is   
-    upper triangular with non-negative diagonal and S is block upper   
-    triangular with 1-by-1 and 2-by-2 blocks.  1-by-1 blocks correspond   
-    to real generalized eigenvalues, while 2-by-2 blocks of S will be   
-    "standardized" by making the corresponding elements of T have the   
-    form:   
-            [  a  0  ]   
-            [  0  b  ]   
-
-    and the pair of corresponding 2-by-2 blocks in S and T will have a   
-    complex conjugate pair of generalized eigenvalues.   
-
-
-    Arguments   
-    =========   
-
-    JOBVSL  (input) CHARACTER*1   
-            = 'N':  do not compute the left Schur vectors;   
-            = 'V':  compute the left Schur vectors.   
-
-    JOBVSR  (input) CHARACTER*1   
-            = 'N':  do not compute the right Schur vectors;   
-            = 'V':  compute the right Schur vectors.   
-
-    SORT    (input) CHARACTER*1   
-            Specifies whether or not to order the eigenvalues on the   
-            diagonal of the generalized Schur form.   
-            = 'N':  Eigenvalues are not ordered;   
-            = 'S':  Eigenvalues are ordered (see SELCTG);   
-
-    SELCTG  (external procedure) LOGICAL FUNCTION of three DOUBLE PRECISION arguments   
-            SELCTG must be declared EXTERNAL in the calling subroutine.   
-            If SORT = 'N', SELCTG is not referenced.   
-            If SORT = 'S', SELCTG is used to select eigenvalues to sort   
-            to the top left of the Schur form.   
-            An eigenvalue (ALPHAR(j)+ALPHAI(j))/BETA(j) is selected if   
-            SELCTG(ALPHAR(j),ALPHAI(j),BETA(j)) is true; i.e. if either   
-            one of a complex conjugate pair of eigenvalues is selected,   
-            then both complex eigenvalues are selected.   
-
-            Note that in the ill-conditioned case, a selected complex   
-            eigenvalue may no longer satisfy SELCTG(ALPHAR(j),ALPHAI(j),   
-            BETA(j)) = .TRUE. after ordering. INFO is to be set to N+2   
-            in this case.   
-
-    N       (input) INTEGER   
-            The order of the matrices A, B, VSL, and VSR.  N >= 0.   
-
-    A       (input/output) DOUBLE PRECISION array, dimension (LDA, N)   
-            On entry, the first of the pair of matrices.   
-            On exit, A has been overwritten by its generalized Schur   
-            form S.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A.  LDA >= max(1,N).   
-
-    B       (input/output) DOUBLE PRECISION array, dimension (LDB, N)   
-            On entry, the second of the pair of matrices.   
-            On exit, B has been overwritten by its generalized Schur   
-            form T.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of B.  LDB >= max(1,N).   
-
-    SDIM    (output) INTEGER   
-            If SORT = 'N', SDIM = 0.   
-            If SORT = 'S', SDIM = number of eigenvalues (after sorting)   
-            for which SELCTG is true.  (Complex conjugate pairs for which   
-            SELCTG is true for either eigenvalue count as 2.)   
-
-    ALPHAR  (output) DOUBLE PRECISION array, dimension (N)   
-    ALPHAI  (output) DOUBLE PRECISION array, dimension (N)   
-    BETA    (output) DOUBLE PRECISION array, dimension (N)   
-            On exit, (ALPHAR(j) + ALPHAI(j)*i)/BETA(j), j=1,...,N, will   
-            be the generalized eigenvalues.  ALPHAR(j) + ALPHAI(j)*i,   
-            and  BETA(j),j=1,...,N are the diagonals of the complex Schur   
-            form (S,T) that would result if the 2-by-2 diagonal blocks of   
-            the real Schur form of (A,B) were further reduced to   
-            triangular form using 2-by-2 complex unitary transformations.   
-            If ALPHAI(j) is zero, then the j-th eigenvalue is real; if   
-            positive, then the j-th and (j+1)-st eigenvalues are a   
-            complex conjugate pair, with ALPHAI(j+1) negative.   
-
-            Note: the quotients ALPHAR(j)/BETA(j) and ALPHAI(j)/BETA(j)   
-            may easily over- or underflow, and BETA(j) may even be zero.   
-            Thus, the user should avoid naively computing the ratio.   
-            However, ALPHAR and ALPHAI will be always less than and   
-            usually comparable with norm(A) in magnitude, and BETA always   
-            less than and usually comparable with norm(B).   
-
-    VSL     (output) DOUBLE PRECISION array, dimension (LDVSL,N)   
-            If JOBVSL = 'V', VSL will contain the left Schur vectors.   
-            Not referenced if JOBVSL = 'N'.   
-
-    LDVSL   (input) INTEGER   
-            The leading dimension of the matrix VSL. LDVSL >=1, and   
-            if JOBVSL = 'V', LDVSL >= N.   
-
-    VSR     (output) DOUBLE PRECISION array, dimension (LDVSR,N)   
-            If JOBVSR = 'V', VSR will contain the right Schur vectors.   
-            Not referenced if JOBVSR = 'N'.   
-
-    LDVSR   (input) INTEGER   
-            The leading dimension of the matrix VSR. LDVSR >= 1, and   
-            if JOBVSR = 'V', LDVSR >= N.   
-
-    WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.   
-            If N = 0, LWORK >= 1, else LWORK >= 8*N+16.   
-            For good performance , LWORK must generally be larger.   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    BWORK   (workspace) LOGICAL array, dimension (N)   
-            Not referenced if SORT = 'N'.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            = 1,...,N:   
-                  The QZ iteration failed.  (A,B) are not in Schur   
-                  form, but ALPHAR(j), ALPHAI(j), and BETA(j) should   
-                  be correct for j=INFO+1,...,N.   
-            > N:  =N+1: other than QZ iteration failed in DHGEQZ.   
-                  =N+2: after reordering, roundoff changed values of   
-                        some complex eigenvalues so that leading   
-                        eigenvalues in the Generalized Schur form no   
-                        longer satisfy SELCTG=.TRUE.  This could also   
-                        be caused due to scaling.   
-                  =N+3: reordering failed in DTGSEN.   
-
-    =====================================================================   
-
-
-       Decode the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static integer c_n1 = -1;
-    static doublereal c_b38 = 0.;
-    static doublereal c_b39 = 1.;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, vsl_dim1, vsl_offset, 
 	    vsr_dim1, vsr_offset, i__1, i__2;
     doublereal d__1;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, ip;
-    static doublereal dif[2];
-    static integer ihi, ilo;
-    static doublereal eps, anrm, bnrm;
-    static integer idum[1], ierr, itau, iwrk;
-    static doublereal pvsl, pvsr;
+    integer i__, ip;
+    doublereal dif[2];
+    integer ihi, ilo;
+    doublereal eps, anrm, bnrm;
+    integer idum[1], ierr, itau, iwrk;
+    doublereal pvsl, pvsr;
     extern logical lsame_(char *, char *);
-    static integer ileft, icols;
-    static logical cursl, ilvsl, ilvsr;
-    static integer irows;
+    integer ileft, icols;
+    logical cursl, ilvsl, ilvsr;
+    integer irows;
     extern /* Subroutine */ int dlabad_(doublereal *, doublereal *), dggbak_(
 	    char *, char *, integer *, integer *, integer *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *), dggbal_(char *, integer *, doublereal *, integer 
 	    *, doublereal *, integer *, integer *, integer *, doublereal *, 
 	    doublereal *, doublereal *, integer *);
-    static logical lst2sl;
+    logical lst2sl;
     extern doublereal dlamch_(char *), dlange_(char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *);
     extern /* Subroutine */ int dgghrd_(char *, char *, integer *, integer *, 
@@ -217,44 +48,235 @@
 	    doublereal *, integer *, doublereal *, integer *, integer *), dlascl_(char *, integer *, integer *, doublereal 
 	    *, doublereal *, integer *, integer *, doublereal *, integer *, 
 	    integer *);
-    static logical ilascl, ilbscl;
+    logical ilascl, ilbscl;
     extern /* Subroutine */ int dgeqrf_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *, integer *), 
 	    dlacpy_(char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static doublereal safmin;
+    doublereal safmin;
     extern /* Subroutine */ int dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *);
-    static doublereal safmax;
+    doublereal safmax;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static doublereal bignum;
+    doublereal bignum;
     extern /* Subroutine */ int dhgeqz_(char *, char *, char *, integer *, 
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *), dtgsen_(integer *, logical *, 
 	    logical *, logical *, integer *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *, doublereal *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *, integer *, integer *);
-    static integer ijobvl, iright;
+    integer ijobvl, iright;
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static integer ijobvr;
+	    integer *, integer *);
+    integer ijobvr;
     extern /* Subroutine */ int dorgqr_(integer *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    integer *);
-    static doublereal anrmto, bnrmto;
-    static logical lastsl;
+    doublereal anrmto, bnrmto;
+    logical lastsl;
     extern /* Subroutine */ int dormqr_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *);
-    static integer minwrk, maxwrk;
-    static doublereal smlnum;
-    static logical wantst, lquery;
+    integer minwrk, maxwrk;
+    doublereal smlnum;
+    logical wantst, lquery;
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+/*     .. Function Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  DGGES computes for a pair of N-by-N real nonsymmetric matrices (A,B), */
+/*  the generalized eigenvalues, the generalized real Schur form (S,T), */
+/*  optionally, the left and/or right matrices of Schur vectors (VSL and */
+/*  VSR). This gives the generalized Schur factorization */
+
+/*           (A,B) = ( (VSL)*S*(VSR)**T, (VSL)*T*(VSR)**T ) */
+
+/*  Optionally, it also orders the eigenvalues so that a selected cluster */
+/*  of eigenvalues appears in the leading diagonal blocks of the upper */
+/*  quasi-triangular matrix S and the upper triangular matrix T.The */
+/*  leading columns of VSL and VSR then form an orthonormal basis for the */
+/*  corresponding left and right eigenspaces (deflating subspaces). */
+
+/*  (If only the generalized eigenvalues are needed, use the driver */
+/*  DGGEV instead, which is faster.) */
+
+/*  A generalized eigenvalue for a pair of matrices (A,B) is a scalar w */
+/*  or a ratio alpha/beta = w, such that  A - w*B is singular.  It is */
+/*  usually represented as the pair (alpha,beta), as there is a */
+/*  reasonable interpretation for beta=0 or both being zero. */
+
+/*  A pair of matrices (S,T) is in generalized real Schur form if T is */
+/*  upper triangular with non-negative diagonal and S is block upper */
+/*  triangular with 1-by-1 and 2-by-2 blocks.  1-by-1 blocks correspond */
+/*  to real generalized eigenvalues, while 2-by-2 blocks of S will be */
+/*  "standardized" by making the corresponding elements of T have the */
+/*  form: */
+/*          [  a  0  ] */
+/*          [  0  b  ] */
+
+/*  and the pair of corresponding 2-by-2 blocks in S and T will have a */
+/*  complex conjugate pair of generalized eigenvalues. */
+
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVSL  (input) CHARACTER*1 */
+/*          = 'N':  do not compute the left Schur vectors; */
+/*          = 'V':  compute the left Schur vectors. */
+
+/*  JOBVSR  (input) CHARACTER*1 */
+/*          = 'N':  do not compute the right Schur vectors; */
+/*          = 'V':  compute the right Schur vectors. */
+
+/*  SORT    (input) CHARACTER*1 */
+/*          Specifies whether or not to order the eigenvalues on the */
+/*          diagonal of the generalized Schur form. */
+/*          = 'N':  Eigenvalues are not ordered; */
+/*          = 'S':  Eigenvalues are ordered (see SELCTG); */
+
+/*  SELCTG  (external procedure) LOGICAL FUNCTION of three DOUBLE PRECISION arguments */
+/*          SELCTG must be declared EXTERNAL in the calling subroutine. */
+/*          If SORT = 'N', SELCTG is not referenced. */
+/*          If SORT = 'S', SELCTG is used to select eigenvalues to sort */
+/*          to the top left of the Schur form. */
+/*          An eigenvalue (ALPHAR(j)+ALPHAI(j))/BETA(j) is selected if */
+/*          SELCTG(ALPHAR(j),ALPHAI(j),BETA(j)) is true; i.e. if either */
+/*          one of a complex conjugate pair of eigenvalues is selected, */
+/*          then both complex eigenvalues are selected. */
+
+/*          Note that in the ill-conditioned case, a selected complex */
+/*          eigenvalue may no longer satisfy SELCTG(ALPHAR(j),ALPHAI(j), */
+/*          BETA(j)) = .TRUE. after ordering. INFO is to be set to N+2 */
+/*          in this case. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A, B, VSL, and VSR.  N >= 0. */
+
+/*  A       (input/output) DOUBLE PRECISION array, dimension (LDA, N) */
+/*          On entry, the first of the pair of matrices. */
+/*          On exit, A has been overwritten by its generalized Schur */
+/*          form S. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A.  LDA >= max(1,N). */
+
+/*  B       (input/output) DOUBLE PRECISION array, dimension (LDB, N) */
+/*          On entry, the second of the pair of matrices. */
+/*          On exit, B has been overwritten by its generalized Schur */
+/*          form T. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B.  LDB >= max(1,N). */
+
+/*  SDIM    (output) INTEGER */
+/*          If SORT = 'N', SDIM = 0. */
+/*          If SORT = 'S', SDIM = number of eigenvalues (after sorting) */
+/*          for which SELCTG is true.  (Complex conjugate pairs for which */
+/*          SELCTG is true for either eigenvalue count as 2.) */
+
+/*  ALPHAR  (output) DOUBLE PRECISION array, dimension (N) */
+/*  ALPHAI  (output) DOUBLE PRECISION array, dimension (N) */
+/*  BETA    (output) DOUBLE PRECISION array, dimension (N) */
+/*          On exit, (ALPHAR(j) + ALPHAI(j)*i)/BETA(j), j=1,...,N, will */
+/*          be the generalized eigenvalues.  ALPHAR(j) + ALPHAI(j)*i, */
+/*          and  BETA(j),j=1,...,N are the diagonals of the complex Schur */
+/*          form (S,T) that would result if the 2-by-2 diagonal blocks of */
+/*          the real Schur form of (A,B) were further reduced to */
+/*          triangular form using 2-by-2 complex unitary transformations. */
+/*          If ALPHAI(j) is zero, then the j-th eigenvalue is real; if */
+/*          positive, then the j-th and (j+1)-st eigenvalues are a */
+/*          complex conjugate pair, with ALPHAI(j+1) negative. */
+
+/*          Note: the quotients ALPHAR(j)/BETA(j) and ALPHAI(j)/BETA(j) */
+/*          may easily over- or underflow, and BETA(j) may even be zero. */
+/*          Thus, the user should avoid naively computing the ratio. */
+/*          However, ALPHAR and ALPHAI will be always less than and */
+/*          usually comparable with norm(A) in magnitude, and BETA always */
+/*          less than and usually comparable with norm(B). */
+
+/*  VSL     (output) DOUBLE PRECISION array, dimension (LDVSL,N) */
+/*          If JOBVSL = 'V', VSL will contain the left Schur vectors. */
+/*          Not referenced if JOBVSL = 'N'. */
+
+/*  LDVSL   (input) INTEGER */
+/*          The leading dimension of the matrix VSL. LDVSL >=1, and */
+/*          if JOBVSL = 'V', LDVSL >= N. */
+
+/*  VSR     (output) DOUBLE PRECISION array, dimension (LDVSR,N) */
+/*          If JOBVSR = 'V', VSR will contain the right Schur vectors. */
+/*          Not referenced if JOBVSR = 'N'. */
+
+/*  LDVSR   (input) INTEGER */
+/*          The leading dimension of the matrix VSR. LDVSR >= 1, and */
+/*          if JOBVSR = 'V', LDVSR >= N. */
+
+/*  WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK. */
+/*          If N = 0, LWORK >= 1, else LWORK >= 8*N+16. */
+/*          For good performance , LWORK must generally be larger. */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  BWORK   (workspace) LOGICAL array, dimension (N) */
+/*          Not referenced if SORT = 'N'. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          = 1,...,N: */
+/*                The QZ iteration failed.  (A,B) are not in Schur */
+/*                form, but ALPHAR(j), ALPHAI(j), and BETA(j) should */
+/*                be correct for j=INFO+1,...,N. */
+/*          > N:  =N+1: other than QZ iteration failed in DHGEQZ. */
+/*                =N+2: after reordering, roundoff changed values of */
+/*                      some complex eigenvalues so that leading */
+/*                      eigenvalues in the Generalized Schur form no */
+/*                      longer satisfy SELCTG=.TRUE.  This could also */
+/*                      be caused due to scaling. */
+/*                =N+3: reordering failed in DTGSEN. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -320,12 +342,12 @@
 	*info = -17;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV.) */
 
     if (*info == 0) {
 	if (*n > 0) {
@@ -333,15 +355,15 @@
 	    i__1 = *n << 3, i__2 = *n * 6 + 16;
 	    minwrk = max(i__1,i__2);
 	    maxwrk = minwrk - *n + *n * ilaenv_(&c__1, "DGEQRF", " ", n, &
-		    c__1, n, &c__0, (ftnlen)6, (ftnlen)1);
+		    c__1, n, &c__0);
 /* Computing MAX */
 	    i__1 = maxwrk, i__2 = minwrk - *n + *n * ilaenv_(&c__1, "DORMQR", 
-		    " ", n, &c__1, n, &c_n1, (ftnlen)6, (ftnlen)1);
+		    " ", n, &c__1, n, &c_n1);
 	    maxwrk = max(i__1,i__2);
 	    if (ilvsl) {
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = minwrk - *n + *n * ilaenv_(&c__1, "DOR"
-			"GQR", " ", n, &c__1, n, &c_n1, (ftnlen)6, (ftnlen)1);
+			"GQR", " ", n, &c__1, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 	    }
 	} else {
@@ -411,8 +433,8 @@
 		ierr);
     }
 
-/*     Permute the matrix to make it more nearly triangular   
-       (Workspace: need 6*N + 2*N space for storing balancing factors) */
+/*     Permute the matrix to make it more nearly triangular */
+/*     (Workspace: need 6*N + 2*N space for storing balancing factors) */
 
     ileft = 1;
     iright = *n + 1;
@@ -420,8 +442,8 @@
     dggbal_("P", n, &a[a_offset], lda, &b[b_offset], ldb, &ilo, &ihi, &work[
 	    ileft], &work[iright], &work[iwrk], &ierr);
 
-/*     Reduce B to triangular form (QR decomposition of B)   
-       (Workspace: need N, prefer N*NB) */
+/*     Reduce B to triangular form (QR decomposition of B) */
+/*     (Workspace: need N, prefer N*NB) */
 
     irows = ihi + 1 - ilo;
     icols = *n + 1 - ilo;
@@ -431,16 +453,16 @@
     dgeqrf_(&irows, &icols, &b[ilo + ilo * b_dim1], ldb, &work[itau], &work[
 	    iwrk], &i__1, &ierr);
 
-/*     Apply the orthogonal transformation to matrix A   
-       (Workspace: need N, prefer N*NB) */
+/*     Apply the orthogonal transformation to matrix A */
+/*     (Workspace: need N, prefer N*NB) */
 
     i__1 = *lwork + 1 - iwrk;
     dormqr_("L", "T", &irows, &icols, &irows, &b[ilo + ilo * b_dim1], ldb, &
 	    work[itau], &a[ilo + ilo * a_dim1], lda, &work[iwrk], &i__1, &
 	    ierr);
 
-/*     Initialize VSL   
-       (Workspace: need N, prefer N*NB) */
+/*     Initialize VSL */
+/*     (Workspace: need N, prefer N*NB) */
 
     if (ilvsl) {
 	dlaset_("Full", n, n, &c_b38, &c_b39, &vsl[vsl_offset], ldvsl);
@@ -461,20 +483,20 @@
 	dlaset_("Full", n, n, &c_b38, &c_b39, &vsr[vsr_offset], ldvsr);
     }
 
-/*     Reduce to generalized Hessenberg form   
-       (Workspace: none needed) */
+/*     Reduce to generalized Hessenberg form */
+/*     (Workspace: none needed) */
 
     dgghrd_(jobvsl, jobvsr, n, &ilo, &ihi, &a[a_offset], lda, &b[b_offset], 
 	    ldb, &vsl[vsl_offset], ldvsl, &vsr[vsr_offset], ldvsr, &ierr);
 
-/*     Perform QZ algorithm, computing Schur vectors if desired   
-       (Workspace: need N) */
+/*     Perform QZ algorithm, computing Schur vectors if desired */
+/*     (Workspace: need N) */
 
     iwrk = itau;
     i__1 = *lwork + 1 - iwrk;
     dhgeqz_("S", jobvsl, jobvsr, n, &ilo, &ihi, &a[a_offset], lda, &b[
 	    b_offset], ldb, &alphar[1], &alphai[1], &beta[1], &vsl[vsl_offset]
-	    , ldvsl, &vsr[vsr_offset], ldvsr, &work[iwrk], &i__1, &ierr);
+, ldvsl, &vsr[vsr_offset], ldvsr, &work[iwrk], &i__1, &ierr);
     if (ierr != 0) {
 	if (ierr > 0 && ierr <= *n) {
 	    *info = ierr;
@@ -486,8 +508,8 @@
 	goto L50;
     }
 
-/*     Sort eigenvalues ALPHA/BETA if desired   
-       (Workspace: need 4*N+16 ) */
+/*     Sort eigenvalues ALPHA/BETA if desired */
+/*     (Workspace: need 4*N+16 ) */
 
     *sdim = 0;
     if (wantst) {
@@ -524,8 +546,8 @@
 
     }
 
-/*     Apply back-permutation to VSL and VSR   
-       (Workspace: none needed) */
+/*     Apply back-permutation to VSL and VSR */
+/*     (Workspace: none needed) */
 
     if (ilvsl) {
 	dggbak_("P", "L", n, &ilo, &ihi, &work[ileft], &work[iright], n, &vsl[
@@ -537,9 +559,9 @@
 		vsr_offset], ldvsr, &ierr);
     }
 
-/*     Check if unscaling would cause over/underflow, if so, rescale   
-       (ALPHAR(I),ALPHAI(I),BETA(I)) so BETA(I) is on the order of   
-       B(I,I) and ALPHAR(I) and ALPHAI(I) are on the order of A(I,I) */
+/*     Check if unscaling would cause over/underflow, if so, rescale */
+/*     (ALPHAR(I),ALPHAI(I),BETA(I)) so BETA(I) is on the order of */
+/*     B(I,I) and ALPHAR(I) and ALPHAI(I) are on the order of A(I,I) */
 
     if (ilascl) {
 	i__1 = *n;
