@@ -1,153 +1,35 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
 
 /* Subroutine */ int dlahqr_(logical *wantt, logical *wantz, integer *n, 
 	integer *ilo, integer *ihi, doublereal *h__, integer *ldh, doublereal 
 	*wr, doublereal *wi, integer *iloz, integer *ihiz, doublereal *z__, 
 	integer *ldz, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-       Purpose   
-       =======   
-
-       DLAHQR is an auxiliary routine called by DHSEQR to update the   
-       eigenvalues and Schur decomposition already computed by DHSEQR, by   
-       dealing with the Hessenberg submatrix in rows and columns ILO to   
-       IHI.   
-
-       Arguments   
-       =========   
-
-       WANTT   (input) LOGICAL   
-            = .TRUE. : the full Schur form T is required;   
-            = .FALSE.: only eigenvalues are required.   
-
-       WANTZ   (input) LOGICAL   
-            = .TRUE. : the matrix of Schur vectors Z is required;   
-            = .FALSE.: Schur vectors are not required.   
-
-       N       (input) INTEGER   
-            The order of the matrix H.  N >= 0.   
-
-       ILO     (input) INTEGER   
-       IHI     (input) INTEGER   
-            It is assumed that H is already upper quasi-triangular in   
-            rows and columns IHI+1:N, and that H(ILO,ILO-1) = 0 (unless   
-            ILO = 1). DLAHQR works primarily with the Hessenberg   
-            submatrix in rows and columns ILO to IHI, but applies   
-            transformations to all of H if WANTT is .TRUE..   
-            1 <= ILO <= max(1,IHI); IHI <= N.   
-
-       H       (input/output) DOUBLE PRECISION array, dimension (LDH,N)   
-            On entry, the upper Hessenberg matrix H.   
-            On exit, if INFO is zero and if WANTT is .TRUE., H is upper   
-            quasi-triangular in rows and columns ILO:IHI, with any   
-            2-by-2 diagonal blocks in standard form. If INFO is zero   
-            and WANTT is .FALSE., the contents of H are unspecified on   
-            exit.  The output state of H if INFO is nonzero is given   
-            below under the description of INFO.   
-
-       LDH     (input) INTEGER   
-            The leading dimension of the array H. LDH >= max(1,N).   
-
-       WR      (output) DOUBLE PRECISION array, dimension (N)   
-       WI      (output) DOUBLE PRECISION array, dimension (N)   
-            The real and imaginary parts, respectively, of the computed   
-            eigenvalues ILO to IHI are stored in the corresponding   
-            elements of WR and WI. If two eigenvalues are computed as a   
-            complex conjugate pair, they are stored in consecutive   
-            elements of WR and WI, say the i-th and (i+1)th, with   
-            WI(i) > 0 and WI(i+1) < 0. If WANTT is .TRUE., the   
-            eigenvalues are stored in the same order as on the diagonal   
-            of the Schur form returned in H, with WR(i) = H(i,i), and, if   
-            H(i:i+1,i:i+1) is a 2-by-2 diagonal block,   
-            WI(i) = sqrt(H(i+1,i)*H(i,i+1)) and WI(i+1) = -WI(i).   
-
-       ILOZ    (input) INTEGER   
-       IHIZ    (input) INTEGER   
-            Specify the rows of Z to which transformations must be   
-            applied if WANTZ is .TRUE..   
-            1 <= ILOZ <= ILO; IHI <= IHIZ <= N.   
-
-       Z       (input/output) DOUBLE PRECISION array, dimension (LDZ,N)   
-            If WANTZ is .TRUE., on entry Z must contain the current   
-            matrix Z of transformations accumulated by DHSEQR, and on   
-            exit Z has been updated; transformations are applied only to   
-            the submatrix Z(ILOZ:IHIZ,ILO:IHI).   
-            If WANTZ is .FALSE., Z is not referenced.   
-
-       LDZ     (input) INTEGER   
-            The leading dimension of the array Z. LDZ >= max(1,N).   
-
-       INFO    (output) INTEGER   
-             =   0: successful exit   
-            .GT. 0: If INFO = i, DLAHQR failed to compute all the   
-                    eigenvalues ILO to IHI in a total of 30 iterations   
-                    per eigenvalue; elements i+1:ihi of WR and WI   
-                    contain those eigenvalues which have been   
-                    successfully computed.   
-
-                    If INFO .GT. 0 and WANTT is .FALSE., then on exit,   
-                    the remaining unconverged eigenvalues are the   
-                    eigenvalues of the upper Hessenberg matrix rows   
-                    and columns ILO thorugh INFO of the final, output   
-                    value of H.   
-
-                    If INFO .GT. 0 and WANTT is .TRUE., then on exit   
-            (*)       (initial value of H)*U  = U*(final value of H)   
-                    where U is an orthognal matrix.    The final   
-                    value of H is upper Hessenberg and triangular in   
-                    rows and columns INFO+1 through IHI.   
-
-                    If INFO .GT. 0 and WANTZ is .TRUE., then on exit   
-                        (final value of Z)  = (initial value of Z)*U   
-                    where U is the orthogonal matrix in (*)   
-                    (regardless of the value of WANTT.)   
-
-       Further Details   
-       ===============   
-
-       02-96 Based on modifications by   
-       David Day, Sandia National Laboratory, USA   
-
-       12-04 Further modifications by   
-       Ralph Byers, University of Kansas, USA   
-
-         This is a modified version of DLAHQR from LAPACK version 3.0.   
-         It is (1) more robust against overflow and underflow and   
-         (2) adopts the more conservative Ahues & Tisseur stopping   
-         criterion (LAWN 122, 1997).   
-
-       =========================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer h_dim1, h_offset, z_dim1, z_offset, i__1, i__2, i__3;
     doublereal d__1, d__2, d__3, d__4;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, j, k, l, m;
-    static doublereal s, v[3];
-    static integer i1, i2;
-    static doublereal t1, t2, t3, v2, v3, aa, ab, ba, bb, h11, h12, h21, h22, 
-	    cs;
-    static integer nh;
-    static doublereal sn;
-    static integer nr;
-    static doublereal tr;
-    static integer nz;
-    static doublereal det, h21s;
-    static integer its;
-    static doublereal ulp, sum, tst, rt1i, rt2i, rt1r, rt2r;
+    integer i__, j, k, l, m;
+    doublereal s, v[3];
+    integer i1, i2;
+    doublereal t1, t2, t3, v2, v3, aa, ab, ba, bb, h11, h12, h21, h22, cs;
+    integer nh;
+    doublereal sn;
+    integer nr;
+    doublereal tr;
+    integer nz;
+    doublereal det, h21s;
+    integer its;
+    doublereal ulp, sum, tst, rt1i, rt2i, rt1r, rt2r;
     extern /* Subroutine */ int drot_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *), dcopy_(
 	    integer *, doublereal *, integer *, doublereal *, integer *), 
@@ -155,11 +37,148 @@
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *), dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
-    extern /* Subroutine */ int dlarfg_(integer *, doublereal *, doublereal *,
+    extern /* Subroutine */ int dlarfg_(integer *, doublereal *, doublereal *, 
 	     integer *, doublereal *);
-    static doublereal safmin, safmax, rtdisc, smlnum;
+    doublereal safmin, safmax, rtdisc, smlnum;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*     Purpose */
+/*     ======= */
+
+/*     DLAHQR is an auxiliary routine called by DHSEQR to update the */
+/*     eigenvalues and Schur decomposition already computed by DHSEQR, by */
+/*     dealing with the Hessenberg submatrix in rows and columns ILO to */
+/*     IHI. */
+
+/*     Arguments */
+/*     ========= */
+
+/*     WANTT   (input) LOGICAL */
+/*          = .TRUE. : the full Schur form T is required; */
+/*          = .FALSE.: only eigenvalues are required. */
+
+/*     WANTZ   (input) LOGICAL */
+/*          = .TRUE. : the matrix of Schur vectors Z is required; */
+/*          = .FALSE.: Schur vectors are not required. */
+
+/*     N       (input) INTEGER */
+/*          The order of the matrix H.  N >= 0. */
+
+/*     ILO     (input) INTEGER */
+/*     IHI     (input) INTEGER */
+/*          It is assumed that H is already upper quasi-triangular in */
+/*          rows and columns IHI+1:N, and that H(ILO,ILO-1) = 0 (unless */
+/*          ILO = 1). DLAHQR works primarily with the Hessenberg */
+/*          submatrix in rows and columns ILO to IHI, but applies */
+/*          transformations to all of H if WANTT is .TRUE.. */
+/*          1 <= ILO <= max(1,IHI); IHI <= N. */
+
+/*     H       (input/output) DOUBLE PRECISION array, dimension (LDH,N) */
+/*          On entry, the upper Hessenberg matrix H. */
+/*          On exit, if INFO is zero and if WANTT is .TRUE., H is upper */
+/*          quasi-triangular in rows and columns ILO:IHI, with any */
+/*          2-by-2 diagonal blocks in standard form. If INFO is zero */
+/*          and WANTT is .FALSE., the contents of H are unspecified on */
+/*          exit.  The output state of H if INFO is nonzero is given */
+/*          below under the description of INFO. */
+
+/*     LDH     (input) INTEGER */
+/*          The leading dimension of the array H. LDH >= max(1,N). */
+
+/*     WR      (output) DOUBLE PRECISION array, dimension (N) */
+/*     WI      (output) DOUBLE PRECISION array, dimension (N) */
+/*          The real and imaginary parts, respectively, of the computed */
+/*          eigenvalues ILO to IHI are stored in the corresponding */
+/*          elements of WR and WI. If two eigenvalues are computed as a */
+/*          complex conjugate pair, they are stored in consecutive */
+/*          elements of WR and WI, say the i-th and (i+1)th, with */
+/*          WI(i) > 0 and WI(i+1) < 0. If WANTT is .TRUE., the */
+/*          eigenvalues are stored in the same order as on the diagonal */
+/*          of the Schur form returned in H, with WR(i) = H(i,i), and, if */
+/*          H(i:i+1,i:i+1) is a 2-by-2 diagonal block, */
+/*          WI(i) = sqrt(H(i+1,i)*H(i,i+1)) and WI(i+1) = -WI(i). */
+
+/*     ILOZ    (input) INTEGER */
+/*     IHIZ    (input) INTEGER */
+/*          Specify the rows of Z to which transformations must be */
+/*          applied if WANTZ is .TRUE.. */
+/*          1 <= ILOZ <= ILO; IHI <= IHIZ <= N. */
+
+/*     Z       (input/output) DOUBLE PRECISION array, dimension (LDZ,N) */
+/*          If WANTZ is .TRUE., on entry Z must contain the current */
+/*          matrix Z of transformations accumulated by DHSEQR, and on */
+/*          exit Z has been updated; transformations are applied only to */
+/*          the submatrix Z(ILOZ:IHIZ,ILO:IHI). */
+/*          If WANTZ is .FALSE., Z is not referenced. */
+
+/*     LDZ     (input) INTEGER */
+/*          The leading dimension of the array Z. LDZ >= max(1,N). */
+
+/*     INFO    (output) INTEGER */
+/*           =   0: successful exit */
+/*          .GT. 0: If INFO = i, DLAHQR failed to compute all the */
+/*                  eigenvalues ILO to IHI in a total of 30 iterations */
+/*                  per eigenvalue; elements i+1:ihi of WR and WI */
+/*                  contain those eigenvalues which have been */
+/*                  successfully computed. */
+
+/*                  If INFO .GT. 0 and WANTT is .FALSE., then on exit, */
+/*                  the remaining unconverged eigenvalues are the */
+/*                  eigenvalues of the upper Hessenberg matrix rows */
+/*                  and columns ILO thorugh INFO of the final, output */
+/*                  value of H. */
+
+/*                  If INFO .GT. 0 and WANTT is .TRUE., then on exit */
+/*          (*)       (initial value of H)*U  = U*(final value of H) */
+/*                  where U is an orthognal matrix.    The final */
+/*                  value of H is upper Hessenberg and triangular in */
+/*                  rows and columns INFO+1 through IHI. */
+
+/*                  If INFO .GT. 0 and WANTZ is .TRUE., then on exit */
+/*                      (final value of Z)  = (initial value of Z)*U */
+/*                  where U is the orthogonal matrix in (*) */
+/*                  (regardless of the value of WANTT.) */
+
+/*     Further Details */
+/*     =============== */
+
+/*     02-96 Based on modifications by */
+/*     David Day, Sandia National Laboratory, USA */
+
+/*     12-04 Further modifications by */
+/*     Ralph Byers, University of Kansas, USA */
+
+/*       This is a modified version of DLAHQR from LAPACK version 3.0. */
+/*       It is (1) more robust against overflow and underflow and */
+/*       (2) adopts the more conservative Ahues & Tisseur stopping */
+/*       criterion (LAWN 122, 1997). */
+
+/*     ========================================================= */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
     h__ -= h_offset;
@@ -205,20 +224,20 @@
     ulp = dlamch_("PRECISION");
     smlnum = safmin * ((doublereal) nh / ulp);
 
-/*     I1 and I2 are the indices of the first row and last column of H   
-       to which transformations must be applied. If eigenvalues only are   
-       being computed, I1 and I2 are set inside the main loop. */
+/*     I1 and I2 are the indices of the first row and last column of H */
+/*     to which transformations must be applied. If eigenvalues only are */
+/*     being computed, I1 and I2 are set inside the main loop. */
 
     if (*wantt) {
 	i1 = 1;
 	i2 = *n;
     }
 
-/*     The main loop begins here. I is the loop index and decreases from   
-       IHI to ILO in steps of 1 or 2. Each iteration of the loop works   
-       with the active submatrix in rows and columns L to I.   
-       Eigenvalues I+1 to IHI have already converged. Either L = ILO or   
-       H(L,L-1) is negligible so that the matrix splits. */
+/*     The main loop begins here. I is the loop index and decreases from */
+/*     IHI to ILO in steps of 1 or 2. Each iteration of the loop works */
+/*     with the active submatrix in rows and columns L to I. */
+/*     Eigenvalues I+1 to IHI have already converged. Either L = ILO or */
+/*     H(L,L-1) is negligible so that the matrix splits. */
 
     i__ = *ihi;
 L20:
@@ -227,9 +246,9 @@ L20:
 	goto L160;
     }
 
-/*     Perform QR iterations on rows and columns ILO to I until a   
-       submatrix of order 1 or 2 splits off at the bottom because a   
-       subdiagonal element has become negligible. */
+/*     Perform QR iterations on rows and columns ILO to I until a */
+/*     submatrix of order 1 or 2 splits off at the bottom because a */
+/*     subdiagonal element has become negligible. */
 
     for (its = 0; its <= 30; ++its) {
 
@@ -250,10 +269,10 @@ L20:
 		    tst += (d__1 = h__[k + 1 + k * h_dim1], abs(d__1));
 		}
 	    }
-/*           ==== The following is a conservative small subdiagonal   
-             .    deflation  criterion due to Ahues & Tisseur (LAWN 122,   
-             .    1997). It has better mathematical foundation and   
-             .    improves accuracy in some cases.  ==== */
+/*           ==== The following is a conservative small subdiagonal */
+/*           .    deflation  criterion due to Ahues & Tisseur (LAWN 122, */
+/*           .    1997). It has better mathematical foundation and */
+/*           .    improves accuracy in some cases.  ==== */
 	    if ((d__1 = h__[k + (k - 1) * h_dim1], abs(d__1)) <= ulp * tst) {
 /* Computing MAX */
 		d__3 = (d__1 = h__[k + (k - 1) * h_dim1], abs(d__1)), d__4 = (
@@ -297,9 +316,9 @@ L40:
 	    goto L150;
 	}
 
-/*        Now the active submatrix is in rows and columns L to I. If   
-          eigenvalues only are being computed, only the active submatrix   
-          need be transformed. */
+/*        Now the active submatrix is in rows and columns L to I. If */
+/*        eigenvalues only are being computed, only the active submatrix */
+/*        need be transformed. */
 
 	if (! (*wantt)) {
 	    i1 = l;
@@ -316,8 +335,8 @@ L40:
 	    h22 = h11;
 	} else {
 
-/*           Prepare to use Francis' double shift   
-             (i.e. 2nd degree generalized Rayleigh quotient) */
+/*           Prepare to use Francis' double shift */
+/*           (i.e. 2nd degree generalized Rayleigh quotient) */
 
 	    h11 = h__[i__ - 1 + (i__ - 1) * h_dim1];
 	    h21 = h__[i__ + (i__ - 1) * h_dim1];
@@ -369,10 +388,10 @@ L40:
 
 	i__1 = l;
 	for (m = i__ - 2; m >= i__1; --m) {
-/*           Determine the effect of starting the double-shift QR   
-             iteration at row M, and see if this would make H(M,M-1)   
-             negligible.  (The following uses scaling to avoid   
-             overflows and most underflows.) */
+/*           Determine the effect of starting the double-shift QR */
+/*           iteration at row M, and see if this would make H(M,M-1) */
+/*           negligible.  (The following uses scaling to avoid */
+/*           overflows and most underflows.) */
 
 	    h21s = h__[m + 1 + m * h_dim1];
 	    s = (d__1 = h__[m + m * h_dim1] - rt2r, abs(d__1)) + abs(rt2i) + 
@@ -407,16 +426,16 @@ L60:
 	i__1 = i__ - 1;
 	for (k = m; k <= i__1; ++k) {
 
-/*           The first iteration of this loop determines a reflection G   
-             from the vector V and applies it from left and right to H,   
-             thus creating a nonzero bulge below the subdiagonal.   
+/*           The first iteration of this loop determines a reflection G */
+/*           from the vector V and applies it from left and right to H, */
+/*           thus creating a nonzero bulge below the subdiagonal. */
 
-             Each subsequent iteration determines a reflection G to   
-             restore the Hessenberg form in the (K-1)th column, and thus   
-             chases the bulge one step toward the bottom of the active   
-             submatrix. NR is the order of G.   
+/*           Each subsequent iteration determines a reflection G to */
+/*           restore the Hessenberg form in the (K-1)th column, and thus */
+/*           chases the bulge one step toward the bottom of the active */
+/*           submatrix. NR is the order of G. */
 
-   Computing MIN */
+/* Computing MIN */
 	    i__2 = 3, i__3 = i__ - k + 1;
 	    nr = min(i__2,i__3);
 	    if (k > m) {
@@ -438,8 +457,8 @@ L60:
 		v3 = v[2];
 		t3 = t1 * v3;
 
-/*              Apply G from the left to transform the rows of the matrix   
-                in columns K to I2. */
+/*              Apply G from the left to transform the rows of the matrix */
+/*              in columns K to I2. */
 
 		i__2 = i2;
 		for (j = k; j <= i__2; ++j) {
@@ -451,10 +470,10 @@ L60:
 /* L70: */
 		}
 
-/*              Apply G from the right to transform the columns of the   
-                matrix in rows I1 to min(K+3,I).   
+/*              Apply G from the right to transform the columns of the */
+/*              matrix in rows I1 to min(K+3,I). */
 
-   Computing MIN */
+/* Computing MIN */
 		i__3 = k + 3;
 		i__2 = min(i__3,i__);
 		for (j = i1; j <= i__2; ++j) {
@@ -482,8 +501,8 @@ L60:
 		}
 	    } else if (nr == 2) {
 
-/*              Apply G from the left to transform the rows of the matrix   
-                in columns K to I2. */
+/*              Apply G from the left to transform the rows of the matrix */
+/*              in columns K to I2. */
 
 		i__2 = i2;
 		for (j = k; j <= i__2; ++j) {
@@ -493,8 +512,8 @@ L60:
 /* L100: */
 		}
 
-/*              Apply G from the right to transform the columns of the   
-                matrix in rows I1 to min(K+3,I). */
+/*              Apply G from the right to transform the columns of the */
+/*              matrix in rows I1 to min(K+3,I). */
 
 		i__2 = i__;
 		for (j = i1; j <= i__2; ++j) {
@@ -540,10 +559,10 @@ L150:
 	wi[i__] = 0.;
     } else if (l == i__ - 1) {
 
-/*        H(I-1,I-2) is negligible: a pair of eigenvalues have converged.   
+/*        H(I-1,I-2) is negligible: a pair of eigenvalues have converged. */
 
-          Transform the 2-by-2 submatrix to standard Schur form,   
-          and compute and store the eigenvalues. */
+/*        Transform the 2-by-2 submatrix to standard Schur form, */
+/*        and compute and store the eigenvalues. */
 
 	dlanv2_(&h__[i__ - 1 + (i__ - 1) * h_dim1], &h__[i__ - 1 + i__ * 
 		h_dim1], &h__[i__ + (i__ - 1) * h_dim1], &h__[i__ + i__ * 
