@@ -1,209 +1,226 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static doublereal c_b36 = .5;
 
 /* Subroutine */ int dlatbs_(char *uplo, char *trans, char *diag, char *
 	normin, integer *n, integer *kd, doublereal *ab, integer *ldab, 
 	doublereal *x, doublereal *scale, doublereal *cnorm, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    DLATBS solves one of the triangular systems   
-
-       A *x = s*b  or  A'*x = s*b   
-
-    with scaling to prevent overflow, where A is an upper or lower   
-    triangular band matrix.  Here A' denotes the transpose of A, x and b   
-    are n-element vectors, and s is a scaling factor, usually less than   
-    or equal to 1, chosen so that the components of x will be less than   
-    the overflow threshold.  If the unscaled problem will not cause   
-    overflow, the Level 2 BLAS routine DTBSV is called.  If the matrix A   
-    is singular (A(j,j) = 0 for some j), then s is set to 0 and a   
-    non-trivial solution to A*x = 0 is returned.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A is upper or lower triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
-
-    TRANS   (input) CHARACTER*1   
-            Specifies the operation applied to A.   
-            = 'N':  Solve A * x = s*b  (No transpose)   
-            = 'T':  Solve A'* x = s*b  (Transpose)   
-            = 'C':  Solve A'* x = s*b  (Conjugate transpose = Transpose)   
-
-    DIAG    (input) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
-
-    NORMIN  (input) CHARACTER*1   
-            Specifies whether CNORM has been set or not.   
-            = 'Y':  CNORM contains the column norms on entry   
-            = 'N':  CNORM is not set on entry.  On exit, the norms will   
-                    be computed and stored in CNORM.   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    KD      (input) INTEGER   
-            The number of subdiagonals or superdiagonals in the   
-            triangular matrix A.  KD >= 0.   
-
-    AB      (input) DOUBLE PRECISION array, dimension (LDAB,N)   
-            The upper or lower triangular band matrix A, stored in the   
-            first KD+1 rows of the array. The j-th column of A is stored   
-            in the j-th column of the array AB as follows:   
-            if UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j;   
-            if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd).   
-
-    LDAB    (input) INTEGER   
-            The leading dimension of the array AB.  LDAB >= KD+1.   
-
-    X       (input/output) DOUBLE PRECISION array, dimension (N)   
-            On entry, the right hand side b of the triangular system.   
-            On exit, X is overwritten by the solution vector x.   
-
-    SCALE   (output) DOUBLE PRECISION   
-            The scaling factor s for the triangular system   
-               A * x = s*b  or  A'* x = s*b.   
-            If SCALE = 0, the matrix A is singular or badly scaled, and   
-            the vector x is an exact or approximate solution to A*x = 0.   
-
-    CNORM   (input or output) DOUBLE PRECISION array, dimension (N)   
-
-            If NORMIN = 'Y', CNORM is an input argument and CNORM(j)   
-            contains the norm of the off-diagonal part of the j-th column   
-            of A.  If TRANS = 'N', CNORM(j) must be greater than or equal   
-            to the infinity-norm, and if TRANS = 'T' or 'C', CNORM(j)   
-            must be greater than or equal to the 1-norm.   
-
-            If NORMIN = 'N', CNORM is an output argument and CNORM(j)   
-            returns the 1-norm of the offdiagonal part of the j-th column   
-            of A.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -k, the k-th argument had an illegal value   
-
-    Further Details   
-    ======= =======   
-
-    A rough bound on x is computed; if that is less than overflow, DTBSV   
-    is called, otherwise, specific code is used which checks for possible   
-    overflow or divide-by-zero at every operation.   
-
-    A columnwise scheme is used for solving A*x = b.  The basic algorithm   
-    if A is lower triangular is   
-
-         x[1:n] := b[1:n]   
-         for j = 1, ..., n   
-              x(j) := x(j) / A(j,j)   
-              x[j+1:n] := x[j+1:n] - x(j) * A[j+1:n,j]   
-         end   
-
-    Define bounds on the components of x after j iterations of the loop:   
-       M(j) = bound on x[1:j]   
-       G(j) = bound on x[j+1:n]   
-    Initially, let M(0) = 0 and G(0) = max{x(i), i=1,...,n}.   
-
-    Then for iteration j+1 we have   
-       M(j+1) <= G(j) / | A(j+1,j+1) |   
-       G(j+1) <= G(j) + M(j+1) * | A[j+2:n,j+1] |   
-              <= G(j) ( 1 + CNORM(j+1) / | A(j+1,j+1) | )   
-
-    where CNORM(j+1) is greater than or equal to the infinity-norm of   
-    column j+1 of A, not counting the diagonal.  Hence   
-
-       G(j) <= G(0) product ( 1 + CNORM(i) / | A(i,i) | )   
-                    1<=i<=j   
-    and   
-
-       |x(j)| <= ( G(0) / |A(j,j)| ) product ( 1 + CNORM(i) / |A(i,i)| )   
-                                     1<=i< j   
-
-    Since |x(j)| <= M(j), we use the Level 2 BLAS routine DTBSV if the   
-    reciprocal of the largest M(j), j=1,..,n, is larger than   
-    max(underflow, 1/overflow).   
-
-    The bound on x(j) is also used to determine when a step in the   
-    columnwise method can be performed without fear of overflow.  If   
-    the computed bound is greater than a large constant, x is scaled to   
-    prevent overflow, but if the bound overflows, x is set to 0, x(j) to   
-    1, and scale to 0, and a non-trivial solution to A*x = 0 is found.   
-
-    Similarly, a row-wise scheme is used to solve A'*x = b.  The basic   
-    algorithm for A upper triangular is   
-
-         for j = 1, ..., n   
-              x(j) := ( b(j) - A[1:j-1,j]' * x[1:j-1] ) / A(j,j)   
-         end   
-
-    We simultaneously compute two bounds   
-         G(j) = bound on ( b(i) - A[1:i-1,i]' * x[1:i-1] ), 1<=i<=j   
-         M(j) = bound on x(i), 1<=i<=j   
-
-    The initial values are G(0) = 0, M(0) = max{b(i), i=1,..,n}, and we   
-    add the constraint G(j) >= G(j-1) and M(j) >= M(j-1) for j >= 1.   
-    Then the bound on x(j) is   
-
-         M(j) <= M(j-1) * ( 1 + CNORM(j) ) / | A(j,j) |   
-
-              <= M(0) * product ( ( 1 + CNORM(i) ) / |A(i,i)| )   
-                        1<=i<=j   
-
-    and we can safely call DTBSV if 1/M(n) and 1/G(n) are both greater   
-    than max(underflow, 1/overflow).   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static doublereal c_b36 = .5;
-    
     /* System generated locals */
     integer ab_dim1, ab_offset, i__1, i__2, i__3, i__4;
     doublereal d__1, d__2, d__3;
+
     /* Local variables */
-    static integer i__, j;
-    static doublereal xj, rec, tjj;
-    static integer jinc, jlen;
+    integer i__, j;
+    doublereal xj, rec, tjj;
+    integer jinc, jlen;
     extern doublereal ddot_(integer *, doublereal *, integer *, doublereal *, 
 	    integer *);
-    static doublereal xbnd;
-    static integer imax;
-    static doublereal tmax, tjjs, xmax, grow, sumj;
+    doublereal xbnd;
+    integer imax;
+    doublereal tmax, tjjs, xmax, grow, sumj;
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
-    static integer maind;
+    integer maind;
     extern logical lsame_(char *, char *);
-    static doublereal tscal, uscal;
+    doublereal tscal, uscal;
     extern doublereal dasum_(integer *, doublereal *, integer *);
-    static integer jlast;
+    integer jlast;
     extern /* Subroutine */ int dtbsv_(char *, char *, char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *), daxpy_(integer *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *);
-    static logical upper;
+    logical upper;
     extern doublereal dlamch_(char *);
     extern integer idamax_(integer *, doublereal *, integer *);
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static doublereal bignum;
-    static logical notran;
-    static integer jfirst;
-    static doublereal smlnum;
-    static logical nounit;
+    doublereal bignum;
+    logical notran;
+    integer jfirst;
+    doublereal smlnum;
+    logical nounit;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  DLATBS solves one of the triangular systems */
+
+/*     A *x = s*b  or  A'*x = s*b */
+
+/*  with scaling to prevent overflow, where A is an upper or lower */
+/*  triangular band matrix.  Here A' denotes the transpose of A, x and b */
+/*  are n-element vectors, and s is a scaling factor, usually less than */
+/*  or equal to 1, chosen so that the components of x will be less than */
+/*  the overflow threshold.  If the unscaled problem will not cause */
+/*  overflow, the Level 2 BLAS routine DTBSV is called.  If the matrix A */
+/*  is singular (A(j,j) = 0 for some j), then s is set to 0 and a */
+/*  non-trivial solution to A*x = 0 is returned. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A is upper or lower triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies the operation applied to A. */
+/*          = 'N':  Solve A * x = s*b  (No transpose) */
+/*          = 'T':  Solve A'* x = s*b  (Transpose) */
+/*          = 'C':  Solve A'* x = s*b  (Conjugate transpose = Transpose) */
+
+/*  DIAG    (input) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
+
+/*  NORMIN  (input) CHARACTER*1 */
+/*          Specifies whether CNORM has been set or not. */
+/*          = 'Y':  CNORM contains the column norms on entry */
+/*          = 'N':  CNORM is not set on entry.  On exit, the norms will */
+/*                  be computed and stored in CNORM. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  KD      (input) INTEGER */
+/*          The number of subdiagonals or superdiagonals in the */
+/*          triangular matrix A.  KD >= 0. */
+
+/*  AB      (input) DOUBLE PRECISION array, dimension (LDAB,N) */
+/*          The upper or lower triangular band matrix A, stored in the */
+/*          first KD+1 rows of the array. The j-th column of A is stored */
+/*          in the j-th column of the array AB as follows: */
+/*          if UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j; */
+/*          if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd). */
+
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array AB.  LDAB >= KD+1. */
+
+/*  X       (input/output) DOUBLE PRECISION array, dimension (N) */
+/*          On entry, the right hand side b of the triangular system. */
+/*          On exit, X is overwritten by the solution vector x. */
+
+/*  SCALE   (output) DOUBLE PRECISION */
+/*          The scaling factor s for the triangular system */
+/*             A * x = s*b  or  A'* x = s*b. */
+/*          If SCALE = 0, the matrix A is singular or badly scaled, and */
+/*          the vector x is an exact or approximate solution to A*x = 0. */
+
+/*  CNORM   (input or output) DOUBLE PRECISION array, dimension (N) */
+
+/*          If NORMIN = 'Y', CNORM is an input argument and CNORM(j) */
+/*          contains the norm of the off-diagonal part of the j-th column */
+/*          of A.  If TRANS = 'N', CNORM(j) must be greater than or equal */
+/*          to the infinity-norm, and if TRANS = 'T' or 'C', CNORM(j) */
+/*          must be greater than or equal to the 1-norm. */
+
+/*          If NORMIN = 'N', CNORM is an output argument and CNORM(j) */
+/*          returns the 1-norm of the offdiagonal part of the j-th column */
+/*          of A. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -k, the k-th argument had an illegal value */
+
+/*  Further Details */
+/*  ======= ======= */
+
+/*  A rough bound on x is computed; if that is less than overflow, DTBSV */
+/*  is called, otherwise, specific code is used which checks for possible */
+/*  overflow or divide-by-zero at every operation. */
+
+/*  A columnwise scheme is used for solving A*x = b.  The basic algorithm */
+/*  if A is lower triangular is */
+
+/*       x[1:n] := b[1:n] */
+/*       for j = 1, ..., n */
+/*            x(j) := x(j) / A(j,j) */
+/*            x[j+1:n] := x[j+1:n] - x(j) * A[j+1:n,j] */
+/*       end */
+
+/*  Define bounds on the components of x after j iterations of the loop: */
+/*     M(j) = bound on x[1:j] */
+/*     G(j) = bound on x[j+1:n] */
+/*  Initially, let M(0) = 0 and G(0) = max{x(i), i=1,...,n}. */
+
+/*  Then for iteration j+1 we have */
+/*     M(j+1) <= G(j) / | A(j+1,j+1) | */
+/*     G(j+1) <= G(j) + M(j+1) * | A[j+2:n,j+1] | */
+/*            <= G(j) ( 1 + CNORM(j+1) / | A(j+1,j+1) | ) */
+
+/*  where CNORM(j+1) is greater than or equal to the infinity-norm of */
+/*  column j+1 of A, not counting the diagonal.  Hence */
+
+/*     G(j) <= G(0) product ( 1 + CNORM(i) / | A(i,i) | ) */
+/*                  1<=i<=j */
+/*  and */
+
+/*     |x(j)| <= ( G(0) / |A(j,j)| ) product ( 1 + CNORM(i) / |A(i,i)| ) */
+/*                                   1<=i< j */
+
+/*  Since |x(j)| <= M(j), we use the Level 2 BLAS routine DTBSV if the */
+/*  reciprocal of the largest M(j), j=1,..,n, is larger than */
+/*  max(underflow, 1/overflow). */
+
+/*  The bound on x(j) is also used to determine when a step in the */
+/*  columnwise method can be performed without fear of overflow.  If */
+/*  the computed bound is greater than a large constant, x is scaled to */
+/*  prevent overflow, but if the bound overflows, x is set to 0, x(j) to */
+/*  1, and scale to 0, and a non-trivial solution to A*x = 0 is found. */
+
+/*  Similarly, a row-wise scheme is used to solve A'*x = b.  The basic */
+/*  algorithm for A upper triangular is */
+
+/*       for j = 1, ..., n */
+/*            x(j) := ( b(j) - A[1:j-1,j]' * x[1:j-1] ) / A(j,j) */
+/*       end */
+
+/*  We simultaneously compute two bounds */
+/*       G(j) = bound on ( b(i) - A[1:i-1,i]' * x[1:i-1] ), 1<=i<=j */
+/*       M(j) = bound on x(i), 1<=i<=j */
+
+/*  The initial values are G(0) = 0, M(0) = max{b(i), i=1,..,n}, and we */
+/*  add the constraint G(j) >= G(j-1) and M(j) >= M(j-1) for j >= 1. */
+/*  Then the bound on x(j) is */
+
+/*       M(j) <= M(j-1) * ( 1 + CNORM(j) ) / | A(j,j) | */
+
+/*            <= M(0) * product ( ( 1 + CNORM(i) ) / |A(i,i)| ) */
+/*                      1<=i<=j */
+
+/*  and we can safely call DTBSV if 1/M(n) and 1/G(n) are both greater */
+/*  than max(underflow, 1/overflow). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
     ab -= ab_offset;
@@ -289,8 +306,8 @@
 	}
     }
 
-/*     Scale the column norms by TSCAL if the maximum element in CNORM is   
-       greater than BIGNUM. */
+/*     Scale the column norms by TSCAL if the maximum element in CNORM is */
+/*     greater than BIGNUM. */
 
     imax = idamax_(n, &cnorm[1], &c__1);
     tmax = cnorm[imax];
@@ -301,8 +318,8 @@
 	dscal_(n, &tscal, &cnorm[1], &c__1);
     }
 
-/*     Compute a bound on the computed solution vector to see if the   
-       Level 2 BLAS routine DTBSV can be used. */
+/*     Compute a bound on the computed solution vector to see if the */
+/*     Level 2 BLAS routine DTBSV can be used. */
 
     j = idamax_(n, &x[1], &c__1);
     xmax = (d__1 = x[j], abs(d__1));
@@ -330,10 +347,10 @@
 
 	if (nounit) {
 
-/*           A is non-unit triangular.   
+/*           A is non-unit triangular. */
 
-             Compute GROW = 1/G(j) and XBND = 1/M(j).   
-             Initially, G(0) = max{x(i), i=1,...,n}. */
+/*           Compute GROW = 1/G(j) and XBND = 1/M(j). */
+/*           Initially, G(0) = max{x(i), i=1,...,n}. */
 
 	    grow = 1. / max(xbnd,smlnum);
 	    xbnd = grow;
@@ -369,11 +386,11 @@
 	    grow = xbnd;
 	} else {
 
-/*           A is unit triangular.   
+/*           A is unit triangular. */
 
-             Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}.   
+/*           Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}. */
 
-   Computing MIN */
+/* Computing MIN */
 	    d__1 = 1., d__2 = 1. / max(xbnd,smlnum);
 	    grow = min(d__1,d__2);
 	    i__2 = jlast;
@@ -418,10 +435,10 @@ L50:
 
 	if (nounit) {
 
-/*           A is non-unit triangular.   
+/*           A is non-unit triangular. */
 
-             Compute GROW = 1/G(j) and XBND = 1/M(j).   
-             Initially, M(0) = max{x(i), i=1,...,n}. */
+/*           Compute GROW = 1/G(j) and XBND = 1/M(j). */
+/*           Initially, M(0) = max{x(i), i=1,...,n}. */
 
 	    grow = 1. / max(xbnd,smlnum);
 	    xbnd = grow;
@@ -453,11 +470,11 @@ L50:
 	    grow = min(grow,xbnd);
 	} else {
 
-/*           A is unit triangular.   
+/*           A is unit triangular. */
 
-             Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}.   
+/*           Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}. */
 
-   Computing MIN */
+/* Computing MIN */
 	    d__1 = 1., d__2 = 1. / max(xbnd,smlnum);
 	    grow = min(d__1,d__2);
 	    i__2 = jlast;
@@ -483,8 +500,8 @@ L80:
 
     if (grow * tscal > smlnum) {
 
-/*        Use the Level 2 BLAS solve if the reciprocal of the bound on   
-          elements of X is not too small. */
+/*        Use the Level 2 BLAS solve if the reciprocal of the bound on */
+/*        elements of X is not too small. */
 
 	dtbsv_(uplo, trans, diag, n, kd, &ab[ab_offset], ldab, &x[1], &c__1);
     } else {
@@ -493,8 +510,8 @@ L80:
 
 	if (xmax > bignum) {
 
-/*           Scale X so that its components are less than or equal to   
-             BIGNUM in absolute value. */
+/*           Scale X so that its components are less than or equal to */
+/*           BIGNUM in absolute value. */
 
 	    *scale = bignum / xmax;
 	    dscal_(n, scale, &x[1], &c__1);
@@ -544,14 +561,14 @@ L80:
 
 		    if (xj > tjj * bignum) {
 
-/*                       Scale x by (1/abs(x(j)))*abs(A(j,j))*BIGNUM   
-                         to avoid overflow when dividing by A(j,j). */
+/*                       Scale x by (1/abs(x(j)))*abs(A(j,j))*BIGNUM */
+/*                       to avoid overflow when dividing by A(j,j). */
 
 			rec = tjj * bignum / xj;
 			if (cnorm[j] > 1.) {
 
-/*                          Scale by 1/CNORM(j) to avoid overflow when   
-                            multiplying x(j) times column j. */
+/*                          Scale by 1/CNORM(j) to avoid overflow when */
+/*                          multiplying x(j) times column j. */
 
 			    rec /= cnorm[j];
 			}
@@ -563,8 +580,8 @@ L80:
 		    xj = (d__1 = x[j], abs(d__1));
 		} else {
 
-/*                    A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                      scale = 0, and compute a solution to A*x = 0. */
+/*                    A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                    scale = 0, and compute a solution to A*x = 0. */
 
 		    i__3 = *n;
 		    for (i__ = 1; i__ <= i__3; ++i__) {
@@ -578,8 +595,8 @@ L80:
 		}
 L100:
 
-/*              Scale x if necessary to avoid overflow when adding a   
-                multiple of column j of A. */
+/*              Scale x if necessary to avoid overflow when adding a */
+/*              multiple of column j of A. */
 
 		if (xj > 1.) {
 		    rec = 1. / xj;
@@ -602,11 +619,11 @@ L100:
 		if (upper) {
 		    if (j > 1) {
 
-/*                    Compute the update   
-                         x(max(1,j-kd):j-1) := x(max(1,j-kd):j-1) -   
-                                               x(j)* A(max(1,j-kd):j-1,j)   
+/*                    Compute the update */
+/*                       x(max(1,j-kd):j-1) := x(max(1,j-kd):j-1) - */
+/*                                             x(j)* A(max(1,j-kd):j-1,j) */
 
-   Computing MIN */
+/* Computing MIN */
 			i__3 = *kd, i__4 = j - 1;
 			jlen = min(i__3,i__4);
 			d__1 = -x[j] * tscal;
@@ -618,11 +635,11 @@ L100:
 		    }
 		} else if (j < *n) {
 
-/*                 Compute the update   
-                      x(j+1:min(j+kd,n)) := x(j+1:min(j+kd,n)) -   
-                                            x(j) * A(j+1:min(j+kd,n),j)   
+/*                 Compute the update */
+/*                    x(j+1:min(j+kd,n)) := x(j+1:min(j+kd,n)) - */
+/*                                          x(j) * A(j+1:min(j+kd,n),j) */
 
-   Computing MIN */
+/* Computing MIN */
 		    i__3 = *kd, i__4 = *n - j;
 		    jlen = min(i__3,i__4);
 		    if (jlen > 0) {
@@ -645,8 +662,8 @@ L100:
 	    i__1 = jinc;
 	    for (j = jfirst; i__1 < 0 ? j >= i__2 : j <= i__2; j += i__1) {
 
-/*              Compute x(j) = b(j) - sum A(k,j)*x(k).   
-                                      k<>j */
+/*              Compute x(j) = b(j) - sum A(k,j)*x(k). */
+/*                                    k<>j */
 
 		xj = (d__1 = x[j], abs(d__1));
 		uscal = tscal;
@@ -664,9 +681,9 @@ L100:
 		    tjj = abs(tjjs);
 		    if (tjj > 1.) {
 
-/*                       Divide by A(j,j) when scaling x if A(j,j) > 1.   
+/*                       Divide by A(j,j) when scaling x if A(j,j) > 1. */
 
-   Computing MIN */
+/* Computing MIN */
 			d__1 = 1., d__2 = rec * tjj;
 			rec = min(d__1,d__2);
 			uscal /= tjjs;
@@ -681,8 +698,8 @@ L100:
 		sumj = 0.;
 		if (uscal == 1.) {
 
-/*                 If the scaling needed for A in the dot product is 1,   
-                   call DDOT to perform the dot product. */
+/*                 If the scaling needed for A in the dot product is 1, */
+/*                 call DDOT to perform the dot product. */
 
 		    if (upper) {
 /* Computing MIN */
@@ -728,8 +745,8 @@ L100:
 
 		if (uscal == tscal) {
 
-/*                 Compute x(j) := ( x(j) - sumj ) / A(j,j) if 1/A(j,j)   
-                   was not used to scale the dotproduct. */
+/*                 Compute x(j) := ( x(j) - sumj ) / A(j,j) if 1/A(j,j) */
+/*                 was not used to scale the dotproduct. */
 
 		    x[j] -= sumj;
 		    xj = (d__1 = x[j], abs(d__1));
@@ -777,8 +794,8 @@ L100:
 			x[j] /= tjjs;
 		    } else {
 
-/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                         scale = 0, and compute a solution to A'*x = 0. */
+/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                       scale = 0, and compute a solution to A'*x = 0. */
 
 			i__3 = *n;
 			for (i__ = 1; i__ <= i__3; ++i__) {
@@ -793,8 +810,8 @@ L150:
 		    ;
 		} else {
 
-/*                 Compute x(j) := x(j) / A(j,j) - sumj if the dot   
-                   product has already been divided by 1/A(j,j). */
+/*                 Compute x(j) := x(j) / A(j,j) - sumj if the dot */
+/*                 product has already been divided by 1/A(j,j). */
 
 		    x[j] = x[j] / tjjs - sumj;
 		}
