@@ -1,5 +1,15 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__2 = 2;
+static integer c_n1 = -1;
+static integer c__5 = 5;
+static doublereal c_b14 = 0.;
+static integer c__1 = 1;
+static doublereal c_b51 = -1.;
+static doublereal c_b52 = 1.;
 
 /* Subroutine */ int dtgsyl_(char *trans, integer *ijob, integer *m, integer *
 	n, doublereal *a, integer *lda, doublereal *b, integer *ldb, 
@@ -8,236 +18,244 @@
 	scale, doublereal *dif, doublereal *work, integer *lwork, integer *
 	iwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    DTGSYL solves the generalized Sylvester equation:   
-
-                A * R - L * B = scale * C                 (1)   
-                D * R - L * E = scale * F   
-
-    where R and L are unknown m-by-n matrices, (A, D), (B, E) and   
-    (C, F) are given matrix pairs of size m-by-m, n-by-n and m-by-n,   
-    respectively, with real entries. (A, D) and (B, E) must be in   
-    generalized (real) Schur canonical form, i.e. A, B are upper quasi   
-    triangular and D, E are upper triangular.   
-
-    The solution (R, L) overwrites (C, F). 0 <= SCALE <= 1 is an output   
-    scaling factor chosen to avoid overflow.   
-
-    In matrix notation (1) is equivalent to solve  Zx = scale b, where   
-    Z is defined as   
-
-               Z = [ kron(In, A)  -kron(B', Im) ]         (2)   
-                   [ kron(In, D)  -kron(E', Im) ].   
-
-    Here Ik is the identity matrix of size k and X' is the transpose of   
-    X. kron(X, Y) is the Kronecker product between the matrices X and Y.   
-
-    If TRANS = 'T', DTGSYL solves the transposed system Z'*y = scale*b,   
-    which is equivalent to solve for R and L in   
-
-                A' * R  + D' * L   = scale *  C           (3)   
-                R  * B' + L  * E'  = scale * (-F)   
-
-    This case (TRANS = 'T') is used to compute an one-norm-based estimate   
-    of Dif[(A,D), (B,E)], the separation between the matrix pairs (A,D)   
-    and (B,E), using DLACON.   
-
-    If IJOB >= 1, DTGSYL computes a Frobenius norm-based estimate   
-    of Dif[(A,D),(B,E)]. That is, the reciprocal of a lower bound on the   
-    reciprocal of the smallest singular value of Z. See [1-2] for more   
-    information.   
-
-    This is a level 3 BLAS algorithm.   
-
-    Arguments   
-    =========   
-
-    TRANS   (input) CHARACTER*1   
-            = 'N', solve the generalized Sylvester equation (1).   
-            = 'T', solve the 'transposed' system (3).   
-
-    IJOB    (input) INTEGER   
-            Specifies what kind of functionality to be performed.   
-             =0: solve (1) only.   
-             =1: The functionality of 0 and 3.   
-             =2: The functionality of 0 and 4.   
-             =3: Only an estimate of Dif[(A,D), (B,E)] is computed.   
-                 (look ahead strategy IJOB  = 1 is used).   
-             =4: Only an estimate of Dif[(A,D), (B,E)] is computed.   
-                 ( DGECON on sub-systems is used ).   
-            Not referenced if TRANS = 'T'.   
-
-    M       (input) INTEGER   
-            The order of the matrices A and D, and the row dimension of   
-            the matrices C, F, R and L.   
-
-    N       (input) INTEGER   
-            The order of the matrices B and E, and the column dimension   
-            of the matrices C, F, R and L.   
-
-    A       (input) DOUBLE PRECISION array, dimension (LDA, M)   
-            The upper quasi triangular matrix A.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A. LDA >= max(1, M).   
-
-    B       (input) DOUBLE PRECISION array, dimension (LDB, N)   
-            The upper quasi triangular matrix B.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B. LDB >= max(1, N).   
-
-    C       (input/output) DOUBLE PRECISION array, dimension (LDC, N)   
-            On entry, C contains the right-hand-side of the first matrix   
-            equation in (1) or (3).   
-            On exit, if IJOB = 0, 1 or 2, C has been overwritten by   
-            the solution R. If IJOB = 3 or 4 and TRANS = 'N', C holds R,   
-            the solution achieved during the computation of the   
-            Dif-estimate.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C. LDC >= max(1, M).   
-
-    D       (input) DOUBLE PRECISION array, dimension (LDD, M)   
-            The upper triangular matrix D.   
-
-    LDD     (input) INTEGER   
-            The leading dimension of the array D. LDD >= max(1, M).   
-
-    E       (input) DOUBLE PRECISION array, dimension (LDE, N)   
-            The upper triangular matrix E.   
-
-    LDE     (input) INTEGER   
-            The leading dimension of the array E. LDE >= max(1, N).   
-
-    F       (input/output) DOUBLE PRECISION array, dimension (LDF, N)   
-            On entry, F contains the right-hand-side of the second matrix   
-            equation in (1) or (3).   
-            On exit, if IJOB = 0, 1 or 2, F has been overwritten by   
-            the solution L. If IJOB = 3 or 4 and TRANS = 'N', F holds L,   
-            the solution achieved during the computation of the   
-            Dif-estimate.   
-
-    LDF     (input) INTEGER   
-            The leading dimension of the array F. LDF >= max(1, M).   
-
-    DIF     (output) DOUBLE PRECISION   
-            On exit DIF is the reciprocal of a lower bound of the   
-            reciprocal of the Dif-function, i.e. DIF is an upper bound of   
-            Dif[(A,D), (B,E)] = sigma_min(Z), where Z as in (2).   
-            IF IJOB = 0 or TRANS = 'T', DIF is not touched.   
-
-    SCALE   (output) DOUBLE PRECISION   
-            On exit SCALE is the scaling factor in (1) or (3).   
-            If 0 < SCALE < 1, C and F hold the solutions R and L, resp.,   
-            to a slightly perturbed system but the input matrices A, B, D   
-            and E have not been changed. If SCALE = 0, C and F hold the   
-            solutions R and L, respectively, to the homogeneous system   
-            with C = F = 0. Normally, SCALE = 1.   
-
-    WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK. LWORK > = 1.   
-            If IJOB = 1 or 2 and TRANS = 'N', LWORK >= max(1,2*M*N).   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    IWORK   (workspace) INTEGER array, dimension (M+N+6)   
-
-    INFO    (output) INTEGER   
-              =0: successful exit   
-              <0: If INFO = -i, the i-th argument had an illegal value.   
-              >0: (A, D) and (B, E) have common or close eigenvalues.   
-
-    Further Details   
-    ===============   
-
-    Based on contributions by   
-       Bo Kagstrom and Peter Poromaa, Department of Computing Science,   
-       Umea University, S-901 87 Umea, Sweden.   
-
-    [1] B. Kagstrom and P. Poromaa, LAPACK-Style Algorithms and Software   
-        for Solving the Generalized Sylvester Equation and Estimating the   
-        Separation between Regular Matrix Pairs, Report UMINF - 93.23,   
-        Department of Computing Science, Umea University, S-901 87 Umea,   
-        Sweden, December 1993, Revised April 1994, Also as LAPACK Working   
-        Note 75.  To appear in ACM Trans. on Math. Software, Vol 22,   
-        No 1, 1996.   
-
-    [2] B. Kagstrom, A Perturbation Analysis of the Generalized Sylvester   
-        Equation (AR - LB, DR - LE ) = (C, F), SIAM J. Matrix Anal.   
-        Appl., 15(4):1045-1060, 1994   
-
-    [3] B. Kagstrom and L. Westin, Generalized Schur Methods with   
-        Condition Estimators for Solving the Generalized Sylvester   
-        Equation, IEEE Transactions on Automatic Control, Vol. 34, No. 7,   
-        July 1989, pp 745-751.   
-
-    =====================================================================   
-    Replaced various illegal calls to DCOPY by calls to DLASET.   
-    Sven Hammarling, 1/5/02.   
-
-
-       Decode and test input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__2 = 2;
-    static integer c_n1 = -1;
-    static integer c__5 = 5;
-    static doublereal c_b14 = 0.;
-    static integer c__1 = 1;
-    static doublereal c_b51 = -1.;
-    static doublereal c_b52 = 1.;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, c_dim1, c_offset, d_dim1, 
 	    d_offset, e_dim1, e_offset, f_dim1, f_offset, i__1, i__2, i__3, 
 	    i__4;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, j, k, p, q, ie, je, mb, nb, is, js, pq;
-    static doublereal dsum;
-    static integer ppqq;
+    integer i__, j, k, p, q, ie, je, mb, nb, is, js, pq;
+    doublereal dsum;
+    integer ppqq;
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *), dgemm_(char *, char *, integer *, integer *, integer *
 , doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *);
     extern logical lsame_(char *, char *);
-    static integer ifunc, linfo, lwmin;
-    static doublereal scale2;
+    integer ifunc, linfo, lwmin;
+    doublereal scale2;
     extern /* Subroutine */ int dtgsy2_(char *, integer *, integer *, integer 
-	    *, doublereal *, integer *, doublereal *, integer *, doublereal *,
+	    *, doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     integer *, integer *, integer *);
-    static doublereal dscale, scaloc;
+    doublereal dscale, scaloc;
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *), 
 	    dlaset_(char *, integer *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static integer iround;
-    static logical notran;
-    static integer isolve;
-    static logical lquery;
+    integer iround;
+    logical notran;
+    integer isolve;
+    logical lquery;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  DTGSYL solves the generalized Sylvester equation: */
+
+/*              A * R - L * B = scale * C                 (1) */
+/*              D * R - L * E = scale * F */
+
+/*  where R and L are unknown m-by-n matrices, (A, D), (B, E) and */
+/*  (C, F) are given matrix pairs of size m-by-m, n-by-n and m-by-n, */
+/*  respectively, with real entries. (A, D) and (B, E) must be in */
+/*  generalized (real) Schur canonical form, i.e. A, B are upper quasi */
+/*  triangular and D, E are upper triangular. */
+
+/*  The solution (R, L) overwrites (C, F). 0 <= SCALE <= 1 is an output */
+/*  scaling factor chosen to avoid overflow. */
+
+/*  In matrix notation (1) is equivalent to solve  Zx = scale b, where */
+/*  Z is defined as */
+
+/*             Z = [ kron(In, A)  -kron(B', Im) ]         (2) */
+/*                 [ kron(In, D)  -kron(E', Im) ]. */
+
+/*  Here Ik is the identity matrix of size k and X' is the transpose of */
+/*  X. kron(X, Y) is the Kronecker product between the matrices X and Y. */
+
+/*  If TRANS = 'T', DTGSYL solves the transposed system Z'*y = scale*b, */
+/*  which is equivalent to solve for R and L in */
+
+/*              A' * R  + D' * L   = scale *  C           (3) */
+/*              R  * B' + L  * E'  = scale * (-F) */
+
+/*  This case (TRANS = 'T') is used to compute an one-norm-based estimate */
+/*  of Dif[(A,D), (B,E)], the separation between the matrix pairs (A,D) */
+/*  and (B,E), using DLACON. */
+
+/*  If IJOB >= 1, DTGSYL computes a Frobenius norm-based estimate */
+/*  of Dif[(A,D),(B,E)]. That is, the reciprocal of a lower bound on the */
+/*  reciprocal of the smallest singular value of Z. See [1-2] for more */
+/*  information. */
+
+/*  This is a level 3 BLAS algorithm. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          = 'N', solve the generalized Sylvester equation (1). */
+/*          = 'T', solve the 'transposed' system (3). */
+
+/*  IJOB    (input) INTEGER */
+/*          Specifies what kind of functionality to be performed. */
+/*           =0: solve (1) only. */
+/*           =1: The functionality of 0 and 3. */
+/*           =2: The functionality of 0 and 4. */
+/*           =3: Only an estimate of Dif[(A,D), (B,E)] is computed. */
+/*               (look ahead strategy IJOB  = 1 is used). */
+/*           =4: Only an estimate of Dif[(A,D), (B,E)] is computed. */
+/*               ( DGECON on sub-systems is used ). */
+/*          Not referenced if TRANS = 'T'. */
+
+/*  M       (input) INTEGER */
+/*          The order of the matrices A and D, and the row dimension of */
+/*          the matrices C, F, R and L. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices B and E, and the column dimension */
+/*          of the matrices C, F, R and L. */
+
+/*  A       (input) DOUBLE PRECISION array, dimension (LDA, M) */
+/*          The upper quasi triangular matrix A. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A. LDA >= max(1, M). */
+
+/*  B       (input) DOUBLE PRECISION array, dimension (LDB, N) */
+/*          The upper quasi triangular matrix B. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B. LDB >= max(1, N). */
+
+/*  C       (input/output) DOUBLE PRECISION array, dimension (LDC, N) */
+/*          On entry, C contains the right-hand-side of the first matrix */
+/*          equation in (1) or (3). */
+/*          On exit, if IJOB = 0, 1 or 2, C has been overwritten by */
+/*          the solution R. If IJOB = 3 or 4 and TRANS = 'N', C holds R, */
+/*          the solution achieved during the computation of the */
+/*          Dif-estimate. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. LDC >= max(1, M). */
+
+/*  D       (input) DOUBLE PRECISION array, dimension (LDD, M) */
+/*          The upper triangular matrix D. */
+
+/*  LDD     (input) INTEGER */
+/*          The leading dimension of the array D. LDD >= max(1, M). */
+
+/*  E       (input) DOUBLE PRECISION array, dimension (LDE, N) */
+/*          The upper triangular matrix E. */
+
+/*  LDE     (input) INTEGER */
+/*          The leading dimension of the array E. LDE >= max(1, N). */
+
+/*  F       (input/output) DOUBLE PRECISION array, dimension (LDF, N) */
+/*          On entry, F contains the right-hand-side of the second matrix */
+/*          equation in (1) or (3). */
+/*          On exit, if IJOB = 0, 1 or 2, F has been overwritten by */
+/*          the solution L. If IJOB = 3 or 4 and TRANS = 'N', F holds L, */
+/*          the solution achieved during the computation of the */
+/*          Dif-estimate. */
+
+/*  LDF     (input) INTEGER */
+/*          The leading dimension of the array F. LDF >= max(1, M). */
+
+/*  DIF     (output) DOUBLE PRECISION */
+/*          On exit DIF is the reciprocal of a lower bound of the */
+/*          reciprocal of the Dif-function, i.e. DIF is an upper bound of */
+/*          Dif[(A,D), (B,E)] = sigma_min(Z), where Z as in (2). */
+/*          IF IJOB = 0 or TRANS = 'T', DIF is not touched. */
+
+/*  SCALE   (output) DOUBLE PRECISION */
+/*          On exit SCALE is the scaling factor in (1) or (3). */
+/*          If 0 < SCALE < 1, C and F hold the solutions R and L, resp., */
+/*          to a slightly perturbed system but the input matrices A, B, D */
+/*          and E have not been changed. If SCALE = 0, C and F hold the */
+/*          solutions R and L, respectively, to the homogeneous system */
+/*          with C = F = 0. Normally, SCALE = 1. */
+
+/*  WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK. LWORK > = 1. */
+/*          If IJOB = 1 or 2 and TRANS = 'N', LWORK >= max(1,2*M*N). */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  IWORK   (workspace) INTEGER array, dimension (M+N+6) */
+
+/*  INFO    (output) INTEGER */
+/*            =0: successful exit */
+/*            <0: If INFO = -i, the i-th argument had an illegal value. */
+/*            >0: (A, D) and (B, E) have common or close eigenvalues. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Based on contributions by */
+/*     Bo Kagstrom and Peter Poromaa, Department of Computing Science, */
+/*     Umea University, S-901 87 Umea, Sweden. */
+
+/*  [1] B. Kagstrom and P. Poromaa, LAPACK-Style Algorithms and Software */
+/*      for Solving the Generalized Sylvester Equation and Estimating the */
+/*      Separation between Regular Matrix Pairs, Report UMINF - 93.23, */
+/*      Department of Computing Science, Umea University, S-901 87 Umea, */
+/*      Sweden, December 1993, Revised April 1994, Also as LAPACK Working */
+/*      Note 75.  To appear in ACM Trans. on Math. Software, Vol 22, */
+/*      No 1, 1996. */
+
+/*  [2] B. Kagstrom, A Perturbation Analysis of the Generalized Sylvester */
+/*      Equation (AR - LB, DR - LE ) = (C, F), SIAM J. Matrix Anal. */
+/*      Appl., 15(4):1045-1060, 1994 */
+
+/*  [3] B. Kagstrom and L. Westin, Generalized Schur Methods with */
+/*      Condition Estimators for Solving the Generalized Sylvester */
+/*      Equation, IEEE Transactions on Automatic Control, Vol. 34, No. 7, */
+/*      July 1989, pp 745-751. */
+
+/*  ===================================================================== */
+/*  Replaced various illegal calls to DCOPY by calls to DLASET. */
+/*  Sven Hammarling, 1/5/02. */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and test input parameters */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -332,10 +350,8 @@
 
 /*     Determine optimal block sizes MB and NB */
 
-    mb = ilaenv_(&c__2, "DTGSYL", trans, m, n, &c_n1, &c_n1, (ftnlen)6, (
-	    ftnlen)1);
-    nb = ilaenv_(&c__5, "DTGSYL", trans, m, n, &c_n1, &c_n1, (ftnlen)6, (
-	    ftnlen)1);
+    mb = ilaenv_(&c__2, "DTGSYL", trans, m, n, &c_n1, &c_n1);
+    nb = ilaenv_(&c__5, "DTGSYL", trans, m, n, &c_n1, &c_n1);
 
     isolve = 1;
     ifunc = 0;
@@ -360,7 +376,7 @@
 	    dscale = 0.;
 	    dsum = 1.;
 	    pq = 0;
-	    dtgsy2_(trans, &ifunc, m, n, &a[a_offset], lda, &b[b_offset], ldb,
+	    dtgsy2_(trans, &ifunc, m, n, &a[a_offset], lda, &b[b_offset], ldb, 
 		     &c__[c_offset], ldc, &d__[d_offset], ldd, &e[e_offset], 
 		    lde, &f[f_offset], ldf, scale, &dsum, &dscale, &iwork[1], 
 		    &pq, info);
@@ -448,10 +464,10 @@ L70:
 	i__1 = isolve;
 	for (iround = 1; iround <= i__1; ++iround) {
 
-/*           Solve (I, J)-subsystem   
-                 A(I, I) * R(I, J) - L(I, J) * B(J, J) = C(I, J)   
-                 D(I, I) * R(I, J) - L(I, J) * E(J, J) = F(I, J)   
-             for I = P, P - 1,..., 1; J = 1, 2,..., Q */
+/*           Solve (I, J)-subsystem */
+/*               A(I, I) * R(I, J) - L(I, J) * B(J, J) = C(I, J) */
+/*               D(I, I) * R(I, J) - L(I, J) * E(J, J) = F(I, J) */
+/*           for I = P, P - 1,..., 1; J = 1, 2,..., Q */
 
 	    dscale = 0.;
 	    dsum = 1.;
@@ -513,8 +529,8 @@ L70:
 			*scale *= scaloc;
 		    }
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (i__ > 1) {
 			i__3 = is - 1;
@@ -568,10 +584,10 @@ L70:
 
     } else {
 
-/*        Solve transposed (I, J)-subsystem   
-               A(I, I)' * R(I, J)  + D(I, I)' * L(I, J)  =  C(I, J)   
-               R(I, J)  * B(J, J)' + L(I, J)  * E(J, J)' = -F(I, J)   
-          for I = 1,2,..., P; J = Q, Q-1,..., 1 */
+/*        Solve transposed (I, J)-subsystem */
+/*             A(I, I)' * R(I, J)  + D(I, I)' * L(I, J)  =  C(I, J) */
+/*             R(I, J)  * B(J, J)' + L(I, J)  * E(J, J)' = -F(I, J) */
+/*        for I = 1,2,..., P; J = Q, Q-1,..., 1 */
 
 	*scale = 1.;
 	i__1 = p;
@@ -585,7 +601,7 @@ L70:
 		je = iwork[j + 1] - 1;
 		nb = je - js + 1;
 		dtgsy2_(trans, &ifunc, &mb, &nb, &a[is + is * a_dim1], lda, &
-			b[js + js * b_dim1], ldb, &c__[is + js * c_dim1], ldc,
+			b[js + js * b_dim1], ldb, &c__[is + js * c_dim1], ldc, 
 			 &d__[is + is * d_dim1], ldd, &e[js + js * e_dim1], 
 			lde, &f[is + js * f_dim1], ldf, &scaloc, &dsum, &
 			dscale, &iwork[q + 2], &ppqq, &linfo);
