@@ -1,205 +1,225 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static logical c_false = FALSE_;
+static integer c__1 = 1;
+static doublereal c_b22 = 1.;
+static doublereal c_b25 = 0.;
+static integer c__2 = 2;
+static logical c_true = TRUE_;
 
 /* Subroutine */ int dtrevc_(char *side, char *howmny, logical *select, 
 	integer *n, doublereal *t, integer *ldt, doublereal *vl, integer *
 	ldvl, doublereal *vr, integer *ldvr, integer *mm, integer *m, 
 	doublereal *work, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    DTREVC computes some or all of the right and/or left eigenvectors of   
-    a real upper quasi-triangular matrix T.   
-    Matrices of this type are produced by the Schur factorization of   
-    a real general matrix:  A = Q*T*Q**T, as computed by DHSEQR.   
-
-    The right eigenvector x and the left eigenvector y of T corresponding   
-    to an eigenvalue w are defined by:   
-
-       T*x = w*x,     (y**H)*T = w*(y**H)   
-
-    where y**H denotes the conjugate transpose of y.   
-    The eigenvalues are not input to this routine, but are read directly   
-    from the diagonal blocks of T.   
-
-    This routine returns the matrices X and/or Y of right and left   
-    eigenvectors of T, or the products Q*X and/or Q*Y, where Q is an   
-    input matrix.  If Q is the orthogonal factor that reduces a matrix   
-    A to Schur form T, then Q*X and Q*Y are the matrices of right and   
-    left eigenvectors of A.   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'R':  compute right eigenvectors only;   
-            = 'L':  compute left eigenvectors only;   
-            = 'B':  compute both right and left eigenvectors.   
-
-    HOWMNY  (input) CHARACTER*1   
-            = 'A':  compute all right and/or left eigenvectors;   
-            = 'B':  compute all right and/or left eigenvectors,   
-                    backtransformed by the matrices in VR and/or VL;   
-            = 'S':  compute selected right and/or left eigenvectors,   
-                    as indicated by the logical array SELECT.   
-
-    SELECT  (input/output) LOGICAL array, dimension (N)   
-            If HOWMNY = 'S', SELECT specifies the eigenvectors to be   
-            computed.   
-            If w(j) is a real eigenvalue, the corresponding real   
-            eigenvector is computed if SELECT(j) is .TRUE..   
-            If w(j) and w(j+1) are the real and imaginary parts of a   
-            complex eigenvalue, the corresponding complex eigenvector is   
-            computed if either SELECT(j) or SELECT(j+1) is .TRUE., and   
-            on exit SELECT(j) is set to .TRUE. and SELECT(j+1) is set to   
-            .FALSE..   
-            Not referenced if HOWMNY = 'A' or 'B'.   
-
-    N       (input) INTEGER   
-            The order of the matrix T. N >= 0.   
-
-    T       (input) DOUBLE PRECISION array, dimension (LDT,N)   
-            The upper quasi-triangular matrix T in Schur canonical form.   
-
-    LDT     (input) INTEGER   
-            The leading dimension of the array T. LDT >= max(1,N).   
-
-    VL      (input/output) DOUBLE PRECISION array, dimension (LDVL,MM)   
-            On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must   
-            contain an N-by-N matrix Q (usually the orthogonal matrix Q   
-            of Schur vectors returned by DHSEQR).   
-            On exit, if SIDE = 'L' or 'B', VL contains:   
-            if HOWMNY = 'A', the matrix Y of left eigenvectors of T;   
-            if HOWMNY = 'B', the matrix Q*Y;   
-            if HOWMNY = 'S', the left eigenvectors of T specified by   
-                             SELECT, stored consecutively in the columns   
-                             of VL, in the same order as their   
-                             eigenvalues.   
-            A complex eigenvector corresponding to a complex eigenvalue   
-            is stored in two consecutive columns, the first holding the   
-            real part, and the second the imaginary part.   
-            Not referenced if SIDE = 'R'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the array VL.  LDVL >= 1, and if   
-            SIDE = 'L' or 'B', LDVL >= N.   
-
-    VR      (input/output) DOUBLE PRECISION array, dimension (LDVR,MM)   
-            On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must   
-            contain an N-by-N matrix Q (usually the orthogonal matrix Q   
-            of Schur vectors returned by DHSEQR).   
-            On exit, if SIDE = 'R' or 'B', VR contains:   
-            if HOWMNY = 'A', the matrix X of right eigenvectors of T;   
-            if HOWMNY = 'B', the matrix Q*X;   
-            if HOWMNY = 'S', the right eigenvectors of T specified by   
-                             SELECT, stored consecutively in the columns   
-                             of VR, in the same order as their   
-                             eigenvalues.   
-            A complex eigenvector corresponding to a complex eigenvalue   
-            is stored in two consecutive columns, the first holding the   
-            real part and the second the imaginary part.   
-            Not referenced if SIDE = 'L'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the array VR.  LDVR >= 1, and if   
-            SIDE = 'R' or 'B', LDVR >= N.   
-
-    MM      (input) INTEGER   
-            The number of columns in the arrays VL and/or VR. MM >= M.   
-
-    M       (output) INTEGER   
-            The number of columns in the arrays VL and/or VR actually   
-            used to store the eigenvectors.   
-            If HOWMNY = 'A' or 'B', M is set to N.   
-            Each selected real eigenvector occupies one column and each   
-            selected complex eigenvector occupies two columns.   
-
-    WORK    (workspace) DOUBLE PRECISION array, dimension (3*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value   
-
-    Further Details   
-    ===============   
-
-    The algorithm used in this program is basically backward (forward)   
-    substitution, with scaling to make the the code robust against   
-    possible overflow.   
-
-    Each eigenvector is normalized so that the element of largest   
-    magnitude has magnitude 1; here the magnitude of a complex number   
-    (x,y) is taken to be |x| + |y|.   
-
-    =====================================================================   
-
-
-       Decode and test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static logical c_false = FALSE_;
-    static integer c__1 = 1;
-    static doublereal c_b22 = 1.;
-    static doublereal c_b25 = 0.;
-    static integer c__2 = 2;
-    static logical c_true = TRUE_;
-    
     /* System generated locals */
     integer t_dim1, t_offset, vl_dim1, vl_offset, vr_dim1, vr_offset, i__1, 
 	    i__2, i__3;
     doublereal d__1, d__2, d__3, d__4;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, j, k;
-    static doublereal x[4]	/* was [2][2] */;
-    static integer j1, j2, n2, ii, ki, ip, is;
-    static doublereal wi, wr, rec, ulp, beta, emax;
-    static logical pair;
+    integer i__, j, k;
+    doublereal x[4]	/* was [2][2] */;
+    integer j1, j2, n2, ii, ki, ip, is;
+    doublereal wi, wr, rec, ulp, beta, emax;
+    logical pair;
     extern doublereal ddot_(integer *, doublereal *, integer *, doublereal *, 
 	    integer *);
-    static logical allv;
-    static integer ierr;
-    static doublereal unfl, ovfl, smin;
-    static logical over;
-    static doublereal vmax;
-    static integer jnxt;
+    logical allv;
+    integer ierr;
+    doublereal unfl, ovfl, smin;
+    logical over;
+    doublereal vmax;
+    integer jnxt;
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
-    static doublereal scale;
+    doublereal scale;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int dgemv_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *);
-    static doublereal remax;
+    doublereal remax;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static logical leftv, bothv;
+    logical leftv, bothv;
     extern /* Subroutine */ int daxpy_(integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *);
-    static doublereal vcrit;
-    static logical somev;
-    static doublereal xnorm;
+    doublereal vcrit;
+    logical somev;
+    doublereal xnorm;
     extern /* Subroutine */ int dlaln2_(logical *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, integer *, doublereal *,
+	    doublereal *, doublereal *, doublereal *, integer *, doublereal *, 
 	     doublereal *, doublereal *, integer *, doublereal *, doublereal *
-	    , doublereal *, integer *, doublereal *, doublereal *, integer *),
+, doublereal *, integer *, doublereal *, doublereal *, integer *),
 	     dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
     extern integer idamax_(integer *, doublereal *, integer *);
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static doublereal bignum;
-    static logical rightv;
-    static doublereal smlnum;
+    doublereal bignum;
+    logical rightv;
+    doublereal smlnum;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  DTREVC computes some or all of the right and/or left eigenvectors of */
+/*  a real upper quasi-triangular matrix T. */
+/*  Matrices of this type are produced by the Schur factorization of */
+/*  a real general matrix:  A = Q*T*Q**T, as computed by DHSEQR. */
+
+/*  The right eigenvector x and the left eigenvector y of T corresponding */
+/*  to an eigenvalue w are defined by: */
+
+/*     T*x = w*x,     (y**H)*T = w*(y**H) */
+
+/*  where y**H denotes the conjugate transpose of y. */
+/*  The eigenvalues are not input to this routine, but are read directly */
+/*  from the diagonal blocks of T. */
+
+/*  This routine returns the matrices X and/or Y of right and left */
+/*  eigenvectors of T, or the products Q*X and/or Q*Y, where Q is an */
+/*  input matrix.  If Q is the orthogonal factor that reduces a matrix */
+/*  A to Schur form T, then Q*X and Q*Y are the matrices of right and */
+/*  left eigenvectors of A. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'R':  compute right eigenvectors only; */
+/*          = 'L':  compute left eigenvectors only; */
+/*          = 'B':  compute both right and left eigenvectors. */
+
+/*  HOWMNY  (input) CHARACTER*1 */
+/*          = 'A':  compute all right and/or left eigenvectors; */
+/*          = 'B':  compute all right and/or left eigenvectors, */
+/*                  backtransformed by the matrices in VR and/or VL; */
+/*          = 'S':  compute selected right and/or left eigenvectors, */
+/*                  as indicated by the logical array SELECT. */
+
+/*  SELECT  (input/output) LOGICAL array, dimension (N) */
+/*          If HOWMNY = 'S', SELECT specifies the eigenvectors to be */
+/*          computed. */
+/*          If w(j) is a real eigenvalue, the corresponding real */
+/*          eigenvector is computed if SELECT(j) is .TRUE.. */
+/*          If w(j) and w(j+1) are the real and imaginary parts of a */
+/*          complex eigenvalue, the corresponding complex eigenvector is */
+/*          computed if either SELECT(j) or SELECT(j+1) is .TRUE., and */
+/*          on exit SELECT(j) is set to .TRUE. and SELECT(j+1) is set to */
+/*          .FALSE.. */
+/*          Not referenced if HOWMNY = 'A' or 'B'. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix T. N >= 0. */
+
+/*  T       (input) DOUBLE PRECISION array, dimension (LDT,N) */
+/*          The upper quasi-triangular matrix T in Schur canonical form. */
+
+/*  LDT     (input) INTEGER */
+/*          The leading dimension of the array T. LDT >= max(1,N). */
+
+/*  VL      (input/output) DOUBLE PRECISION array, dimension (LDVL,MM) */
+/*          On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must */
+/*          contain an N-by-N matrix Q (usually the orthogonal matrix Q */
+/*          of Schur vectors returned by DHSEQR). */
+/*          On exit, if SIDE = 'L' or 'B', VL contains: */
+/*          if HOWMNY = 'A', the matrix Y of left eigenvectors of T; */
+/*          if HOWMNY = 'B', the matrix Q*Y; */
+/*          if HOWMNY = 'S', the left eigenvectors of T specified by */
+/*                           SELECT, stored consecutively in the columns */
+/*                           of VL, in the same order as their */
+/*                           eigenvalues. */
+/*          A complex eigenvector corresponding to a complex eigenvalue */
+/*          is stored in two consecutive columns, the first holding the */
+/*          real part, and the second the imaginary part. */
+/*          Not referenced if SIDE = 'R'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the array VL.  LDVL >= 1, and if */
+/*          SIDE = 'L' or 'B', LDVL >= N. */
+
+/*  VR      (input/output) DOUBLE PRECISION array, dimension (LDVR,MM) */
+/*          On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must */
+/*          contain an N-by-N matrix Q (usually the orthogonal matrix Q */
+/*          of Schur vectors returned by DHSEQR). */
+/*          On exit, if SIDE = 'R' or 'B', VR contains: */
+/*          if HOWMNY = 'A', the matrix X of right eigenvectors of T; */
+/*          if HOWMNY = 'B', the matrix Q*X; */
+/*          if HOWMNY = 'S', the right eigenvectors of T specified by */
+/*                           SELECT, stored consecutively in the columns */
+/*                           of VR, in the same order as their */
+/*                           eigenvalues. */
+/*          A complex eigenvector corresponding to a complex eigenvalue */
+/*          is stored in two consecutive columns, the first holding the */
+/*          real part and the second the imaginary part. */
+/*          Not referenced if SIDE = 'L'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the array VR.  LDVR >= 1, and if */
+/*          SIDE = 'R' or 'B', LDVR >= N. */
+
+/*  MM      (input) INTEGER */
+/*          The number of columns in the arrays VL and/or VR. MM >= M. */
+
+/*  M       (output) INTEGER */
+/*          The number of columns in the arrays VL and/or VR actually */
+/*          used to store the eigenvectors. */
+/*          If HOWMNY = 'A' or 'B', M is set to N. */
+/*          Each selected real eigenvector occupies one column and each */
+/*          selected complex eigenvector occupies two columns. */
+
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension (3*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
+
+/*  Further Details */
+/*  =============== */
+
+/*  The algorithm used in this program is basically backward (forward) */
+/*  substitution, with scaling to make the the code robust against */
+/*  possible overflow. */
+
+/*  Each eigenvector is normalized so that the element of largest */
+/*  magnitude has magnitude 1; here the magnitude of a complex number */
+/*  (x,y) is taken to be |x| + |y|. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and test the input parameters */
+
+    /* Parameter adjustments */
     --select;
     t_dim1 = *ldt;
     t_offset = 1 + t_dim1;
@@ -236,9 +256,9 @@
 	*info = -10;
     } else {
 
-/*        Set M to the number of columns required to store the selected   
-          eigenvectors, standardize the array SELECT if necessary, and   
-          test MM. */
+/*        Set M to the number of columns required to store the selected */
+/*        eigenvectors, standardize the array SELECT if necessary, and */
+/*        test MM. */
 
 	if (somev) {
 	    *m = 0;
@@ -298,8 +318,8 @@
     smlnum = unfl * (*n / ulp);
     bignum = (1. - ulp) / smlnum;
 
-/*     Compute 1-norm of each column of strictly upper triangular   
-       part of T to control overflow in triangular solver. */
+/*     Compute 1-norm of each column of strictly upper triangular */
+/*     part of T to control overflow in triangular solver. */
 
     work[1] = 0.;
     i__1 = *n;
@@ -313,10 +333,10 @@
 /* L30: */
     }
 
-/*     Index IP is used to specify the real or complex eigenvalue:   
-         IP = 0, real eigenvalue,   
-              1, first of conjugate complex pair: (wr,wi)   
-             -1, second of conjugate complex pair: (wr,wi) */
+/*     Index IP is used to specify the real or complex eigenvalue: */
+/*       IP = 0, real eigenvalue, */
+/*            1, first of conjugate complex pair: (wr,wi) */
+/*           -1, second of conjugate complex pair: (wr,wi) */
 
     n2 = *n << 1;
 
@@ -378,8 +398,8 @@ L40:
 /* L50: */
 		}
 
-/*              Solve the upper quasi-triangular system:   
-                   (T(1:KI-1,1:KI-1) - WR)*X = SCALE*WORK. */
+/*              Solve the upper quasi-triangular system: */
+/*                 (T(1:KI-1,1:KI-1) - WR)*X = SCALE*WORK. */
 
 		jnxt = ki - 1;
 		for (j = ki - 1; j >= 1; --j) {
@@ -405,8 +425,8 @@ L40:
 				n], n, &wr, &c_b25, x, &c__2, &scale, &xnorm, 
 				&ierr);
 
-/*                    Scale X(1,1) to avoid overflow when updating   
-                      the right-hand side. */
+/*                    Scale X(1,1) to avoid overflow when updating */
+/*                    the right-hand side. */
 
 			if (xnorm > 1.) {
 			    if (work[j] > bignum / xnorm) {
@@ -438,8 +458,8 @@ L40:
 				work[j - 1 + *n], n, &wr, &c_b25, x, &c__2, &
 				scale, &xnorm, &ierr);
 
-/*                    Scale X(1,1) and X(2,1) to avoid overflow when   
-                      updating the right-hand side. */
+/*                    Scale X(1,1) and X(2,1) to avoid overflow when */
+/*                    updating the right-hand side. */
 
 			if (xnorm > 1.) {
 /* Computing MAX */
@@ -505,11 +525,11 @@ L60:
 
 	    } else {
 
-/*              Complex right eigenvector.   
+/*              Complex right eigenvector. */
 
-                Initial solve   
-                  [ (T(KI-1,KI-1) T(KI-1,KI) ) - (WR + I* WI)]*X = 0.   
-                  [ (T(KI,KI-1)   T(KI,KI)   )               ] */
+/*              Initial solve */
+/*                [ (T(KI-1,KI-1) T(KI-1,KI) ) - (WR + I* WI)]*X = 0. */
+/*                [ (T(KI,KI-1)   T(KI,KI)   )               ] */
 
 		if ((d__1 = t[ki - 1 + ki * t_dim1], abs(d__1)) >= (d__2 = t[
 			ki + (ki - 1) * t_dim1], abs(d__2))) {
@@ -532,8 +552,8 @@ L60:
 /* L80: */
 		}
 
-/*              Solve upper quasi-triangular system:   
-                (T(1:KI-2,1:KI-2) - (WR+i*WI))*X = SCALE*(WORK+i*WORK2) */
+/*              Solve upper quasi-triangular system: */
+/*              (T(1:KI-2,1:KI-2) - (WR+i*WI))*X = SCALE*(WORK+i*WORK2) */
 
 		jnxt = ki - 2;
 		for (j = ki - 2; j >= 1; --j) {
@@ -559,8 +579,8 @@ L60:
 				n], n, &wr, &wi, x, &c__2, &scale, &xnorm, &
 				ierr);
 
-/*                    Scale X(1,1) and X(1,2) to avoid overflow when   
-                      updating the right-hand side. */
+/*                    Scale X(1,1) and X(1,2) to avoid overflow when */
+/*                    updating the right-hand side. */
 
 			if (xnorm > 1.) {
 			    if (work[j] > bignum / xnorm) {
@@ -599,8 +619,8 @@ L60:
 				work[j - 1 + *n], n, &wr, &wi, x, &c__2, &
 				scale, &xnorm, &ierr);
 
-/*                    Scale X to avoid overflow when updating   
-                      the right-hand side. */
+/*                    Scale X to avoid overflow when updating */
+/*                    the right-hand side. */
 
 			if (xnorm > 1.) {
 /* Computing MAX */
@@ -782,8 +802,8 @@ L150:
 /* L160: */
 		}
 
-/*              Solve the quasi-triangular system:   
-                   (T(KI+1:N,KI+1:N) - WR)'*X = SCALE*WORK */
+/*              Solve the quasi-triangular system: */
+/*                 (T(KI+1:N,KI+1:N) - WR)'*X = SCALE*WORK */
 
 		vmax = 1.;
 		vcrit = bignum;
@@ -806,10 +826,10 @@ L150:
 
 		    if (j1 == j2) {
 
-/*                    1-by-1 diagonal block   
+/*                    1-by-1 diagonal block */
 
-                      Scale if necessary to avoid overflow when forming   
-                      the right-hand side. */
+/*                    Scale if necessary to avoid overflow when forming */
+/*                    the right-hand side. */
 
 			if (work[j] > vcrit) {
 			    rec = 1. / vmax;
@@ -844,12 +864,12 @@ L150:
 
 		    } else {
 
-/*                    2-by-2 diagonal block   
+/*                    2-by-2 diagonal block */
 
-                      Scale if necessary to avoid overflow when forming   
-                      the right-hand side.   
+/*                    Scale if necessary to avoid overflow when forming */
+/*                    the right-hand side. */
 
-   Computing MAX */
+/* Computing MAX */
 			d__1 = work[j], d__2 = work[j + 1];
 			beta = max(d__1,d__2);
 			if (beta > vcrit) {
@@ -868,9 +888,9 @@ L150:
 			work[j + 1 + *n] -= ddot_(&i__3, &t[ki + 1 + (j + 1) *
 				 t_dim1], &c__1, &work[ki + 1 + *n], &c__1);
 
-/*                    Solve   
-                        [T(J,J)-WR   T(J,J+1)     ]'* X = SCALE*( WORK1 )   
-                        [T(J+1,J)    T(J+1,J+1)-WR]             ( WORK2 ) */
+/*                    Solve */
+/*                      [T(J,J)-WR   T(J,J+1)     ]'* X = SCALE*( WORK1 ) */
+/*                      [T(J+1,J)    T(J+1,J+1)-WR]             ( WORK2 ) */
 
 			dlaln2_(&c_true, &c__2, &c__1, &smin, &c_b22, &t[j + 
 				j * t_dim1], ldt, &c_b22, &c_b22, &work[j + *
@@ -935,11 +955,11 @@ L170:
 
 	    } else {
 
-/*              Complex left eigenvector.   
+/*              Complex left eigenvector. */
 
-                 Initial solve:   
-                   ((T(KI,KI)    T(KI,KI+1) )' - (WR - I* WI))*X = 0.   
-                   ((T(KI+1,KI) T(KI+1,KI+1))                ) */
+/*               Initial solve: */
+/*                 ((T(KI,KI)    T(KI,KI+1) )' - (WR - I* WI))*X = 0. */
+/*                 ((T(KI+1,KI) T(KI+1,KI+1))                ) */
 
 		if ((d__1 = t[ki + (ki + 1) * t_dim1], abs(d__1)) >= (d__2 = 
 			t[ki + 1 + ki * t_dim1], abs(d__2))) {
@@ -962,8 +982,8 @@ L170:
 /* L190: */
 		}
 
-/*              Solve complex quasi-triangular system:   
-                ( T(KI+2,N:KI+2,N) - (WR-i*WI) )*X = WORK1+i*WORK2 */
+/*              Solve complex quasi-triangular system: */
+/*              ( T(KI+2,N:KI+2,N) - (WR-i*WI) )*X = WORK1+i*WORK2 */
 
 		vmax = 1.;
 		vcrit = bignum;
@@ -986,10 +1006,10 @@ L170:
 
 		    if (j1 == j2) {
 
-/*                    1-by-1 diagonal block   
+/*                    1-by-1 diagonal block */
 
-                      Scale if necessary to avoid overflow when   
-                      forming the right-hand side elements. */
+/*                    Scale if necessary to avoid overflow when */
+/*                    forming the right-hand side elements. */
 
 			if (work[j] > vcrit) {
 			    rec = 1. / vmax;
@@ -1035,12 +1055,12 @@ L170:
 
 		    } else {
 
-/*                    2-by-2 diagonal block   
+/*                    2-by-2 diagonal block */
 
-                      Scale if necessary to avoid overflow when forming   
-                      the right-hand side elements.   
+/*                    Scale if necessary to avoid overflow when forming */
+/*                    the right-hand side elements. */
 
-   Computing MAX */
+/* Computing MAX */
 			d__1 = work[j], d__2 = work[j + 1];
 			beta = max(d__1,d__2);
 			if (beta > vcrit) {
@@ -1069,9 +1089,9 @@ L170:
 			work[j + 1 + n2] -= ddot_(&i__3, &t[ki + 2 + (j + 1) *
 				 t_dim1], &c__1, &work[ki + 2 + n2], &c__1);
 
-/*                    Solve 2-by-2 complex linear equation   
-                        ([T(j,j)   T(j,j+1)  ]'-(wr-i*wi)*I)*X = SCALE*B   
-                        ([T(j+1,j) T(j+1,j+1)]             ) */
+/*                    Solve 2-by-2 complex linear equation */
+/*                      ([T(j,j)   T(j,j+1)  ]'-(wr-i*wi)*I)*X = SCALE*B */
+/*                      ([T(j+1,j) T(j+1,j+1)]             ) */
 
 			d__1 = -wi;
 			dlaln2_(&c_true, &c__2, &c__2, &smin, &c_b22, &t[j + 
