@@ -1,138 +1,35 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static integer c__0 = 0;
+static integer c_n1 = -1;
 
 /* Subroutine */ int sgeev_(char *jobvl, char *jobvr, integer *n, real *a, 
-	integer *lda, real *wr, real *wi, real *vl, integer *ldvl, real *vr,  	integer *ldvr, real *work, integer *lwork, integer *info  	)
+	integer *lda, real *wr, real *wi, real *vl, integer *ldvl, real *vr, 
+	integer *ldvr, real *work, integer *lwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SGEEV computes for an N-by-N real nonsymmetric matrix A, the   
-    eigenvalues and, optionally, the left and/or right eigenvectors.   
-
-    The right eigenvector v(j) of A satisfies   
-                     A * v(j) = lambda(j) * v(j)   
-    where lambda(j) is its eigenvalue.   
-    The left eigenvector u(j) of A satisfies   
-                  u(j)**H * A = lambda(j) * u(j)**H   
-    where u(j)**H denotes the conjugate transpose of u(j).   
-
-    The computed eigenvectors are normalized to have Euclidean norm   
-    equal to 1 and largest component real.   
-
-    Arguments   
-    =========   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N': left eigenvectors of A are not computed;   
-            = 'V': left eigenvectors of A are computed.   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N': right eigenvectors of A are not computed;   
-            = 'V': right eigenvectors of A are computed.   
-
-    N       (input) INTEGER   
-            The order of the matrix A. N >= 0.   
-
-    A       (input/output) REAL array, dimension (LDA,N)   
-            On entry, the N-by-N matrix A.   
-            On exit, A has been overwritten.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,N).   
-
-    WR      (output) REAL array, dimension (N)   
-    WI      (output) REAL array, dimension (N)   
-            WR and WI contain the real and imaginary parts,   
-            respectively, of the computed eigenvalues.  Complex   
-            conjugate pairs of eigenvalues appear consecutively   
-            with the eigenvalue having the positive imaginary part   
-            first.   
-
-    VL      (output) REAL array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left eigenvectors u(j) are stored one   
-            after another in the columns of VL, in the same order   
-            as their eigenvalues.   
-            If JOBVL = 'N', VL is not referenced.   
-            If the j-th eigenvalue is real, then u(j) = VL(:,j),   
-            the j-th column of VL.   
-            If the j-th and (j+1)-st eigenvalues form a complex   
-            conjugate pair, then u(j) = VL(:,j) + i*VL(:,j+1) and   
-            u(j+1) = VL(:,j) - i*VL(:,j+1).   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the array VL.  LDVL >= 1; if   
-            JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) REAL array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right eigenvectors v(j) are stored one   
-            after another in the columns of VR, in the same order   
-            as their eigenvalues.   
-            If JOBVR = 'N', VR is not referenced.   
-            If the j-th eigenvalue is real, then v(j) = VR(:,j),   
-            the j-th column of VR.   
-            If the j-th and (j+1)-st eigenvalues form a complex   
-            conjugate pair, then v(j) = VR(:,j) + i*VR(:,j+1) and   
-            v(j+1) = VR(:,j) - i*VR(:,j+1).   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the array VR.  LDVR >= 1; if   
-            JOBVR = 'V', LDVR >= N.   
-
-    WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,3*N), and   
-            if JOBVL = 'V' or JOBVR = 'V', LWORK >= 4*N.  For good   
-            performance, LWORK must generally be larger.   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  if INFO = i, the QR algorithm failed to compute all the   
-                  eigenvalues, and no eigenvectors have been computed;   
-                  elements i+1:N of WR and WI contain eigenvalues which   
-                  have converged.   
-
-    =====================================================================   
-
-
-       Test the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static integer c_n1 = -1;
-    
     /* System generated locals */
     integer a_dim1, a_offset, vl_dim1, vl_offset, vr_dim1, vr_offset, i__1, 
 	    i__2, i__3;
     real r__1, r__2;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, k;
-    static real r__, cs, sn;
-    static integer ihi;
-    static real scl;
-    static integer ilo;
-    static real dum[1], eps;
-    static integer ibal;
-    static char side[1];
-    static real anrm;
-    static integer ierr, itau, iwrk, nout;
+    integer i__, k;
+    real r__, cs, sn;
+    integer ihi;
+    real scl;
+    integer ilo;
+    real dum[1], eps;
+    integer ibal;
+    char side[1];
+    real anrm;
+    integer ierr, itau, iwrk, nout;
     extern /* Subroutine */ int srot_(integer *, real *, integer *, real *, 
 	    integer *, real *, real *);
     extern doublereal snrm2_(integer *, real *, integer *);
@@ -140,8 +37,8 @@
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
     extern doublereal slapy2_(real *, real *);
     extern /* Subroutine */ int slabad_(real *, real *);
-    static logical scalea;
-    static real cscale;
+    logical scalea;
+    real cscale;
     extern /* Subroutine */ int sgebak_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, integer *), sgebal_(char *, integer *, real *, integer *, 
 	    integer *, integer *, real *, integer *);
@@ -151,9 +48,9 @@
 	    *, integer *, real *, real *, integer *, integer *), xerbla_(char 
 	    *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static logical select[1];
-    static real bignum;
+	    integer *, integer *);
+    logical select[1];
+    real bignum;
     extern /* Subroutine */ int slascl_(char *, integer *, integer *, real *, 
 	    real *, integer *, integer *, real *, integer *, integer *);
     extern integer isamax_(integer *, real *, integer *);
@@ -162,16 +59,140 @@
 	    real *, real *, real *), sorghr_(integer *, integer *, integer *, 
 	    real *, integer *, real *, real *, integer *, integer *), shseqr_(
 	    char *, char *, integer *, integer *, integer *, real *, integer *
-	    , real *, real *, real *, integer *, real *, integer *, integer *), strevc_(char *, char *, logical *, integer *, 
+, real *, real *, real *, integer *, real *, integer *, integer *), strevc_(char *, char *, logical *, integer *, 
 	    real *, integer *, real *, integer *, real *, integer *, integer *
-	    , integer *, real *, integer *);
-    static integer minwrk, maxwrk;
-    static logical wantvl;
-    static real smlnum;
-    static integer hswork;
-    static logical lquery, wantvr;
+, integer *, real *, integer *);
+    integer minwrk, maxwrk;
+    logical wantvl;
+    real smlnum;
+    integer hswork;
+    logical lquery, wantvr;
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SGEEV computes for an N-by-N real nonsymmetric matrix A, the */
+/*  eigenvalues and, optionally, the left and/or right eigenvectors. */
+
+/*  The right eigenvector v(j) of A satisfies */
+/*                   A * v(j) = lambda(j) * v(j) */
+/*  where lambda(j) is its eigenvalue. */
+/*  The left eigenvector u(j) of A satisfies */
+/*                u(j)**H * A = lambda(j) * u(j)**H */
+/*  where u(j)**H denotes the conjugate transpose of u(j). */
+
+/*  The computed eigenvectors are normalized to have Euclidean norm */
+/*  equal to 1 and largest component real. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N': left eigenvectors of A are not computed; */
+/*          = 'V': left eigenvectors of A are computed. */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N': right eigenvectors of A are not computed; */
+/*          = 'V': right eigenvectors of A are computed. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A. N >= 0. */
+
+/*  A       (input/output) REAL array, dimension (LDA,N) */
+/*          On entry, the N-by-N matrix A. */
+/*          On exit, A has been overwritten. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,N). */
+
+/*  WR      (output) REAL array, dimension (N) */
+/*  WI      (output) REAL array, dimension (N) */
+/*          WR and WI contain the real and imaginary parts, */
+/*          respectively, of the computed eigenvalues.  Complex */
+/*          conjugate pairs of eigenvalues appear consecutively */
+/*          with the eigenvalue having the positive imaginary part */
+/*          first. */
+
+/*  VL      (output) REAL array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left eigenvectors u(j) are stored one */
+/*          after another in the columns of VL, in the same order */
+/*          as their eigenvalues. */
+/*          If JOBVL = 'N', VL is not referenced. */
+/*          If the j-th eigenvalue is real, then u(j) = VL(:,j), */
+/*          the j-th column of VL. */
+/*          If the j-th and (j+1)-st eigenvalues form a complex */
+/*          conjugate pair, then u(j) = VL(:,j) + i*VL(:,j+1) and */
+/*          u(j+1) = VL(:,j) - i*VL(:,j+1). */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the array VL.  LDVL >= 1; if */
+/*          JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) REAL array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right eigenvectors v(j) are stored one */
+/*          after another in the columns of VR, in the same order */
+/*          as their eigenvalues. */
+/*          If JOBVR = 'N', VR is not referenced. */
+/*          If the j-th eigenvalue is real, then v(j) = VR(:,j), */
+/*          the j-th column of VR. */
+/*          If the j-th and (j+1)-st eigenvalues form a complex */
+/*          conjugate pair, then v(j) = VR(:,j) + i*VR(:,j+1) and */
+/*          v(j+1) = VR(:,j) - i*VR(:,j+1). */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the array VR.  LDVR >= 1; if */
+/*          JOBVR = 'V', LDVR >= N. */
+
+/*  WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,3*N), and */
+/*          if JOBVL = 'V' or JOBVR = 'V', LWORK >= 4*N.  For good */
+/*          performance, LWORK must generally be larger. */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  if INFO = i, the QR algorithm failed to compute all the */
+/*                eigenvalues, and no eigenvectors have been computed; */
+/*                elements i+1:N of WR and WI contain eigenvalues which */
+/*                have converged. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -204,15 +225,15 @@
 	*info = -11;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.   
-         HSWORK refers to the workspace preferred by SHSEQR, as   
-         calculated below. HSWORK is computed assuming ILO=1 and IHI=N,   
-         the worst case.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. */
+/*       HSWORK refers to the workspace preferred by SHSEQR, as */
+/*       calculated below. HSWORK is computed assuming ILO=1 and IHI=N, */
+/*       the worst case.) */
 
     if (*info == 0) {
 	if (*n == 0) {
@@ -220,13 +241,12 @@
 	    maxwrk = 1;
 	} else {
 	    maxwrk = (*n << 1) + *n * ilaenv_(&c__1, "SGEHRD", " ", n, &c__1, 
-		    n, &c__0, (ftnlen)6, (ftnlen)1);
+		    n, &c__0);
 	    if (wantvl) {
 		minwrk = *n << 2;
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = (*n << 1) + (*n - 1) * ilaenv_(&c__1, 
-			"SORGHR", " ", n, &c__1, n, &c_n1, (ftnlen)6, (ftnlen)
--			1);
+			"SORGHR", " ", n, &c__1, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 		shseqr_("S", "V", n, &c__1, n, &a[a_offset], lda, &wr[1], &wi[
 			1], &vl[vl_offset], ldvl, &work[1], &c_n1, info);
@@ -242,8 +262,7 @@
 		minwrk = *n << 2;
 /* Computing MAX */
 		i__1 = maxwrk, i__2 = (*n << 1) + (*n - 1) * ilaenv_(&c__1, 
-			"SORGHR", " ", n, &c__1, n, &c_n1, (ftnlen)6, (ftnlen)
--			1);
+			"SORGHR", " ", n, &c__1, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 		shseqr_("S", "V", n, &c__1, n, &a[a_offset], lda, &wr[1], &wi[
 			1], &vr[vr_offset], ldvr, &work[1], &c_n1, info);
@@ -313,39 +332,39 @@
 		ierr);
     }
 
-/*     Balance the matrix   
-       (Workspace: need N) */
+/*     Balance the matrix */
+/*     (Workspace: need N) */
 
     ibal = 1;
     sgebal_("B", n, &a[a_offset], lda, &ilo, &ihi, &work[ibal], &ierr);
 
-/*     Reduce to upper Hessenberg form   
-       (Workspace: need 3*N, prefer 2*N+N*NB) */
+/*     Reduce to upper Hessenberg form */
+/*     (Workspace: need 3*N, prefer 2*N+N*NB) */
 
     itau = ibal + *n;
     iwrk = itau + *n;
     i__1 = *lwork - iwrk + 1;
-    sgehrd_(n, &ilo, &ihi, &a[a_offset], lda, &work[itau], &work[iwrk], &i__1,
+    sgehrd_(n, &ilo, &ihi, &a[a_offset], lda, &work[itau], &work[iwrk], &i__1, 
 	     &ierr);
 
     if (wantvl) {
 
-/*        Want left eigenvectors   
-          Copy Householder vectors to VL */
+/*        Want left eigenvectors */
+/*        Copy Householder vectors to VL */
 
 	*(unsigned char *)side = 'L';
 	slacpy_("L", n, n, &a[a_offset], lda, &vl[vl_offset], ldvl)
 		;
 
-/*        Generate orthogonal matrix in VL   
-          (Workspace: need 3*N-1, prefer 2*N+(N-1)*NB) */
+/*        Generate orthogonal matrix in VL */
+/*        (Workspace: need 3*N-1, prefer 2*N+(N-1)*NB) */
 
 	i__1 = *lwork - iwrk + 1;
-	sorghr_(n, &ilo, &ihi, &vl[vl_offset], ldvl, &work[itau], &work[iwrk],
+	sorghr_(n, &ilo, &ihi, &vl[vl_offset], ldvl, &work[itau], &work[iwrk], 
 		 &i__1, &ierr);
 
-/*        Perform QR iteration, accumulating Schur vectors in VL   
-          (Workspace: need N+1, prefer N+HSWORK (see comments) ) */
+/*        Perform QR iteration, accumulating Schur vectors in VL */
+/*        (Workspace: need N+1, prefer N+HSWORK (see comments) ) */
 
 	iwrk = itau;
 	i__1 = *lwork - iwrk + 1;
@@ -354,8 +373,8 @@
 
 	if (wantvr) {
 
-/*           Want left and right eigenvectors   
-             Copy Schur vectors to VR */
+/*           Want left and right eigenvectors */
+/*           Copy Schur vectors to VR */
 
 	    *(unsigned char *)side = 'B';
 	    slacpy_("F", n, n, &vl[vl_offset], ldvl, &vr[vr_offset], ldvr);
@@ -363,22 +382,22 @@
 
     } else if (wantvr) {
 
-/*        Want right eigenvectors   
-          Copy Householder vectors to VR */
+/*        Want right eigenvectors */
+/*        Copy Householder vectors to VR */
 
 	*(unsigned char *)side = 'R';
 	slacpy_("L", n, n, &a[a_offset], lda, &vr[vr_offset], ldvr)
 		;
 
-/*        Generate orthogonal matrix in VR   
-          (Workspace: need 3*N-1, prefer 2*N+(N-1)*NB) */
+/*        Generate orthogonal matrix in VR */
+/*        (Workspace: need 3*N-1, prefer 2*N+(N-1)*NB) */
 
 	i__1 = *lwork - iwrk + 1;
-	sorghr_(n, &ilo, &ihi, &vr[vr_offset], ldvr, &work[itau], &work[iwrk],
+	sorghr_(n, &ilo, &ihi, &vr[vr_offset], ldvr, &work[itau], &work[iwrk], 
 		 &i__1, &ierr);
 
-/*        Perform QR iteration, accumulating Schur vectors in VR   
-          (Workspace: need N+1, prefer N+HSWORK (see comments) ) */
+/*        Perform QR iteration, accumulating Schur vectors in VR */
+/*        (Workspace: need N+1, prefer N+HSWORK (see comments) ) */
 
 	iwrk = itau;
 	i__1 = *lwork - iwrk + 1;
@@ -387,8 +406,8 @@
 
     } else {
 
-/*        Compute eigenvalues only   
-          (Workspace: need N+1, prefer N+HSWORK (see comments) ) */
+/*        Compute eigenvalues only */
+/*        (Workspace: need N+1, prefer N+HSWORK (see comments) ) */
 
 	iwrk = itau;
 	i__1 = *lwork - iwrk + 1;
@@ -404,19 +423,19 @@
 
     if (wantvl || wantvr) {
 
-/*        Compute left and/or right eigenvectors   
-          (Workspace: need 4*N) */
+/*        Compute left and/or right eigenvectors */
+/*        (Workspace: need 4*N) */
 
-	strevc_(side, "B", select, n, &a[a_offset], lda, &vl[vl_offset], ldvl,
+	strevc_(side, "B", select, n, &a[a_offset], lda, &vl[vl_offset], ldvl, 
 		 &vr[vr_offset], ldvr, n, &nout, &work[iwrk], &ierr);
     }
 
     if (wantvl) {
 
-/*        Undo balancing of left eigenvectors   
-          (Workspace: need N) */
+/*        Undo balancing of left eigenvectors */
+/*        (Workspace: need N) */
 
-	sgebak_("B", "L", n, &ilo, &ihi, &work[ibal], n, &vl[vl_offset], ldvl,
+	sgebak_("B", "L", n, &ilo, &ihi, &work[ibal], n, &vl[vl_offset], ldvl, 
 		 &ierr);
 
 /*        Normalize left eigenvectors and make largest component real */
@@ -454,10 +473,10 @@
 
     if (wantvr) {
 
-/*        Undo balancing of right eigenvectors   
-          (Workspace: need N) */
+/*        Undo balancing of right eigenvectors */
+/*        (Workspace: need N) */
 
-	sgebak_("B", "R", n, &ilo, &ihi, &work[ibal], n, &vr[vr_offset], ldvr,
+	sgebak_("B", "R", n, &ilo, &ihi, &work[ibal], n, &vr[vr_offset], ldvr, 
 		 &ierr);
 
 /*        Normalize right eigenvectors and make largest component real */
