@@ -1,229 +1,44 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static integer c__0 = 0;
+static integer c_n1 = -1;
 
 /* Subroutine */ int sgeevx_(char *balanc, char *jobvl, char *jobvr, char *
 	sense, integer *n, real *a, integer *lda, real *wr, real *wi, real *
 	vl, integer *ldvl, real *vr, integer *ldvr, integer *ilo, integer *
-	ihi, real *scale, real *abnrm, real *rconde, real *rcondv, real *work,
+	ihi, real *scale, real *abnrm, real *rconde, real *rcondv, real *work, 
 	 integer *lwork, integer *iwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SGEEVX computes for an N-by-N real nonsymmetric matrix A, the   
-    eigenvalues and, optionally, the left and/or right eigenvectors.   
-
-    Optionally also, it computes a balancing transformation to improve   
-    the conditioning of the eigenvalues and eigenvectors (ILO, IHI,   
-    SCALE, and ABNRM), reciprocal condition numbers for the eigenvalues   
-    (RCONDE), and reciprocal condition numbers for the right   
-    eigenvectors (RCONDV).   
-
-    The right eigenvector v(j) of A satisfies   
-                     A * v(j) = lambda(j) * v(j)   
-    where lambda(j) is its eigenvalue.   
-    The left eigenvector u(j) of A satisfies   
-                  u(j)**H * A = lambda(j) * u(j)**H   
-    where u(j)**H denotes the conjugate transpose of u(j).   
-
-    The computed eigenvectors are normalized to have Euclidean norm   
-    equal to 1 and largest component real.   
-
-    Balancing a matrix means permuting the rows and columns to make it   
-    more nearly upper triangular, and applying a diagonal similarity   
-    transformation D * A * D**(-1), where D is a diagonal matrix, to   
-    make its rows and columns closer in norm and the condition numbers   
-    of its eigenvalues and eigenvectors smaller.  The computed   
-    reciprocal condition numbers correspond to the balanced matrix.   
-    Permuting rows and columns will not change the condition numbers   
-    (in exact arithmetic) but diagonal scaling will.  For further   
-    explanation of balancing, see section 4.10.2 of the LAPACK   
-    Users' Guide.   
-
-    Arguments   
-    =========   
-
-    BALANC  (input) CHARACTER*1   
-            Indicates how the input matrix should be diagonally scaled   
-            and/or permuted to improve the conditioning of its   
-            eigenvalues.   
-            = 'N': Do not diagonally scale or permute;   
-            = 'P': Perform permutations to make the matrix more nearly   
-                   upper triangular. Do not diagonally scale;   
-            = 'S': Diagonally scale the matrix, i.e. replace A by   
-                   D*A*D**(-1), where D is a diagonal matrix chosen   
-                   to make the rows and columns of A more equal in   
-                   norm. Do not permute;   
-            = 'B': Both diagonally scale and permute A.   
-
-            Computed reciprocal condition numbers will be for the matrix   
-            after balancing and/or permuting. Permuting does not change   
-            condition numbers (in exact arithmetic), but balancing does.   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N': left eigenvectors of A are not computed;   
-            = 'V': left eigenvectors of A are computed.   
-            If SENSE = 'E' or 'B', JOBVL must = 'V'.   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N': right eigenvectors of A are not computed;   
-            = 'V': right eigenvectors of A are computed.   
-            If SENSE = 'E' or 'B', JOBVR must = 'V'.   
-
-    SENSE   (input) CHARACTER*1   
-            Determines which reciprocal condition numbers are computed.   
-            = 'N': None are computed;   
-            = 'E': Computed for eigenvalues only;   
-            = 'V': Computed for right eigenvectors only;   
-            = 'B': Computed for eigenvalues and right eigenvectors.   
-
-            If SENSE = 'E' or 'B', both left and right eigenvectors   
-            must also be computed (JOBVL = 'V' and JOBVR = 'V').   
-
-    N       (input) INTEGER   
-            The order of the matrix A. N >= 0.   
-
-    A       (input/output) REAL array, dimension (LDA,N)   
-            On entry, the N-by-N matrix A.   
-            On exit, A has been overwritten.  If JOBVL = 'V' or   
-            JOBVR = 'V', A contains the real Schur form of the balanced   
-            version of the input matrix A.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,N).   
-
-    WR      (output) REAL array, dimension (N)   
-    WI      (output) REAL array, dimension (N)   
-            WR and WI contain the real and imaginary parts,   
-            respectively, of the computed eigenvalues.  Complex   
-            conjugate pairs of eigenvalues will appear consecutively   
-            with the eigenvalue having the positive imaginary part   
-            first.   
-
-    VL      (output) REAL array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left eigenvectors u(j) are stored one   
-            after another in the columns of VL, in the same order   
-            as their eigenvalues.   
-            If JOBVL = 'N', VL is not referenced.   
-            If the j-th eigenvalue is real, then u(j) = VL(:,j),   
-            the j-th column of VL.   
-            If the j-th and (j+1)-st eigenvalues form a complex   
-            conjugate pair, then u(j) = VL(:,j) + i*VL(:,j+1) and   
-            u(j+1) = VL(:,j) - i*VL(:,j+1).   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the array VL.  LDVL >= 1; if   
-            JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) REAL array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right eigenvectors v(j) are stored one   
-            after another in the columns of VR, in the same order   
-            as their eigenvalues.   
-            If JOBVR = 'N', VR is not referenced.   
-            If the j-th eigenvalue is real, then v(j) = VR(:,j),   
-            the j-th column of VR.   
-            If the j-th and (j+1)-st eigenvalues form a complex   
-            conjugate pair, then v(j) = VR(:,j) + i*VR(:,j+1) and   
-            v(j+1) = VR(:,j) - i*VR(:,j+1).   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the array VR.  LDVR >= 1, and if   
-            JOBVR = 'V', LDVR >= N.   
-
-    ILO     (output) INTEGER   
-    IHI     (output) INTEGER   
-            ILO and IHI are integer values determined when A was   
-            balanced.  The balanced A(i,j) = 0 if I > J and   
-            J = 1,...,ILO-1 or I = IHI+1,...,N.   
-
-    SCALE   (output) REAL array, dimension (N)   
-            Details of the permutations and scaling factors applied   
-            when balancing A.  If P(j) is the index of the row and column   
-            interchanged with row and column j, and D(j) is the scaling   
-            factor applied to row and column j, then   
-            SCALE(J) = P(J),    for J = 1,...,ILO-1   
-                     = D(J),    for J = ILO,...,IHI   
-                     = P(J)     for J = IHI+1,...,N.   
-            The order in which the interchanges are made is N to IHI+1,   
-            then 1 to ILO-1.   
-
-    ABNRM   (output) REAL   
-            The one-norm of the balanced matrix (the maximum   
-            of the sum of absolute values of elements of any column).   
-
-    RCONDE  (output) REAL array, dimension (N)   
-            RCONDE(j) is the reciprocal condition number of the j-th   
-            eigenvalue.   
-
-    RCONDV  (output) REAL array, dimension (N)   
-            RCONDV(j) is the reciprocal condition number of the j-th   
-            right eigenvector.   
-
-    WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.   If SENSE = 'N' or 'E',   
-            LWORK >= max(1,2*N), and if JOBVL = 'V' or JOBVR = 'V',   
-            LWORK >= 3*N.  If SENSE = 'V' or 'B', LWORK >= N*(N+6).   
-            For good performance, LWORK must generally be larger.   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    IWORK   (workspace) INTEGER array, dimension (2*N-2)   
-            If SENSE = 'N' or 'E', not referenced.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  if INFO = i, the QR algorithm failed to compute all the   
-                  eigenvalues, and no eigenvectors or condition numbers   
-                  have been computed; elements 1:ILO-1 and i+1:N of WR   
-                  and WI contain eigenvalues which have converged.   
-
-    =====================================================================   
-
-
-       Test the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static integer c_n1 = -1;
-    
     /* System generated locals */
     integer a_dim1, a_offset, vl_dim1, vl_offset, vr_dim1, vr_offset, i__1, 
 	    i__2, i__3;
     real r__1, r__2;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, k;
-    static real r__, cs, sn;
-    static char job[1];
-    static real scl, dum[1], eps;
-    static char side[1];
-    static real anrm;
-    static integer ierr, itau, iwrk, nout;
+    integer i__, k;
+    real r__, cs, sn;
+    char job[1];
+    real scl, dum[1], eps;
+    char side[1];
+    real anrm;
+    integer ierr, itau, iwrk, nout;
     extern /* Subroutine */ int srot_(integer *, real *, integer *, real *, 
 	    integer *, real *, real *);
     extern doublereal snrm2_(integer *, real *, integer *);
-    static integer icond;
+    integer icond;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
     extern doublereal slapy2_(real *, real *);
     extern /* Subroutine */ int slabad_(real *, real *);
-    static logical scalea;
-    static real cscale;
+    logical scalea;
+    real cscale;
     extern /* Subroutine */ int sgebak_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, integer *), sgebal_(char *, integer *, real *, integer *, 
 	    integer *, integer *, real *, integer *);
@@ -233,9 +48,9 @@
 	    *, integer *, real *, real *, integer *, integer *), xerbla_(char 
 	    *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static logical select[1];
-    static real bignum;
+	    integer *, integer *);
+    logical select[1];
+    real bignum;
     extern /* Subroutine */ int slascl_(char *, integer *, integer *, real *, 
 	    real *, integer *, integer *, real *, integer *, integer *);
     extern integer isamax_(integer *, real *, integer *);
@@ -244,21 +59,226 @@
 	    real *, real *, real *), sorghr_(integer *, integer *, integer *, 
 	    real *, integer *, real *, real *, integer *, integer *), shseqr_(
 	    char *, char *, integer *, integer *, integer *, real *, integer *
-	    , real *, real *, real *, integer *, real *, integer *, integer *), strevc_(char *, char *, logical *, integer *, 
+, real *, real *, real *, integer *, real *, integer *, integer *), strevc_(char *, char *, logical *, integer *, 
 	    real *, integer *, real *, integer *, real *, integer *, integer *
-	    , integer *, real *, integer *);
-    static integer minwrk, maxwrk;
+, integer *, real *, integer *);
+    integer minwrk, maxwrk;
     extern /* Subroutine */ int strsna_(char *, char *, logical *, integer *, 
 	    real *, integer *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *, integer *, real *, integer *, integer *, 
 	    integer *);
-    static logical wantvl, wntsnb;
-    static integer hswork;
-    static logical wntsne;
-    static real smlnum;
-    static logical lquery, wantvr, wntsnn, wntsnv;
+    logical wantvl, wntsnb;
+    integer hswork;
+    logical wntsne;
+    real smlnum;
+    logical lquery, wantvr, wntsnn, wntsnv;
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SGEEVX computes for an N-by-N real nonsymmetric matrix A, the */
+/*  eigenvalues and, optionally, the left and/or right eigenvectors. */
+
+/*  Optionally also, it computes a balancing transformation to improve */
+/*  the conditioning of the eigenvalues and eigenvectors (ILO, IHI, */
+/*  SCALE, and ABNRM), reciprocal condition numbers for the eigenvalues */
+/*  (RCONDE), and reciprocal condition numbers for the right */
+/*  eigenvectors (RCONDV). */
+
+/*  The right eigenvector v(j) of A satisfies */
+/*                   A * v(j) = lambda(j) * v(j) */
+/*  where lambda(j) is its eigenvalue. */
+/*  The left eigenvector u(j) of A satisfies */
+/*                u(j)**H * A = lambda(j) * u(j)**H */
+/*  where u(j)**H denotes the conjugate transpose of u(j). */
+
+/*  The computed eigenvectors are normalized to have Euclidean norm */
+/*  equal to 1 and largest component real. */
+
+/*  Balancing a matrix means permuting the rows and columns to make it */
+/*  more nearly upper triangular, and applying a diagonal similarity */
+/*  transformation D * A * D**(-1), where D is a diagonal matrix, to */
+/*  make its rows and columns closer in norm and the condition numbers */
+/*  of its eigenvalues and eigenvectors smaller.  The computed */
+/*  reciprocal condition numbers correspond to the balanced matrix. */
+/*  Permuting rows and columns will not change the condition numbers */
+/*  (in exact arithmetic) but diagonal scaling will.  For further */
+/*  explanation of balancing, see section 4.10.2 of the LAPACK */
+/*  Users' Guide. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  BALANC  (input) CHARACTER*1 */
+/*          Indicates how the input matrix should be diagonally scaled */
+/*          and/or permuted to improve the conditioning of its */
+/*          eigenvalues. */
+/*          = 'N': Do not diagonally scale or permute; */
+/*          = 'P': Perform permutations to make the matrix more nearly */
+/*                 upper triangular. Do not diagonally scale; */
+/*          = 'S': Diagonally scale the matrix, i.e. replace A by */
+/*                 D*A*D**(-1), where D is a diagonal matrix chosen */
+/*                 to make the rows and columns of A more equal in */
+/*                 norm. Do not permute; */
+/*          = 'B': Both diagonally scale and permute A. */
+
+/*          Computed reciprocal condition numbers will be for the matrix */
+/*          after balancing and/or permuting. Permuting does not change */
+/*          condition numbers (in exact arithmetic), but balancing does. */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N': left eigenvectors of A are not computed; */
+/*          = 'V': left eigenvectors of A are computed. */
+/*          If SENSE = 'E' or 'B', JOBVL must = 'V'. */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N': right eigenvectors of A are not computed; */
+/*          = 'V': right eigenvectors of A are computed. */
+/*          If SENSE = 'E' or 'B', JOBVR must = 'V'. */
+
+/*  SENSE   (input) CHARACTER*1 */
+/*          Determines which reciprocal condition numbers are computed. */
+/*          = 'N': None are computed; */
+/*          = 'E': Computed for eigenvalues only; */
+/*          = 'V': Computed for right eigenvectors only; */
+/*          = 'B': Computed for eigenvalues and right eigenvectors. */
+
+/*          If SENSE = 'E' or 'B', both left and right eigenvectors */
+/*          must also be computed (JOBVL = 'V' and JOBVR = 'V'). */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A. N >= 0. */
+
+/*  A       (input/output) REAL array, dimension (LDA,N) */
+/*          On entry, the N-by-N matrix A. */
+/*          On exit, A has been overwritten.  If JOBVL = 'V' or */
+/*          JOBVR = 'V', A contains the real Schur form of the balanced */
+/*          version of the input matrix A. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,N). */
+
+/*  WR      (output) REAL array, dimension (N) */
+/*  WI      (output) REAL array, dimension (N) */
+/*          WR and WI contain the real and imaginary parts, */
+/*          respectively, of the computed eigenvalues.  Complex */
+/*          conjugate pairs of eigenvalues will appear consecutively */
+/*          with the eigenvalue having the positive imaginary part */
+/*          first. */
+
+/*  VL      (output) REAL array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left eigenvectors u(j) are stored one */
+/*          after another in the columns of VL, in the same order */
+/*          as their eigenvalues. */
+/*          If JOBVL = 'N', VL is not referenced. */
+/*          If the j-th eigenvalue is real, then u(j) = VL(:,j), */
+/*          the j-th column of VL. */
+/*          If the j-th and (j+1)-st eigenvalues form a complex */
+/*          conjugate pair, then u(j) = VL(:,j) + i*VL(:,j+1) and */
+/*          u(j+1) = VL(:,j) - i*VL(:,j+1). */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the array VL.  LDVL >= 1; if */
+/*          JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) REAL array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right eigenvectors v(j) are stored one */
+/*          after another in the columns of VR, in the same order */
+/*          as their eigenvalues. */
+/*          If JOBVR = 'N', VR is not referenced. */
+/*          If the j-th eigenvalue is real, then v(j) = VR(:,j), */
+/*          the j-th column of VR. */
+/*          If the j-th and (j+1)-st eigenvalues form a complex */
+/*          conjugate pair, then v(j) = VR(:,j) + i*VR(:,j+1) and */
+/*          v(j+1) = VR(:,j) - i*VR(:,j+1). */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the array VR.  LDVR >= 1, and if */
+/*          JOBVR = 'V', LDVR >= N. */
+
+/*  ILO     (output) INTEGER */
+/*  IHI     (output) INTEGER */
+/*          ILO and IHI are integer values determined when A was */
+/*          balanced.  The balanced A(i,j) = 0 if I > J and */
+/*          J = 1,...,ILO-1 or I = IHI+1,...,N. */
+
+/*  SCALE   (output) REAL array, dimension (N) */
+/*          Details of the permutations and scaling factors applied */
+/*          when balancing A.  If P(j) is the index of the row and column */
+/*          interchanged with row and column j, and D(j) is the scaling */
+/*          factor applied to row and column j, then */
+/*          SCALE(J) = P(J),    for J = 1,...,ILO-1 */
+/*                   = D(J),    for J = ILO,...,IHI */
+/*                   = P(J)     for J = IHI+1,...,N. */
+/*          The order in which the interchanges are made is N to IHI+1, */
+/*          then 1 to ILO-1. */
+
+/*  ABNRM   (output) REAL */
+/*          The one-norm of the balanced matrix (the maximum */
+/*          of the sum of absolute values of elements of any column). */
+
+/*  RCONDE  (output) REAL array, dimension (N) */
+/*          RCONDE(j) is the reciprocal condition number of the j-th */
+/*          eigenvalue. */
+
+/*  RCONDV  (output) REAL array, dimension (N) */
+/*          RCONDV(j) is the reciprocal condition number of the j-th */
+/*          right eigenvector. */
+
+/*  WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.   If SENSE = 'N' or 'E', */
+/*          LWORK >= max(1,2*N), and if JOBVL = 'V' or JOBVR = 'V', */
+/*          LWORK >= 3*N.  If SENSE = 'V' or 'B', LWORK >= N*(N+6). */
+/*          For good performance, LWORK must generally be larger. */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  IWORK   (workspace) INTEGER array, dimension (2*N-2) */
+/*          If SENSE = 'N' or 'E', not referenced. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  if INFO = i, the QR algorithm failed to compute all the */
+/*                eigenvalues, and no eigenvectors or condition numbers */
+/*                have been computed; elements 1:ILO-1 and i+1:N of WR */
+/*                and WI contain eigenvalues which have converged. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -305,15 +325,15 @@
 	*info = -13;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.   
-         HSWORK refers to the workspace preferred by SHSEQR, as   
-         calculated below. HSWORK is computed assuming ILO=1 and IHI=N,   
-         the worst case.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. */
+/*       HSWORK refers to the workspace preferred by SHSEQR, as */
+/*       calculated below. HSWORK is computed assuming ILO=1 and IHI=N, */
+/*       the worst case.) */
 
     if (*info == 0) {
 	if (*n == 0) {
@@ -321,7 +341,7 @@
 	    maxwrk = 1;
 	} else {
 	    maxwrk = *n + *n * ilaenv_(&c__1, "SGEHRD", " ", n, &c__1, n, &
-		    c__0, (ftnlen)6, (ftnlen)1);
+		    c__0);
 
 	    if (wantvl) {
 		shseqr_("S", "V", n, &c__1, n, &a[a_offset], lda, &wr[1], &wi[
@@ -364,8 +384,8 @@
 		}
 		maxwrk = max(maxwrk,hswork);
 /* Computing MAX */
-		i__1 = maxwrk, i__2 = *n + (*n - 1) * ilaenv_(&c__1, "SORGHR",
-			 " ", n, &c__1, n, &c_n1, (ftnlen)6, (ftnlen)1);
+		i__1 = maxwrk, i__2 = *n + (*n - 1) * ilaenv_(&c__1, "SORGHR", 
+			 " ", n, &c__1, n, &c_n1);
 		maxwrk = max(i__1,i__2);
 		if (! wntsnn && ! wntsne) {
 /* Computing MAX */
@@ -436,8 +456,8 @@
 	*abnrm = dum[0];
     }
 
-/*     Reduce to upper Hessenberg form   
-       (Workspace: need 2*N, prefer N+N*NB) */
+/*     Reduce to upper Hessenberg form */
+/*     (Workspace: need 2*N, prefer N+N*NB) */
 
     itau = 1;
     iwrk = itau + *n;
@@ -447,22 +467,22 @@
 
     if (wantvl) {
 
-/*        Want left eigenvectors   
-          Copy Householder vectors to VL */
+/*        Want left eigenvectors */
+/*        Copy Householder vectors to VL */
 
 	*(unsigned char *)side = 'L';
 	slacpy_("L", n, n, &a[a_offset], lda, &vl[vl_offset], ldvl)
 		;
 
-/*        Generate orthogonal matrix in VL   
-          (Workspace: need 2*N-1, prefer N+(N-1)*NB) */
+/*        Generate orthogonal matrix in VL */
+/*        (Workspace: need 2*N-1, prefer N+(N-1)*NB) */
 
 	i__1 = *lwork - iwrk + 1;
 	sorghr_(n, ilo, ihi, &vl[vl_offset], ldvl, &work[itau], &work[iwrk], &
 		i__1, &ierr);
 
-/*        Perform QR iteration, accumulating Schur vectors in VL   
-          (Workspace: need 1, prefer HSWORK (see comments) ) */
+/*        Perform QR iteration, accumulating Schur vectors in VL */
+/*        (Workspace: need 1, prefer HSWORK (see comments) ) */
 
 	iwrk = itau;
 	i__1 = *lwork - iwrk + 1;
@@ -471,8 +491,8 @@
 
 	if (wantvr) {
 
-/*           Want left and right eigenvectors   
-             Copy Schur vectors to VR */
+/*           Want left and right eigenvectors */
+/*           Copy Schur vectors to VR */
 
 	    *(unsigned char *)side = 'B';
 	    slacpy_("F", n, n, &vl[vl_offset], ldvl, &vr[vr_offset], ldvr);
@@ -480,22 +500,22 @@
 
     } else if (wantvr) {
 
-/*        Want right eigenvectors   
-          Copy Householder vectors to VR */
+/*        Want right eigenvectors */
+/*        Copy Householder vectors to VR */
 
 	*(unsigned char *)side = 'R';
 	slacpy_("L", n, n, &a[a_offset], lda, &vr[vr_offset], ldvr)
 		;
 
-/*        Generate orthogonal matrix in VR   
-          (Workspace: need 2*N-1, prefer N+(N-1)*NB) */
+/*        Generate orthogonal matrix in VR */
+/*        (Workspace: need 2*N-1, prefer N+(N-1)*NB) */
 
 	i__1 = *lwork - iwrk + 1;
 	sorghr_(n, ilo, ihi, &vr[vr_offset], ldvr, &work[itau], &work[iwrk], &
 		i__1, &ierr);
 
-/*        Perform QR iteration, accumulating Schur vectors in VR   
-          (Workspace: need 1, prefer HSWORK (see comments) ) */
+/*        Perform QR iteration, accumulating Schur vectors in VR */
+/*        (Workspace: need 1, prefer HSWORK (see comments) ) */
 
 	iwrk = itau;
 	i__1 = *lwork - iwrk + 1;
@@ -504,8 +524,8 @@
 
     } else {
 
-/*        Compute eigenvalues only   
-          If condition numbers desired, compute Schur form */
+/*        Compute eigenvalues only */
+/*        If condition numbers desired, compute Schur form */
 
 	if (wntsnn) {
 	    *(unsigned char *)job = 'E';
@@ -529,15 +549,15 @@
 
     if (wantvl || wantvr) {
 
-/*        Compute left and/or right eigenvectors   
-          (Workspace: need 3*N) */
+/*        Compute left and/or right eigenvectors */
+/*        (Workspace: need 3*N) */
 
-	strevc_(side, "B", select, n, &a[a_offset], lda, &vl[vl_offset], ldvl,
+	strevc_(side, "B", select, n, &a[a_offset], lda, &vl[vl_offset], ldvl, 
 		 &vr[vr_offset], ldvr, n, &nout, &work[iwrk], &ierr);
     }
 
-/*     Compute condition numbers if desired   
-       (Workspace: need N*N+6*N unless SENSE = 'E') */
+/*     Compute condition numbers if desired */
+/*     (Workspace: need N*N+6*N unless SENSE = 'E') */
 
     if (! wntsnn) {
 	strsna_(sense, "A", select, n, &a[a_offset], lda, &vl[vl_offset], 
