@@ -1,291 +1,311 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static integer c_n1 = -1;
+static real c_b27 = 1.f;
+static real c_b38 = 0.f;
 
 /* Subroutine */ int sgegv_(char *jobvl, char *jobvr, integer *n, real *a, 
 	integer *lda, real *b, integer *ldb, real *alphar, real *alphai, real 
 	*beta, real *vl, integer *ldvl, real *vr, integer *ldvr, real *work, 
 	integer *lwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    This routine is deprecated and has been replaced by routine SGGEV.   
-
-    SGEGV computes the eigenvalues and, optionally, the left and/or right   
-    eigenvectors of a real matrix pair (A,B).   
-    Given two square matrices A and B,   
-    the generalized nonsymmetric eigenvalue problem (GNEP) is to find the   
-    eigenvalues lambda and corresponding (non-zero) eigenvectors x such   
-    that   
-
-       A*x = lambda*B*x.   
-
-    An alternate form is to find the eigenvalues mu and corresponding   
-    eigenvectors y such that   
-
-       mu*A*y = B*y.   
-
-    These two forms are equivalent with mu = 1/lambda and x = y if   
-    neither lambda nor mu is zero.  In order to deal with the case that   
-    lambda or mu is zero or small, two values alpha and beta are returned   
-    for each eigenvalue, such that lambda = alpha/beta and   
-    mu = beta/alpha.   
-
-    The vectors x and y in the above equations are right eigenvectors of   
-    the matrix pair (A,B).  Vectors u and v satisfying   
-
-       u**H*A = lambda*u**H*B  or  mu*v**H*A = v**H*B   
-
-    are left eigenvectors of (A,B).   
-
-    Note: this routine performs "full balancing" on A and B -- see   
-    "Further Details", below.   
-
-    Arguments   
-    =========   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N':  do not compute the left generalized eigenvectors;   
-            = 'V':  compute the left generalized eigenvectors (returned   
-                    in VL).   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N':  do not compute the right generalized eigenvectors;   
-            = 'V':  compute the right generalized eigenvectors (returned   
-                    in VR).   
-
-    N       (input) INTEGER   
-            The order of the matrices A, B, VL, and VR.  N >= 0.   
-
-    A       (input/output) REAL array, dimension (LDA, N)   
-            On entry, the matrix A.   
-            If JOBVL = 'V' or JOBVR = 'V', then on exit A   
-            contains the real Schur form of A from the generalized Schur   
-            factorization of the pair (A,B) after balancing.   
-            If no eigenvectors were computed, then only the diagonal   
-            blocks from the Schur form will be correct.  See SGGHRD and   
-            SHGEQZ for details.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A.  LDA >= max(1,N).   
-
-    B       (input/output) REAL array, dimension (LDB, N)   
-            On entry, the matrix B.   
-            If JOBVL = 'V' or JOBVR = 'V', then on exit B contains the   
-            upper triangular matrix obtained from B in the generalized   
-            Schur factorization of the pair (A,B) after balancing.   
-            If no eigenvectors were computed, then only those elements of   
-            B corresponding to the diagonal blocks from the Schur form of   
-            A will be correct.  See SGGHRD and SHGEQZ for details.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of B.  LDB >= max(1,N).   
-
-    ALPHAR  (output) REAL array, dimension (N)   
-            The real parts of each scalar alpha defining an eigenvalue of   
-            GNEP.   
-
-    ALPHAI  (output) REAL array, dimension (N)   
-            The imaginary parts of each scalar alpha defining an   
-            eigenvalue of GNEP.  If ALPHAI(j) is zero, then the j-th   
-            eigenvalue is real; if positive, then the j-th and   
-            (j+1)-st eigenvalues are a complex conjugate pair, with   
-            ALPHAI(j+1) = -ALPHAI(j).   
-
-    BETA    (output) REAL array, dimension (N)   
-            The scalars beta that define the eigenvalues of GNEP.   
-
-            Together, the quantities alpha = (ALPHAR(j),ALPHAI(j)) and   
-            beta = BETA(j) represent the j-th eigenvalue of the matrix   
-            pair (A,B), in one of the forms lambda = alpha/beta or   
-            mu = beta/alpha.  Since either lambda or mu may overflow,   
-            they should not, in general, be computed.   
-
-    VL      (output) REAL array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left eigenvectors u(j) are stored   
-            in the columns of VL, in the same order as their eigenvalues.   
-            If the j-th eigenvalue is real, then u(j) = VL(:,j).   
-            If the j-th and (j+1)-st eigenvalues form a complex conjugate   
-            pair, then   
-               u(j) = VL(:,j) + i*VL(:,j+1)   
-            and   
-              u(j+1) = VL(:,j) - i*VL(:,j+1).   
-
-            Each eigenvector is scaled so that its largest component has   
-            abs(real part) + abs(imag. part) = 1, except for eigenvectors   
-            corresponding to an eigenvalue with alpha = beta = 0, which   
-            are set to zero.   
-            Not referenced if JOBVL = 'N'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the matrix VL. LDVL >= 1, and   
-            if JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) REAL array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right eigenvectors x(j) are stored   
-            in the columns of VR, in the same order as their eigenvalues.   
-            If the j-th eigenvalue is real, then x(j) = VR(:,j).   
-            If the j-th and (j+1)-st eigenvalues form a complex conjugate   
-            pair, then   
-              x(j) = VR(:,j) + i*VR(:,j+1)   
-            and   
-              x(j+1) = VR(:,j) - i*VR(:,j+1).   
-
-            Each eigenvector is scaled so that its largest component has   
-            abs(real part) + abs(imag. part) = 1, except for eigenvalues   
-            corresponding to an eigenvalue with alpha = beta = 0, which   
-            are set to zero.   
-            Not referenced if JOBVR = 'N'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the matrix VR. LDVR >= 1, and   
-            if JOBVR = 'V', LDVR >= N.   
-
-    WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,8*N).   
-            For good performance, LWORK must generally be larger.   
-            To compute the optimal value of LWORK, call ILAENV to get   
-            blocksizes (for SGEQRF, SORMQR, and SORGQR.)  Then compute:   
-            NB  -- MAX of the blocksizes for SGEQRF, SORMQR, and SORGQR;   
-            The optimal LWORK is:   
-                2*N + MAX( 6*N, N*(NB+1) ).   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            = 1,...,N:   
-                  The QZ iteration failed.  No eigenvectors have been   
-                  calculated, but ALPHAR(j), ALPHAI(j), and BETA(j)   
-                  should be correct for j=INFO+1,...,N.   
-            > N:  errors that usually indicate LAPACK problems:   
-                  =N+1: error return from SGGBAL   
-                  =N+2: error return from SGEQRF   
-                  =N+3: error return from SORMQR   
-                  =N+4: error return from SORGQR   
-                  =N+5: error return from SGGHRD   
-                  =N+6: error return from SHGEQZ (other than failed   
-                                                  iteration)   
-                  =N+7: error return from STGEVC   
-                  =N+8: error return from SGGBAK (computing VL)   
-                  =N+9: error return from SGGBAK (computing VR)   
-                  =N+10: error return from SLASCL (various calls)   
-
-    Further Details   
-    ===============   
-
-    Balancing   
-    ---------   
-
-    This driver calls SGGBAL to both permute and scale rows and columns   
-    of A and B.  The permutations PL and PR are chosen so that PL*A*PR   
-    and PL*B*R will be upper triangular except for the diagonal blocks   
-    A(i:j,i:j) and B(i:j,i:j), with i and j as close together as   
-    possible.  The diagonal scaling matrices DL and DR are chosen so   
-    that the pair  DL*PL*A*PR*DR, DL*PL*B*PR*DR have elements close to   
-    one (except for the elements that start out zero.)   
-
-    After the eigenvalues and eigenvectors of the balanced matrices   
-    have been computed, SGGBAK transforms the eigenvectors back to what   
-    they would have been (in perfect arithmetic) if they had not been   
-    balanced.   
-
-    Contents of A and B on Exit   
-    -------- -- - --- - -- ----   
-
-    If any eigenvectors are computed (either JOBVL='V' or JOBVR='V' or   
-    both), then on exit the arrays A and B will contain the real Schur   
-    form[*] of the "balanced" versions of A and B.  If no eigenvectors   
-    are computed, then only the diagonal blocks will be correct.   
-
-    [*] See SHGEQZ, SGEGS, or read the book "Matrix Computations",   
-        by Golub & van Loan, pub. by Johns Hopkins U. Press.   
-
-    =====================================================================   
-
-
-       Decode the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static integer c_n1 = -1;
-    static real c_b27 = 1.f;
-    static real c_b38 = 0.f;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2;
     real r__1, r__2, r__3, r__4;
+
     /* Local variables */
-    static integer jc, nb, in, jr, nb1, nb2, nb3, ihi, ilo;
-    static real eps;
-    static logical ilv;
-    static real absb, anrm, bnrm;
-    static integer itau;
-    static real temp;
-    static logical ilvl, ilvr;
-    static integer lopt;
-    static real anrm1, anrm2, bnrm1, bnrm2, absai, scale, absar, sbeta;
+    integer jc, nb, in, jr, nb1, nb2, nb3, ihi, ilo;
+    real eps;
+    logical ilv;
+    real absb, anrm, bnrm;
+    integer itau;
+    real temp;
+    logical ilvl, ilvr;
+    integer lopt;
+    real anrm1, anrm2, bnrm1, bnrm2, absai, scale, absar, sbeta;
     extern logical lsame_(char *, char *);
-    static integer ileft, iinfo, icols, iwork, irows;
-    static real salfai;
-    extern /* Subroutine */ int sggbak_(char *, char *, integer *, integer *,  	    integer *, real *, real *, integer *, real *, integer *, integer * 	    ), sggbal_(char *, integer *, real *, integer *, 
+    integer ileft, iinfo, icols, iwork, irows;
+    real salfai;
+    extern /* Subroutine */ int sggbak_(char *, char *, integer *, integer *, 
+	    integer *, real *, real *, integer *, real *, integer *, integer *
+), sggbal_(char *, integer *, real *, integer *, 
 	    real *, integer *, integer *, integer *, real *, real *, real *, 
 	    integer *);
-    static real salfar;
+    real salfar;
     extern doublereal slamch_(char *), slange_(char *, integer *, 
 	    integer *, real *, integer *, real *);
-    static real safmin;
+    real safmin;
     extern /* Subroutine */ int sgghrd_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , real *, integer *, integer *);
-    static real safmax;
-    static char chtemp[1];
-    static logical ldumma[1];
+, real *, integer *, integer *);
+    real safmax;
+    char chtemp[1];
+    logical ldumma[1];
     extern /* Subroutine */ int slascl_(char *, integer *, integer *, real *, 
-	    real *, integer *, integer *, real *, integer *, integer *),
-            xerbla_(char *, integer *);
+	    real *, integer *, integer *, real *, integer *, integer *), xerbla_(char *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static integer ijobvl, iright;
-    static logical ilimit;
+	    integer *, integer *);
+    integer ijobvl, iright;
+    logical ilimit;
     extern /* Subroutine */ int sgeqrf_(integer *, integer *, real *, integer 
 	    *, real *, real *, integer *, integer *);
-    static integer ijobvr;
+    integer ijobvr;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), slaset_(char *, integer *, 
 	    integer *, real *, real *, real *, integer *), stgevc_(
 	    char *, char *, logical *, integer *, real *, integer *, real *, 
 	    integer *, real *, integer *, real *, integer *, integer *, 
 	    integer *, real *, integer *);
-    static real onepls;
-    static integer lwkmin;
+    real onepls;
+    integer lwkmin;
     extern /* Subroutine */ int shgeqz_(char *, char *, char *, integer *, 
 	    integer *, integer *, real *, integer *, real *, integer *, real *
-	    , real *, real *, real *, integer *, real *, integer *, real *, 
+, real *, real *, real *, integer *, real *, integer *, real *, 
 	    integer *, integer *), sorgqr_(integer *, 
 	    integer *, integer *, real *, integer *, real *, real *, integer *
-	    , integer *);
-    static integer lwkopt;
-    static logical lquery;
+, integer *);
+    integer lwkopt;
+    logical lquery;
     extern /* Subroutine */ int sormqr_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, real *, integer *, real *, 
 	    integer *, integer *);
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  This routine is deprecated and has been replaced by routine SGGEV. */
+
+/*  SGEGV computes the eigenvalues and, optionally, the left and/or right */
+/*  eigenvectors of a real matrix pair (A,B). */
+/*  Given two square matrices A and B, */
+/*  the generalized nonsymmetric eigenvalue problem (GNEP) is to find the */
+/*  eigenvalues lambda and corresponding (non-zero) eigenvectors x such */
+/*  that */
+
+/*     A*x = lambda*B*x. */
+
+/*  An alternate form is to find the eigenvalues mu and corresponding */
+/*  eigenvectors y such that */
+
+/*     mu*A*y = B*y. */
+
+/*  These two forms are equivalent with mu = 1/lambda and x = y if */
+/*  neither lambda nor mu is zero.  In order to deal with the case that */
+/*  lambda or mu is zero or small, two values alpha and beta are returned */
+/*  for each eigenvalue, such that lambda = alpha/beta and */
+/*  mu = beta/alpha. */
+
+/*  The vectors x and y in the above equations are right eigenvectors of */
+/*  the matrix pair (A,B).  Vectors u and v satisfying */
+
+/*     u**H*A = lambda*u**H*B  or  mu*v**H*A = v**H*B */
+
+/*  are left eigenvectors of (A,B). */
+
+/*  Note: this routine performs "full balancing" on A and B -- see */
+/*  "Further Details", below. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the left generalized eigenvectors; */
+/*          = 'V':  compute the left generalized eigenvectors (returned */
+/*                  in VL). */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the right generalized eigenvectors; */
+/*          = 'V':  compute the right generalized eigenvectors (returned */
+/*                  in VR). */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A, B, VL, and VR.  N >= 0. */
+
+/*  A       (input/output) REAL array, dimension (LDA, N) */
+/*          On entry, the matrix A. */
+/*          If JOBVL = 'V' or JOBVR = 'V', then on exit A */
+/*          contains the real Schur form of A from the generalized Schur */
+/*          factorization of the pair (A,B) after balancing. */
+/*          If no eigenvectors were computed, then only the diagonal */
+/*          blocks from the Schur form will be correct.  See SGGHRD and */
+/*          SHGEQZ for details. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A.  LDA >= max(1,N). */
+
+/*  B       (input/output) REAL array, dimension (LDB, N) */
+/*          On entry, the matrix B. */
+/*          If JOBVL = 'V' or JOBVR = 'V', then on exit B contains the */
+/*          upper triangular matrix obtained from B in the generalized */
+/*          Schur factorization of the pair (A,B) after balancing. */
+/*          If no eigenvectors were computed, then only those elements of */
+/*          B corresponding to the diagonal blocks from the Schur form of */
+/*          A will be correct.  See SGGHRD and SHGEQZ for details. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B.  LDB >= max(1,N). */
+
+/*  ALPHAR  (output) REAL array, dimension (N) */
+/*          The real parts of each scalar alpha defining an eigenvalue of */
+/*          GNEP. */
+
+/*  ALPHAI  (output) REAL array, dimension (N) */
+/*          The imaginary parts of each scalar alpha defining an */
+/*          eigenvalue of GNEP.  If ALPHAI(j) is zero, then the j-th */
+/*          eigenvalue is real; if positive, then the j-th and */
+/*          (j+1)-st eigenvalues are a complex conjugate pair, with */
+/*          ALPHAI(j+1) = -ALPHAI(j). */
+
+/*  BETA    (output) REAL array, dimension (N) */
+/*          The scalars beta that define the eigenvalues of GNEP. */
+
+/*          Together, the quantities alpha = (ALPHAR(j),ALPHAI(j)) and */
+/*          beta = BETA(j) represent the j-th eigenvalue of the matrix */
+/*          pair (A,B), in one of the forms lambda = alpha/beta or */
+/*          mu = beta/alpha.  Since either lambda or mu may overflow, */
+/*          they should not, in general, be computed. */
+
+/*  VL      (output) REAL array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left eigenvectors u(j) are stored */
+/*          in the columns of VL, in the same order as their eigenvalues. */
+/*          If the j-th eigenvalue is real, then u(j) = VL(:,j). */
+/*          If the j-th and (j+1)-st eigenvalues form a complex conjugate */
+/*          pair, then */
+/*             u(j) = VL(:,j) + i*VL(:,j+1) */
+/*          and */
+/*            u(j+1) = VL(:,j) - i*VL(:,j+1). */
+
+/*          Each eigenvector is scaled so that its largest component has */
+/*          abs(real part) + abs(imag. part) = 1, except for eigenvectors */
+/*          corresponding to an eigenvalue with alpha = beta = 0, which */
+/*          are set to zero. */
+/*          Not referenced if JOBVL = 'N'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the matrix VL. LDVL >= 1, and */
+/*          if JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) REAL array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right eigenvectors x(j) are stored */
+/*          in the columns of VR, in the same order as their eigenvalues. */
+/*          If the j-th eigenvalue is real, then x(j) = VR(:,j). */
+/*          If the j-th and (j+1)-st eigenvalues form a complex conjugate */
+/*          pair, then */
+/*            x(j) = VR(:,j) + i*VR(:,j+1) */
+/*          and */
+/*            x(j+1) = VR(:,j) - i*VR(:,j+1). */
+
+/*          Each eigenvector is scaled so that its largest component has */
+/*          abs(real part) + abs(imag. part) = 1, except for eigenvalues */
+/*          corresponding to an eigenvalue with alpha = beta = 0, which */
+/*          are set to zero. */
+/*          Not referenced if JOBVR = 'N'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the matrix VR. LDVR >= 1, and */
+/*          if JOBVR = 'V', LDVR >= N. */
+
+/*  WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,8*N). */
+/*          For good performance, LWORK must generally be larger. */
+/*          To compute the optimal value of LWORK, call ILAENV to get */
+/*          blocksizes (for SGEQRF, SORMQR, and SORGQR.)  Then compute: */
+/*          NB  -- MAX of the blocksizes for SGEQRF, SORMQR, and SORGQR; */
+/*          The optimal LWORK is: */
+/*              2*N + MAX( 6*N, N*(NB+1) ). */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          = 1,...,N: */
+/*                The QZ iteration failed.  No eigenvectors have been */
+/*                calculated, but ALPHAR(j), ALPHAI(j), and BETA(j) */
+/*                should be correct for j=INFO+1,...,N. */
+/*          > N:  errors that usually indicate LAPACK problems: */
+/*                =N+1: error return from SGGBAL */
+/*                =N+2: error return from SGEQRF */
+/*                =N+3: error return from SORMQR */
+/*                =N+4: error return from SORGQR */
+/*                =N+5: error return from SGGHRD */
+/*                =N+6: error return from SHGEQZ (other than failed */
+/*                                                iteration) */
+/*                =N+7: error return from STGEVC */
+/*                =N+8: error return from SGGBAK (computing VL) */
+/*                =N+9: error return from SGGBAK (computing VR) */
+/*                =N+10: error return from SLASCL (various calls) */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Balancing */
+/*  --------- */
+
+/*  This driver calls SGGBAL to both permute and scale rows and columns */
+/*  of A and B.  The permutations PL and PR are chosen so that PL*A*PR */
+/*  and PL*B*R will be upper triangular except for the diagonal blocks */
+/*  A(i:j,i:j) and B(i:j,i:j), with i and j as close together as */
+/*  possible.  The diagonal scaling matrices DL and DR are chosen so */
+/*  that the pair  DL*PL*A*PR*DR, DL*PL*B*PR*DR have elements close to */
+/*  one (except for the elements that start out zero.) */
+
+/*  After the eigenvalues and eigenvectors of the balanced matrices */
+/*  have been computed, SGGBAK transforms the eigenvectors back to what */
+/*  they would have been (in perfect arithmetic) if they had not been */
+/*  balanced. */
+
+/*  Contents of A and B on Exit */
+/*  -------- -- - --- - -- ---- */
+
+/*  If any eigenvectors are computed (either JOBVL='V' or JOBVR='V' or */
+/*  both), then on exit the arrays A and B will contain the real Schur */
+/*  form[*] of the "balanced" versions of A and B.  If no eigenvectors */
+/*  are computed, then only the diagonal blocks will be correct. */
+
+/*  [*] See SHGEQZ, SGEGS, or read the book "Matrix Computations", */
+/*      by Golub & van Loan, pub. by Johns Hopkins U. Press. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -327,9 +347,9 @@
     }
     ilv = ilvl || ilvr;
 
-/*     Test the input arguments   
+/*     Test the input arguments */
 
-   Computing MAX */
+/* Computing MAX */
     i__1 = *n << 3;
     lwkmin = max(i__1,1);
     lwkopt = lwkmin;
@@ -355,12 +375,9 @@
     }
 
     if (*info == 0) {
-	nb1 = ilaenv_(&c__1, "SGEQRF", " ", n, n, &c_n1, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-	nb2 = ilaenv_(&c__1, "SORMQR", " ", n, n, n, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-	nb3 = ilaenv_(&c__1, "SORGQR", " ", n, n, n, &c_n1, (ftnlen)6, (
-		ftnlen)1);
+	nb1 = ilaenv_(&c__1, "SGEQRF", " ", n, n, &c_n1, &c_n1);
+	nb2 = ilaenv_(&c__1, "SORMQR", " ", n, n, n, &c_n1);
+	nb3 = ilaenv_(&c__1, "SORGQR", " ", n, n, n, &c_n1);
 /* Computing MAX */
 	i__1 = max(nb1,nb2);
 	nb = max(i__1,nb3);
@@ -434,9 +451,9 @@
 	}
     }
 
-/*     Permute the matrix to make it more nearly triangular   
-       Workspace layout:  (8*N words -- "work" requires 6*N words)   
-          left_permutation, right_permutation, work... */
+/*     Permute the matrix to make it more nearly triangular */
+/*     Workspace layout:  (8*N words -- "work" requires 6*N words) */
+/*        left_permutation, right_permutation, work... */
 
     ileft = 1;
     iright = *n + 1;
@@ -448,9 +465,9 @@
 	goto L120;
     }
 
-/*     Reduce B to triangular form, and initialize VL and/or VR   
-       Workspace layout:  ("work..." must have at least N words)   
-          left_permutation, right_permutation, tau, work... */
+/*     Reduce B to triangular form, and initialize VL and/or VR */
+/*     Workspace layout:  ("work..." must have at least N words) */
+/*        left_permutation, right_permutation, tau, work... */
 
     irows = ihi + 1 - ilo;
     if (ilv) {
@@ -531,9 +548,9 @@
 	goto L120;
     }
 
-/*     Perform QZ algorithm   
-       Workspace layout:  ("work..." must have at least 1 word)   
-          left_permutation, right_permutation, work... */
+/*     Perform QZ algorithm */
+/*     Workspace layout:  ("work..." must have at least 1 word) */
+/*        left_permutation, right_permutation, work... */
 
     iwork = itau;
     if (ilv) {
@@ -700,13 +717,13 @@ L100:
 
     }
 
-/*     Undo scaling in alpha, beta   
+/*     Undo scaling in alpha, beta */
 
-       Note: this does not give the alpha and beta for the unscaled   
-       problem.   
+/*     Note: this does not give the alpha and beta for the unscaled */
+/*     problem. */
 
-       Un-scaling is limited to avoid underflow in alpha and beta   
-       if they are significant. */
+/*     Un-scaling is limited to avoid underflow in alpha and beta */
+/*     if they are significant. */
 
     i__1 = *n;
     for (jc = 1; jc <= i__1; ++jc) {
@@ -719,9 +736,9 @@ L100:
 	ilimit = FALSE_;
 	scale = 1.f;
 
-/*        Check for significant underflow in ALPHAI   
+/*        Check for significant underflow in ALPHAI */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = safmin, r__2 = eps * absar, r__1 = max(r__1,r__2), r__2 = eps *
 		 absb;
 	if (dabs(salfai) < safmin && absai >= dmax(r__1,r__2)) {
@@ -732,8 +749,8 @@ L100:
 
 	} else if (salfai == 0.f) {
 
-/*           If insignificant underflow in ALPHAI, then make the   
-             conjugate eigenvalue real. */
+/*           If insignificant underflow in ALPHAI, then make the */
+/*           conjugate eigenvalue real. */
 
 	    if (alphai[jc] < 0.f && jc > 1) {
 		alphai[jc - 1] = 0.f;
@@ -742,29 +759,29 @@ L100:
 	    }
 	}
 
-/*        Check for significant underflow in ALPHAR   
+/*        Check for significant underflow in ALPHAR */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = safmin, r__2 = eps * absai, r__1 = max(r__1,r__2), r__2 = eps *
 		 absb;
 	if (dabs(salfar) < safmin && absar >= dmax(r__1,r__2)) {
 	    ilimit = TRUE_;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    r__3 = onepls * safmin, r__4 = anrm2 * absar;
 	    r__1 = scale, r__2 = onepls * safmin / anrm1 / dmax(r__3,r__4);
 	    scale = dmax(r__1,r__2);
 	}
 
-/*        Check for significant underflow in BETA   
+/*        Check for significant underflow in BETA */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = safmin, r__2 = eps * absar, r__1 = max(r__1,r__2), r__2 = eps *
 		 absai;
 	if (dabs(sbeta) < safmin && absb >= dmax(r__1,r__2)) {
 	    ilimit = TRUE_;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    r__3 = onepls * safmin, r__4 = bnrm2 * absb;
 	    r__1 = scale, r__2 = onepls * safmin / bnrm1 / dmax(r__3,r__4);
 	    scale = dmax(r__1,r__2);
