@@ -1,212 +1,232 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static integer c__0 = 0;
+static integer c_n1 = -1;
+static real c_b36 = 0.f;
+static real c_b37 = 1.f;
 
 /* Subroutine */ int sggev_(char *jobvl, char *jobvr, integer *n, real *a, 
 	integer *lda, real *b, integer *ldb, real *alphar, real *alphai, real 
 	*beta, real *vl, integer *ldvl, real *vr, integer *ldvr, real *work, 
 	integer *lwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SGGEV computes for a pair of N-by-N real nonsymmetric matrices (A,B)   
-    the generalized eigenvalues, and optionally, the left and/or right   
-    generalized eigenvectors.   
-
-    A generalized eigenvalue for a pair of matrices (A,B) is a scalar   
-    lambda or a ratio alpha/beta = lambda, such that A - lambda*B is   
-    singular. It is usually represented as the pair (alpha,beta), as   
-    there is a reasonable interpretation for beta=0, and even for both   
-    being zero.   
-
-    The right eigenvector v(j) corresponding to the eigenvalue lambda(j)   
-    of (A,B) satisfies   
-
-                     A * v(j) = lambda(j) * B * v(j).   
-
-    The left eigenvector u(j) corresponding to the eigenvalue lambda(j)   
-    of (A,B) satisfies   
-
-                     u(j)**H * A  = lambda(j) * u(j)**H * B .   
-
-    where u(j)**H is the conjugate-transpose of u(j).   
-
-
-    Arguments   
-    =========   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N':  do not compute the left generalized eigenvectors;   
-            = 'V':  compute the left generalized eigenvectors.   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N':  do not compute the right generalized eigenvectors;   
-            = 'V':  compute the right generalized eigenvectors.   
-
-    N       (input) INTEGER   
-            The order of the matrices A, B, VL, and VR.  N >= 0.   
-
-    A       (input/output) REAL array, dimension (LDA, N)   
-            On entry, the matrix A in the pair (A,B).   
-            On exit, A has been overwritten.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A.  LDA >= max(1,N).   
-
-    B       (input/output) REAL array, dimension (LDB, N)   
-            On entry, the matrix B in the pair (A,B).   
-            On exit, B has been overwritten.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of B.  LDB >= max(1,N).   
-
-    ALPHAR  (output) REAL array, dimension (N)   
-    ALPHAI  (output) REAL array, dimension (N)   
-    BETA    (output) REAL array, dimension (N)   
-            On exit, (ALPHAR(j) + ALPHAI(j)*i)/BETA(j), j=1,...,N, will   
-            be the generalized eigenvalues.  If ALPHAI(j) is zero, then   
-            the j-th eigenvalue is real; if positive, then the j-th and   
-            (j+1)-st eigenvalues are a complex conjugate pair, with   
-            ALPHAI(j+1) negative.   
-
-            Note: the quotients ALPHAR(j)/BETA(j) and ALPHAI(j)/BETA(j)   
-            may easily over- or underflow, and BETA(j) may even be zero.   
-            Thus, the user should avoid naively computing the ratio   
-            alpha/beta.  However, ALPHAR and ALPHAI will be always less   
-            than and usually comparable with norm(A) in magnitude, and   
-            BETA always less than and usually comparable with norm(B).   
-
-    VL      (output) REAL array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left eigenvectors u(j) are stored one   
-            after another in the columns of VL, in the same order as   
-            their eigenvalues. If the j-th eigenvalue is real, then   
-            u(j) = VL(:,j), the j-th column of VL. If the j-th and   
-            (j+1)-th eigenvalues form a complex conjugate pair, then   
-            u(j) = VL(:,j)+i*VL(:,j+1) and u(j+1) = VL(:,j)-i*VL(:,j+1).   
-            Each eigenvector is scaled so the largest component has   
-            abs(real part)+abs(imag. part)=1.   
-            Not referenced if JOBVL = 'N'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the matrix VL. LDVL >= 1, and   
-            if JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) REAL array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right eigenvectors v(j) are stored one   
-            after another in the columns of VR, in the same order as   
-            their eigenvalues. If the j-th eigenvalue is real, then   
-            v(j) = VR(:,j), the j-th column of VR. If the j-th and   
-            (j+1)-th eigenvalues form a complex conjugate pair, then   
-            v(j) = VR(:,j)+i*VR(:,j+1) and v(j+1) = VR(:,j)-i*VR(:,j+1).   
-            Each eigenvector is scaled so the largest component has   
-            abs(real part)+abs(imag. part)=1.   
-            Not referenced if JOBVR = 'N'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the matrix VR. LDVR >= 1, and   
-            if JOBVR = 'V', LDVR >= N.   
-
-    WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,8*N).   
-            For good performance, LWORK must generally be larger.   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            = 1,...,N:   
-                  The QZ iteration failed.  No eigenvectors have been   
-                  calculated, but ALPHAR(j), ALPHAI(j), and BETA(j)   
-                  should be correct for j=INFO+1,...,N.   
-            > N:  =N+1: other than QZ iteration failed in SHGEQZ.   
-                  =N+2: error return from STGEVC.   
-
-    =====================================================================   
-
-
-       Decode the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static integer c__0 = 0;
-    static integer c_n1 = -1;
-    static real c_b36 = 0.f;
-    static real c_b37 = 1.f;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2;
     real r__1, r__2, r__3, r__4;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer jc, in, jr, ihi, ilo;
-    static real eps;
-    static logical ilv;
-    static real anrm, bnrm;
-    static integer ierr, itau;
-    static real temp;
-    static logical ilvl, ilvr;
-    static integer iwrk;
+    integer jc, in, jr, ihi, ilo;
+    real eps;
+    logical ilv;
+    real anrm, bnrm;
+    integer ierr, itau;
+    real temp;
+    logical ilvl, ilvr;
+    integer iwrk;
     extern logical lsame_(char *, char *);
-    static integer ileft, icols, irows;
+    integer ileft, icols, irows;
     extern /* Subroutine */ int slabad_(real *, real *), sggbak_(char *, char 
 	    *, integer *, integer *, integer *, real *, real *, integer *, 
 	    real *, integer *, integer *), sggbal_(char *, 
 	    integer *, real *, integer *, real *, integer *, integer *, 
 	    integer *, real *, real *, real *, integer *);
-    static logical ilascl, ilbscl;
+    logical ilascl, ilbscl;
     extern doublereal slamch_(char *), slange_(char *, integer *, 
 	    integer *, real *, integer *, real *);
     extern /* Subroutine */ int xerbla_(char *, integer *), sgghrd_(
 	    char *, char *, integer *, integer *, integer *, real *, integer *
-	    , real *, integer *, real *, integer *, real *, integer *, 
+, real *, integer *, real *, integer *, real *, integer *, 
 	    integer *);
-    static logical ldumma[1];
-    static char chtemp[1];
-    static real bignum;
+    logical ldumma[1];
+    char chtemp[1];
+    real bignum;
     extern /* Subroutine */ int slascl_(char *, integer *, integer *, real *, 
 	    real *, integer *, integer *, real *, integer *, integer *);
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
-    static integer ijobvl, iright;
+	    integer *, integer *);
+    integer ijobvl, iright;
     extern /* Subroutine */ int sgeqrf_(integer *, integer *, real *, integer 
 	    *, real *, real *, integer *, integer *);
-    static integer ijobvr;
+    integer ijobvr;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), slaset_(char *, integer *, 
 	    integer *, real *, real *, real *, integer *), stgevc_(
 	    char *, char *, logical *, integer *, real *, integer *, real *, 
 	    integer *, real *, integer *, real *, integer *, integer *, 
 	    integer *, real *, integer *);
-    static real anrmto, bnrmto;
+    real anrmto, bnrmto;
     extern /* Subroutine */ int shgeqz_(char *, char *, char *, integer *, 
 	    integer *, integer *, real *, integer *, real *, integer *, real *
-	    , real *, real *, real *, integer *, real *, integer *, real *, 
+, real *, real *, real *, integer *, real *, integer *, real *, 
 	    integer *, integer *);
-    static integer minwrk, maxwrk;
-    static real smlnum;
+    integer minwrk, maxwrk;
+    real smlnum;
     extern /* Subroutine */ int sorgqr_(integer *, integer *, integer *, real 
 	    *, integer *, real *, real *, integer *, integer *);
-    static logical lquery;
+    logical lquery;
     extern /* Subroutine */ int sormqr_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, real *, integer *, real *, 
 	    integer *, integer *);
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SGGEV computes for a pair of N-by-N real nonsymmetric matrices (A,B) */
+/*  the generalized eigenvalues, and optionally, the left and/or right */
+/*  generalized eigenvectors. */
+
+/*  A generalized eigenvalue for a pair of matrices (A,B) is a scalar */
+/*  lambda or a ratio alpha/beta = lambda, such that A - lambda*B is */
+/*  singular. It is usually represented as the pair (alpha,beta), as */
+/*  there is a reasonable interpretation for beta=0, and even for both */
+/*  being zero. */
+
+/*  The right eigenvector v(j) corresponding to the eigenvalue lambda(j) */
+/*  of (A,B) satisfies */
+
+/*                   A * v(j) = lambda(j) * B * v(j). */
+
+/*  The left eigenvector u(j) corresponding to the eigenvalue lambda(j) */
+/*  of (A,B) satisfies */
+
+/*                   u(j)**H * A  = lambda(j) * u(j)**H * B . */
+
+/*  where u(j)**H is the conjugate-transpose of u(j). */
+
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the left generalized eigenvectors; */
+/*          = 'V':  compute the left generalized eigenvectors. */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the right generalized eigenvectors; */
+/*          = 'V':  compute the right generalized eigenvectors. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A, B, VL, and VR.  N >= 0. */
+
+/*  A       (input/output) REAL array, dimension (LDA, N) */
+/*          On entry, the matrix A in the pair (A,B). */
+/*          On exit, A has been overwritten. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A.  LDA >= max(1,N). */
+
+/*  B       (input/output) REAL array, dimension (LDB, N) */
+/*          On entry, the matrix B in the pair (A,B). */
+/*          On exit, B has been overwritten. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B.  LDB >= max(1,N). */
+
+/*  ALPHAR  (output) REAL array, dimension (N) */
+/*  ALPHAI  (output) REAL array, dimension (N) */
+/*  BETA    (output) REAL array, dimension (N) */
+/*          On exit, (ALPHAR(j) + ALPHAI(j)*i)/BETA(j), j=1,...,N, will */
+/*          be the generalized eigenvalues.  If ALPHAI(j) is zero, then */
+/*          the j-th eigenvalue is real; if positive, then the j-th and */
+/*          (j+1)-st eigenvalues are a complex conjugate pair, with */
+/*          ALPHAI(j+1) negative. */
+
+/*          Note: the quotients ALPHAR(j)/BETA(j) and ALPHAI(j)/BETA(j) */
+/*          may easily over- or underflow, and BETA(j) may even be zero. */
+/*          Thus, the user should avoid naively computing the ratio */
+/*          alpha/beta.  However, ALPHAR and ALPHAI will be always less */
+/*          than and usually comparable with norm(A) in magnitude, and */
+/*          BETA always less than and usually comparable with norm(B). */
+
+/*  VL      (output) REAL array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left eigenvectors u(j) are stored one */
+/*          after another in the columns of VL, in the same order as */
+/*          their eigenvalues. If the j-th eigenvalue is real, then */
+/*          u(j) = VL(:,j), the j-th column of VL. If the j-th and */
+/*          (j+1)-th eigenvalues form a complex conjugate pair, then */
+/*          u(j) = VL(:,j)+i*VL(:,j+1) and u(j+1) = VL(:,j)-i*VL(:,j+1). */
+/*          Each eigenvector is scaled so the largest component has */
+/*          abs(real part)+abs(imag. part)=1. */
+/*          Not referenced if JOBVL = 'N'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the matrix VL. LDVL >= 1, and */
+/*          if JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) REAL array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right eigenvectors v(j) are stored one */
+/*          after another in the columns of VR, in the same order as */
+/*          their eigenvalues. If the j-th eigenvalue is real, then */
+/*          v(j) = VR(:,j), the j-th column of VR. If the j-th and */
+/*          (j+1)-th eigenvalues form a complex conjugate pair, then */
+/*          v(j) = VR(:,j)+i*VR(:,j+1) and v(j+1) = VR(:,j)-i*VR(:,j+1). */
+/*          Each eigenvector is scaled so the largest component has */
+/*          abs(real part)+abs(imag. part)=1. */
+/*          Not referenced if JOBVR = 'N'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the matrix VR. LDVR >= 1, and */
+/*          if JOBVR = 'V', LDVR >= N. */
+
+/*  WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,8*N). */
+/*          For good performance, LWORK must generally be larger. */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          = 1,...,N: */
+/*                The QZ iteration failed.  No eigenvectors have been */
+/*                calculated, but ALPHAR(j), ALPHAI(j), and BETA(j) */
+/*                should be correct for j=INFO+1,...,N. */
+/*          > N:  =N+1: other than QZ iteration failed in SHGEQZ. */
+/*                =N+2: error return from STGEVC. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -268,13 +288,13 @@
 	*info = -14;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV. The workspace is   
-         computed assuming ILO = 1 and IHI = N, the worst case.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. The workspace is */
+/*       computed assuming ILO = 1 and IHI = N, the worst case.) */
 
     if (*info == 0) {
 /* Computing MAX */
@@ -282,16 +302,16 @@
 	minwrk = max(i__1,i__2);
 /* Computing MAX */
 	i__1 = 1, i__2 = *n * (ilaenv_(&c__1, "SGEQRF", " ", n, &c__1, n, &
-		c__0, (ftnlen)6, (ftnlen)1) + 7);
+		c__0) + 7);
 	maxwrk = max(i__1,i__2);
 /* Computing MAX */
-	i__1 = maxwrk, i__2 = *n * (ilaenv_(&c__1, "SORMQR", " ", n, &c__1, n,
-		 &c__0, (ftnlen)6, (ftnlen)1) + 7);
+	i__1 = maxwrk, i__2 = *n * (ilaenv_(&c__1, "SORMQR", " ", n, &c__1, n, 
+		 &c__0) + 7);
 	maxwrk = max(i__1,i__2);
 	if (ilvl) {
 /* Computing MAX */
 	    i__1 = maxwrk, i__2 = *n * (ilaenv_(&c__1, "SORGQR", " ", n, &
-		    c__1, n, &c_n1, (ftnlen)6, (ftnlen)1) + 7);
+		    c__1, n, &c_n1) + 7);
 	    maxwrk = max(i__1,i__2);
 	}
 	work[1] = (real) maxwrk;
@@ -356,8 +376,8 @@
 		ierr);
     }
 
-/*     Permute the matrices A, B to isolate eigenvalues if possible   
-       (Workspace: need 6*N) */
+/*     Permute the matrices A, B to isolate eigenvalues if possible */
+/*     (Workspace: need 6*N) */
 
     ileft = 1;
     iright = *n + 1;
@@ -365,8 +385,8 @@
     sggbal_("P", n, &a[a_offset], lda, &b[b_offset], ldb, &ilo, &ihi, &work[
 	    ileft], &work[iright], &work[iwrk], &ierr);
 
-/*     Reduce B to triangular form (QR decomposition of B)   
-       (Workspace: need N, prefer N*NB) */
+/*     Reduce B to triangular form (QR decomposition of B) */
+/*     (Workspace: need N, prefer N*NB) */
 
     irows = ihi + 1 - ilo;
     if (ilv) {
@@ -380,16 +400,16 @@
     sgeqrf_(&irows, &icols, &b[ilo + ilo * b_dim1], ldb, &work[itau], &work[
 	    iwrk], &i__1, &ierr);
 
-/*     Apply the orthogonal transformation to matrix A   
-       (Workspace: need N, prefer N*NB) */
+/*     Apply the orthogonal transformation to matrix A */
+/*     (Workspace: need N, prefer N*NB) */
 
     i__1 = *lwork + 1 - iwrk;
     sormqr_("L", "T", &irows, &icols, &irows, &b[ilo + ilo * b_dim1], ldb, &
 	    work[itau], &a[ilo + ilo * a_dim1], lda, &work[iwrk], &i__1, &
 	    ierr);
 
-/*     Initialize VL   
-       (Workspace: need N, prefer N*NB) */
+/*     Initialize VL */
+/*     (Workspace: need N, prefer N*NB) */
 
     if (ilvl) {
 	slaset_("Full", n, n, &c_b36, &c_b37, &vl[vl_offset], ldvl)
@@ -412,8 +432,8 @@
 		;
     }
 
-/*     Reduce to generalized Hessenberg form   
-       (Workspace: none needed) */
+/*     Reduce to generalized Hessenberg form */
+/*     (Workspace: none needed) */
 
     if (ilv) {
 
@@ -427,9 +447,9 @@
 		vr_offset], ldvr, &ierr);
     }
 
-/*     Perform QZ algorithm (Compute eigenvalues, and optionally, the   
-       Schur forms and Schur vectors)   
-       (Workspace: need N) */
+/*     Perform QZ algorithm (Compute eigenvalues, and optionally, the */
+/*     Schur forms and Schur vectors) */
+/*     (Workspace: need N) */
 
     iwrk = itau;
     if (ilv) {
@@ -452,8 +472,8 @@
 	goto L110;
     }
 
-/*     Compute Eigenvectors   
-       (Workspace: need 6*N) */
+/*     Compute Eigenvectors */
+/*     (Workspace: need 6*N) */
 
     if (ilv) {
 	if (ilvl) {
@@ -473,8 +493,8 @@
 	    goto L110;
 	}
 
-/*        Undo balancing on VL and VR and normalization   
-          (Workspace: none needed) */
+/*        Undo balancing on VL and VR and normalization */
+/*        (Workspace: none needed) */
 
 	if (ilvl) {
 	    sggbak_("P", "L", n, &ilo, &ihi, &work[ileft], &work[iright], n, &
