@@ -1,278 +1,298 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static real c_b12 = 0.f;
+static real c_b13 = 1.f;
+static integer c__1 = 1;
+static integer c__3 = 3;
 
 /* Subroutine */ int shgeqz_(char *job, char *compq, char *compz, integer *n, 
 	integer *ilo, integer *ihi, real *h__, integer *ldh, real *t, integer 
 	*ldt, real *alphar, real *alphai, real *beta, real *q, integer *ldq, 
 	real *z__, integer *ldz, real *work, integer *lwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SHGEQZ computes the eigenvalues of a real matrix pair (H,T),   
-    where H is an upper Hessenberg matrix and T is upper triangular,   
-    using the double-shift QZ method.   
-    Matrix pairs of this type are produced by the reduction to   
-    generalized upper Hessenberg form of a real matrix pair (A,B):   
-
-       A = Q1*H*Z1**T,  B = Q1*T*Z1**T,   
-
-    as computed by SGGHRD.   
-
-    If JOB='S', then the Hessenberg-triangular pair (H,T) is   
-    also reduced to generalized Schur form,   
-
-       H = Q*S*Z**T,  T = Q*P*Z**T,   
-
-    where Q and Z are orthogonal matrices, P is an upper triangular   
-    matrix, and S is a quasi-triangular matrix with 1-by-1 and 2-by-2   
-    diagonal blocks.   
-
-    The 1-by-1 blocks correspond to real eigenvalues of the matrix pair   
-    (H,T) and the 2-by-2 blocks correspond to complex conjugate pairs of   
-    eigenvalues.   
-
-    Additionally, the 2-by-2 upper triangular diagonal blocks of P   
-    corresponding to 2-by-2 blocks of S are reduced to positive diagonal   
-    form, i.e., if S(j+1,j) is non-zero, then P(j+1,j) = P(j,j+1) = 0,   
-    P(j,j) > 0, and P(j+1,j+1) > 0.   
-
-    Optionally, the orthogonal matrix Q from the generalized Schur   
-    factorization may be postmultiplied into an input matrix Q1, and the   
-    orthogonal matrix Z may be postmultiplied into an input matrix Z1.   
-    If Q1 and Z1 are the orthogonal matrices from SGGHRD that reduced   
-    the matrix pair (A,B) to generalized upper Hessenberg form, then the   
-    output matrices Q1*Q and Z1*Z are the orthogonal factors from the   
-    generalized Schur factorization of (A,B):   
-
-       A = (Q1*Q)*S*(Z1*Z)**T,  B = (Q1*Q)*P*(Z1*Z)**T.   
-
-    To avoid overflow, eigenvalues of the matrix pair (H,T) (equivalently,   
-    of (A,B)) are computed as a pair of values (alpha,beta), where alpha is   
-    complex and beta real.   
-    If beta is nonzero, lambda = alpha / beta is an eigenvalue of the   
-    generalized nonsymmetric eigenvalue problem (GNEP)   
-       A*x = lambda*B*x   
-    and if alpha is nonzero, mu = beta / alpha is an eigenvalue of the   
-    alternate form of the GNEP   
-       mu*A*y = B*y.   
-    Real eigenvalues can be read directly from the generalized Schur   
-    form:   
-      alpha = S(i,i), beta = P(i,i).   
-
-    Ref: C.B. Moler & G.W. Stewart, "An Algorithm for Generalized Matrix   
-         Eigenvalue Problems", SIAM J. Numer. Anal., 10(1973),   
-         pp. 241--256.   
-
-    Arguments   
-    =========   
-
-    JOB     (input) CHARACTER*1   
-            = 'E': Compute eigenvalues only;   
-            = 'S': Compute eigenvalues and the Schur form.   
-
-    COMPQ   (input) CHARACTER*1   
-            = 'N': Left Schur vectors (Q) are not computed;   
-            = 'I': Q is initialized to the unit matrix and the matrix Q   
-                   of left Schur vectors of (H,T) is returned;   
-            = 'V': Q must contain an orthogonal matrix Q1 on entry and   
-                   the product Q1*Q is returned.   
-
-    COMPZ   (input) CHARACTER*1   
-            = 'N': Right Schur vectors (Z) are not computed;   
-            = 'I': Z is initialized to the unit matrix and the matrix Z   
-                   of right Schur vectors of (H,T) is returned;   
-            = 'V': Z must contain an orthogonal matrix Z1 on entry and   
-                   the product Z1*Z is returned.   
-
-    N       (input) INTEGER   
-            The order of the matrices H, T, Q, and Z.  N >= 0.   
-
-    ILO     (input) INTEGER   
-    IHI     (input) INTEGER   
-            ILO and IHI mark the rows and columns of H which are in   
-            Hessenberg form.  It is assumed that A is already upper   
-            triangular in rows and columns 1:ILO-1 and IHI+1:N.   
-            If N > 0, 1 <= ILO <= IHI <= N; if N = 0, ILO=1 and IHI=0.   
-
-    H       (input/output) REAL array, dimension (LDH, N)   
-            On entry, the N-by-N upper Hessenberg matrix H.   
-            On exit, if JOB = 'S', H contains the upper quasi-triangular   
-            matrix S from the generalized Schur factorization;   
-            2-by-2 diagonal blocks (corresponding to complex conjugate   
-            pairs of eigenvalues) are returned in standard form, with   
-            H(i,i) = H(i+1,i+1) and H(i+1,i)*H(i,i+1) < 0.   
-            If JOB = 'E', the diagonal blocks of H match those of S, but   
-            the rest of H is unspecified.   
-
-    LDH     (input) INTEGER   
-            The leading dimension of the array H.  LDH >= max( 1, N ).   
-
-    T       (input/output) REAL array, dimension (LDT, N)   
-            On entry, the N-by-N upper triangular matrix T.   
-            On exit, if JOB = 'S', T contains the upper triangular   
-            matrix P from the generalized Schur factorization;   
-            2-by-2 diagonal blocks of P corresponding to 2-by-2 blocks of S   
-            are reduced to positive diagonal form, i.e., if H(j+1,j) is   
-            non-zero, then T(j+1,j) = T(j,j+1) = 0, T(j,j) > 0, and   
-            T(j+1,j+1) > 0.   
-            If JOB = 'E', the diagonal blocks of T match those of P, but   
-            the rest of T is unspecified.   
-
-    LDT     (input) INTEGER   
-            The leading dimension of the array T.  LDT >= max( 1, N ).   
-
-    ALPHAR  (output) REAL array, dimension (N)   
-            The real parts of each scalar alpha defining an eigenvalue   
-            of GNEP.   
-
-    ALPHAI  (output) REAL array, dimension (N)   
-            The imaginary parts of each scalar alpha defining an   
-            eigenvalue of GNEP.   
-            If ALPHAI(j) is zero, then the j-th eigenvalue is real; if   
-            positive, then the j-th and (j+1)-st eigenvalues are a   
-            complex conjugate pair, with ALPHAI(j+1) = -ALPHAI(j).   
-
-    BETA    (output) REAL array, dimension (N)   
-            The scalars beta that define the eigenvalues of GNEP.   
-            Together, the quantities alpha = (ALPHAR(j),ALPHAI(j)) and   
-            beta = BETA(j) represent the j-th eigenvalue of the matrix   
-            pair (A,B), in one of the forms lambda = alpha/beta or   
-            mu = beta/alpha.  Since either lambda or mu may overflow,   
-            they should not, in general, be computed.   
-
-    Q       (input/output) REAL array, dimension (LDQ, N)   
-            On entry, if COMPZ = 'V', the orthogonal matrix Q1 used in   
-            the reduction of (A,B) to generalized Hessenberg form.   
-            On exit, if COMPZ = 'I', the orthogonal matrix of left Schur   
-            vectors of (H,T), and if COMPZ = 'V', the orthogonal matrix   
-            of left Schur vectors of (A,B).   
-            Not referenced if COMPZ = 'N'.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of the array Q.  LDQ >= 1.   
-            If COMPQ='V' or 'I', then LDQ >= N.   
-
-    Z       (input/output) REAL array, dimension (LDZ, N)   
-            On entry, if COMPZ = 'V', the orthogonal matrix Z1 used in   
-            the reduction of (A,B) to generalized Hessenberg form.   
-            On exit, if COMPZ = 'I', the orthogonal matrix of   
-            right Schur vectors of (H,T), and if COMPZ = 'V', the   
-            orthogonal matrix of right Schur vectors of (A,B).   
-            Not referenced if COMPZ = 'N'.   
-
-    LDZ     (input) INTEGER   
-            The leading dimension of the array Z.  LDZ >= 1.   
-            If COMPZ='V' or 'I', then LDZ >= N.   
-
-    WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK))   
-            On exit, if INFO >= 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,N).   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            < 0: if INFO = -i, the i-th argument had an illegal value   
-            = 1,...,N: the QZ iteration did not converge.  (H,T) is not   
-                       in Schur form, but ALPHAR(i), ALPHAI(i), and   
-                       BETA(i), i=INFO+1,...,N should be correct.   
-            = N+1,...,2*N: the shift calculation failed.  (H,T) is not   
-                       in Schur form, but ALPHAR(i), ALPHAI(i), and   
-                       BETA(i), i=INFO-N+1,...,N should be correct.   
-
-    Further Details   
-    ===============   
-
-    Iteration counters:   
-
-    JITER  -- counts iterations.   
-    IITER  -- counts iterations run since ILAST was last   
-              changed.  This is therefore reset only when a 1-by-1 or   
-              2-by-2 block deflates off the bottom.   
-
-    =====================================================================   
-
-      $                     SAFETY = 1.0E+0 )   
-
-       Decode JOB, COMPQ, COMPZ   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static real c_b12 = 0.f;
-    static real c_b13 = 1.f;
-    static integer c__1 = 1;
-    static integer c__3 = 3;
-    
     /* System generated locals */
     integer h_dim1, h_offset, q_dim1, q_offset, t_dim1, t_offset, z_dim1, 
 	    z_offset, i__1, i__2, i__3, i__4;
     real r__1, r__2, r__3, r__4;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static real c__;
-    static integer j;
-    static real s, v[3], s1, s2, t1, u1, u2, a11, a12, a21, a22, b11, b22, 
-	    c12, c21;
-    static integer jc;
-    static real an, bn, cl, cq, cr;
-    static integer in;
-    static real u12, w11, w12, w21;
-    static integer jr;
-    static real cz, w22, sl, wi, sr, vs, wr, b1a, b2a, a1i, a2i, b1i, b2i, 
-	    a1r, a2r, b1r, b2r, wr2, ad11, ad12, ad21, ad22, c11i, c22i;
-    static integer jch;
-    static real c11r, c22r;
-    static logical ilq;
-    static real u12l, tau, sqi;
-    static logical ilz;
-    static real ulp, sqr, szi, szr, ad11l, ad12l, ad21l, ad22l, ad32l, wabs, 
-	    atol, btol, temp;
+    real c__;
+    integer j;
+    real s, v[3], s1, s2, t1, u1, u2, a11, a12, a21, a22, b11, b22, c12, c21;
+    integer jc;
+    real an, bn, cl, cq, cr;
+    integer in;
+    real u12, w11, w12, w21;
+    integer jr;
+    real cz, w22, sl, wi, sr, vs, wr, b1a, b2a, a1i, a2i, b1i, b2i, a1r, a2r, 
+	    b1r, b2r, wr2, ad11, ad12, ad21, ad22, c11i, c22i;
+    integer jch;
+    real c11r, c22r;
+    logical ilq;
+    real u12l, tau, sqi;
+    logical ilz;
+    real ulp, sqr, szi, szr, ad11l, ad12l, ad21l, ad22l, ad32l, wabs, atol, 
+	    btol, temp;
     extern /* Subroutine */ int srot_(integer *, real *, integer *, real *, 
 	    integer *, real *, real *), slag2_(real *, integer *, real *, 
 	    integer *, real *, real *, real *, real *, real *, real *);
-    static real temp2, s1inv, scale;
+    real temp2, s1inv, scale;
     extern logical lsame_(char *, char *);
-    static integer iiter, ilast, jiter;
-    static real anorm, bnorm;
-    static integer maxit;
-    static real tempi, tempr;
-    static logical ilazr2;
+    integer iiter, ilast, jiter;
+    real anorm, bnorm;
+    integer maxit;
+    real tempi, tempr;
+    logical ilazr2;
     extern doublereal slapy2_(real *, real *), slapy3_(real *, real *, real *)
 	    ;
     extern /* Subroutine */ int slasv2_(real *, real *, real *, real *, real *
-	    , real *, real *, real *, real *);
-    static real ascale, bscale;
+, real *, real *, real *, real *);
+    real ascale, bscale;
     extern doublereal slamch_(char *);
-    static real safmin;
+    real safmin;
     extern /* Subroutine */ int slarfg_(integer *, real *, real *, integer *, 
 	    real *);
-    static real safmax;
+    real safmax;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static real eshift;
-    static logical ilschr;
-    static integer icompq, ilastm;
+    real eshift;
+    logical ilschr;
+    integer icompq, ilastm;
     extern doublereal slanhs_(char *, integer *, real *, integer *, real *);
-    extern /* Subroutine */ int slartg_(real *, real *, real *, real *, real * );
-    static integer ischur;
+    extern /* Subroutine */ int slartg_(real *, real *, real *, real *, real *
+);
+    integer ischur;
     extern /* Subroutine */ int slaset_(char *, integer *, integer *, real *, 
 	    real *, real *, integer *);
-    static logical ilazro;
-    static integer icompz, ifirst, ifrstm, istart;
-    static logical ilpivt, lquery;
+    logical ilazro;
+    integer icompz, ifirst, ifrstm, istart;
+    logical ilpivt, lquery;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SHGEQZ computes the eigenvalues of a real matrix pair (H,T), */
+/*  where H is an upper Hessenberg matrix and T is upper triangular, */
+/*  using the double-shift QZ method. */
+/*  Matrix pairs of this type are produced by the reduction to */
+/*  generalized upper Hessenberg form of a real matrix pair (A,B): */
+
+/*     A = Q1*H*Z1**T,  B = Q1*T*Z1**T, */
+
+/*  as computed by SGGHRD. */
+
+/*  If JOB='S', then the Hessenberg-triangular pair (H,T) is */
+/*  also reduced to generalized Schur form, */
+
+/*     H = Q*S*Z**T,  T = Q*P*Z**T, */
+
+/*  where Q and Z are orthogonal matrices, P is an upper triangular */
+/*  matrix, and S is a quasi-triangular matrix with 1-by-1 and 2-by-2 */
+/*  diagonal blocks. */
+
+/*  The 1-by-1 blocks correspond to real eigenvalues of the matrix pair */
+/*  (H,T) and the 2-by-2 blocks correspond to complex conjugate pairs of */
+/*  eigenvalues. */
+
+/*  Additionally, the 2-by-2 upper triangular diagonal blocks of P */
+/*  corresponding to 2-by-2 blocks of S are reduced to positive diagonal */
+/*  form, i.e., if S(j+1,j) is non-zero, then P(j+1,j) = P(j,j+1) = 0, */
+/*  P(j,j) > 0, and P(j+1,j+1) > 0. */
+
+/*  Optionally, the orthogonal matrix Q from the generalized Schur */
+/*  factorization may be postmultiplied into an input matrix Q1, and the */
+/*  orthogonal matrix Z may be postmultiplied into an input matrix Z1. */
+/*  If Q1 and Z1 are the orthogonal matrices from SGGHRD that reduced */
+/*  the matrix pair (A,B) to generalized upper Hessenberg form, then the */
+/*  output matrices Q1*Q and Z1*Z are the orthogonal factors from the */
+/*  generalized Schur factorization of (A,B): */
+
+/*     A = (Q1*Q)*S*(Z1*Z)**T,  B = (Q1*Q)*P*(Z1*Z)**T. */
+
+/*  To avoid overflow, eigenvalues of the matrix pair (H,T) (equivalently, */
+/*  of (A,B)) are computed as a pair of values (alpha,beta), where alpha is */
+/*  complex and beta real. */
+/*  If beta is nonzero, lambda = alpha / beta is an eigenvalue of the */
+/*  generalized nonsymmetric eigenvalue problem (GNEP) */
+/*     A*x = lambda*B*x */
+/*  and if alpha is nonzero, mu = beta / alpha is an eigenvalue of the */
+/*  alternate form of the GNEP */
+/*     mu*A*y = B*y. */
+/*  Real eigenvalues can be read directly from the generalized Schur */
+/*  form: */
+/*    alpha = S(i,i), beta = P(i,i). */
+
+/*  Ref: C.B. Moler & G.W. Stewart, "An Algorithm for Generalized Matrix */
+/*       Eigenvalue Problems", SIAM J. Numer. Anal., 10(1973), */
+/*       pp. 241--256. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOB     (input) CHARACTER*1 */
+/*          = 'E': Compute eigenvalues only; */
+/*          = 'S': Compute eigenvalues and the Schur form. */
+
+/*  COMPQ   (input) CHARACTER*1 */
+/*          = 'N': Left Schur vectors (Q) are not computed; */
+/*          = 'I': Q is initialized to the unit matrix and the matrix Q */
+/*                 of left Schur vectors of (H,T) is returned; */
+/*          = 'V': Q must contain an orthogonal matrix Q1 on entry and */
+/*                 the product Q1*Q is returned. */
+
+/*  COMPZ   (input) CHARACTER*1 */
+/*          = 'N': Right Schur vectors (Z) are not computed; */
+/*          = 'I': Z is initialized to the unit matrix and the matrix Z */
+/*                 of right Schur vectors of (H,T) is returned; */
+/*          = 'V': Z must contain an orthogonal matrix Z1 on entry and */
+/*                 the product Z1*Z is returned. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices H, T, Q, and Z.  N >= 0. */
+
+/*  ILO     (input) INTEGER */
+/*  IHI     (input) INTEGER */
+/*          ILO and IHI mark the rows and columns of H which are in */
+/*          Hessenberg form.  It is assumed that A is already upper */
+/*          triangular in rows and columns 1:ILO-1 and IHI+1:N. */
+/*          If N > 0, 1 <= ILO <= IHI <= N; if N = 0, ILO=1 and IHI=0. */
+
+/*  H       (input/output) REAL array, dimension (LDH, N) */
+/*          On entry, the N-by-N upper Hessenberg matrix H. */
+/*          On exit, if JOB = 'S', H contains the upper quasi-triangular */
+/*          matrix S from the generalized Schur factorization; */
+/*          2-by-2 diagonal blocks (corresponding to complex conjugate */
+/*          pairs of eigenvalues) are returned in standard form, with */
+/*          H(i,i) = H(i+1,i+1) and H(i+1,i)*H(i,i+1) < 0. */
+/*          If JOB = 'E', the diagonal blocks of H match those of S, but */
+/*          the rest of H is unspecified. */
+
+/*  LDH     (input) INTEGER */
+/*          The leading dimension of the array H.  LDH >= max( 1, N ). */
+
+/*  T       (input/output) REAL array, dimension (LDT, N) */
+/*          On entry, the N-by-N upper triangular matrix T. */
+/*          On exit, if JOB = 'S', T contains the upper triangular */
+/*          matrix P from the generalized Schur factorization; */
+/*          2-by-2 diagonal blocks of P corresponding to 2-by-2 blocks of S */
+/*          are reduced to positive diagonal form, i.e., if H(j+1,j) is */
+/*          non-zero, then T(j+1,j) = T(j,j+1) = 0, T(j,j) > 0, and */
+/*          T(j+1,j+1) > 0. */
+/*          If JOB = 'E', the diagonal blocks of T match those of P, but */
+/*          the rest of T is unspecified. */
+
+/*  LDT     (input) INTEGER */
+/*          The leading dimension of the array T.  LDT >= max( 1, N ). */
+
+/*  ALPHAR  (output) REAL array, dimension (N) */
+/*          The real parts of each scalar alpha defining an eigenvalue */
+/*          of GNEP. */
+
+/*  ALPHAI  (output) REAL array, dimension (N) */
+/*          The imaginary parts of each scalar alpha defining an */
+/*          eigenvalue of GNEP. */
+/*          If ALPHAI(j) is zero, then the j-th eigenvalue is real; if */
+/*          positive, then the j-th and (j+1)-st eigenvalues are a */
+/*          complex conjugate pair, with ALPHAI(j+1) = -ALPHAI(j). */
+
+/*  BETA    (output) REAL array, dimension (N) */
+/*          The scalars beta that define the eigenvalues of GNEP. */
+/*          Together, the quantities alpha = (ALPHAR(j),ALPHAI(j)) and */
+/*          beta = BETA(j) represent the j-th eigenvalue of the matrix */
+/*          pair (A,B), in one of the forms lambda = alpha/beta or */
+/*          mu = beta/alpha.  Since either lambda or mu may overflow, */
+/*          they should not, in general, be computed. */
+
+/*  Q       (input/output) REAL array, dimension (LDQ, N) */
+/*          On entry, if COMPZ = 'V', the orthogonal matrix Q1 used in */
+/*          the reduction of (A,B) to generalized Hessenberg form. */
+/*          On exit, if COMPZ = 'I', the orthogonal matrix of left Schur */
+/*          vectors of (H,T), and if COMPZ = 'V', the orthogonal matrix */
+/*          of left Schur vectors of (A,B). */
+/*          Not referenced if COMPZ = 'N'. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of the array Q.  LDQ >= 1. */
+/*          If COMPQ='V' or 'I', then LDQ >= N. */
+
+/*  Z       (input/output) REAL array, dimension (LDZ, N) */
+/*          On entry, if COMPZ = 'V', the orthogonal matrix Z1 used in */
+/*          the reduction of (A,B) to generalized Hessenberg form. */
+/*          On exit, if COMPZ = 'I', the orthogonal matrix of */
+/*          right Schur vectors of (H,T), and if COMPZ = 'V', the */
+/*          orthogonal matrix of right Schur vectors of (A,B). */
+/*          Not referenced if COMPZ = 'N'. */
+
+/*  LDZ     (input) INTEGER */
+/*          The leading dimension of the array Z.  LDZ >= 1. */
+/*          If COMPZ='V' or 'I', then LDZ >= N. */
+
+/*  WORK    (workspace/output) REAL array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO >= 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,N). */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          < 0: if INFO = -i, the i-th argument had an illegal value */
+/*          = 1,...,N: the QZ iteration did not converge.  (H,T) is not */
+/*                     in Schur form, but ALPHAR(i), ALPHAI(i), and */
+/*                     BETA(i), i=INFO+1,...,N should be correct. */
+/*          = N+1,...,2*N: the shift calculation failed.  (H,T) is not */
+/*                     in Schur form, but ALPHAR(i), ALPHAI(i), and */
+/*                     BETA(i), i=INFO-N+1,...,N should be correct. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Iteration counters: */
+
+/*  JITER  -- counts iterations. */
+/*  IITER  -- counts iterations run since ILAST was last */
+/*            changed.  This is therefore reset only when a 1-by-1 or */
+/*            2-by-2 block deflates off the bottom. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*    $                     SAFETY = 1.0E+0 ) */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode JOB, COMPQ, COMPZ */
+
+    /* Parameter adjustments */
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
     h__ -= h_offset;
@@ -432,20 +452,20 @@
 	goto L380;
     }
 
-/*     MAIN QZ ITERATION LOOP   
+/*     MAIN QZ ITERATION LOOP */
 
-       Initialize dynamic indices   
+/*     Initialize dynamic indices */
 
-       Eigenvalues ILAST+1:N have been found.   
-          Column operations modify rows IFRSTM:whatever.   
-          Row operations modify columns whatever:ILASTM.   
+/*     Eigenvalues ILAST+1:N have been found. */
+/*        Column operations modify rows IFRSTM:whatever. */
+/*        Row operations modify columns whatever:ILASTM. */
 
-       If only eigenvalues are being computed, then   
-          IFRSTM is the row of the last splitting row above row ILAST;   
-          this is always at least ILO.   
-       IITER counts iterations since the last eigenvalue was found,   
-          to tell when to use an extraordinary shift.   
-       MAXIT is the maximum number of QZ sweeps allowed. */
+/*     If only eigenvalues are being computed, then */
+/*        IFRSTM is the row of the last splitting row above row ILAST; */
+/*        this is always at least ILO. */
+/*     IITER counts iterations since the last eigenvalue was found, */
+/*        to tell when to use an extraordinary shift. */
+/*     MAXIT is the maximum number of QZ sweeps allowed. */
 
     ilast = *ihi;
     if (ilschr) {
@@ -462,11 +482,11 @@
     i__1 = maxit;
     for (jiter = 1; jiter <= i__1; ++jiter) {
 
-/*        Split the matrix if possible.   
+/*        Split the matrix if possible. */
 
-          Two tests:   
-             1: H(j,j-1)=0  or  j=ILO   
-             2: T(j,j)=0 */
+/*        Two tests: */
+/*           1: H(j,j-1)=0  or  j=ILO */
+/*           2: T(j,j)=0 */
 
 	if (ilast == *ilo) {
 
@@ -526,17 +546,17 @@
 		    }
 		}
 
-/*              If both tests pass (1 & 2), i.e., the leading diagonal   
-                element of B in the block is zero, split a 1x1 block off   
-                at the top. (I.e., at the J-th row/column) The leading   
-                diagonal element of the remainder can also be zero, so   
-                this may have to be done repeatedly. */
+/*              If both tests pass (1 & 2), i.e., the leading diagonal */
+/*              element of B in the block is zero, split a 1x1 block off */
+/*              at the top. (I.e., at the J-th row/column) The leading */
+/*              diagonal element of the remainder can also be zero, so */
+/*              this may have to be done repeatedly. */
 
 		if (ilazro || ilazr2) {
 		    i__3 = ilast - 1;
 		    for (jch = j; jch <= i__3; ++jch) {
 			temp = h__[jch + jch * h_dim1];
-			slartg_(&temp, &h__[jch + 1 + jch * h_dim1], &c__, &s,
+			slartg_(&temp, &h__[jch + 1 + jch * h_dim1], &c__, &s, 
 				 &h__[jch + jch * h_dim1]);
 			h__[jch + 1 + jch * h_dim1] = 0.f;
 			i__4 = ilastm - jch;
@@ -569,13 +589,13 @@
 		    goto L70;
 		} else {
 
-/*                 Only test 2 passed -- chase the zero to T(ILAST,ILAST)   
-                   Then process as in the case T(ILAST,ILAST)=0 */
+/*                 Only test 2 passed -- chase the zero to T(ILAST,ILAST) */
+/*                 Then process as in the case T(ILAST,ILAST)=0 */
 
 		    i__3 = ilast - 1;
 		    for (jch = j; jch <= i__3; ++jch) {
 			temp = t[jch + (jch + 1) * t_dim1];
-			slartg_(&temp, &t[jch + 1 + (jch + 1) * t_dim1], &c__,
+			slartg_(&temp, &t[jch + 1 + (jch + 1) * t_dim1], &c__, 
 				 &s, &t[jch + (jch + 1) * t_dim1]);
 			t[jch + 1 + (jch + 1) * t_dim1] = 0.f;
 			if (jch < ilastm - 1) {
@@ -620,9 +640,9 @@
 		goto L110;
 	    }
 
-/*           Neither test passed -- try next J   
+/*           Neither test passed -- try next J */
 
-   L60: */
+/* L60: */
 	}
 
 /*        (Drop-through is "impossible") */
@@ -630,8 +650,8 @@
 	*info = *n + 1;
 	goto L420;
 
-/*        T(ILAST,ILAST)=0 -- clear H(ILAST,ILAST-1) to split off a   
-          1x1 block. */
+/*        T(ILAST,ILAST)=0 -- clear H(ILAST,ILAST-1) to split off a */
+/*        1x1 block. */
 
 L70:
 	temp = h__[ilast + ilast * h_dim1];
@@ -649,8 +669,8 @@ L70:
 		    z_dim1 + 1], &c__1, &c__, &s);
 	}
 
-/*        H(ILAST,ILAST-1)=0 -- Standardize B, set ALPHAR, ALPHAI,   
-                                and BETA */
+/*        H(ILAST,ILAST-1)=0 -- Standardize B, set ALPHAR, ALPHAI, */
+/*                              and BETA */
 
 L80:
 	if (t[ilast + ilast * t_dim1] < 0.f) {
@@ -696,10 +716,10 @@ L80:
 	}
 	goto L350;
 
-/*        QZ step   
+/*        QZ step */
 
-          This iteration only involves rows/columns IFIRST:ILAST. We   
-          assume IFIRST < ILAST, and that the diagonal of B is non-zero. */
+/*        This iteration only involves rows/columns IFIRST:ILAST. We */
+/*        assume IFIRST < ILAST, and that the diagonal of B is non-zero. */
 
 L110:
 	++iiter;
@@ -707,16 +727,16 @@ L110:
 	    ifrstm = ifirst;
 	}
 
-/*        Compute single shifts.   
+/*        Compute single shifts. */
 
-          At this point, IFIRST < ILAST, and the diagonal elements of   
-          T(IFIRST:ILAST,IFIRST,ILAST) are larger than BTOL (in   
-          magnitude) */
+/*        At this point, IFIRST < ILAST, and the diagonal elements of */
+/*        T(IFIRST:ILAST,IFIRST,ILAST) are larger than BTOL (in */
+/*        magnitude) */
 
 	if (iiter / 10 * 10 == iiter) {
 
-/*           Exceptional shift.  Chosen for no particularly good reason.   
-             (Single shift only.) */
+/*           Exceptional shift.  Chosen for no particularly good reason. */
+/*           (Single shift only.) */
 
 	    if ((real) maxit * safmin * (r__1 = h__[ilast - 1 + ilast * 
 		    h_dim1], dabs(r__1)) < (r__2 = t[ilast - 1 + (ilast - 1) *
@@ -731,17 +751,17 @@ L110:
 
 	} else {
 
-/*           Shifts based on the generalized eigenvalues of the   
-             bottom-right 2x2 block of A and B. The first eigenvalue   
-             returned by SLAG2 is the Wilkinson shift (AEP p.512), */
+/*           Shifts based on the generalized eigenvalues of the */
+/*           bottom-right 2x2 block of A and B. The first eigenvalue */
+/*           returned by SLAG2 is the Wilkinson shift (AEP p.512), */
 
 	    r__1 = safmin * 100.f;
 	    slag2_(&h__[ilast - 1 + (ilast - 1) * h_dim1], ldh, &t[ilast - 1 
 		    + (ilast - 1) * t_dim1], ldt, &r__1, &s1, &s2, &wr, &wr2, 
 		    &wi);
 
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    r__3 = 1.f, r__4 = dabs(wr), r__3 = max(r__3,r__4), r__4 = dabs(
 		    wi);
 	    r__1 = s1, r__2 = safmin * dmax(r__3,r__4);
@@ -792,9 +812,9 @@ L110:
 	istart = ifirst;
 L130:
 
-/*        Do an implicit single-shift QZ sweep.   
+/*        Do an implicit single-shift QZ sweep. */
 
-          Initial Q */
+/*        Initial Q */
 
 	temp = s1 * h__[istart + istart * h_dim1] - wr * t[istart + istart * 
 		t_dim1];
@@ -878,23 +898,23 @@ L130:
 
 	goto L350;
 
-/*        Use Francis double-shift   
+/*        Use Francis double-shift */
 
-          Note: the Francis double-shift should work with real shifts,   
-                but only if the block is at least 3x3.   
-                This code may break if this point is reached with   
-                a 2x2 block with real eigenvalues. */
+/*        Note: the Francis double-shift should work with real shifts, */
+/*              but only if the block is at least 3x3. */
+/*              This code may break if this point is reached with */
+/*              a 2x2 block with real eigenvalues. */
 
 L200:
 	if (ifirst + 1 == ilast) {
 
-/*           Special case -- 2x2 block with complex eigenvectors   
+/*           Special case -- 2x2 block with complex eigenvectors */
 
-             Step 1: Standardize, that is, rotate so that   
+/*           Step 1: Standardize, that is, rotate so that */
 
-                         ( B11  0  )   
-                     B = (         )  with B11 non-negative.   
-                         (  0  B22 ) */
+/*                       ( B11  0  ) */
+/*                   B = (         )  with B11 non-negative. */
+/*                       (  0  B22 ) */
 
 	    slasv2_(&t[ilast - 1 + (ilast - 1) * t_dim1], &t[ilast - 1 + 
 		    ilast * t_dim1], &t[ilast + ilast * t_dim1], &b22, &b11, &
@@ -958,17 +978,17 @@ L200:
 		}
 	    }
 
-/*           Step 2: Compute ALPHAR, ALPHAI, and BETA (see refs.)   
+/*           Step 2: Compute ALPHAR, ALPHAI, and BETA (see refs.) */
 
-             Recompute shift */
+/*           Recompute shift */
 
 	    r__1 = safmin * 100.f;
 	    slag2_(&h__[ilast - 1 + (ilast - 1) * h_dim1], ldh, &t[ilast - 1 
 		    + (ilast - 1) * t_dim1], ldt, &r__1, &s1, &temp, &wr, &
 		    temp2, &wi);
 
-/*           If standardization has perturbed the shift onto real line,   
-             do another (real single-shift) QR step. */
+/*           If standardization has perturbed the shift onto real line, */
+/*           do another (real single-shift) QR step. */
 
 	    if (wi == 0.f) {
 		goto L350;
@@ -982,11 +1002,11 @@ L200:
 	    a12 = h__[ilast - 1 + ilast * h_dim1];
 	    a22 = h__[ilast + ilast * h_dim1];
 
-/*           Compute complex Givens rotation on right   
-             (Assume some element of C = (sA - wB) > unfl )   
-                              __   
-             (sA - wB) ( CZ   -SZ )   
-                       ( SZ    CZ ) */
+/*           Compute complex Givens rotation on right */
+/*           (Assume some element of C = (sA - wB) > unfl ) */
+/*                            __ */
+/*           (sA - wB) ( CZ   -SZ ) */
+/*                     ( SZ    CZ ) */
 
 	    c11r = s1 * a11 - wr * b11;
 	    c11i = -wi * b11;
@@ -1017,11 +1037,11 @@ L200:
 		}
 	    }
 
-/*           Compute Givens rotation on left   
+/*           Compute Givens rotation on left */
 
-             (  CQ   SQ )   
-             (  __      )  A or B   
-             ( -SQ   CQ ) */
+/*           (  CQ   SQ ) */
+/*           (  __      )  A or B */
+/*           ( -SQ   CQ ) */
 
 	    an = dabs(a11) + dabs(a12) + dabs(a21) + dabs(a22);
 	    bn = dabs(b11) + dabs(b22);
@@ -1092,17 +1112,17 @@ L200:
 	    goto L350;
 	} else {
 
-/*           Usual case: 3x3 or larger block, using Francis implicit   
-                         double-shift   
+/*           Usual case: 3x3 or larger block, using Francis implicit */
+/*                       double-shift */
 
-                                      2   
-             Eigenvalue equation is  w  - c w + d = 0,   
+/*                                    2 */
+/*           Eigenvalue equation is  w  - c w + d = 0, */
 
-                                           -1 2        -1   
-             so compute 1st column of  (A B  )  - c A B   + d   
-             using the formula in QZIT (from EISPACK)   
+/*                                         -1 2        -1 */
+/*           so compute 1st column of  (A B  )  - c A B   + d */
+/*           using the formula in QZIT (from EISPACK) */
 
-             We assume that the block is at least 3x3 */
+/*           We assume that the block is at least 3x3 */
 
 	    ad11 = ascale * h__[ilast - 1 + (ilast - 1) * h_dim1] / (bscale * 
 		    t[ilast - 1 + (ilast - 1) * t_dim1]);
@@ -1142,9 +1162,9 @@ L200:
 	    i__2 = ilast - 2;
 	    for (j = istart; j <= i__2; ++j) {
 
-/*              All but last elements: use 3x3 Householder transforms.   
+/*              All but last elements: use 3x3 Householder transforms. */
 
-                Zero (j-1)st column of A */
+/*              Zero (j-1)st column of A */
 
 		if (j > istart) {
 		    v[0] = h__[j + (j - 1) * h_dim1];
@@ -1176,7 +1196,8 @@ L200:
 		    i__3 = *n;
 		    for (jr = 1; jr <= i__3; ++jr) {
 			temp = tau * (q[jr + j * q_dim1] + v[1] * q[jr + (j + 
-				1) * q_dim1] + v[2] * q[jr + (j + 2) * q_dim1] );
+				1) * q_dim1] + v[2] * q[jr + (j + 2) * q_dim1]
+				);
 			q[jr + j * q_dim1] -= temp;
 			q[jr + (j + 1) * q_dim1] -= temp * v[1];
 			q[jr + (j + 2) * q_dim1] -= temp * v[2];
@@ -1184,9 +1205,9 @@ L200:
 		    }
 		}
 
-/*              Zero j-th column of B (see SLAGBC for details)   
+/*              Zero j-th column of B (see SLAGBC for details) */
 
-                Swap rows to pivot */
+/*              Swap rows to pivot */
 
 		ilpivt = FALSE_;
 /* Computing MAX */
@@ -1267,9 +1288,9 @@ L250:
 		    u1 = temp;
 		}
 
-/*              Compute Householder Vector   
+/*              Compute Householder Vector */
 
-   Computing 2nd power */
+/* Computing 2nd power */
 		r__1 = scale;
 /* Computing 2nd power */
 		r__2 = u1;
@@ -1282,9 +1303,9 @@ L250:
 		v[1] = vs * u1;
 		v[2] = vs * u2;
 
-/*              Apply transformations from the right.   
+/*              Apply transformations from the right. */
 
-   Computing MIN */
+/* Computing MIN */
 		i__4 = j + 3;
 		i__3 = min(i__4,ilast);
 		for (jr = ifrstm; jr <= i__3; ++jr) {
@@ -1321,9 +1342,9 @@ L250:
 /* L290: */
 	    }
 
-/*           Last elements: Use Givens rotations   
+/*           Last elements: Use Givens rotations */
 
-             Rotations from the left */
+/*           Rotations from the left */
 
 	    j = ilast - 1;
 	    temp = h__[j + (j - 1) * h_dim1];
