@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* slaed4.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int slaed4_(integer *n, integer *i__, real *d__, real *z__, 
 	real *delta, real *rho, real *dlam, integer *info)
@@ -24,115 +12,132 @@
     double sqrt(doublereal);
 
     /* Local variables */
-    static real a, b, c__;
-    static integer j;
-    static real w;
-    static integer ii;
-    static real dw, zz[3];
-    static integer ip1;
-    static real del, eta, phi, eps, tau, psi;
-    static integer iim1, iip1;
-    static real dphi, dpsi;
-    static integer iter;
-    static real temp, prew, temp1, dltlb, dltub, midpt;
-    static integer niter;
-    static logical swtch;
+    real a, b, c__;
+    integer j;
+    real w;
+    integer ii;
+    real dw, zz[3];
+    integer ip1;
+    real del, eta, phi, eps, tau, psi;
+    integer iim1, iip1;
+    real dphi, dpsi;
+    integer iter;
+    real temp, prew, temp1, dltlb, dltub, midpt;
+    integer niter;
+    logical swtch;
     extern /* Subroutine */ int slaed5_(integer *, real *, real *, real *, 
 	    real *, real *), slaed6_(integer *, logical *, real *, real *, 
 	    real *, real *, real *, integer *);
-    static logical swtch3;
+    logical swtch3;
     extern doublereal slamch_(char *);
-    static logical orgati;
-    static real erretm, rhoinv;
+    logical orgati;
+    real erretm, rhoinv;
 
 
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    This subroutine computes the I-th updated eigenvalue of a symmetric   
-    rank-one modification to a diagonal matrix whose elements are   
-    given in the array d, and that   
+/*  This subroutine computes the I-th updated eigenvalue of a symmetric */
+/*  rank-one modification to a diagonal matrix whose elements are */
+/*  given in the array d, and that */
 
-               D(i) < D(j)  for  i < j   
+/*             D(i) < D(j)  for  i < j */
 
-    and that RHO > 0.  This is arranged by the calling routine, and is   
-    no loss in generality.  The rank-one modified system is thus   
+/*  and that RHO > 0.  This is arranged by the calling routine, and is */
+/*  no loss in generality.  The rank-one modified system is thus */
 
-               diag( D )  +  RHO *  Z * Z_transpose.   
+/*             diag( D )  +  RHO *  Z * Z_transpose. */
 
-    where we assume the Euclidean norm of Z is 1.   
+/*  where we assume the Euclidean norm of Z is 1. */
 
-    The method consists of approximating the rational functions in the   
-    secular equation by simpler interpolating rational functions.   
+/*  The method consists of approximating the rational functions in the */
+/*  secular equation by simpler interpolating rational functions. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    N      (input) INTEGER   
-           The length of all arrays.   
+/*  N      (input) INTEGER */
+/*         The length of all arrays. */
 
-    I      (input) INTEGER   
-           The index of the eigenvalue to be computed.  1 <= I <= N.   
+/*  I      (input) INTEGER */
+/*         The index of the eigenvalue to be computed.  1 <= I <= N. */
 
-    D      (input) REAL array, dimension (N)   
-           The original eigenvalues.  It is assumed that they are in   
-           order, D(I) < D(J)  for I < J.   
+/*  D      (input) REAL array, dimension (N) */
+/*         The original eigenvalues.  It is assumed that they are in */
+/*         order, D(I) < D(J)  for I < J. */
 
-    Z      (input) REAL array, dimension (N)   
-           The components of the updating vector.   
+/*  Z      (input) REAL array, dimension (N) */
+/*         The components of the updating vector. */
 
-    DELTA  (output) REAL array, dimension (N)   
-           If N .GT. 2, DELTA contains (D(j) - lambda_I) in its  j-th   
-           component.  If N = 1, then DELTA(1) = 1. If N = 2, see SLAED5   
-           for detail. The vector DELTA contains the information necessary   
-           to construct the eigenvectors by SLAED3 and SLAED9.   
+/*  DELTA  (output) REAL array, dimension (N) */
+/*         If N .GT. 2, DELTA contains (D(j) - lambda_I) in its  j-th */
+/*         component.  If N = 1, then DELTA(1) = 1. If N = 2, see SLAED5 */
+/*         for detail. The vector DELTA contains the information necessary */
+/*         to construct the eigenvectors by SLAED3 and SLAED9. */
 
-    RHO    (input) REAL   
-           The scalar in the symmetric updating formula.   
+/*  RHO    (input) REAL */
+/*         The scalar in the symmetric updating formula. */
 
-    DLAM   (output) REAL   
-           The computed lambda_I, the I-th updated eigenvalue.   
+/*  DLAM   (output) REAL */
+/*         The computed lambda_I, the I-th updated eigenvalue. */
 
-    INFO   (output) INTEGER   
-           = 0:  successful exit   
-           > 0:  if INFO = 1, the updating process failed.   
+/*  INFO   (output) INTEGER */
+/*         = 0:  successful exit */
+/*         > 0:  if INFO = 1, the updating process failed. */
 
-    Internal Parameters   
-    ===================   
+/*  Internal Parameters */
+/*  =================== */
 
-    Logical variable ORGATI (origin-at-i?) is used for distinguishing   
-    whether D(i) or D(i+1) is treated as the origin.   
+/*  Logical variable ORGATI (origin-at-i?) is used for distinguishing */
+/*  whether D(i) or D(i+1) is treated as the origin. */
 
-              ORGATI = .true.    origin at i   
-              ORGATI = .false.   origin at i+1   
+/*            ORGATI = .true.    origin at i */
+/*            ORGATI = .false.   origin at i+1 */
 
-     Logical variable SWTCH3 (switch-for-3-poles?) is for noting   
-     if we are working with THREE poles!   
+/*   Logical variable SWTCH3 (switch-for-3-poles?) is for noting */
+/*   if we are working with THREE poles! */
 
-     MAXIT is the maximum number of iterations allowed for each   
-     eigenvalue.   
+/*   MAXIT is the maximum number of iterations allowed for each */
+/*   eigenvalue. */
 
-    Further Details   
-    ===============   
+/*  Further Details */
+/*  =============== */
 
-    Based on contributions by   
-       Ren-Cang Li, Computer Science Division, University of California   
-       at Berkeley, USA   
+/*  Based on contributions by */
+/*     Ren-Cang Li, Computer Science Division, University of California */
+/*     at Berkeley, USA */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Since this routine is called in an inner loop, we do no argument   
-       checking.   
+/*     Since this routine is called in an inner loop, we do no argument */
+/*     checking. */
 
-       Quick return for N=1 and 2.   
+/*     Quick return for N=1 and 2. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --delta;
     --z__;
     --d__;
@@ -170,8 +175,8 @@
 
 	midpt = *rho / 2.f;
 
-/*        If ||Z||_2 is not one, then TEMP should be set to   
-          RHO * ||Z||_2^2 / TWO */
+/*        If ||Z||_2 is not one, then TEMP should be set to */
+/*        RHO * ||Z||_2^2 / TWO */
 
 	i__1 = *n;
 	for (j = 1; j <= i__1; ++j) {
@@ -207,8 +212,8 @@
 		}
 	    }
 
-/*           It can be proved that   
-                 D(N)+RHO/2 <= LAMBDA(N) < D(N)+TAU <= D(N)+RHO */
+/*           It can be proved that */
+/*               D(N)+RHO/2 <= LAMBDA(N) < D(N)+TAU <= D(N)+RHO */
 
 	    dltlb = midpt;
 	    dltub = *rho;
@@ -222,8 +227,8 @@
 		tau = (a + sqrt(a * a + b * 4.f * c__)) / (c__ * 2.f);
 	    }
 
-/*           It can be proved that   
-                 D(N) < D(N)+TAU < LAMBDA(N) < D(N)+RHO/2 */
+/*           It can be proved that */
+/*               D(N) < D(N)+TAU < LAMBDA(N) < D(N)+RHO/2 */
 
 	    dltlb = 0.f;
 	    dltub = midpt;
@@ -284,8 +289,8 @@
 	    c__ = dabs(c__);
 	}
 	if (c__ == 0.f) {
-/*          ETA = B/A   
-             ETA = RHO - TAU */
+/*          ETA = B/A */
+/*           ETA = RHO - TAU */
 	    eta = dltub - tau;
 	} else if (a >= 0.f) {
 	    eta = (a + sqrt((r__1 = a * a - b * 4.f * c__, dabs(r__1)))) / (
@@ -295,11 +300,11 @@
 		    r__1))));
 	}
 
-/*        Note, eta should be positive if w is negative, and   
-          eta should be negative otherwise. However,   
-          if for some reason caused by roundoff, eta*w > 0,   
-          we simply use one Newton step instead. This way   
-          will guarantee eta*w < 0. */
+/*        Note, eta should be positive if w is negative, and */
+/*        eta should be negative otherwise. However, */
+/*        if for some reason caused by roundoff, eta*w > 0, */
+/*        we simply use one Newton step instead. This way */
+/*        will guarantee eta*w < 0. */
 
 	if (w * eta > 0.f) {
 	    eta = -w / (dpsi + dphi);
@@ -378,11 +383,11 @@
 			r__1))));
 	    }
 
-/*           Note, eta should be positive if w is negative, and   
-             eta should be negative otherwise. However,   
-             if for some reason caused by roundoff, eta*w > 0,   
-             we simply use one Newton step instead. This way   
-             will guarantee eta*w < 0. */
+/*           Note, eta should be positive if w is negative, and */
+/*           eta should be negative otherwise. However, */
+/*           if for some reason caused by roundoff, eta*w > 0, */
+/*           we simply use one Newton step instead. This way */
+/*           will guarantee eta*w < 0. */
 
 	    if (w * eta > 0.f) {
 		eta = -w / (dpsi + dphi);
@@ -474,9 +479,9 @@
 
 	if (w > 0.f) {
 
-/*           d(i)< the ith eigenvalue < (d(i)+d(i+1))/2   
+/*           d(i)< the ith eigenvalue < (d(i)+d(i+1))/2 */
 
-             We choose d(i) as origin. */
+/*           We choose d(i) as origin. */
 
 	    orgati = TRUE_;
 	    a = c__ * del + z__[*i__] * z__[*i__] + z__[ip1] * z__[ip1];
@@ -492,9 +497,9 @@
 	    dltub = midpt;
 	} else {
 
-/*           (d(i)+d(i+1))/2 <= the ith eigenvalue < d(i+1)   
+/*           (d(i)+d(i+1))/2 <= the ith eigenvalue < d(i+1) */
 
-             We choose d(i+1) as origin. */
+/*           We choose d(i+1) as origin. */
 
 	    orgati = FALSE_;
 	    a = c__ * del - z__[*i__] * z__[*i__] - z__[ip1] * z__[ip1];
@@ -561,8 +566,8 @@
 
 	w = rhoinv + phi + psi;
 
-/*        W is the value of the secular function with   
-          its ii-th element removed. */
+/*        W is the value of the secular function with */
+/*        its ii-th element removed. */
 
 	swtch3 = FALSE_;
 	if (orgati) {
@@ -665,11 +670,11 @@
 	    }
 	}
 
-/*        Note, eta should be positive if w is negative, and   
-          eta should be negative otherwise. However,   
-          if for some reason caused by roundoff, eta*w > 0,   
-          we simply use one Newton step instead. This way   
-          will guarantee eta*w < 0. */
+/*        Note, eta should be positive if w is negative, and */
+/*        eta should be negative otherwise. However, */
+/*        if for some reason caused by roundoff, eta*w > 0, */
+/*        we simply use one Newton step instead. This way */
+/*        will guarantee eta*w < 0. */
 
 	if (w * eta >= 0.f) {
 	    eta = -w / dw;
@@ -806,7 +811,8 @@
 		    }
 		    eta = b / a;
 		} else if (a <= 0.f) {
-		    eta = (a - sqrt((r__1 = a * a - b * 4.f * c__, dabs(r__1)) 			    )) / (c__ * 2.f);
+		    eta = (a - sqrt((r__1 = a * a - b * 4.f * c__, dabs(r__1))
+			    )) / (c__ * 2.f);
 		} else {
 		    eta = b * 2.f / (a + sqrt((r__1 = a * a - b * 4.f * c__, 
 			    dabs(r__1))));
@@ -846,11 +852,11 @@
 		}
 	    }
 
-/*           Note, eta should be positive if w is negative, and   
-             eta should be negative otherwise. However,   
-             if for some reason caused by roundoff, eta*w > 0,   
-             we simply use one Newton step instead. This way   
-             will guarantee eta*w < 0. */
+/*           Note, eta should be positive if w is negative, and */
+/*           eta should be negative otherwise. However, */
+/*           if for some reason caused by roundoff, eta*w > 0, */
+/*           we simply use one Newton step instead. This way */
+/*           will guarantee eta*w < 0. */
 
 	    if (w * eta >= 0.f) {
 		eta = -w / dw;
