@@ -1,125 +1,143 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
 
 /* Subroutine */ int slaein_(logical *rightv, logical *noinit, integer *n, 
 	real *h__, integer *ldh, real *wr, real *wi, real *vr, real *vi, real 
 	*b, integer *ldb, real *work, real *eps3, real *smlnum, real *bignum, 
 	integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SLAEIN uses inverse iteration to find a right or left eigenvector   
-    corresponding to the eigenvalue (WR,WI) of a real upper Hessenberg   
-    matrix H.   
-
-    Arguments   
-    =========   
-
-    RIGHTV   (input) LOGICAL   
-            = .TRUE. : compute right eigenvector;   
-            = .FALSE.: compute left eigenvector.   
-
-    NOINIT   (input) LOGICAL   
-            = .TRUE. : no initial vector supplied in (VR,VI).   
-            = .FALSE.: initial vector supplied in (VR,VI).   
-
-    N       (input) INTEGER   
-            The order of the matrix H.  N >= 0.   
-
-    H       (input) REAL array, dimension (LDH,N)   
-            The upper Hessenberg matrix H.   
-
-    LDH     (input) INTEGER   
-            The leading dimension of the array H.  LDH >= max(1,N).   
-
-    WR      (input) REAL   
-    WI      (input) REAL   
-            The real and imaginary parts of the eigenvalue of H whose   
-            corresponding right or left eigenvector is to be computed.   
-
-    VR      (input/output) REAL array, dimension (N)   
-    VI      (input/output) REAL array, dimension (N)   
-            On entry, if NOINIT = .FALSE. and WI = 0.0, VR must contain   
-            a real starting vector for inverse iteration using the real   
-            eigenvalue WR; if NOINIT = .FALSE. and WI.ne.0.0, VR and VI   
-            must contain the real and imaginary parts of a complex   
-            starting vector for inverse iteration using the complex   
-            eigenvalue (WR,WI); otherwise VR and VI need not be set.   
-            On exit, if WI = 0.0 (real eigenvalue), VR contains the   
-            computed real eigenvector; if WI.ne.0.0 (complex eigenvalue),   
-            VR and VI contain the real and imaginary parts of the   
-            computed complex eigenvector. The eigenvector is normalized   
-            so that the component of largest magnitude has magnitude 1;   
-            here the magnitude of a complex number (x,y) is taken to be   
-            |x| + |y|.   
-            VI is not referenced if WI = 0.0.   
-
-    B       (workspace) REAL array, dimension (LDB,N)   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B.  LDB >= N+1.   
-
-    WORK   (workspace) REAL array, dimension (N)   
-
-    EPS3    (input) REAL   
-            A small machine-dependent value which is used to perturb   
-            close eigenvalues, and to replace zero pivots.   
-
-    SMLNUM  (input) REAL   
-            A machine-dependent value close to the underflow threshold.   
-
-    BIGNUM  (input) REAL   
-            A machine-dependent value close to the overflow threshold.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            = 1:  inverse iteration did not converge; VR is set to the   
-                  last iterate, and so is VI if WI.ne.0.0.   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer b_dim1, b_offset, h_dim1, h_offset, i__1, i__2, i__3, i__4;
     real r__1, r__2, r__3, r__4;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer i__, j;
-    static real w, x, y;
-    static integer i1, i2, i3;
-    static real w1, ei, ej, xi, xr, rec;
-    static integer its, ierr;
-    static real temp, norm, vmax;
+    integer i__, j;
+    real w, x, y;
+    integer i1, i2, i3;
+    real w1, ei, ej, xi, xr, rec;
+    integer its, ierr;
+    real temp, norm, vmax;
     extern doublereal snrm2_(integer *, real *, integer *);
-    static real scale;
+    real scale;
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static char trans[1];
-    static real vcrit;
+    char trans[1];
+    real vcrit;
     extern doublereal sasum_(integer *, real *, integer *);
-    static real rootn, vnorm;
+    real rootn, vnorm;
     extern doublereal slapy2_(real *, real *);
-    static real absbii, absbjj;
+    real absbii, absbjj;
     extern integer isamax_(integer *, real *, integer *);
     extern /* Subroutine */ int sladiv_(real *, real *, real *, real *, real *
-	    , real *);
-    static char normin[1];
-    static real nrmsml;
+, real *);
+    char normin[1];
+    real nrmsml;
     extern /* Subroutine */ int slatrs_(char *, char *, char *, char *, 
 	    integer *, real *, integer *, real *, real *, real *, integer *);
-    static real growto;
+    real growto;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SLAEIN uses inverse iteration to find a right or left eigenvector */
+/*  corresponding to the eigenvalue (WR,WI) of a real upper Hessenberg */
+/*  matrix H. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  RIGHTV   (input) LOGICAL */
+/*          = .TRUE. : compute right eigenvector; */
+/*          = .FALSE.: compute left eigenvector. */
+
+/*  NOINIT   (input) LOGICAL */
+/*          = .TRUE. : no initial vector supplied in (VR,VI). */
+/*          = .FALSE.: initial vector supplied in (VR,VI). */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix H.  N >= 0. */
+
+/*  H       (input) REAL array, dimension (LDH,N) */
+/*          The upper Hessenberg matrix H. */
+
+/*  LDH     (input) INTEGER */
+/*          The leading dimension of the array H.  LDH >= max(1,N). */
+
+/*  WR      (input) REAL */
+/*  WI      (input) REAL */
+/*          The real and imaginary parts of the eigenvalue of H whose */
+/*          corresponding right or left eigenvector is to be computed. */
+
+/*  VR      (input/output) REAL array, dimension (N) */
+/*  VI      (input/output) REAL array, dimension (N) */
+/*          On entry, if NOINIT = .FALSE. and WI = 0.0, VR must contain */
+/*          a real starting vector for inverse iteration using the real */
+/*          eigenvalue WR; if NOINIT = .FALSE. and WI.ne.0.0, VR and VI */
+/*          must contain the real and imaginary parts of a complex */
+/*          starting vector for inverse iteration using the complex */
+/*          eigenvalue (WR,WI); otherwise VR and VI need not be set. */
+/*          On exit, if WI = 0.0 (real eigenvalue), VR contains the */
+/*          computed real eigenvector; if WI.ne.0.0 (complex eigenvalue), */
+/*          VR and VI contain the real and imaginary parts of the */
+/*          computed complex eigenvector. The eigenvector is normalized */
+/*          so that the component of largest magnitude has magnitude 1; */
+/*          here the magnitude of a complex number (x,y) is taken to be */
+/*          |x| + |y|. */
+/*          VI is not referenced if WI = 0.0. */
+
+/*  B       (workspace) REAL array, dimension (LDB,N) */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B.  LDB >= N+1. */
+
+/*  WORK   (workspace) REAL array, dimension (N) */
+
+/*  EPS3    (input) REAL */
+/*          A small machine-dependent value which is used to perturb */
+/*          close eigenvalues, and to replace zero pivots. */
+
+/*  SMLNUM  (input) REAL */
+/*          A machine-dependent value close to the underflow threshold. */
+
+/*  BIGNUM  (input) REAL */
+/*          A machine-dependent value close to the overflow threshold. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          = 1:  inverse iteration did not converge; VR is set to the */
+/*                last iterate, and so is VI if WI.ne.0.0. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
     h__ -= h_offset;
@@ -133,8 +151,8 @@
     /* Function Body */
     *info = 0;
 
-/*     GROWTO is the threshold used in the acceptance test for an   
-       eigenvector. */
+/*     GROWTO is the threshold used in the acceptance test for an */
+/*     eigenvector. */
 
     rootn = sqrt((real) (*n));
     growto = .1f / rootn;
@@ -142,8 +160,8 @@
     r__1 = 1.f, r__2 = *eps3 * rootn;
     nrmsml = dmax(r__1,r__2) * *smlnum;
 
-/*     Form B = H - (WR,WI)*I (except that the subdiagonal elements and   
-       the imaginary parts of the diagonal elements are not stored). */
+/*     Form B = H - (WR,WI)*I (except that the subdiagonal elements and */
+/*     the imaginary parts of the diagonal elements are not stored). */
 
     i__1 = *n;
     for (j = 1; j <= i__1; ++j) {
@@ -180,8 +198,8 @@
 
 	if (*rightv) {
 
-/*           LU decomposition with partial pivoting of B, replacing zero   
-             pivots by EPS3. */
+/*           LU decomposition with partial pivoting of B, replacing zero */
+/*           pivots by EPS3. */
 
 	    i__1 = *n - 1;
 	    for (i__ = 1; i__ <= i__1; ++i__) {
@@ -227,8 +245,8 @@
 
 	} else {
 
-/*           UL decomposition with partial pivoting of B, replacing zero   
-             pivots by EPS3. */
+/*           UL decomposition with partial pivoting of B, replacing zero */
+/*           pivots by EPS3. */
 
 	    for (j = *n; j >= 2; --j) {
 		ej = h__[j + (j - 1) * h_dim1];
@@ -277,9 +295,9 @@
 	i__1 = *n;
 	for (its = 1; its <= i__1; ++its) {
 
-/*           Solve U*x = scale*v for a right eigenvector   
-               or U'*x = scale*v for a left eigenvector,   
-             overwriting x on v. */
+/*           Solve U*x = scale*v for a right eigenvector */
+/*             or U'*x = scale*v for a left eigenvector, */
+/*           overwriting x on v. */
 
 	    slatrs_("Upper", trans, "Nonunit", normin, n, &b[b_offset], ldb, &
 		    vr[1], &scale, &work[1], &ierr);
@@ -344,11 +362,11 @@ L120:
 
 	if (*rightv) {
 
-/*           LU decomposition with partial pivoting of B, replacing zero   
-             pivots by EPS3.   
+/*           LU decomposition with partial pivoting of B, replacing zero */
+/*           pivots by EPS3. */
 
-             The imaginary part of the (i,j)-th element of U is stored in   
-             B(j+1,i). */
+/*           The imaginary part of the (i,j)-th element of U is stored in */
+/*           B(j+1,i). */
 
 	    b[b_dim1 + 2] = -(*wi);
 	    i__1 = *n;
@@ -427,11 +445,11 @@ L120:
 	    i3 = -1;
 	} else {
 
-/*           UL decomposition with partial pivoting of conjg(B),   
-             replacing zero pivots by EPS3.   
+/*           UL decomposition with partial pivoting of conjg(B), */
+/*           replacing zero pivots by EPS3. */
 
-             The imaginary part of the (i,j)-th element of U is stored in   
-             B(j+1,i). */
+/*           The imaginary part of the (i,j)-th element of U is stored in */
+/*           B(j+1,i). */
 
 	    b[*n + 1 + *n * b_dim1] = *wi;
 	    i__1 = *n - 1;
@@ -513,9 +531,9 @@ L120:
 	    vmax = 1.f;
 	    vcrit = *bignum;
 
-/*           Solve U*(xr,xi) = scale*(vr,vi) for a right eigenvector,   
-               or U'*(xr,xi) = scale*(vr,vi) for a left eigenvector,   
-             overwriting (xr,xi) on (vr,vi). */
+/*           Solve U*(xr,xi) = scale*(vr,vi) for a right eigenvector, */
+/*             or U'*(xr,xi) = scale*(vr,vi) for a left eigenvector, */
+/*           overwriting (xr,xi) on (vr,vi). */
 
 	    i__2 = i2;
 	    i__3 = i3;
