@@ -1,5 +1,13 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static real c_b7 = 0.f;
+static real c_b8 = 1.f;
+static integer c__3 = 3;
+static integer c__1 = 1;
+static integer c__2 = 2;
 
 /* Subroutine */ int slaqr5_(logical *wantt, logical *wantz, integer *kacc22, 
 	integer *n, integer *ktop, integer *kbot, integer *nshfts, real *sr, 
@@ -8,187 +16,198 @@
 	integer *nv, real *wv, integer *ldwv, integer *nh, real *wh, integer *
 	ldwh)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-       This auxiliary subroutine called by SLAQR0 performs a   
-       single small-bulge multi-shift QR sweep.   
-
-        WANTT  (input) logical scalar   
-               WANTT = .true. if the quasi-triangular Schur factor   
-               is being computed.  WANTT is set to .false. otherwise.   
-
-        WANTZ  (input) logical scalar   
-               WANTZ = .true. if the orthogonal Schur factor is being   
-               computed.  WANTZ is set to .false. otherwise.   
-
-        KACC22 (input) integer with value 0, 1, or 2.   
-               Specifies the computation mode of far-from-diagonal   
-               orthogonal updates.   
-          = 0: SLAQR5 does not accumulate reflections and does not   
-               use matrix-matrix multiply to update far-from-diagonal   
-               matrix entries.   
-          = 1: SLAQR5 accumulates reflections and uses matrix-matrix   
-               multiply to update the far-from-diagonal matrix entries.   
-          = 2: SLAQR5 accumulates reflections, uses matrix-matrix   
-               multiply to update the far-from-diagonal matrix entries,   
-               and takes advantage of 2-by-2 block structure during   
-               matrix multiplies.   
-
-        N      (input) integer scalar   
-               N is the order of the Hessenberg matrix H upon which this   
-               subroutine operates.   
-
-        KTOP   (input) integer scalar   
-        KBOT   (input) integer scalar   
-               These are the first and last rows and columns of an   
-               isolated diagonal block upon which the QR sweep is to be   
-               applied. It is assumed without a check that   
-                         either KTOP = 1  or   H(KTOP,KTOP-1) = 0   
-               and   
-                         either KBOT = N  or   H(KBOT+1,KBOT) = 0.   
-
-        NSHFTS (input) integer scalar   
-               NSHFTS gives the number of simultaneous shifts.  NSHFTS   
-               must be positive and even.   
-
-        SR     (input) REAL array of size (NSHFTS)   
-        SI     (input) REAL array of size (NSHFTS)   
-               SR contains the real parts and SI contains the imaginary   
-               parts of the NSHFTS shifts of origin that define the   
-               multi-shift QR sweep.   
-
-        H      (input/output) REAL array of size (LDH,N)   
-               On input H contains a Hessenberg matrix.  On output a   
-               multi-shift QR sweep with shifts SR(J)+i*SI(J) is applied   
-               to the isolated diagonal block in rows and columns KTOP   
-               through KBOT.   
-
-        LDH    (input) integer scalar   
-               LDH is the leading dimension of H just as declared in the   
-               calling procedure.  LDH.GE.MAX(1,N).   
-
-        ILOZ   (input) INTEGER   
-        IHIZ   (input) INTEGER   
-               Specify the rows of Z to which transformations must be   
-               applied if WANTZ is .TRUE.. 1 .LE. ILOZ .LE. IHIZ .LE. N   
-
-        Z      (input/output) REAL array of size (LDZ,IHI)   
-               If WANTZ = .TRUE., then the QR Sweep orthogonal   
-               similarity transformation is accumulated into   
-               Z(ILOZ:IHIZ,ILO:IHI) from the right.   
-               If WANTZ = .FALSE., then Z is unreferenced.   
-
-        LDZ    (input) integer scalar   
-               LDA is the leading dimension of Z just as declared in   
-               the calling procedure. LDZ.GE.N.   
-
-        V      (workspace) REAL array of size (LDV,NSHFTS/2)   
-
-        LDV    (input) integer scalar   
-               LDV is the leading dimension of V as declared in the   
-               calling procedure.  LDV.GE.3.   
-
-        U      (workspace) REAL array of size   
-               (LDU,3*NSHFTS-3)   
-
-        LDU    (input) integer scalar   
-               LDU is the leading dimension of U just as declared in the   
-               in the calling subroutine.  LDU.GE.3*NSHFTS-3.   
-
-        NH     (input) integer scalar   
-               NH is the number of columns in array WH available for   
-               workspace. NH.GE.1.   
-
-        WH     (workspace) REAL array of size (LDWH,NH)   
-
-        LDWH   (input) integer scalar   
-               Leading dimension of WH just as declared in the   
-               calling procedure.  LDWH.GE.3*NSHFTS-3.   
-
-        NV     (input) integer scalar   
-               NV is the number of rows in WV agailable for workspace.   
-               NV.GE.1.   
-
-        WV     (workspace) REAL array of size   
-               (LDWV,3*NSHFTS-3)   
-
-        LDWV   (input) integer scalar   
-               LDWV is the leading dimension of WV as declared in the   
-               in the calling subroutine.  LDWV.GE.NV.   
-
-
-       ================================================================   
-       Based on contributions by   
-          Karen Braman and Ralph Byers, Department of Mathematics,   
-          University of Kansas, USA   
-
-       ============================================================   
-       Reference:   
-
-       K. Braman, R. Byers and R. Mathias, The Multi-Shift QR   
-       Algorithm Part I: Maintaining Well Focused Shifts, and   
-       Level 3 Performance, SIAM Journal of Matrix Analysis,   
-       volume 23, pages 929--947, 2002.   
-
-       ============================================================   
-
-
-       ==== If there are no shifts, then there is nothing to do. ====   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static real c_b7 = 0.f;
-    static real c_b8 = 1.f;
-    static integer c__3 = 3;
-    static integer c__1 = 1;
-    static integer c__2 = 2;
-    
     /* System generated locals */
     integer h_dim1, h_offset, u_dim1, u_offset, v_dim1, v_offset, wh_dim1, 
 	    wh_offset, wv_dim1, wv_offset, z_dim1, z_offset, i__1, i__2, i__3,
 	     i__4, i__5, i__6, i__7;
     real r__1, r__2, r__3, r__4;
+
     /* Local variables */
-    static integer i__, j, k, m, i2, j2, i4, j4, k1;
-    static real h11, h12, h21, h22;
-    static integer m22, ns, nu;
-    static real vt[3], scl;
-    static integer kdu, kms;
-    static real ulp;
-    static integer knz, kzs;
-    static real tst1, tst2, beta;
-    static logical blk22, bmp22;
-    static integer mend, jcol, jlen, jbot, mbot;
-    static real swap;
-    static integer jtop, jrow, mtop;
-    static real alpha;
-    static logical accum;
-    static integer ndcol, incol;
+    integer i__, j, k, m, i2, j2, i4, j4, k1;
+    real h11, h12, h21, h22;
+    integer m22, ns, nu;
+    real vt[3], scl;
+    integer kdu, kms;
+    real ulp;
+    integer knz, kzs;
+    real tst1, tst2, beta;
+    logical blk22, bmp22;
+    integer mend, jcol, jlen, jbot, mbot;
+    real swap;
+    integer jtop, jrow, mtop;
+    real alpha;
+    logical accum;
+    integer ndcol, incol;
     extern /* Subroutine */ int sgemm_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *);
-    static integer krcol, nbmps;
+    integer krcol, nbmps;
     extern /* Subroutine */ int strmm_(char *, char *, char *, char *, 
 	    integer *, integer *, real *, real *, integer *, real *, integer *
 ), slaqr1_(integer *, real *, 
 	    integer *, real *, real *, real *, real *, real *), slabad_(real *
-	    , real *);
+, real *);
     extern doublereal slamch_(char *);
-    static real safmin;
+    real safmin;
     extern /* Subroutine */ int slarfg_(integer *, real *, real *, integer *, 
 	    real *);
-    static real safmax;
+    real safmax;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), slaset_(char *, integer *, 
 	    integer *, real *, real *, real *, integer *);
-    static real refsum;
-    static integer mstart;
-    static real smlnum;
+    real refsum;
+    integer mstart;
+    real smlnum;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*     This auxiliary subroutine called by SLAQR0 performs a */
+/*     single small-bulge multi-shift QR sweep. */
+
+/*      WANTT  (input) logical scalar */
+/*             WANTT = .true. if the quasi-triangular Schur factor */
+/*             is being computed.  WANTT is set to .false. otherwise. */
+
+/*      WANTZ  (input) logical scalar */
+/*             WANTZ = .true. if the orthogonal Schur factor is being */
+/*             computed.  WANTZ is set to .false. otherwise. */
+
+/*      KACC22 (input) integer with value 0, 1, or 2. */
+/*             Specifies the computation mode of far-from-diagonal */
+/*             orthogonal updates. */
+/*        = 0: SLAQR5 does not accumulate reflections and does not */
+/*             use matrix-matrix multiply to update far-from-diagonal */
+/*             matrix entries. */
+/*        = 1: SLAQR5 accumulates reflections and uses matrix-matrix */
+/*             multiply to update the far-from-diagonal matrix entries. */
+/*        = 2: SLAQR5 accumulates reflections, uses matrix-matrix */
+/*             multiply to update the far-from-diagonal matrix entries, */
+/*             and takes advantage of 2-by-2 block structure during */
+/*             matrix multiplies. */
+
+/*      N      (input) integer scalar */
+/*             N is the order of the Hessenberg matrix H upon which this */
+/*             subroutine operates. */
+
+/*      KTOP   (input) integer scalar */
+/*      KBOT   (input) integer scalar */
+/*             These are the first and last rows and columns of an */
+/*             isolated diagonal block upon which the QR sweep is to be */
+/*             applied. It is assumed without a check that */
+/*                       either KTOP = 1  or   H(KTOP,KTOP-1) = 0 */
+/*             and */
+/*                       either KBOT = N  or   H(KBOT+1,KBOT) = 0. */
+
+/*      NSHFTS (input) integer scalar */
+/*             NSHFTS gives the number of simultaneous shifts.  NSHFTS */
+/*             must be positive and even. */
+
+/*      SR     (input) REAL array of size (NSHFTS) */
+/*      SI     (input) REAL array of size (NSHFTS) */
+/*             SR contains the real parts and SI contains the imaginary */
+/*             parts of the NSHFTS shifts of origin that define the */
+/*             multi-shift QR sweep. */
+
+/*      H      (input/output) REAL array of size (LDH,N) */
+/*             On input H contains a Hessenberg matrix.  On output a */
+/*             multi-shift QR sweep with shifts SR(J)+i*SI(J) is applied */
+/*             to the isolated diagonal block in rows and columns KTOP */
+/*             through KBOT. */
+
+/*      LDH    (input) integer scalar */
+/*             LDH is the leading dimension of H just as declared in the */
+/*             calling procedure.  LDH.GE.MAX(1,N). */
+
+/*      ILOZ   (input) INTEGER */
+/*      IHIZ   (input) INTEGER */
+/*             Specify the rows of Z to which transformations must be */
+/*             applied if WANTZ is .TRUE.. 1 .LE. ILOZ .LE. IHIZ .LE. N */
+
+/*      Z      (input/output) REAL array of size (LDZ,IHI) */
+/*             If WANTZ = .TRUE., then the QR Sweep orthogonal */
+/*             similarity transformation is accumulated into */
+/*             Z(ILOZ:IHIZ,ILO:IHI) from the right. */
+/*             If WANTZ = .FALSE., then Z is unreferenced. */
+
+/*      LDZ    (input) integer scalar */
+/*             LDA is the leading dimension of Z just as declared in */
+/*             the calling procedure. LDZ.GE.N. */
+
+/*      V      (workspace) REAL array of size (LDV,NSHFTS/2) */
+
+/*      LDV    (input) integer scalar */
+/*             LDV is the leading dimension of V as declared in the */
+/*             calling procedure.  LDV.GE.3. */
+
+/*      U      (workspace) REAL array of size */
+/*             (LDU,3*NSHFTS-3) */
+
+/*      LDU    (input) integer scalar */
+/*             LDU is the leading dimension of U just as declared in the */
+/*             in the calling subroutine.  LDU.GE.3*NSHFTS-3. */
+
+/*      NH     (input) integer scalar */
+/*             NH is the number of columns in array WH available for */
+/*             workspace. NH.GE.1. */
+
+/*      WH     (workspace) REAL array of size (LDWH,NH) */
+
+/*      LDWH   (input) integer scalar */
+/*             Leading dimension of WH just as declared in the */
+/*             calling procedure.  LDWH.GE.3*NSHFTS-3. */
+
+/*      NV     (input) integer scalar */
+/*             NV is the number of rows in WV agailable for workspace. */
+/*             NV.GE.1. */
+
+/*      WV     (workspace) REAL array of size */
+/*             (LDWV,3*NSHFTS-3) */
+
+/*      LDWV   (input) integer scalar */
+/*             LDWV is the leading dimension of WV as declared in the */
+/*             in the calling subroutine.  LDWV.GE.NV. */
+
+
+/*     ================================================================ */
+/*     Based on contributions by */
+/*        Karen Braman and Ralph Byers, Department of Mathematics, */
+/*        University of Kansas, USA */
+
+/*     ============================================================ */
+/*     Reference: */
+
+/*     K. Braman, R. Byers and R. Mathias, The Multi-Shift QR */
+/*     Algorithm Part I: Maintaining Well Focused Shifts, and */
+/*     Level 3 Performance, SIAM Journal of Matrix Analysis, */
+/*     volume 23, pages 929--947, 2002. */
+
+/*     ============================================================ */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     ==== If there are no shifts, then there is nothing to do. ==== */
+
+    /* Parameter adjustments */
     --sr;
     --si;
     h_dim1 = *ldh;
@@ -215,17 +234,17 @@
 	return 0;
     }
 
-/*     ==== If the active block is empty or 1-by-1, then there   
-       .    is nothing to do. ==== */
+/*     ==== If the active block is empty or 1-by-1, then there */
+/*     .    is nothing to do. ==== */
 
     if (*ktop >= *kbot) {
 	return 0;
     }
 
-/*     ==== Shuffle shifts into pairs of real shifts and pairs   
-       .    of complex conjugate shifts assuming complex   
-       .    conjugate shifts are already adjacent to one   
-       .    another. ==== */
+/*     ==== Shuffle shifts into pairs of real shifts and pairs */
+/*     .    of complex conjugate shifts assuming complex */
+/*     .    conjugate shifts are already adjacent to one */
+/*     .    another. ==== */
 
     i__1 = *nshfts - 2;
     for (i__ = 1; i__ <= i__1; i__ += 2) {
@@ -244,10 +263,10 @@
 /* L10: */
     }
 
-/*     ==== NSHFTS is supposed to be even, but if is odd,   
-       .    then simply reduce it by one.  The shuffle above   
-       .    ensures that the dropped shift is real and that   
-       .    the remaining shifts are paired. ==== */
+/*     ==== NSHFTS is supposed to be even, but if is odd, */
+/*     .    then simply reduce it by one.  The shuffle above */
+/*     .    ensures that the dropped shift is real and that */
+/*     .    the remaining shifts are paired. ==== */
 
     ns = *nshfts - *nshfts % 2;
 
@@ -259,8 +278,8 @@
     ulp = slamch_("PRECISION");
     smlnum = safmin * ((real) (*n) / ulp);
 
-/*     ==== Use accumulated reflections to update far-from-diagonal   
-       .    entries ? ==== */
+/*     ==== Use accumulated reflections to update far-from-diagonal */
+/*     .    entries ? ==== */
 
     accum = *kacc22 == 1 || *kacc22 == 2;
 
@@ -293,31 +312,31 @@
 	    slaset_("ALL", &kdu, &kdu, &c_b7, &c_b8, &u[u_offset], ldu);
 	}
 
-/*        ==== Near-the-diagonal bulge chase.  The following loop   
-          .    performs the near-the-diagonal part of a small bulge   
-          .    multi-shift QR sweep.  Each 6*NBMPS-2 column diagonal   
-          .    chunk extends from column INCOL to column NDCOL   
-          .    (including both column INCOL and column NDCOL). The   
-          .    following loop chases a 3*NBMPS column long chain of   
-          .    NBMPS bulges 3*NBMPS-2 columns to the right.  (INCOL   
-          .    may be less than KTOP and and NDCOL may be greater than   
-          .    KBOT indicating phantom columns from which to chase   
-          .    bulges before they are actually introduced or to which   
-          .    to chase bulges beyond column KBOT.)  ====   
+/*        ==== Near-the-diagonal bulge chase.  The following loop */
+/*        .    performs the near-the-diagonal part of a small bulge */
+/*        .    multi-shift QR sweep.  Each 6*NBMPS-2 column diagonal */
+/*        .    chunk extends from column INCOL to column NDCOL */
+/*        .    (including both column INCOL and column NDCOL). The */
+/*        .    following loop chases a 3*NBMPS column long chain of */
+/*        .    NBMPS bulges 3*NBMPS-2 columns to the right.  (INCOL */
+/*        .    may be less than KTOP and and NDCOL may be greater than */
+/*        .    KBOT indicating phantom columns from which to chase */
+/*        .    bulges before they are actually introduced or to which */
+/*        .    to chase bulges beyond column KBOT.)  ==== */
 
-   Computing MIN */
+/* Computing MIN */
 	i__4 = incol + nbmps * 3 - 3, i__5 = *kbot - 2;
 	i__3 = min(i__4,i__5);
 	for (krcol = incol; krcol <= i__3; ++krcol) {
 
-/*           ==== Bulges number MTOP to MBOT are active double implicit   
-             .    shift bulges.  There may or may not also be small   
-             .    2-by-2 bulge, if there is room.  The inactive bulges   
-             .    (if any) must wait until the active bulges have moved   
-             .    down the diagonal to make room.  The phantom matrix   
-             .    paradigm described above helps keep track.  ====   
+/*           ==== Bulges number MTOP to MBOT are active double implicit */
+/*           .    shift bulges.  There may or may not also be small */
+/*           .    2-by-2 bulge, if there is room.  The inactive bulges */
+/*           .    (if any) must wait until the active bulges have moved */
+/*           .    down the diagonal to make room.  The phantom matrix */
+/*           .    paradigm described above helps keep track.  ==== */
 
-   Computing MAX */
+/* Computing MAX */
 	    i__4 = 1, i__5 = (*ktop - 1 - krcol + 2) / 3 + 1;
 	    mtop = max(i__4,i__5);
 /* Computing MIN */
@@ -326,8 +345,8 @@
 	    m22 = mbot + 1;
 	    bmp22 = mbot < nbmps && krcol + (m22 - 1) * 3 == *kbot - 2;
 
-/*           ==== Generate reflections to chase the chain right   
-             .    one column.  (The minimum value of K is KTOP-1.) ==== */
+/*           ==== Generate reflections to chase the chain right */
+/*           .    one column.  (The minimum value of K is KTOP-1.) ==== */
 
 	    i__4 = mbot;
 	    for (m = mtop; m <= i__4; ++m) {
@@ -346,15 +365,15 @@
 		    slarfg_(&c__3, &beta, &v[m * v_dim1 + 2], &c__1, &v[m * 
 			    v_dim1 + 1]);
 
-/*                 ==== A Bulge may collapse because of vigilant   
-                   .    deflation or destructive underflow.  (The   
-                   .    initial bulge is always collapsed.) Use   
-                   .    the two-small-subdiagonals trick to try   
-                   .    to get it started again. If V(2,M).NE.0 and   
-                   .    V(3,M) = H(K+3,K+1) = H(K+3,K+2) = 0, then   
-                   .    this bulge is collapsing into a zero   
-                   .    subdiagonal.  It will be restarted next   
-                   .    trip through the loop.) */
+/*                 ==== A Bulge may collapse because of vigilant */
+/*                 .    deflation or destructive underflow.  (The */
+/*                 .    initial bulge is always collapsed.) Use */
+/*                 .    the two-small-subdiagonals trick to try */
+/*                 .    to get it started again. If V(2,M).NE.0 and */
+/*                 .    V(3,M) = H(K+3,K+1) = H(K+3,K+2) = 0, then */
+/*                 .    this bulge is collapsing into a zero */
+/*                 .    subdiagonal.  It will be restarted next */
+/*                 .    trip through the loop.) */
 
 		    if (v[m * v_dim1 + 1] != 0.f && (v[m * v_dim1 + 3] != 0.f 
 			    || h__[k + 3 + (k + 1) * h_dim1] == 0.f && h__[k 
@@ -367,11 +386,11 @@
 			h__[k + 3 + k * h_dim1] = 0.f;
 		    } else {
 
-/*                    ==== Atypical case: collapsed.  Attempt to   
-                      .    reintroduce ignoring H(K+1,K).  If the   
-                      .    fill resulting from the new reflector   
-                      .    is too large, then abandon it.   
-                      .    Otherwise, use the new one. ==== */
+/*                    ==== Atypical case: collapsed.  Attempt to */
+/*                    .    reintroduce ignoring H(K+1,K).  If the */
+/*                    .    fill resulting from the new reflector */
+/*                    .    is too large, then abandon it. */
+/*                    .    Otherwise, use the new one. ==== */
 
 			slaqr1_(&c__3, &h__[k + 1 + (k + 1) * h_dim1], ldh, &
 				sr[(m << 1) - 1], &si[(m << 1) - 1], &sr[m * 
@@ -383,10 +402,10 @@
 			    vt[2] /= scl;
 			}
 
-/*                    ==== The following is the traditional and   
-                      .    conservative two-small-subdiagonals   
-                      .    test.  ====   
-                      . */
+/*                    ==== The following is the traditional and */
+/*                    .    conservative two-small-subdiagonals */
+/*                    .    test.  ==== */
+/*                    . */
 			if ((r__1 = h__[k + 1 + k * h_dim1], dabs(r__1)) * (
 				dabs(vt[1]) + dabs(vt[2])) > ulp * dabs(vt[0])
 				 * ((r__2 = h__[k + k * h_dim1], dabs(r__2)) 
@@ -394,12 +413,12 @@
 				r__3)) + (r__4 = h__[k + 2 + (k + 2) * h_dim1]
 				, dabs(r__4)))) {
 
-/*                       ==== Starting a new bulge here would   
-                         .    create non-negligible fill.   If   
-                         .    the old reflector is diagonal (only   
-                         .    possible with underflows), then   
-                         .    change it to I.  Otherwise, use   
-                         .    it with trepidation. ==== */
+/*                       ==== Starting a new bulge here would */
+/*                       .    create non-negligible fill.   If */
+/*                       .    the old reflector is diagonal (only */
+/*                       .    possible with underflows), then */
+/*                       .    change it to I.  Otherwise, use */
+/*                       .    it with trepidation. ==== */
 
 			    if (v[m * v_dim1 + 2] == 0.f && v[m * v_dim1 + 3] 
 				    == 0.f) {
@@ -411,10 +430,10 @@
 			    }
 			} else {
 
-/*                       ==== Stating a new bulge here would   
-                         .    create only negligible fill.   
-                         .    Replace the old reflector with   
-                         .    the new one. ==== */
+/*                       ==== Stating a new bulge here would */
+/*                       .    create only negligible fill. */
+/*                       .    Replace the old reflector with */
+/*                       .    the new one. ==== */
 
 			    alpha = vt[0];
 			    slarfg_(&c__3, &alpha, &vt[1], &c__1, vt);
@@ -439,7 +458,7 @@
 	    if (bmp22) {
 		if (k == *ktop - 1) {
 		    slaqr1_(&c__2, &h__[k + 1 + (k + 1) * h_dim1], ldh, &sr[(
-			    m22 << 1) - 1], &si[(m22 << 1) - 1], &sr[m22 * 2],
+			    m22 << 1) - 1], &si[(m22 << 1) - 1], &sr[m22 * 2], 
 			     &si[m22 * 2], &v[m22 * v_dim1 + 1]);
 		    beta = v[m22 * v_dim1 + 1];
 		    slarfg_(&c__2, &beta, &v[m22 * v_dim1 + 2], &c__1, &v[m22 
@@ -454,8 +473,8 @@
 		}
 	    } else {
 
-/*              ==== Initialize V(1,M22) here to avoid possible undefined   
-                .    variable problems later. ==== */
+/*              ==== Initialize V(1,M22) here to avoid possible undefined */
+/*              .    variable problems later. ==== */
 
 		v[m22 * v_dim1 + 1] = 0.f;
 	    }
@@ -501,9 +520,9 @@
 		}
 	    }
 
-/*           ==== Multiply H by reflections from the right.   
-             .    Delay filling in the last row until the   
-             .    vigilant deflation check is complete. ==== */
+/*           ==== Multiply H by reflections from the right. */
+/*           .    Delay filling in the last row until the */
+/*           .    vigilant deflation check is complete. ==== */
 
 	    if (accum) {
 		jtop = max(*ktop,incol);
@@ -534,9 +553,9 @@
 
 		    if (accum) {
 
-/*                    ==== Accumulate U. (If necessary, update Z later   
-                      .    with with an efficient matrix-matrix   
-                      .    multiply.) ==== */
+/*                    ==== Accumulate U. (If necessary, update Z later */
+/*                    .    with with an efficient matrix-matrix */
+/*                    .    multiply.) ==== */
 
 			kms = k - incol;
 /* Computing MAX */
@@ -556,9 +575,9 @@
 			}
 		    } else if (*wantz) {
 
-/*                    ==== U is not accumulated, so update Z   
-                      .    now by multiplying by reflections   
-                      .    from the right. ==== */
+/*                    ==== U is not accumulated, so update Z */
+/*                    .    now by multiplying by reflections */
+/*                    .    from the right. ==== */
 
 			i__7 = *ihiz;
 			for (j = *iloz; j <= i__7; ++j) {
@@ -641,14 +660,14 @@
 		i__5 = *kbot - 1, i__7 = krcol + (m - 1) * 3;
 		k = min(i__5,i__7);
 
-/*              ==== The following convergence test requires that   
-                .    the tradition small-compared-to-nearby-diagonals   
-                .    criterion and the Ahues & Tisseur (LAWN 122, 1997)   
-                .    criteria both be satisfied.  The latter improves   
-                .    accuracy in some examples. Falling back on an   
-                .    alternate convergence criterion when TST1 or TST2   
-                .    is zero (as done here) is traditional but probably   
-                .    unnecessary. ==== */
+/*              ==== The following convergence test requires that */
+/*              .    the tradition small-compared-to-nearby-diagonals */
+/*              .    criterion and the Ahues & Tisseur (LAWN 122, 1997) */
+/*              .    criteria both be satisfied.  The latter improves */
+/*              .    accuracy in some examples. Falling back on an */
+/*              .    alternate convergence criterion when TST1 or TST2 */
+/*              .    is zero (as done here) is traditional but probably */
+/*              .    unnecessary. ==== */
 
 		if (h__[k + 1 + k * h_dim1] != 0.f) {
 		    tst1 = (r__1 = h__[k + k * h_dim1], dabs(r__1)) + (r__2 = 
@@ -717,9 +736,9 @@
 /* L130: */
 	    }
 
-/*           ==== Fill in the last row of each bulge. ====   
+/*           ==== Fill in the last row of each bulge. ==== */
 
-   Computing MIN */
+/* Computing MIN */
 	    i__4 = nbmps, i__5 = (*kbot - krcol - 1) / 3;
 	    mend = min(i__4,i__5);
 	    i__4 = mend;
@@ -733,14 +752,14 @@
 /* L140: */
 	    }
 
-/*           ==== End of near-the-diagonal bulge chase. ====   
+/*           ==== End of near-the-diagonal bulge chase. ==== */
 
-   L150: */
+/* L150: */
 	}
 
-/*        ==== Use U (if accumulated) to update far-from-diagonal   
-          .    entries in H.  If required, use U to update Z as   
-          .    well. ==== */
+/*        ==== Use U (if accumulated) to update far-from-diagonal */
+/*        .    entries in H.  If required, use U to update Z as */
+/*        .    well. ==== */
 
 	if (accum) {
 	    if (*wantt) {
@@ -752,16 +771,16 @@
 	    }
 	    if (! blk22 || incol < *ktop || ndcol > *kbot || ns <= 2) {
 
-/*              ==== Updates not exploiting the 2-by-2 block   
-                .    structure of U.  K1 and NU keep track of   
-                .    the location and size of U in the special   
-                .    cases of introducing bulges and chasing   
-                .    bulges off the bottom.  In these special   
-                .    cases and in case the number of shifts   
-                .    is NS = 2, there is no 2-by-2 block   
-                .    structure to exploit.  ====   
+/*              ==== Updates not exploiting the 2-by-2 block */
+/*              .    structure of U.  K1 and NU keep track of */
+/*              .    the location and size of U in the special */
+/*              .    cases of introducing bulges and chasing */
+/*              .    bulges off the bottom.  In these special */
+/*              .    cases and in case the number of shifts */
+/*              .    is NS = 2, there is no 2-by-2 block */
+/*              .    structure to exploit.  ==== */
 
-   Computing MAX */
+/* Computing MAX */
 		i__3 = 1, i__4 = *ktop - incol;
 		k1 = max(i__3,i__4);
 /* Computing MAX */
@@ -823,18 +842,18 @@
 		}
 	    } else {
 
-/*              ==== Updates exploiting U's 2-by-2 block structure.   
-                .    (I2, I4, J2, J4 are the last rows and columns   
-                .    of the blocks.) ==== */
+/*              ==== Updates exploiting U's 2-by-2 block structure. */
+/*              .    (I2, I4, J2, J4 are the last rows and columns */
+/*              .    of the blocks.) ==== */
 
 		i2 = (kdu + 1) / 2;
 		i4 = kdu;
 		j2 = i4 - i2;
 		j4 = kdu;
 
-/*              ==== KZS and KNZ deal with the band of zeros   
-                .    along the diagonal of one of the triangular   
-                .    blocks. ==== */
+/*              ==== KZS and KNZ deal with the band of zeros */
+/*              .    along the diagonal of one of the triangular */
+/*              .    blocks. ==== */
 
 		kzs = j4 - j2 - (ns + 1);
 		knz = ns + 1;
@@ -849,8 +868,8 @@
 		    i__5 = *nh, i__7 = jbot - jcol + 1;
 		    jlen = min(i__5,i__7);
 
-/*                 ==== Copy bottom of H to top+KZS of scratch ====   
-                    (The first KZS rows get multiplied by zero.) ==== */
+/*                 ==== Copy bottom of H to top+KZS of scratch ==== */
+/*                  (The first KZS rows get multiplied by zero.) ==== */
 
 		    slacpy_("ALL", &knz, &jlen, &h__[incol + 1 + j2 + jcol * 
 			    h_dim1], ldh, &wh[kzs + 1 + wh_dim1], ldwh);
@@ -872,7 +891,7 @@
 /*                 ==== Copy top of H bottom of WH ==== */
 
 		    slacpy_("ALL", &j2, &jlen, &h__[incol + 1 + jcol * h_dim1]
-			    , ldh, &wh[i2 + 1 + wh_dim1], ldwh);
+, ldh, &wh[i2 + 1 + wh_dim1], ldwh);
 
 /*                 ==== Multiply by U21' ==== */
 
@@ -905,8 +924,8 @@
 		    i__5 = *nv, i__7 = max(incol,*ktop) - jrow;
 		    jlen = min(i__5,i__7);
 
-/*                 ==== Copy right of H to scratch (the first KZS   
-                   .    columns get multiplied by zero) ==== */
+/*                 ==== Copy right of H to scratch (the first KZS */
+/*                 .    columns get multiplied by zero) ==== */
 
 		    slacpy_("ALL", &jlen, &knz, &h__[jrow + (incol + 1 + j2) *
 			     h_dim1], ldh, &wv[(kzs + 1) * wv_dim1 + 1], ldwv);
@@ -964,8 +983,8 @@
 			i__5 = *nv, i__7 = *ihiz - jrow + 1;
 			jlen = min(i__5,i__7);
 
-/*                    ==== Copy right of Z to left of scratch (first   
-                      .     KZS columns get multiplied by zero) ==== */
+/*                    ==== Copy right of Z to left of scratch (first */
+/*                    .     KZS columns get multiplied by zero) ==== */
 
 			slacpy_("ALL", &jlen, &knz, &z__[jrow + (incol + 1 + 
 				j2) * z_dim1], ldz, &wv[(kzs + 1) * wv_dim1 + 
