@@ -1,143 +1,162 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static logical c_false = FALSE_;
+static integer c__2 = 2;
+static real c_b21 = 1.f;
+static real c_b25 = 0.f;
+static logical c_true = TRUE_;
 
 /* Subroutine */ int slaqtr_(logical *ltran, logical *lreal, integer *n, real 
 	*t, integer *ldt, real *b, real *w, real *scale, real *x, real *work, 
 	integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SLAQTR solves the real quasi-triangular system   
-
-                 op(T)*p = scale*c,               if LREAL = .TRUE.   
-
-    or the complex quasi-triangular systems   
-
-               op(T + iB)*(p+iq) = scale*(c+id),  if LREAL = .FALSE.   
-
-    in real arithmetic, where T is upper quasi-triangular.   
-    If LREAL = .FALSE., then the first diagonal block of T must be   
-    1 by 1, B is the specially structured matrix   
-
-                   B = [ b(1) b(2) ... b(n) ]   
-                       [       w            ]   
-                       [           w        ]   
-                       [              .     ]   
-                       [                 w  ]   
-
-    op(A) = A or A', A' denotes the conjugate transpose of   
-    matrix A.   
-
-    On input, X = [ c ].  On output, X = [ p ].   
-                  [ d ]                  [ q ]   
-
-    This subroutine is designed for the condition number estimation   
-    in routine STRSNA.   
-
-    Arguments   
-    =========   
-
-    LTRAN   (input) LOGICAL   
-            On entry, LTRAN specifies the option of conjugate transpose:   
-               = .FALSE.,    op(T+i*B) = T+i*B,   
-               = .TRUE.,     op(T+i*B) = (T+i*B)'.   
-
-    LREAL   (input) LOGICAL   
-            On entry, LREAL specifies the input matrix structure:   
-               = .FALSE.,    the input is complex   
-               = .TRUE.,     the input is real   
-
-    N       (input) INTEGER   
-            On entry, N specifies the order of T+i*B. N >= 0.   
-
-    T       (input) REAL array, dimension (LDT,N)   
-            On entry, T contains a matrix in Schur canonical form.   
-            If LREAL = .FALSE., then the first diagonal block of T must   
-            be 1 by 1.   
-
-    LDT     (input) INTEGER   
-            The leading dimension of the matrix T. LDT >= max(1,N).   
-
-    B       (input) REAL array, dimension (N)   
-            On entry, B contains the elements to form the matrix   
-            B as described above.   
-            If LREAL = .TRUE., B is not referenced.   
-
-    W       (input) REAL   
-            On entry, W is the diagonal element of the matrix B.   
-            If LREAL = .TRUE., W is not referenced.   
-
-    SCALE   (output) REAL   
-            On exit, SCALE is the scale factor.   
-
-    X       (input/output) REAL array, dimension (2*N)   
-            On entry, X contains the right hand side of the system.   
-            On exit, X is overwritten by the solution.   
-
-    WORK    (workspace) REAL array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            On exit, INFO is set to   
-               0: successful exit.   
-                 1: the some diagonal 1 by 1 block has been perturbed by   
-                    a small number SMIN to keep nonsingularity.   
-                 2: the some diagonal 2 by 2 block has been perturbed by   
-                    a small number in SLALN2 to keep nonsingularity.   
-            NOTE: In the interests of speed, this routine does not   
-                  check the inputs for errors.   
-
-   =====================================================================   
-
-
-       Do not test the input parameters for errors   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static logical c_false = FALSE_;
-    static integer c__2 = 2;
-    static real c_b21 = 1.f;
-    static real c_b25 = 0.f;
-    static logical c_true = TRUE_;
-    
     /* System generated locals */
     integer t_dim1, t_offset, i__1, i__2;
     real r__1, r__2, r__3, r__4, r__5, r__6;
+
     /* Local variables */
-    static real d__[4]	/* was [2][2] */;
-    static integer i__, j, k;
-    static real v[4]	/* was [2][2] */, z__;
-    static integer j1, j2, n1, n2;
-    static real si, xj, sr, rec, eps, tjj, tmp;
-    static integer ierr;
-    static real smin;
+    real d__[4]	/* was [2][2] */;
+    integer i__, j, k;
+    real v[4]	/* was [2][2] */, z__;
+    integer j1, j2, n1, n2;
+    real si, xj, sr, rec, eps, tjj, tmp;
+    integer ierr;
+    real smin;
     extern doublereal sdot_(integer *, real *, integer *, real *, integer *);
-    static real xmax;
+    real xmax;
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static integer jnext;
+    integer jnext;
     extern doublereal sasum_(integer *, real *, integer *);
-    static real sminw, xnorm;
+    real sminw, xnorm;
     extern /* Subroutine */ int saxpy_(integer *, real *, real *, integer *, 
 	    real *, integer *), slaln2_(logical *, integer *, integer *, real 
 	    *, real *, real *, integer *, real *, real *, real *, integer *, 
 	    real *, real *, real *, integer *, real *, real *, integer *);
-    static real scaloc;
+    real scaloc;
     extern doublereal slamch_(char *), slange_(char *, integer *, 
 	    integer *, real *, integer *, real *);
-    static real bignum;
+    real bignum;
     extern integer isamax_(integer *, real *, integer *);
     extern /* Subroutine */ int sladiv_(real *, real *, real *, real *, real *
-	    , real *);
-    static logical notran;
-    static real smlnum;
+, real *);
+    logical notran;
+    real smlnum;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SLAQTR solves the real quasi-triangular system */
+
+/*               op(T)*p = scale*c,               if LREAL = .TRUE. */
+
+/*  or the complex quasi-triangular systems */
+
+/*             op(T + iB)*(p+iq) = scale*(c+id),  if LREAL = .FALSE. */
+
+/*  in real arithmetic, where T is upper quasi-triangular. */
+/*  If LREAL = .FALSE., then the first diagonal block of T must be */
+/*  1 by 1, B is the specially structured matrix */
+
+/*                 B = [ b(1) b(2) ... b(n) ] */
+/*                     [       w            ] */
+/*                     [           w        ] */
+/*                     [              .     ] */
+/*                     [                 w  ] */
+
+/*  op(A) = A or A', A' denotes the conjugate transpose of */
+/*  matrix A. */
+
+/*  On input, X = [ c ].  On output, X = [ p ]. */
+/*                [ d ]                  [ q ] */
+
+/*  This subroutine is designed for the condition number estimation */
+/*  in routine STRSNA. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  LTRAN   (input) LOGICAL */
+/*          On entry, LTRAN specifies the option of conjugate transpose: */
+/*             = .FALSE.,    op(T+i*B) = T+i*B, */
+/*             = .TRUE.,     op(T+i*B) = (T+i*B)'. */
+
+/*  LREAL   (input) LOGICAL */
+/*          On entry, LREAL specifies the input matrix structure: */
+/*             = .FALSE.,    the input is complex */
+/*             = .TRUE.,     the input is real */
+
+/*  N       (input) INTEGER */
+/*          On entry, N specifies the order of T+i*B. N >= 0. */
+
+/*  T       (input) REAL array, dimension (LDT,N) */
+/*          On entry, T contains a matrix in Schur canonical form. */
+/*          If LREAL = .FALSE., then the first diagonal block of T must */
+/*          be 1 by 1. */
+
+/*  LDT     (input) INTEGER */
+/*          The leading dimension of the matrix T. LDT >= max(1,N). */
+
+/*  B       (input) REAL array, dimension (N) */
+/*          On entry, B contains the elements to form the matrix */
+/*          B as described above. */
+/*          If LREAL = .TRUE., B is not referenced. */
+
+/*  W       (input) REAL */
+/*          On entry, W is the diagonal element of the matrix B. */
+/*          If LREAL = .TRUE., W is not referenced. */
+
+/*  SCALE   (output) REAL */
+/*          On exit, SCALE is the scale factor. */
+
+/*  X       (input/output) REAL array, dimension (2*N) */
+/*          On entry, X contains the right hand side of the system. */
+/*          On exit, X is overwritten by the solution. */
+
+/*  WORK    (workspace) REAL array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          On exit, INFO is set to */
+/*             0: successful exit. */
+/*               1: the some diagonal 1 by 1 block has been perturbed by */
+/*                  a small number SMIN to keep nonsingularity. */
+/*               2: the some diagonal 2 by 2 block has been perturbed by */
+/*                  a small number in SLALN2 to keep nonsingularity. */
+/*          NOTE: In the interests of speed, this routine does not */
+/*                check the inputs for errors. */
+
+/* ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Do not test the input parameters for errors */
+
+    /* Parameter adjustments */
     t_dim1 = *ldt;
     t_offset = 1 + t_dim1;
     t -= t_offset;
@@ -172,8 +191,8 @@
     r__1 = smlnum, r__2 = eps * xnorm;
     smin = dmax(r__1,r__2);
 
-/*     Compute 1-norm of each column of strictly upper triangular   
-       part of T to control overflow in triangular solver. */
+/*     Compute 1-norm of each column of strictly upper triangular */
+/*     part of T to control overflow in triangular solver. */
 
     work[1] = 0.f;
     i__1 = *n;
@@ -229,10 +248,10 @@
 
 		if (j1 == j2) {
 
-/*                 Meet 1 by 1 diagonal block   
+/*                 Meet 1 by 1 diagonal block */
 
-                   Scale to avoid overflow when computing   
-                       x(j) = b(j)/T(j,j) */
+/*                 Scale to avoid overflow when computing */
+/*                     x(j) = b(j)/T(j,j) */
 
 		    xj = (r__1 = x[j1], dabs(r__1));
 		    tjj = (r__1 = t[j1 + j1 * t_dim1], dabs(r__1));
@@ -258,8 +277,8 @@
 		    x[j1] /= tmp;
 		    xj = (r__1 = x[j1], dabs(r__1));
 
-/*                 Scale x if necessary to avoid overflow when adding a   
-                   multiple of column j1 of T. */
+/*                 Scale x if necessary to avoid overflow when adding a */
+/*                 multiple of column j1 of T. */
 
 		    if (xj > 1.f) {
 			rec = 1.f / xj;
@@ -280,10 +299,10 @@
 
 		} else {
 
-/*                 Meet 2 by 2 diagonal block   
+/*                 Meet 2 by 2 diagonal block */
 
-                   Call 2 by 2 linear system solve, to take   
-                   care of possible overflow by scaling factor. */
+/*                 Call 2 by 2 linear system solve, to take */
+/*                 care of possible overflow by scaling factor. */
 
 		    d__[0] = x[j1];
 		    d__[1] = x[j2];
@@ -301,10 +320,10 @@
 		    x[j1] = v[0];
 		    x[j2] = v[1];
 
-/*                 Scale V(1,1) (= X(J1)) and/or V(2,1) (=X(J2))   
-                   to avoid overflow in updating right-hand side.   
+/*                 Scale V(1,1) (= X(J1)) and/or V(2,1) (=X(J2)) */
+/*                 to avoid overflow in updating right-hand side. */
 
-   Computing MAX */
+/* Computing MAX */
 		    r__1 = dabs(v[0]), r__2 = dabs(v[1]);
 		    xj = dmax(r__1,r__2);
 		    if (xj > 1.f) {
@@ -361,10 +380,10 @@ L30:
 
 		if (j1 == j2) {
 
-/*                 1 by 1 diagonal block   
+/*                 1 by 1 diagonal block */
 
-                   Scale if necessary to avoid overflow in forming the   
-                   right-hand side element by inner product. */
+/*                 Scale if necessary to avoid overflow in forming the */
+/*                 right-hand side element by inner product. */
 
 		    xj = (r__1 = x[j1], dabs(r__1));
 		    if (xmax > 1.f) {
@@ -404,12 +423,12 @@ L30:
 
 		} else {
 
-/*                 2 by 2 diagonal block   
+/*                 2 by 2 diagonal block */
 
-                   Scale if necessary to avoid overflow in forming the   
-                   right-hand side elements by inner product.   
+/*                 Scale if necessary to avoid overflow in forming the */
+/*                 right-hand side elements by inner product. */
 
-   Computing MAX */
+/* Computing MAX */
 		    r__3 = (r__1 = x[j1], dabs(r__1)), r__4 = (r__2 = x[j2], 
 			    dabs(r__2));
 		    xj = dmax(r__3,r__4);
@@ -432,7 +451,7 @@ L30:
 			    &x[1], &c__1);
 
 		    slaln2_(&c_true, &c__2, &c__1, &smin, &c_b21, &t[j1 + j1 *
-			     t_dim1], ldt, &c_b21, &c_b21, d__, &c__2, &c_b25,
+			     t_dim1], ldt, &c_b21, &c_b21, d__, &c__2, &c_b25, 
 			     &c_b25, v, &c__2, &scaloc, &xnorm, &ierr);
 		    if (ierr != 0) {
 			*info = 2;
@@ -481,9 +500,9 @@ L40:
 
 		if (j1 == j2) {
 
-/*                 1 by 1 diagonal block   
+/*                 1 by 1 diagonal block */
 
-                   Scale if necessary to avoid overflow in division */
+/*                 Scale if necessary to avoid overflow in division */
 
 		    z__ = *w;
 		    if (j1 == 1) {
@@ -518,8 +537,8 @@ L40:
 		    xj = (r__1 = x[j1], dabs(r__1)) + (r__2 = x[*n + j1], 
 			    dabs(r__2));
 
-/*                 Scale x if necessary to avoid overflow when adding a   
-                   multiple of column j1 of T. */
+/*                 Scale x if necessary to avoid overflow when adding a */
+/*                 multiple of column j1 of T. */
 
 		    if (xj > 1.f) {
 			rec = 1.f / xj;
@@ -579,10 +598,10 @@ L40:
 		    x[*n + j1] = v[2];
 		    x[*n + j2] = v[3];
 
-/*                 Scale X(J1), .... to avoid overflow in   
-                   updating right hand side.   
+/*                 Scale X(J1), .... to avoid overflow in */
+/*                 updating right hand side. */
 
-   Computing MAX */
+/* Computing MAX */
 		    r__1 = dabs(v[0]) + dabs(v[2]), r__2 = dabs(v[1]) + dabs(
 			    v[3]);
 		    xj = dmax(r__1,r__2);
@@ -658,10 +677,10 @@ L70:
 
 		if (j1 == j2) {
 
-/*                 1 by 1 diagonal block   
+/*                 1 by 1 diagonal block */
 
-                   Scale if necessary to avoid overflow in forming the   
-                   right-hand side element by inner product. */
+/*                 Scale if necessary to avoid overflow in forming the */
+/*                 right-hand side element by inner product. */
 
 		    xj = (r__1 = x[j1], dabs(r__1)) + (r__2 = x[j1 + *n], 
 			    dabs(r__2));
@@ -692,8 +711,8 @@ L70:
 			z__ = b[1];
 		    }
 
-/*                 Scale if necessary to avoid overflow in   
-                   complex division */
+/*                 Scale if necessary to avoid overflow in */
+/*                 complex division */
 
 		    tjj = (r__1 = t[j1 + j1 * t_dim1], dabs(r__1)) + dabs(z__)
 			    ;
@@ -723,12 +742,12 @@ L70:
 
 		} else {
 
-/*                 2 by 2 diagonal block   
+/*                 2 by 2 diagonal block */
 
-                   Scale if necessary to avoid overflow in forming the   
-                   right-hand side element by inner product.   
+/*                 Scale if necessary to avoid overflow in forming the */
+/*                 right-hand side element by inner product. */
 
-   Computing MAX */
+/* Computing MAX */
 		    r__5 = (r__1 = x[j1], dabs(r__1)) + (r__2 = x[*n + j1], 
 			    dabs(r__2)), r__6 = (r__3 = x[j2], dabs(r__3)) + (
 			    r__4 = x[*n + j2], dabs(r__4));
