@@ -1,104 +1,23 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static real c_b14 = 1.f;
+static real c_b25 = -1.f;
 
 /* Subroutine */ int slarfb_(char *side, char *trans, char *direct, char *
 	storev, integer *m, integer *n, integer *k, real *v, integer *ldv, 
 	real *t, integer *ldt, real *c__, integer *ldc, real *work, integer *
-	ldwork  	)
+	ldwork)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SLARFB applies a real block reflector H or its transpose H' to a   
-    real m by n matrix C, from either the left or the right.   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'L': apply H or H' from the Left   
-            = 'R': apply H or H' from the Right   
-
-    TRANS   (input) CHARACTER*1   
-            = 'N': apply H (No transpose)   
-            = 'T': apply H' (Transpose)   
-
-    DIRECT  (input) CHARACTER*1   
-            Indicates how H is formed from a product of elementary   
-            reflectors   
-            = 'F': H = H(1) H(2) . . . H(k) (Forward)   
-            = 'B': H = H(k) . . . H(2) H(1) (Backward)   
-
-    STOREV  (input) CHARACTER*1   
-            Indicates how the vectors which define the elementary   
-            reflectors are stored:   
-            = 'C': Columnwise   
-            = 'R': Rowwise   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix C.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix C.   
-
-    K       (input) INTEGER   
-            The order of the matrix T (= the number of elementary   
-            reflectors whose product defines the block reflector).   
-
-    V       (input) REAL array, dimension   
-                                  (LDV,K) if STOREV = 'C'   
-                                  (LDV,M) if STOREV = 'R' and SIDE = 'L'   
-                                  (LDV,N) if STOREV = 'R' and SIDE = 'R'   
-            The matrix V. See further details.   
-
-    LDV     (input) INTEGER   
-            The leading dimension of the array V.   
-            If STOREV = 'C' and SIDE = 'L', LDV >= max(1,M);   
-            if STOREV = 'C' and SIDE = 'R', LDV >= max(1,N);   
-            if STOREV = 'R', LDV >= K.   
-
-    T       (input) REAL array, dimension (LDT,K)   
-            The triangular k by k matrix T in the representation of the   
-            block reflector.   
-
-    LDT     (input) INTEGER   
-            The leading dimension of the array T. LDT >= K.   
-
-    C       (input/output) REAL array, dimension (LDC,N)   
-            On entry, the m by n matrix C.   
-            On exit, C is overwritten by H*C or H'*C or C*H or C*H'.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C. LDA >= max(1,M).   
-
-    WORK    (workspace) REAL array, dimension (LDWORK,K)   
-
-    LDWORK  (input) INTEGER   
-            The leading dimension of the array WORK.   
-            If SIDE = 'L', LDWORK >= max(1,N);   
-            if SIDE = 'R', LDWORK >= max(1,M).   
-
-    =====================================================================   
-
-
-       Quick return if possible   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static real c_b14 = 1.f;
-    static real c_b25 = -1.f;
-    
     /* System generated locals */
     integer c_dim1, c_offset, t_dim1, t_offset, v_dim1, v_offset, work_dim1, 
 	    work_offset, i__1, i__2;
+
     /* Local variables */
-    static integer i__, j;
+    integer i__, j;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sgemm_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, real *, integer *, real *, 
@@ -106,9 +25,105 @@
 	    integer *, real *, integer *), strmm_(char *, char *, char *, 
 	    char *, integer *, integer *, real *, real *, integer *, real *, 
 	    integer *);
-    static char transt[1];
+    char transt[1];
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SLARFB applies a real block reflector H or its transpose H' to a */
+/*  real m by n matrix C, from either the left or the right. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'L': apply H or H' from the Left */
+/*          = 'R': apply H or H' from the Right */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          = 'N': apply H (No transpose) */
+/*          = 'T': apply H' (Transpose) */
+
+/*  DIRECT  (input) CHARACTER*1 */
+/*          Indicates how H is formed from a product of elementary */
+/*          reflectors */
+/*          = 'F': H = H(1) H(2) . . . H(k) (Forward) */
+/*          = 'B': H = H(k) . . . H(2) H(1) (Backward) */
+
+/*  STOREV  (input) CHARACTER*1 */
+/*          Indicates how the vectors which define the elementary */
+/*          reflectors are stored: */
+/*          = 'C': Columnwise */
+/*          = 'R': Rowwise */
+
+/*  M       (input) INTEGER */
+/*          The number of rows of the matrix C. */
+
+/*  N       (input) INTEGER */
+/*          The number of columns of the matrix C. */
+
+/*  K       (input) INTEGER */
+/*          The order of the matrix T (= the number of elementary */
+/*          reflectors whose product defines the block reflector). */
+
+/*  V       (input) REAL array, dimension */
+/*                                (LDV,K) if STOREV = 'C' */
+/*                                (LDV,M) if STOREV = 'R' and SIDE = 'L' */
+/*                                (LDV,N) if STOREV = 'R' and SIDE = 'R' */
+/*          The matrix V. See further details. */
+
+/*  LDV     (input) INTEGER */
+/*          The leading dimension of the array V. */
+/*          If STOREV = 'C' and SIDE = 'L', LDV >= max(1,M); */
+/*          if STOREV = 'C' and SIDE = 'R', LDV >= max(1,N); */
+/*          if STOREV = 'R', LDV >= K. */
+
+/*  T       (input) REAL array, dimension (LDT,K) */
+/*          The triangular k by k matrix T in the representation of the */
+/*          block reflector. */
+
+/*  LDT     (input) INTEGER */
+/*          The leading dimension of the array T. LDT >= K. */
+
+/*  C       (input/output) REAL array, dimension (LDC,N) */
+/*          On entry, the m by n matrix C. */
+/*          On exit, C is overwritten by H*C or H'*C or C*H or C*H'. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. LDA >= max(1,M). */
+
+/*  WORK    (workspace) REAL array, dimension (LDWORK,K) */
+
+/*  LDWORK  (input) INTEGER */
+/*          The leading dimension of the array WORK. */
+/*          If SIDE = 'L', LDWORK >= max(1,N); */
+/*          if SIDE = 'R', LDWORK >= max(1,M). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Quick return if possible */
+
+    /* Parameter adjustments */
     v_dim1 = *ldv;
     v_offset = 1 + v_dim1;
     v -= v_offset;
@@ -137,18 +152,18 @@
 
 	if (lsame_(direct, "F")) {
 
-/*           Let  V =  ( V1 )    (first K rows)   
-                       ( V2 )   
-             where  V1  is unit lower triangular. */
+/*           Let  V =  ( V1 )    (first K rows) */
+/*                     ( V2 ) */
+/*           where  V1  is unit lower triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK)   
+/*              W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK) */
 
-                W := C1' */
+/*              W := C1' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -207,11 +222,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK)   
+/*              W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK) */
 
-                W := C1 */
+/*              W := C1 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -272,18 +287,18 @@
 
 	} else {
 
-/*           Let  V =  ( V1 )   
-                       ( V2 )    (last K rows)   
-             where  V2  is unit upper triangular. */
+/*           Let  V =  ( V1 ) */
+/*                     ( V2 )    (last K rows) */
+/*           where  V2  is unit upper triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK)   
+/*              W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK) */
 
-                W := C2' */
+/*              W := C2' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -346,11 +361,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK)   
+/*              W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK) */
 
-                W := C2 */
+/*              W := C2 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -417,17 +432,17 @@
 
 	if (lsame_(direct, "F")) {
 
-/*           Let  V =  ( V1  V2 )    (V1: first K columns)   
-             where  V1  is unit upper triangular. */
+/*           Let  V =  ( V1  V2 )    (V1: first K columns) */
+/*           where  V1  is unit upper triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK)   
+/*              W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK) */
 
-                W := C1' */
+/*              W := C1' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -486,11 +501,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK)   
+/*              W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK) */
 
-                W := C1 */
+/*              W := C1 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -553,17 +568,17 @@
 
 	} else {
 
-/*           Let  V =  ( V1  V2 )    (V2: last K columns)   
-             where  V2  is unit lower triangular. */
+/*           Let  V =  ( V1  V2 )    (V2: last K columns) */
+/*           where  V2  is unit lower triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK)   
+/*              W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK) */
 
-                W := C2' */
+/*              W := C2' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -625,11 +640,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK)   
+/*              W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK) */
 
-                W := C2 */
+/*              W := C2 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
