@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* slasd4.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int slasd4_(integer *n, integer *i__, real *d__, real *z__, 
 	real *delta, real *rho, real *sigma, real *work, integer *info)
@@ -24,125 +12,142 @@
     double sqrt(doublereal);
 
     /* Local variables */
-    static real a, b, c__;
-    static integer j;
-    static real w, dd[3];
-    static integer ii;
-    static real dw, zz[3];
-    static integer ip1;
-    static real eta, phi, eps, tau, psi;
-    static integer iim1, iip1;
-    static real dphi, dpsi;
-    static integer iter;
-    static real temp, prew, sg2lb, sg2ub, temp1, temp2, dtiim, delsq, dtiip;
-    static integer niter;
-    static real dtisq;
-    static logical swtch;
-    static real dtnsq;
+    real a, b, c__;
+    integer j;
+    real w, dd[3];
+    integer ii;
+    real dw, zz[3];
+    integer ip1;
+    real eta, phi, eps, tau, psi;
+    integer iim1, iip1;
+    real dphi, dpsi;
+    integer iter;
+    real temp, prew, sg2lb, sg2ub, temp1, temp2, dtiim, delsq, dtiip;
+    integer niter;
+    real dtisq;
+    logical swtch;
+    real dtnsq;
     extern /* Subroutine */ int slaed6_(integer *, logical *, real *, real *, 
 	    real *, real *, real *, integer *);
-    static real delsq2;
+    real delsq2;
     extern /* Subroutine */ int slasd5_(integer *, real *, real *, real *, 
 	    real *, real *, real *);
-    static real dtnsq1;
-    static logical swtch3;
+    real dtnsq1;
+    logical swtch3;
     extern doublereal slamch_(char *);
-    static logical orgati;
-    static real erretm, dtipsq, rhoinv;
+    logical orgati;
+    real erretm, dtipsq, rhoinv;
 
 
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    This subroutine computes the square root of the I-th updated   
-    eigenvalue of a positive symmetric rank-one modification to   
-    a positive diagonal matrix whose entries are given as the squares   
-    of the corresponding entries in the array d, and that   
+/*  This subroutine computes the square root of the I-th updated */
+/*  eigenvalue of a positive symmetric rank-one modification to */
+/*  a positive diagonal matrix whose entries are given as the squares */
+/*  of the corresponding entries in the array d, and that */
 
-           0 <= D(i) < D(j)  for  i < j   
+/*         0 <= D(i) < D(j)  for  i < j */
 
-    and that RHO > 0. This is arranged by the calling routine, and is   
-    no loss in generality.  The rank-one modified system is thus   
+/*  and that RHO > 0. This is arranged by the calling routine, and is */
+/*  no loss in generality.  The rank-one modified system is thus */
 
-           diag( D ) * diag( D ) +  RHO *  Z * Z_transpose.   
+/*         diag( D ) * diag( D ) +  RHO *  Z * Z_transpose. */
 
-    where we assume the Euclidean norm of Z is 1.   
+/*  where we assume the Euclidean norm of Z is 1. */
 
-    The method consists of approximating the rational functions in the   
-    secular equation by simpler interpolating rational functions.   
+/*  The method consists of approximating the rational functions in the */
+/*  secular equation by simpler interpolating rational functions. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    N      (input) INTEGER   
-           The length of all arrays.   
+/*  N      (input) INTEGER */
+/*         The length of all arrays. */
 
-    I      (input) INTEGER   
-           The index of the eigenvalue to be computed.  1 <= I <= N.   
+/*  I      (input) INTEGER */
+/*         The index of the eigenvalue to be computed.  1 <= I <= N. */
 
-    D      (input) REAL array, dimension ( N )   
-           The original eigenvalues.  It is assumed that they are in   
-           order, 0 <= D(I) < D(J)  for I < J.   
+/*  D      (input) REAL array, dimension ( N ) */
+/*         The original eigenvalues.  It is assumed that they are in */
+/*         order, 0 <= D(I) < D(J)  for I < J. */
 
-    Z      (input) REAL array, dimension (N)   
-           The components of the updating vector.   
+/*  Z      (input) REAL array, dimension (N) */
+/*         The components of the updating vector. */
 
-    DELTA  (output) REAL array, dimension (N)   
-           If N .ne. 1, DELTA contains (D(j) - sigma_I) in its  j-th   
-           component.  If N = 1, then DELTA(1) = 1.  The vector DELTA   
-           contains the information necessary to construct the   
-           (singular) eigenvectors.   
+/*  DELTA  (output) REAL array, dimension (N) */
+/*         If N .ne. 1, DELTA contains (D(j) - sigma_I) in its  j-th */
+/*         component.  If N = 1, then DELTA(1) = 1.  The vector DELTA */
+/*         contains the information necessary to construct the */
+/*         (singular) eigenvectors. */
 
-    RHO    (input) REAL   
-           The scalar in the symmetric updating formula.   
+/*  RHO    (input) REAL */
+/*         The scalar in the symmetric updating formula. */
 
-    SIGMA  (output) REAL   
-           The computed sigma_I, the I-th updated eigenvalue.   
+/*  SIGMA  (output) REAL */
+/*         The computed sigma_I, the I-th updated eigenvalue. */
 
-    WORK   (workspace) REAL array, dimension (N)   
-           If N .ne. 1, WORK contains (D(j) + sigma_I) in its  j-th   
-           component.  If N = 1, then WORK( 1 ) = 1.   
+/*  WORK   (workspace) REAL array, dimension (N) */
+/*         If N .ne. 1, WORK contains (D(j) + sigma_I) in its  j-th */
+/*         component.  If N = 1, then WORK( 1 ) = 1. */
 
-    INFO   (output) INTEGER   
-           = 0:  successful exit   
-           > 0:  if INFO = 1, the updating process failed.   
+/*  INFO   (output) INTEGER */
+/*         = 0:  successful exit */
+/*         > 0:  if INFO = 1, the updating process failed. */
 
-    Internal Parameters   
-    ===================   
+/*  Internal Parameters */
+/*  =================== */
 
-    Logical variable ORGATI (origin-at-i?) is used for distinguishing   
-    whether D(i) or D(i+1) is treated as the origin.   
+/*  Logical variable ORGATI (origin-at-i?) is used for distinguishing */
+/*  whether D(i) or D(i+1) is treated as the origin. */
 
-              ORGATI = .true.    origin at i   
-              ORGATI = .false.   origin at i+1   
+/*            ORGATI = .true.    origin at i */
+/*            ORGATI = .false.   origin at i+1 */
 
-    Logical variable SWTCH3 (switch-for-3-poles?) is for noting   
-    if we are working with THREE poles!   
+/*  Logical variable SWTCH3 (switch-for-3-poles?) is for noting */
+/*  if we are working with THREE poles! */
 
-    MAXIT is the maximum number of iterations allowed for each   
-    eigenvalue.   
+/*  MAXIT is the maximum number of iterations allowed for each */
+/*  eigenvalue. */
 
-    Further Details   
-    ===============   
+/*  Further Details */
+/*  =============== */
 
-    Based on contributions by   
-       Ren-Cang Li, Computer Science Division, University of California   
-       at Berkeley, USA   
+/*  Based on contributions by */
+/*     Ren-Cang Li, Computer Science Division, University of California */
+/*     at Berkeley, USA */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Since this routine is called in an inner loop, we do no argument   
-       checking.   
+/*     Since this routine is called in an inner loop, we do no argument */
+/*     checking. */
 
-       Quick return for N=1 and 2.   
+/*     Quick return for N=1 and 2. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --work;
     --delta;
     --z__;
@@ -182,8 +187,8 @@
 
 	temp = *rho / 2.f;
 
-/*        If ||Z||_2 is not one, then TEMP should be set to   
-          RHO * ||Z||_2^2 / TWO */
+/*        If ||Z||_2 is not one, then TEMP should be set to */
+/*        RHO * ||Z||_2^2 / TWO */
 
 	temp1 = temp / (d__[*n] + sqrt(d__[*n] * d__[*n] + temp));
 	i__1 = *n;
@@ -210,8 +215,8 @@
 		    n] - d__[*n - 1] + *rho / (d__[*n] + temp1))) + z__[*n] * 
 		    z__[*n] / *rho;
 
-/*           The following TAU is to approximate   
-             SIGMA_n^2 - D( N )*D( N ) */
+/*           The following TAU is to approximate */
+/*           SIGMA_n^2 - D( N )*D( N ) */
 
 	    if (c__ <= temp) {
 		tau = *rho;
@@ -227,16 +232,16 @@
 		}
 	    }
 
-/*           It can be proved that   
-                 D(N)^2+RHO/2 <= SIGMA_n^2 < D(N)^2+TAU <= D(N)^2+RHO */
+/*           It can be proved that */
+/*               D(N)^2+RHO/2 <= SIGMA_n^2 < D(N)^2+TAU <= D(N)^2+RHO */
 
 	} else {
 	    delsq = (d__[*n] - d__[*n - 1]) * (d__[*n] + d__[*n - 1]);
 	    a = -c__ * delsq + z__[*n - 1] * z__[*n - 1] + z__[*n] * z__[*n];
 	    b = z__[*n] * z__[*n] * delsq;
 
-/*           The following TAU is to approximate   
-             SIGMA_n^2 - D( N )*D( N ) */
+/*           The following TAU is to approximate */
+/*           SIGMA_n^2 - D( N )*D( N ) */
 
 	    if (a < 0.f) {
 		tau = b * 2.f / (sqrt(a * a + b * 4.f * c__) - a);
@@ -244,8 +249,8 @@
 		tau = (a + sqrt(a * a + b * 4.f * c__)) / (c__ * 2.f);
 	    }
 
-/*           It can be proved that   
-             D(N)^2 < D(N)^2+TAU < SIGMA(N)^2 < D(N)^2+RHO/2 */
+/*           It can be proved that */
+/*           D(N)^2 < D(N)^2+TAU < SIGMA(N)^2 < D(N)^2+RHO/2 */
 
 	}
 
@@ -313,11 +318,11 @@
 		    r__1))));
 	}
 
-/*        Note, eta should be positive if w is negative, and   
-          eta should be negative otherwise. However,   
-          if for some reason caused by roundoff, eta*w > 0,   
-          we simply use one Newton step instead. This way   
-          will guarantee eta*w < 0. */
+/*        Note, eta should be positive if w is negative, and */
+/*        eta should be negative otherwise. However, */
+/*        if for some reason caused by roundoff, eta*w > 0, */
+/*        we simply use one Newton step instead. This way */
+/*        will guarantee eta*w < 0. */
 
 	if (w * eta > 0.f) {
 	    eta = -w / (dpsi + dphi);
@@ -390,11 +395,11 @@
 			r__1))));
 	    }
 
-/*           Note, eta should be positive if w is negative, and   
-             eta should be negative otherwise. However,   
-             if for some reason caused by roundoff, eta*w > 0,   
-             we simply use one Newton step instead. This way   
-             will guarantee eta*w < 0. */
+/*           Note, eta should be positive if w is negative, and */
+/*           eta should be negative otherwise. However, */
+/*           if for some reason caused by roundoff, eta*w > 0, */
+/*           we simply use one Newton step instead. This way */
+/*           will guarantee eta*w < 0. */
 
 	    if (w * eta > 0.f) {
 		eta = -w / (dpsi + dphi);
@@ -487,9 +492,9 @@
 
 	if (w > 0.f) {
 
-/*           d(i)^2 < the ith sigma^2 < (d(i)^2+d(i+1)^2)/2   
+/*           d(i)^2 < the ith sigma^2 < (d(i)^2+d(i+1)^2)/2 */
 
-             We choose d(i) as origin. */
+/*           We choose d(i) as origin. */
 
 	    orgati = TRUE_;
 	    sg2lb = 0.f;
@@ -504,16 +509,16 @@
 			 (c__ * 2.f);
 	    }
 
-/*           TAU now is an estimation of SIGMA^2 - D( I )^2. The   
-             following, however, is the corresponding estimation of   
-             SIGMA - D( I ). */
+/*           TAU now is an estimation of SIGMA^2 - D( I )^2. The */
+/*           following, however, is the corresponding estimation of */
+/*           SIGMA - D( I ). */
 
 	    eta = tau / (d__[*i__] + sqrt(d__[*i__] * d__[*i__] + tau));
 	} else {
 
-/*           (d(i)^2+d(i+1)^2)/2 <= the ith sigma^2 < d(i+1)^2/2   
+/*           (d(i)^2+d(i+1)^2)/2 <= the ith sigma^2 < d(i+1)^2/2 */
 
-             We choose d(i+1) as origin. */
+/*           We choose d(i+1) as origin. */
 
 	    orgati = FALSE_;
 	    sg2lb = -delsq2;
@@ -528,9 +533,9 @@
 			/ (c__ * 2.f);
 	    }
 
-/*           TAU now is an estimation of SIGMA^2 - D( IP1 )^2. The   
-             following, however, is the corresponding estimation of   
-             SIGMA - D( IP1 ). */
+/*           TAU now is an estimation of SIGMA^2 - D( IP1 )^2. The */
+/*           following, however, is the corresponding estimation of */
+/*           SIGMA - D( IP1 ). */
 
 	    eta = tau / (d__[ip1] + sqrt((r__1 = d__[ip1] * d__[ip1] + tau, 
 		    dabs(r__1))));
@@ -588,8 +593,8 @@
 
 	w = rhoinv + phi + psi;
 
-/*        W is the value of the secular function with   
-          its ii-th element removed. */
+/*        W is the value of the secular function with */
+/*        its ii-th element removed. */
 
 	swtch3 = FALSE_;
 	if (orgati) {
@@ -699,11 +704,11 @@
 	    }
 	}
 
-/*        Note, eta should be positive if w is negative, and   
-          eta should be negative otherwise. However,   
-          if for some reason caused by roundoff, eta*w > 0,   
-          we simply use one Newton step instead. This way   
-          will guarantee eta*w < 0. */
+/*        Note, eta should be positive if w is negative, and */
+/*        eta should be negative otherwise. However, */
+/*        if for some reason caused by roundoff, eta*w > 0, */
+/*        we simply use one Newton step instead. This way */
+/*        will guarantee eta*w < 0. */
 
 	if (w * eta >= 0.f) {
 	    eta = -w / dw;
@@ -842,7 +847,8 @@
 		    }
 		    eta = b / a;
 		} else if (a <= 0.f) {
-		    eta = (a - sqrt((r__1 = a * a - b * 4.f * c__, dabs(r__1)) 			    )) / (c__ * 2.f);
+		    eta = (a - sqrt((r__1 = a * a - b * 4.f * c__, dabs(r__1))
+			    )) / (c__ * 2.f);
 		} else {
 		    eta = b * 2.f / (a + sqrt((r__1 = a * a - b * 4.f * c__, 
 			    dabs(r__1))));
@@ -894,11 +900,11 @@
 		}
 	    }
 
-/*           Note, eta should be positive if w is negative, and   
-             eta should be negative otherwise. However,   
-             if for some reason caused by roundoff, eta*w > 0,   
-             we simply use one Newton step instead. This way   
-             will guarantee eta*w < 0. */
+/*           Note, eta should be positive if w is negative, and */
+/*           eta should be negative otherwise. However, */
+/*           if for some reason caused by roundoff, eta*w > 0, */
+/*           we simply use one Newton step instead. This way */
+/*           will guarantee eta*w < 0. */
 
 	    if (w * eta >= 0.f) {
 		eta = -w / dw;
