@@ -1,126 +1,144 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
-/* Subroutine */ int slasyf_(char *uplo, integer *n, integer *nb, integer *kb,
+/* Table of constant values */
+
+static integer c__1 = 1;
+static real c_b8 = -1.f;
+static real c_b9 = 1.f;
+
+/* Subroutine */ int slasyf_(char *uplo, integer *n, integer *nb, integer *kb, 
 	 real *a, integer *lda, integer *ipiv, real *w, integer *ldw, integer 
 	*info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SLASYF computes a partial factorization of a real symmetric matrix A   
-    using the Bunch-Kaufman diagonal pivoting method. The partial   
-    factorization has the form:   
-
-    A  =  ( I  U12 ) ( A11  0  ) (  I    0   )  if UPLO = 'U', or:   
-          ( 0  U22 ) (  0   D  ) ( U12' U22' )   
-
-    A  =  ( L11  0 ) (  D   0  ) ( L11' L21' )  if UPLO = 'L'   
-          ( L21  I ) (  0  A22 ) (  0    I   )   
-
-    where the order of D is at most NB. The actual order is returned in   
-    the argument KB, and is either NB or NB-1, or N if N <= NB.   
-
-    SLASYF is an auxiliary routine called by SSYTRF. It uses blocked code   
-    (calling Level 3 BLAS) to update the submatrix A11 (if UPLO = 'U') or   
-    A22 (if UPLO = 'L').   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the upper or lower triangular part of the   
-            symmetric matrix A is stored:   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    NB      (input) INTEGER   
-            The maximum number of columns of the matrix A that should be   
-            factored.  NB should be at least 2 to allow for 2-by-2 pivot   
-            blocks.   
-
-    KB      (output) INTEGER   
-            The number of columns of A that were actually factored.   
-            KB is either NB-1 or NB, or N if N <= NB.   
-
-    A       (input/output) REAL array, dimension (LDA,N)   
-            On entry, the symmetric matrix A.  If UPLO = 'U', the leading   
-            n-by-n upper triangular part of A contains the upper   
-            triangular part of the matrix A, and the strictly lower   
-            triangular part of A is not referenced.  If UPLO = 'L', the   
-            leading n-by-n lower triangular part of A contains the lower   
-            triangular part of the matrix A, and the strictly upper   
-            triangular part of A is not referenced.   
-            On exit, A contains details of the partial factorization.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,N).   
-
-    IPIV    (output) INTEGER array, dimension (N)   
-            Details of the interchanges and the block structure of D.   
-            If UPLO = 'U', only the last KB elements of IPIV are set;   
-            if UPLO = 'L', only the first KB elements are set.   
-
-            If IPIV(k) > 0, then rows and columns k and IPIV(k) were   
-            interchanged and D(k,k) is a 1-by-1 diagonal block.   
-            If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and   
-            columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)   
-            is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =   
-            IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were   
-            interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.   
-
-    W       (workspace) REAL array, dimension (LDW,NB)   
-
-    LDW     (input) INTEGER   
-            The leading dimension of the array W.  LDW >= max(1,N).   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            > 0: if INFO = k, D(k,k) is exactly zero.  The factorization   
-                 has been completed, but the block diagonal matrix D is   
-                 exactly singular.   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static real c_b8 = -1.f;
-    static real c_b9 = 1.f;
-    
     /* System generated locals */
     integer a_dim1, a_offset, w_dim1, w_offset, i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2, r__3;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static integer j, k;
-    static real t, r1, d11, d21, d22;
-    static integer jb, jj, kk, jp, kp, kw, kkw, imax, jmax;
-    static real alpha;
+    integer j, k;
+    real t, r1, d11, d21, d22;
+    integer jb, jj, kk, jp, kp, kw, kkw, imax, jmax;
+    real alpha;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *), 
 	    sgemm_(char *, char *, integer *, integer *, integer *, real *, 
 	    real *, integer *, real *, integer *, real *, real *, integer *), sgemv_(char *, integer *, integer *, real *, 
 	    real *, integer *, real *, integer *, real *, real *, integer *);
-    static integer kstep;
+    integer kstep;
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *), sswap_(integer *, real *, integer *, real *, integer *
 );
-    static real absakk;
+    real absakk;
     extern integer isamax_(integer *, real *, integer *);
-    static real colmax, rowmax;
+    real colmax, rowmax;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SLASYF computes a partial factorization of a real symmetric matrix A */
+/*  using the Bunch-Kaufman diagonal pivoting method. The partial */
+/*  factorization has the form: */
+
+/*  A  =  ( I  U12 ) ( A11  0  ) (  I    0   )  if UPLO = 'U', or: */
+/*        ( 0  U22 ) (  0   D  ) ( U12' U22' ) */
+
+/*  A  =  ( L11  0 ) (  D   0  ) ( L11' L21' )  if UPLO = 'L' */
+/*        ( L21  I ) (  0  A22 ) (  0    I   ) */
+
+/*  where the order of D is at most NB. The actual order is returned in */
+/*  the argument KB, and is either NB or NB-1, or N if N <= NB. */
+
+/*  SLASYF is an auxiliary routine called by SSYTRF. It uses blocked code */
+/*  (calling Level 3 BLAS) to update the submatrix A11 (if UPLO = 'U') or */
+/*  A22 (if UPLO = 'L'). */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the upper or lower triangular part of the */
+/*          symmetric matrix A is stored: */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  NB      (input) INTEGER */
+/*          The maximum number of columns of the matrix A that should be */
+/*          factored.  NB should be at least 2 to allow for 2-by-2 pivot */
+/*          blocks. */
+
+/*  KB      (output) INTEGER */
+/*          The number of columns of A that were actually factored. */
+/*          KB is either NB-1 or NB, or N if N <= NB. */
+
+/*  A       (input/output) REAL array, dimension (LDA,N) */
+/*          On entry, the symmetric matrix A.  If UPLO = 'U', the leading */
+/*          n-by-n upper triangular part of A contains the upper */
+/*          triangular part of the matrix A, and the strictly lower */
+/*          triangular part of A is not referenced.  If UPLO = 'L', the */
+/*          leading n-by-n lower triangular part of A contains the lower */
+/*          triangular part of the matrix A, and the strictly upper */
+/*          triangular part of A is not referenced. */
+/*          On exit, A contains details of the partial factorization. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,N). */
+
+/*  IPIV    (output) INTEGER array, dimension (N) */
+/*          Details of the interchanges and the block structure of D. */
+/*          If UPLO = 'U', only the last KB elements of IPIV are set; */
+/*          if UPLO = 'L', only the first KB elements are set. */
+
+/*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were */
+/*          interchanged and D(k,k) is a 1-by-1 diagonal block. */
+/*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and */
+/*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k) */
+/*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) = */
+/*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were */
+/*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block. */
+
+/*  W       (workspace) REAL array, dimension (LDW,NB) */
+
+/*  LDW     (input) INTEGER */
+/*          The leading dimension of the array W.  LDW >= max(1,N). */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          > 0: if INFO = k, D(k,k) is exactly zero.  The factorization */
+/*               has been completed, but the block diagonal matrix D is */
+/*               exactly singular. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -138,13 +156,13 @@
 
     if (lsame_(uplo, "U")) {
 
-/*        Factorize the trailing columns of A using the upper triangle   
-          of A and working backwards, and compute the matrix W = U12*D   
-          for use in updating A11   
+/*        Factorize the trailing columns of A using the upper triangle */
+/*        of A and working backwards, and compute the matrix W = U12*D */
+/*        for use in updating A11 */
 
-          K is the main loop index, decreasing from N in steps of 1 or 2   
+/*        K is the main loop index, decreasing from N in steps of 1 or 2 */
 
-          KW is the column of W which corresponds to column K of A */
+/*        KW is the column of W which corresponds to column K of A */
 
 	k = *n;
 L10:
@@ -168,13 +186,13 @@ L10:
 
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	absakk = (r__1 = w[k + kw * w_dim1], dabs(r__1));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k > 1) {
 	    i__1 = k - 1;
@@ -214,8 +232,8 @@ L10:
 			    ldw, &c_b9, &w[(kw - 1) * w_dim1 + 1], &c__1);
 		}
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		i__1 = k - imax;
 		jmax = imax + isamax_(&i__1, &w[imax + 1 + (kw - 1) * w_dim1], 
@@ -238,8 +256,8 @@ L10:
 		} else if ((r__1 = w[imax + (kw - 1) * w_dim1], dabs(r__1)) >=
 			 alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 		    kp = imax;
 
@@ -249,8 +267,8 @@ L10:
 			    w_dim1 + 1], &c__1);
 		} else {
 
-/*                 interchange rows and columns K-1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K-1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 		    kp = imax;
 		    kstep = 2;
@@ -285,13 +303,13 @@ L10:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column KW of W now holds   
+/*              1-by-1 pivot block D(k): column KW of W now holds */
 
-                W(k) = U(k)*D(k)   
+/*              W(k) = U(k)*D(k) */
 
-                where U(k) is the k-th column of U   
+/*              where U(k) is the k-th column of U */
 
-                Store U(k) in column k of A */
+/*              Store U(k) in column k of A */
 
 		scopy_(&k, &w[kw * w_dim1 + 1], &c__1, &a[k * a_dim1 + 1], &
 			c__1);
@@ -300,13 +318,13 @@ L10:
 		sscal_(&i__1, &r1, &a[k * a_dim1 + 1], &c__1);
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns KW and KW-1 of W now   
-                hold   
+/*              2-by-2 pivot block D(k): columns KW and KW-1 of W now */
+/*              hold */
 
-                ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k)   
+/*              ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k) */
 
-                where U(k) and U(k-1) are the k-th and (k-1)-th columns   
-                of U */
+/*              where U(k) and U(k-1) are the k-th and (k-1)-th columns */
+/*              of U */
 
 		if (k > 2) {
 
@@ -351,11 +369,11 @@ L10:
 
 L30:
 
-/*        Update the upper triangle of A11 (= A(1:k,1:k)) as   
+/*        Update the upper triangle of A11 (= A(1:k,1:k)) as */
 
-          A11 := A11 - U12*D*U12' = A11 - U12*W'   
+/*        A11 := A11 - U12*D*U12' = A11 - U12*W' */
 
-          computing blocks of NB columns at a time */
+/*        computing blocks of NB columns at a time */
 
 	i__1 = -(*nb);
 	for (j = (k - 1) / *nb * *nb + 1; i__1 < 0 ? j >= 1 : j <= 1; j += 
@@ -386,8 +404,8 @@ L30:
 /* L50: */
 	}
 
-/*        Put U12 in standard form by partially undoing the interchanges   
-          in columns k+1:n */
+/*        Put U12 in standard form by partially undoing the interchanges */
+/*        in columns k+1:n */
 
 	j = k + 1;
 L60:
@@ -412,11 +430,11 @@ L60:
 
     } else {
 
-/*        Factorize the leading columns of A using the lower triangle   
-          of A and working forwards, and compute the matrix W = L21*D   
-          for use in updating A22   
+/*        Factorize the leading columns of A using the lower triangle */
+/*        of A and working forwards, and compute the matrix W = L21*D */
+/*        for use in updating A22 */
 
-          K is the main loop index, increasing from 1 in steps of 1 or 2 */
+/*        K is the main loop index, increasing from 1 in steps of 1 or 2 */
 
 	k = 1;
 L70:
@@ -438,13 +456,13 @@ L70:
 
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	absakk = (r__1 = w[k + k * w_dim1], dabs(r__1));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k < *n) {
 	    i__1 = *n - k;
@@ -484,8 +502,8 @@ L70:
 			lda, &w[imax + w_dim1], ldw, &c_b9, &w[k + (k + 1) * 
 			w_dim1], &c__1);
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		i__1 = imax - k;
 		jmax = k - 1 + isamax_(&i__1, &w[k + (k + 1) * w_dim1], &c__1)
@@ -509,8 +527,8 @@ L70:
 		} else if ((r__1 = w[imax + (k + 1) * w_dim1], dabs(r__1)) >= 
 			alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 		    kp = imax;
 
@@ -521,8 +539,8 @@ L70:
 			    w_dim1], &c__1);
 		} else {
 
-/*                 interchange rows and columns K+1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K+1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 		    kp = imax;
 		    kstep = 2;
@@ -553,13 +571,13 @@ L70:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k of W now holds   
+/*              1-by-1 pivot block D(k): column k of W now holds */
 
-                W(k) = L(k)*D(k)   
+/*              W(k) = L(k)*D(k) */
 
-                where L(k) is the k-th column of L   
+/*              where L(k) is the k-th column of L */
 
-                Store L(k) in column k of A */
+/*              Store L(k) in column k of A */
 
 		i__1 = *n - k + 1;
 		scopy_(&i__1, &w[k + k * w_dim1], &c__1, &a[k + k * a_dim1], &
@@ -571,12 +589,12 @@ L70:
 		}
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns k and k+1 of W now hold   
+/*              2-by-2 pivot block D(k): columns k and k+1 of W now hold */
 
-                ( W(k) W(k+1) ) = ( L(k) L(k+1) )*D(k)   
+/*              ( W(k) W(k+1) ) = ( L(k) L(k+1) )*D(k) */
 
-                where L(k) and L(k+1) are the k-th and (k+1)-th columns   
-                of L */
+/*              where L(k) and L(k+1) are the k-th and (k+1)-th columns */
+/*              of L */
 
 		if (k < *n - 1) {
 
@@ -621,11 +639,11 @@ L70:
 
 L90:
 
-/*        Update the lower triangle of A22 (= A(k:n,k:n)) as   
+/*        Update the lower triangle of A22 (= A(k:n,k:n)) as */
 
-          A22 := A22 - L21*D*L21' = A22 - L21*W'   
+/*        A22 := A22 - L21*D*L21' = A22 - L21*W' */
 
-          computing blocks of NB columns at a time */
+/*        computing blocks of NB columns at a time */
 
 	i__1 = *n;
 	i__2 = *nb;
@@ -658,8 +676,8 @@ L90:
 /* L110: */
 	}
 
-/*        Put L21 in standard form by partially undoing the interchanges   
-          in columns 1:k-1 */
+/*        Put L21 in standard form by partially undoing the interchanges */
+/*        in columns 1:k-1 */
 
 	j = k - 1;
 L120:
