@@ -1,127 +1,144 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static real c_b8 = 0.f;
+static real c_b9 = 1.f;
+static integer c__1 = 1;
+static real c_b20 = -1.f;
 
 /* Subroutine */ int ssbgst_(char *vect, char *uplo, integer *n, integer *ka, 
 	integer *kb, real *ab, integer *ldab, real *bb, integer *ldbb, real *
-	x, integer *ldx, real *work, integer *info  	)
+	x, integer *ldx, real *work, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SSBGST reduces a real symmetric-definite banded generalized   
-    eigenproblem  A*x = lambda*B*x  to standard form  C*y = lambda*y,   
-    such that C has the same bandwidth as A.   
-
-    B must have been previously factorized as S**T*S by SPBSTF, using a   
-    split Cholesky factorization. A is overwritten by C = X**T*A*X, where   
-    X = S**(-1)*Q and Q is an orthogonal matrix chosen to preserve the   
-    bandwidth of A.   
-
-    Arguments   
-    =========   
-
-    VECT    (input) CHARACTER*1   
-            = 'N':  do not form the transformation matrix X;   
-            = 'V':  form X.   
-
-    UPLO    (input) CHARACTER*1   
-            = 'U':  Upper triangle of A is stored;   
-            = 'L':  Lower triangle of A is stored.   
-
-    N       (input) INTEGER   
-            The order of the matrices A and B.  N >= 0.   
-
-    KA      (input) INTEGER   
-            The number of superdiagonals of the matrix A if UPLO = 'U',   
-            or the number of subdiagonals if UPLO = 'L'.  KA >= 0.   
-
-    KB      (input) INTEGER   
-            The number of superdiagonals of the matrix B if UPLO = 'U',   
-            or the number of subdiagonals if UPLO = 'L'.  KA >= KB >= 0.   
-
-    AB      (input/output) REAL array, dimension (LDAB,N)   
-            On entry, the upper or lower triangle of the symmetric band   
-            matrix A, stored in the first ka+1 rows of the array.  The   
-            j-th column of A is stored in the j-th column of the array AB   
-            as follows:   
-            if UPLO = 'U', AB(ka+1+i-j,j) = A(i,j) for max(1,j-ka)<=i<=j;   
-            if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+ka).   
-
-            On exit, the transformed matrix X**T*A*X, stored in the same   
-            format as A.   
-
-    LDAB    (input) INTEGER   
-            The leading dimension of the array AB.  LDAB >= KA+1.   
-
-    BB      (input) REAL array, dimension (LDBB,N)   
-            The banded factor S from the split Cholesky factorization of   
-            B, as returned by SPBSTF, stored in the first KB+1 rows of   
-            the array.   
-
-    LDBB    (input) INTEGER   
-            The leading dimension of the array BB.  LDBB >= KB+1.   
-
-    X       (output) REAL array, dimension (LDX,N)   
-            If VECT = 'V', the n-by-n matrix X.   
-            If VECT = 'N', the array X is not referenced.   
-
-    LDX     (input) INTEGER   
-            The leading dimension of the array X.   
-            LDX >= max(1,N) if VECT = 'V'; LDX >= 1 otherwise.   
-
-    WORK    (workspace) REAL array, dimension (2*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-
-    =====================================================================   
-
-
-       Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static real c_b8 = 0.f;
-    static real c_b9 = 1.f;
-    static integer c__1 = 1;
-    static real c_b20 = -1.f;
-    
     /* System generated locals */
     integer ab_dim1, ab_offset, bb_dim1, bb_offset, x_dim1, x_offset, i__1, 
 	    i__2, i__3, i__4;
     real r__1;
+
     /* Local variables */
-    static integer i__, j, k, l, m;
-    static real t;
-    static integer i0, i1, i2, j1, j2;
-    static real ra;
-    static integer nr, nx, ka1, kb1;
-    static real ra1;
-    static integer j1t, j2t;
-    static real bii;
-    static integer kbt, nrt, inca;
+    integer i__, j, k, l, m;
+    real t;
+    integer i0, i1, i2, j1, j2;
+    real ra;
+    integer nr, nx, ka1, kb1;
+    real ra1;
+    integer j1t, j2t;
+    real bii;
+    integer kbt, nrt, inca;
     extern /* Subroutine */ int sger_(integer *, integer *, real *, real *, 
 	    integer *, real *, integer *, real *, integer *), srot_(integer *, 
 	     real *, integer *, real *, integer *, real *, real *);
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static logical upper, wantx;
+    logical upper, wantx;
     extern /* Subroutine */ int slar2v_(integer *, real *, real *, real *, 
 	    integer *, real *, real *, integer *), xerbla_(char *, integer *);
-    static logical update;
+    logical update;
     extern /* Subroutine */ int slaset_(char *, integer *, integer *, real *, 
 	    real *, real *, integer *), slartg_(real *, real *, real *
-	    , real *, real *), slargv_(integer *, real *, integer *, real *, 
+, real *, real *), slargv_(integer *, real *, integer *, real *, 
 	    integer *, real *, integer *), slartv_(integer *, real *, integer 
 	    *, real *, integer *, real *, real *, integer *);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SSBGST reduces a real symmetric-definite banded generalized */
+/*  eigenproblem  A*x = lambda*B*x  to standard form  C*y = lambda*y, */
+/*  such that C has the same bandwidth as A. */
+
+/*  B must have been previously factorized as S**T*S by SPBSTF, using a */
+/*  split Cholesky factorization. A is overwritten by C = X**T*A*X, where */
+/*  X = S**(-1)*Q and Q is an orthogonal matrix chosen to preserve the */
+/*  bandwidth of A. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  VECT    (input) CHARACTER*1 */
+/*          = 'N':  do not form the transformation matrix X; */
+/*          = 'V':  form X. */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          = 'U':  Upper triangle of A is stored; */
+/*          = 'L':  Lower triangle of A is stored. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A and B.  N >= 0. */
+
+/*  KA      (input) INTEGER */
+/*          The number of superdiagonals of the matrix A if UPLO = 'U', */
+/*          or the number of subdiagonals if UPLO = 'L'.  KA >= 0. */
+
+/*  KB      (input) INTEGER */
+/*          The number of superdiagonals of the matrix B if UPLO = 'U', */
+/*          or the number of subdiagonals if UPLO = 'L'.  KA >= KB >= 0. */
+
+/*  AB      (input/output) REAL array, dimension (LDAB,N) */
+/*          On entry, the upper or lower triangle of the symmetric band */
+/*          matrix A, stored in the first ka+1 rows of the array.  The */
+/*          j-th column of A is stored in the j-th column of the array AB */
+/*          as follows: */
+/*          if UPLO = 'U', AB(ka+1+i-j,j) = A(i,j) for max(1,j-ka)<=i<=j; */
+/*          if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+ka). */
+
+/*          On exit, the transformed matrix X**T*A*X, stored in the same */
+/*          format as A. */
+
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array AB.  LDAB >= KA+1. */
+
+/*  BB      (input) REAL array, dimension (LDBB,N) */
+/*          The banded factor S from the split Cholesky factorization of */
+/*          B, as returned by SPBSTF, stored in the first KB+1 rows of */
+/*          the array. */
+
+/*  LDBB    (input) INTEGER */
+/*          The leading dimension of the array BB.  LDBB >= KB+1. */
+
+/*  X       (output) REAL array, dimension (LDX,N) */
+/*          If VECT = 'V', the n-by-n matrix X. */
+/*          If VECT = 'N', the array X is not referenced. */
+
+/*  LDX     (input) INTEGER */
+/*          The leading dimension of the array X. */
+/*          LDX >= max(1,N) if VECT = 'V'; LDX >= 1 otherwise. */
+
+/*  WORK    (workspace) REAL array, dimension (2*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters */
+
+    /* Parameter adjustments */
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
     ab -= ab_offset;
@@ -176,72 +193,72 @@
 	slaset_("Full", n, n, &c_b8, &c_b9, &x[x_offset], ldx);
     }
 
-/*     Set M to the splitting point m. It must be the same value as is   
-       used in SPBSTF. The chosen value allows the arrays WORK and RWORK   
-       to be of dimension (N). */
+/*     Set M to the splitting point m. It must be the same value as is */
+/*     used in SPBSTF. The chosen value allows the arrays WORK and RWORK */
+/*     to be of dimension (N). */
 
     m = (*n + *kb) / 2;
 
-/*     The routine works in two phases, corresponding to the two halves   
-       of the split Cholesky factorization of B as S**T*S where   
+/*     The routine works in two phases, corresponding to the two halves */
+/*     of the split Cholesky factorization of B as S**T*S where */
 
-       S = ( U    )   
-           ( M  L )   
+/*     S = ( U    ) */
+/*         ( M  L ) */
 
-       with U upper triangular of order m, and L lower triangular of   
-       order n-m. S has the same bandwidth as B.   
+/*     with U upper triangular of order m, and L lower triangular of */
+/*     order n-m. S has the same bandwidth as B. */
 
-       S is treated as a product of elementary matrices:   
+/*     S is treated as a product of elementary matrices: */
 
-       S = S(m)*S(m-1)*...*S(2)*S(1)*S(m+1)*S(m+2)*...*S(n-1)*S(n)   
+/*     S = S(m)*S(m-1)*...*S(2)*S(1)*S(m+1)*S(m+2)*...*S(n-1)*S(n) */
 
-       where S(i) is determined by the i-th row of S.   
+/*     where S(i) is determined by the i-th row of S. */
 
-       In phase 1, the index i takes the values n, n-1, ... , m+1;   
-       in phase 2, it takes the values 1, 2, ... , m.   
+/*     In phase 1, the index i takes the values n, n-1, ... , m+1; */
+/*     in phase 2, it takes the values 1, 2, ... , m. */
 
-       For each value of i, the current matrix A is updated by forming   
-       inv(S(i))**T*A*inv(S(i)). This creates a triangular bulge outside   
-       the band of A. The bulge is then pushed down toward the bottom of   
-       A in phase 1, and up toward the top of A in phase 2, by applying   
-       plane rotations.   
+/*     For each value of i, the current matrix A is updated by forming */
+/*     inv(S(i))**T*A*inv(S(i)). This creates a triangular bulge outside */
+/*     the band of A. The bulge is then pushed down toward the bottom of */
+/*     A in phase 1, and up toward the top of A in phase 2, by applying */
+/*     plane rotations. */
 
-       There are kb*(kb+1)/2 elements in the bulge, but at most 2*kb-1   
-       of them are linearly independent, so annihilating a bulge requires   
-       only 2*kb-1 plane rotations. The rotations are divided into a 1st   
-       set of kb-1 rotations, and a 2nd set of kb rotations.   
+/*     There are kb*(kb+1)/2 elements in the bulge, but at most 2*kb-1 */
+/*     of them are linearly independent, so annihilating a bulge requires */
+/*     only 2*kb-1 plane rotations. The rotations are divided into a 1st */
+/*     set of kb-1 rotations, and a 2nd set of kb rotations. */
 
-       Wherever possible, rotations are generated and applied in vector   
-       operations of length NR between the indices J1 and J2 (sometimes   
-       replaced by modified values NRT, J1T or J2T).   
+/*     Wherever possible, rotations are generated and applied in vector */
+/*     operations of length NR between the indices J1 and J2 (sometimes */
+/*     replaced by modified values NRT, J1T or J2T). */
 
-       The cosines and sines of the rotations are stored in the array   
-       WORK. The cosines of the 1st set of rotations are stored in   
-       elements n+2:n+m-kb-1 and the sines of the 1st set in elements   
-       2:m-kb-1; the cosines of the 2nd set are stored in elements   
-       n+m-kb+1:2*n and the sines of the second set in elements m-kb+1:n.   
+/*     The cosines and sines of the rotations are stored in the array */
+/*     WORK. The cosines of the 1st set of rotations are stored in */
+/*     elements n+2:n+m-kb-1 and the sines of the 1st set in elements */
+/*     2:m-kb-1; the cosines of the 2nd set are stored in elements */
+/*     n+m-kb+1:2*n and the sines of the second set in elements m-kb+1:n. */
 
-       The bulges are not formed explicitly; nonzero elements outside the   
-       band are created only when they are required for generating new   
-       rotations; they are stored in the array WORK, in positions where   
-       they are later overwritten by the sines of the rotations which   
-       annihilate them.   
+/*     The bulges are not formed explicitly; nonzero elements outside the */
+/*     band are created only when they are required for generating new */
+/*     rotations; they are stored in the array WORK, in positions where */
+/*     they are later overwritten by the sines of the rotations which */
+/*     annihilate them. */
 
-       **************************** Phase 1 *****************************   
+/*     **************************** Phase 1 ***************************** */
 
-       The logical structure of this phase is:   
+/*     The logical structure of this phase is: */
 
-       UPDATE = .TRUE.   
-       DO I = N, M + 1, -1   
-          use S(i) to update A and create a new bulge   
-          apply rotations to push all bulges KA positions downward   
-       END DO   
-       UPDATE = .FALSE.   
-       DO I = M + KA + 1, N - 1   
-          apply rotations to push all bulges KA positions downward   
-       END DO   
+/*     UPDATE = .TRUE. */
+/*     DO I = N, M + 1, -1 */
+/*        use S(i) to update A and create a new bulge */
+/*        apply rotations to push all bulges KA positions downward */
+/*     END DO */
+/*     UPDATE = .FALSE. */
+/*     DO I = M + KA + 1, N - 1 */
+/*        apply rotations to push all bulges KA positions downward */
+/*     END DO */
 
-       To avoid duplicating code, the two loops are merged. */
+/*     To avoid duplicating code, the two loops are merged. */
 
     update = TRUE_;
     i__ = *n + 1;
@@ -349,16 +366,16 @@ L10:
 	    ra1 = ab[i__ - i1 + ka1 + i1 * ab_dim1];
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions down toward the bottom of the   
-          band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions down toward the bottom of the */
+/*        band */
 
 	i__3 = *kb - 1;
 	for (k = 1; k <= i__3; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ - k + *ka < *n && i__ - k > 1) {
 
@@ -368,8 +385,8 @@ L10:
 			    work[*n + i__ - k + *ka - m], &work[i__ - k + *ka 
 			    - m], &ra);
 
-/*                 create nonzero element a(i-k,i-k+ka+1) outside the   
-                   band and store it in WORK(i-k) */
+/*                 create nonzero element a(i-k,i-k+ka+1) outside the */
+/*                 band and store it in WORK(i-k) */
 
 		    t = -bb[kb1 - k + i__ * bb_dim1] * ra1;
 		    work[i__ - k] = work[*n + i__ - k + *ka - m] * t - work[
@@ -398,8 +415,8 @@ L10:
 	    i__4 = ka1;
 	    for (j = j2t; i__4 < 0 ? j >= i__2 : j <= i__2; j += i__4) {
 
-/*              create nonzero element a(j-ka,j+1) outside the band   
-                and store it in WORK(j-m) */
+/*              create nonzero element a(j-ka,j+1) outside the band */
+/*              and store it in WORK(j-m) */
 
 		work[j - m] *= ab[(j + 1) * ab_dim1 + 1];
 		ab[(j + 1) * ab_dim1 + 1] = work[*n + j - m] * ab[(j + 1) * 
@@ -407,8 +424,8 @@ L10:
 /* L90: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
 		slargv_(&nrt, &ab[j2t * ab_dim1 + 1], &inca, &work[j2t - m], &
@@ -426,8 +443,8 @@ L10:
 /* L100: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[ka1 + j2 * ab_dim1], &ab[ka1 + (j2 + 1) * 
 			ab_dim1], &ab[*ka + (j2 + 1) * ab_dim1], &inca, &work[
@@ -468,8 +485,8 @@ L10:
 	if (update) {
 	    if (i2 <= *n && kbt > 0) {
 
-/*              create nonzero element a(i-kbt,i-kbt+ka+1) outside the   
-                band and store it in WORK(i-kbt) */
+/*              create nonzero element a(i-kbt,i-kbt+ka+1) outside the */
+/*              band and store it in WORK(i-kbt) */
 
 		work[i__ - kbt] = -bb[kb1 - kbt + i__ * bb_dim1] * ra1;
 	    }
@@ -510,8 +527,8 @@ L10:
 	    i__3 = ka1;
 	    for (j = j2; i__3 < 0 ? j >= i__2 : j <= i__2; j += i__3) {
 
-/*              create nonzero element a(j-ka,j+1) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j-ka,j+1) outside the band */
+/*              and store it in WORK(j) */
 
 		work[j] *= ab[(j + 1) * ab_dim1 + 1];
 		ab[(j + 1) * ab_dim1 + 1] = work[*n + j] * ab[(j + 1) * 
@@ -534,8 +551,8 @@ L10:
 	    j1 = j2 + (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		slargv_(&nr, &ab[j2 * ab_dim1 + 1], &inca, &work[j2], &ka1, &
 			work[*n + j2], &ka1);
@@ -550,8 +567,8 @@ L10:
 /* L180: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[ka1 + j2 * ab_dim1], &ab[ka1 + (j2 + 1) * 
 			ab_dim1], &ab[*ka + (j2 + 1) * ab_dim1], &inca, &work[
@@ -694,16 +711,16 @@ L10:
 	    ra1 = ab[i1 - i__ + 1 + i__ * ab_dim1];
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions down toward the bottom of the   
-          band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions down toward the bottom of the */
+/*        band */
 
 	i__4 = *kb - 1;
 	for (k = 1; k <= i__4; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ - k + *ka < *n && i__ - k > 1) {
 
@@ -713,8 +730,8 @@ L10:
 			    i__ - k + *ka - m], &work[i__ - k + *ka - m], &ra)
 			    ;
 
-/*                 create nonzero element a(i-k+ka+1,i-k) outside the   
-                   band and store it in WORK(i-k) */
+/*                 create nonzero element a(i-k+ka+1,i-k) outside the */
+/*                 band and store it in WORK(i-k) */
 
 		    t = -bb[k + 1 + (i__ - k) * bb_dim1] * ra1;
 		    work[i__ - k] = work[*n + i__ - k + *ka - m] * t - work[
@@ -743,8 +760,8 @@ L10:
 	    i__1 = ka1;
 	    for (j = j2t; i__1 < 0 ? j >= i__3 : j <= i__3; j += i__1) {
 
-/*              create nonzero element a(j+1,j-ka) outside the band   
-                and store it in WORK(j-m) */
+/*              create nonzero element a(j+1,j-ka) outside the band */
+/*              and store it in WORK(j-m) */
 
 		work[j - m] *= ab[ka1 + (j - *ka + 1) * ab_dim1];
 		ab[ka1 + (j - *ka + 1) * ab_dim1] = work[*n + j - m] * ab[ka1 
@@ -752,8 +769,8 @@ L10:
 /* L320: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
 		slargv_(&nrt, &ab[ka1 + (j2t - *ka) * ab_dim1], &inca, &work[
@@ -771,8 +788,8 @@ L10:
 /* L330: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[j2 * ab_dim1 + 1], &ab[(j2 + 1) * ab_dim1 + 
 			1], &ab[j2 * ab_dim1 + 2], &inca, &work[*n + j2 - m], 
@@ -813,8 +830,8 @@ L10:
 	if (update) {
 	    if (i2 <= *n && kbt > 0) {
 
-/*              create nonzero element a(i-kbt+ka+1,i-kbt) outside the   
-                band and store it in WORK(i-kbt) */
+/*              create nonzero element a(i-kbt+ka+1,i-kbt) outside the */
+/*              band and store it in WORK(i-kbt) */
 
 		work[i__ - kbt] = -bb[kbt + 1 + (i__ - kbt) * bb_dim1] * ra1;
 	    }
@@ -856,8 +873,8 @@ L10:
 	    i__4 = ka1;
 	    for (j = j2; i__4 < 0 ? j >= i__3 : j <= i__3; j += i__4) {
 
-/*              create nonzero element a(j+1,j-ka) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j+1,j-ka) outside the band */
+/*              and store it in WORK(j) */
 
 		work[j] *= ab[ka1 + (j - *ka + 1) * ab_dim1];
 		ab[ka1 + (j - *ka + 1) * ab_dim1] = work[*n + j] * ab[ka1 + (
@@ -880,11 +897,11 @@ L10:
 	    j1 = j2 + (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		slargv_(&nr, &ab[ka1 + (j2 - *ka) * ab_dim1], &inca, &work[j2]
-			, &ka1, &work[*n + j2], &ka1);
+, &ka1, &work[*n + j2], &ka1);
 
 /*              apply rotations in 2nd set from the left */
 
@@ -892,12 +909,12 @@ L10:
 		for (l = 1; l <= i__4; ++l) {
 		    slartv_(&nr, &ab[l + 1 + (j2 - l) * ab_dim1], &inca, &ab[
 			    l + 2 + (j2 - l) * ab_dim1], &inca, &work[*n + j2]
-			    , &work[j2], &ka1);
+, &work[j2], &ka1);
 /* L410: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[j2 * ab_dim1 + 1], &ab[(j2 + 1) * ab_dim1 + 
 			1], &ab[j2 * ab_dim1 + 2], &inca, &work[*n + j2], &
@@ -969,21 +986,21 @@ L10:
 
 L480:
 
-/*     **************************** Phase 2 *****************************   
+/*     **************************** Phase 2 ***************************** */
 
-       The logical structure of this phase is:   
+/*     The logical structure of this phase is: */
 
-       UPDATE = .TRUE.   
-       DO I = 1, M   
-          use S(i) to update A and create a new bulge   
-          apply rotations to push all bulges KA positions upward   
-       END DO   
-       UPDATE = .FALSE.   
-       DO I = M - KA - 1, 2, -1   
-          apply rotations to push all bulges KA positions upward   
-       END DO   
+/*     UPDATE = .TRUE. */
+/*     DO I = 1, M */
+/*        use S(i) to update A and create a new bulge */
+/*        apply rotations to push all bulges KA positions upward */
+/*     END DO */
+/*     UPDATE = .FALSE. */
+/*     DO I = M - KA - 1, 2, -1 */
+/*        apply rotations to push all bulges KA positions upward */
+/*     END DO */
 
-       To avoid duplicating code, the two loops are merged. */
+/*     To avoid duplicating code, the two loops are merged. */
 
     update = TRUE_;
     i__ = 0;
@@ -1095,15 +1112,15 @@ L490:
 	    ra1 = ab[i1 - i__ + ka1 + i__ * ab_dim1];
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions up toward the top of the band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions up toward the top of the band */
 
 	i__3 = *kb - 1;
 	for (k = 1; k <= i__3; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ + k - ka1 > 0 && i__ + k < m) {
 
@@ -1112,8 +1129,8 @@ L490:
 		    slartg_(&ab[k + 1 + i__ * ab_dim1], &ra1, &work[*n + i__ 
 			    + k - *ka], &work[i__ + k - *ka], &ra);
 
-/*                 create nonzero element a(i+k-ka-1,i+k) outside the   
-                   band and store it in WORK(m-kb+i+k) */
+/*                 create nonzero element a(i+k-ka-1,i+k) outside the */
+/*                 band and store it in WORK(m-kb+i+k) */
 
 		    t = -bb[kb1 - k + (i__ + k) * bb_dim1] * ra1;
 		    work[m - *kb + i__ + k] = work[*n + i__ + k - *ka] * t - 
@@ -1141,8 +1158,8 @@ L490:
 	    i__1 = ka1;
 	    for (j = j1; i__1 < 0 ? j >= i__4 : j <= i__4; j += i__1) {
 
-/*              create nonzero element a(j-1,j+ka) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j-1,j+ka) outside the band */
+/*              and store it in WORK(j) */
 
 		work[j] *= ab[(j + *ka - 1) * ab_dim1 + 1];
 		ab[(j + *ka - 1) * ab_dim1 + 1] = work[*n + j] * ab[(j + *ka 
@@ -1150,11 +1167,11 @@ L490:
 /* L570: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
-		slargv_(&nrt, &ab[(j1 + *ka) * ab_dim1 + 1], &inca, &work[j1],
+		slargv_(&nrt, &ab[(j1 + *ka) * ab_dim1 + 1], &inca, &work[j1], 
 			 &ka1, &work[*n + j1], &ka1);
 	    }
 	    if (nr > 0) {
@@ -1169,8 +1186,8 @@ L490:
 /* L580: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[ka1 + j1 * ab_dim1], &ab[ka1 + (j1 - 1) * 
 			ab_dim1], &ab[*ka + j1 * ab_dim1], &inca, &work[*n + 
@@ -1210,8 +1227,8 @@ L490:
 	if (update) {
 	    if (i2 > 0 && kbt > 0) {
 
-/*              create nonzero element a(i+kbt-ka-1,i+kbt) outside the   
-                band and store it in WORK(m-kb+i+kbt) */
+/*              create nonzero element a(i+kbt-ka-1,i+kbt) outside the */
+/*              band and store it in WORK(m-kb+i+kbt) */
 
 		work[m - *kb + i__ + kbt] = -bb[kb1 - kbt + (i__ + kbt) * 
 			bb_dim1] * ra1;
@@ -1255,8 +1272,8 @@ L490:
 	    i__3 = ka1;
 	    for (j = j1; i__3 < 0 ? j >= i__4 : j <= i__4; j += i__3) {
 
-/*              create nonzero element a(j-1,j+ka) outside the band   
-                and store it in WORK(m-kb+j) */
+/*              create nonzero element a(j-1,j+ka) outside the band */
+/*              and store it in WORK(m-kb+j) */
 
 		work[m - *kb + j] *= ab[(j + *ka - 1) * ab_dim1 + 1];
 		ab[(j + *ka - 1) * ab_dim1 + 1] = work[*n + m - *kb + j] * ab[
@@ -1279,8 +1296,8 @@ L490:
 	    j1 = j2 - (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		slargv_(&nr, &ab[(j1 + *ka) * ab_dim1 + 1], &inca, &work[m - *
 			kb + j1], &ka1, &work[*n + m - *kb + j1], &ka1);
@@ -1295,8 +1312,8 @@ L490:
 /* L660: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[ka1 + j1 * ab_dim1], &ab[ka1 + (j1 - 1) * 
 			ab_dim1], &ab[*ka + j1 * ab_dim1], &inca, &work[*n + 
@@ -1440,15 +1457,15 @@ L490:
 	    ra1 = ab[i__ - i1 + 1 + i1 * ab_dim1];
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions up toward the top of the band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions up toward the top of the band */
 
 	i__4 = *kb - 1;
 	for (k = 1; k <= i__4; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ + k - ka1 > 0 && i__ + k < m) {
 
@@ -1458,8 +1475,8 @@ L490:
 			    work[*n + i__ + k - *ka], &work[i__ + k - *ka], &
 			    ra);
 
-/*                 create nonzero element a(i+k,i+k-ka-1) outside the   
-                   band and store it in WORK(m-kb+i+k) */
+/*                 create nonzero element a(i+k,i+k-ka-1) outside the */
+/*                 band and store it in WORK(m-kb+i+k) */
 
 		    t = -bb[k + 1 + i__ * bb_dim1] * ra1;
 		    work[m - *kb + i__ + k] = work[*n + i__ + k - *ka] * t - 
@@ -1488,8 +1505,8 @@ L490:
 	    i__1 = ka1;
 	    for (j = j1; i__1 < 0 ? j >= i__3 : j <= i__3; j += i__1) {
 
-/*              create nonzero element a(j+ka,j-1) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j+ka,j-1) outside the band */
+/*              and store it in WORK(j) */
 
 		work[j] *= ab[ka1 + (j - 1) * ab_dim1];
 		ab[ka1 + (j - 1) * ab_dim1] = work[*n + j] * ab[ka1 + (j - 1) 
@@ -1497,11 +1514,11 @@ L490:
 /* L800: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
-		slargv_(&nrt, &ab[ka1 + j1 * ab_dim1], &inca, &work[j1], &ka1,
+		slargv_(&nrt, &ab[ka1 + j1 * ab_dim1], &inca, &work[j1], &ka1, 
 			 &work[*n + j1], &ka1);
 	    }
 	    if (nr > 0) {
@@ -1516,12 +1533,12 @@ L490:
 /* L810: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[j1 * ab_dim1 + 1], &ab[(j1 - 1) * ab_dim1 + 
 			1], &ab[(j1 - 1) * ab_dim1 + 2], &inca, &work[*n + j1]
-			, &work[j1], &ka1);
+, &work[j1], &ka1);
 
 	    }
 
@@ -1533,7 +1550,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    slartv_(&nrt, &ab[ka1 - l + 1 + (j1t - ka1 + l) * ab_dim1]
-			    , &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1],
+, &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1], 
 			     &inca, &work[*n + j1t], &work[j1t], &ka1);
 		}
 /* L820: */
@@ -1557,8 +1574,8 @@ L490:
 	if (update) {
 	    if (i2 > 0 && kbt > 0) {
 
-/*              create nonzero element a(i+kbt,i+kbt-ka-1) outside the   
-                band and store it in WORK(m-kb+i+kbt) */
+/*              create nonzero element a(i+kbt,i+kbt-ka-1) outside the */
+/*              band and store it in WORK(m-kb+i+kbt) */
 
 		work[m - *kb + i__ + kbt] = -bb[kbt + 1 + i__ * bb_dim1] * 
 			ra1;
@@ -1602,8 +1619,8 @@ L490:
 	    i__4 = ka1;
 	    for (j = j1; i__4 < 0 ? j >= i__3 : j <= i__3; j += i__4) {
 
-/*              create nonzero element a(j+ka,j-1) outside the band   
-                and store it in WORK(m-kb+j) */
+/*              create nonzero element a(j+ka,j-1) outside the band */
+/*              and store it in WORK(m-kb+j) */
 
 		work[m - *kb + j] *= ab[ka1 + (j - 1) * ab_dim1];
 		ab[ka1 + (j - 1) * ab_dim1] = work[*n + m - *kb + j] * ab[ka1 
@@ -1626,8 +1643,8 @@ L490:
 	    j1 = j2 - (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		slargv_(&nr, &ab[ka1 + j1 * ab_dim1], &inca, &work[m - *kb + 
 			j1], &ka1, &work[*n + m - *kb + j1], &ka1);
@@ -1642,8 +1659,8 @@ L490:
 /* L890: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		slar2v_(&nr, &ab[j1 * ab_dim1 + 1], &ab[(j1 - 1) * ab_dim1 + 
 			1], &ab[(j1 - 1) * ab_dim1 + 2], &inca, &work[*n + m 
@@ -1659,7 +1676,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    slartv_(&nrt, &ab[ka1 - l + 1 + (j1t - ka1 + l) * ab_dim1]
-			    , &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1],
+, &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1], 
 			     &inca, &work[*n + m - *kb + j1t], &work[m - *kb 
 			    + j1t], &ka1);
 		}
@@ -1695,7 +1712,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    slartv_(&nrt, &ab[ka1 - l + 1 + (j1t - ka1 + l) * ab_dim1]
-			    , &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1],
+, &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1], 
 			     &inca, &work[*n + j1t], &work[j1t], &ka1);
 		}
 /* L930: */
