@@ -1,121 +1,139 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static real c_b9 = 0.f;
+static real c_b10 = 1.f;
+static integer c__1 = 1;
 
 /* Subroutine */ int ssbtrd_(char *vect, char *uplo, integer *n, integer *kd, 
 	real *ab, integer *ldab, real *d__, real *e, real *q, integer *ldq, 
 	real *work, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    SSBTRD reduces a real symmetric band matrix A to symmetric   
-    tridiagonal form T by an orthogonal similarity transformation:   
-    Q**T * A * Q = T.   
-
-    Arguments   
-    =========   
-
-    VECT    (input) CHARACTER*1   
-            = 'N':  do not form Q;   
-            = 'V':  form Q;   
-            = 'U':  update a matrix X, by forming X*Q.   
-
-    UPLO    (input) CHARACTER*1   
-            = 'U':  Upper triangle of A is stored;   
-            = 'L':  Lower triangle of A is stored.   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    KD      (input) INTEGER   
-            The number of superdiagonals of the matrix A if UPLO = 'U',   
-            or the number of subdiagonals if UPLO = 'L'.  KD >= 0.   
-
-    AB      (input/output) REAL array, dimension (LDAB,N)   
-            On entry, the upper or lower triangle of the symmetric band   
-            matrix A, stored in the first KD+1 rows of the array.  The   
-            j-th column of A is stored in the j-th column of the array AB   
-            as follows:   
-            if UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j;   
-            if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd).   
-            On exit, the diagonal elements of AB are overwritten by the   
-            diagonal elements of the tridiagonal matrix T; if KD > 0, the   
-            elements on the first superdiagonal (if UPLO = 'U') or the   
-            first subdiagonal (if UPLO = 'L') are overwritten by the   
-            off-diagonal elements of T; the rest of AB is overwritten by   
-            values generated during the reduction.   
-
-    LDAB    (input) INTEGER   
-            The leading dimension of the array AB.  LDAB >= KD+1.   
-
-    D       (output) REAL array, dimension (N)   
-            The diagonal elements of the tridiagonal matrix T.   
-
-    E       (output) REAL array, dimension (N-1)   
-            The off-diagonal elements of the tridiagonal matrix T:   
-            E(i) = T(i,i+1) if UPLO = 'U'; E(i) = T(i+1,i) if UPLO = 'L'.   
-
-    Q       (input/output) REAL array, dimension (LDQ,N)   
-            On entry, if VECT = 'U', then Q must contain an N-by-N   
-            matrix X; if VECT = 'N' or 'V', then Q need not be set.   
-
-            On exit:   
-            if VECT = 'V', Q contains the N-by-N orthogonal matrix Q;   
-            if VECT = 'U', Q contains the product X*Q;   
-            if VECT = 'N', the array Q is not referenced.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of the array Q.   
-            LDQ >= 1, and LDQ >= N if VECT = 'V' or 'U'.   
-
-    WORK    (workspace) REAL array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value   
-
-    Further Details   
-    ===============   
-
-    Modified by Linda Kaufman, Bell Labs.   
-
-    =====================================================================   
-
-
-       Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static real c_b9 = 0.f;
-    static real c_b10 = 1.f;
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer ab_dim1, ab_offset, q_dim1, q_offset, i__1, i__2, i__3, i__4, 
 	    i__5;
+
     /* Local variables */
-    static integer i__, j, k, l, i2, j1, j2, nq, nr, kd1, ibl, iqb, kdn, jin, 
-	    nrt, kdm1, inca, jend, lend, jinc, incx, last;
-    static real temp;
+    integer i__, j, k, l, i2, j1, j2, nq, nr, kd1, ibl, iqb, kdn, jin, nrt, 
+	    kdm1, inca, jend, lend, jinc, incx, last;
+    real temp;
     extern /* Subroutine */ int srot_(integer *, real *, integer *, real *, 
 	    integer *, real *, real *);
-    static integer j1end, j1inc, iqend;
+    integer j1end, j1inc, iqend;
     extern logical lsame_(char *, char *);
-    static logical initq, wantq, upper;
+    logical initq, wantq, upper;
     extern /* Subroutine */ int slar2v_(integer *, real *, real *, real *, 
 	    integer *, real *, real *, integer *);
-    static integer iqaend;
+    integer iqaend;
     extern /* Subroutine */ int xerbla_(char *, integer *), slaset_(
 	    char *, integer *, integer *, real *, real *, real *, integer *), slartg_(real *, real *, real *, real *, real *), slargv_(
-	    integer *, real *, integer *, real *, integer *, real *, integer * 	    ), slartv_(integer *, real *, integer *, real *, integer *, real *
-	    , real *, integer *);
+	    integer *, real *, integer *, real *, integer *, real *, integer *
+), slartv_(integer *, real *, integer *, real *, integer *, real *
+, real *, integer *);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  SSBTRD reduces a real symmetric band matrix A to symmetric */
+/*  tridiagonal form T by an orthogonal similarity transformation: */
+/*  Q**T * A * Q = T. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  VECT    (input) CHARACTER*1 */
+/*          = 'N':  do not form Q; */
+/*          = 'V':  form Q; */
+/*          = 'U':  update a matrix X, by forming X*Q. */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          = 'U':  Upper triangle of A is stored; */
+/*          = 'L':  Lower triangle of A is stored. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  KD      (input) INTEGER */
+/*          The number of superdiagonals of the matrix A if UPLO = 'U', */
+/*          or the number of subdiagonals if UPLO = 'L'.  KD >= 0. */
+
+/*  AB      (input/output) REAL array, dimension (LDAB,N) */
+/*          On entry, the upper or lower triangle of the symmetric band */
+/*          matrix A, stored in the first KD+1 rows of the array.  The */
+/*          j-th column of A is stored in the j-th column of the array AB */
+/*          as follows: */
+/*          if UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j; */
+/*          if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd). */
+/*          On exit, the diagonal elements of AB are overwritten by the */
+/*          diagonal elements of the tridiagonal matrix T; if KD > 0, the */
+/*          elements on the first superdiagonal (if UPLO = 'U') or the */
+/*          first subdiagonal (if UPLO = 'L') are overwritten by the */
+/*          off-diagonal elements of T; the rest of AB is overwritten by */
+/*          values generated during the reduction. */
+
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array AB.  LDAB >= KD+1. */
+
+/*  D       (output) REAL array, dimension (N) */
+/*          The diagonal elements of the tridiagonal matrix T. */
+
+/*  E       (output) REAL array, dimension (N-1) */
+/*          The off-diagonal elements of the tridiagonal matrix T: */
+/*          E(i) = T(i,i+1) if UPLO = 'U'; E(i) = T(i+1,i) if UPLO = 'L'. */
+
+/*  Q       (input/output) REAL array, dimension (LDQ,N) */
+/*          On entry, if VECT = 'U', then Q must contain an N-by-N */
+/*          matrix X; if VECT = 'N' or 'V', then Q need not be set. */
+
+/*          On exit: */
+/*          if VECT = 'V', Q contains the N-by-N orthogonal matrix Q; */
+/*          if VECT = 'U', Q contains the product X*Q; */
+/*          if VECT = 'N', the array Q is not referenced. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of the array Q. */
+/*          LDQ >= 1, and LDQ >= N if VECT = 'V' or 'U'. */
+
+/*  WORK    (workspace) REAL array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Modified by Linda Kaufman, Bell Labs. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters */
+
+    /* Parameter adjustments */
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
     ab -= ab_offset;
@@ -167,11 +185,11 @@
 	slaset_("Full", n, n, &c_b9, &c_b10, &q[q_offset], ldq);
     }
 
-/*     Wherever possible, plane rotations are generated and applied in   
-       vector operations of length NR over the index set J1:J2:KD1.   
+/*     Wherever possible, plane rotations are generated and applied in */
+/*     vector operations of length NR over the index set J1:J2:KD1. */
 
-       The cosines and sines of the plane rotations are stored in the   
-       arrays D and WORK. */
+/*     The cosines and sines of the plane rotations are stored in the */
+/*     arrays D and WORK. */
 
     inca = kd1 * *ldab;
 /* Computing MIN */
@@ -198,17 +216,17 @@
 
 		    if (nr > 0) {
 
-/*                    generate plane rotations to annihilate nonzero   
-                      elements which have been created outside the band */
+/*                    generate plane rotations to annihilate nonzero */
+/*                    elements which have been created outside the band */
 
 			slargv_(&nr, &ab[(j1 - 1) * ab_dim1 + 1], &inca, &
 				work[j1], &kd1, &d__[j1], &kd1);
 
-/*                    apply rotations from the right   
+/*                    apply rotations from the right */
 
 
-                      Dependent on the the number of diagonals either   
-                      SLARTV or SROT is used */
+/*                    Dependent on the the number of diagonals either */
+/*                    SLARTV or SROT is used */
 
 			if (nr >= (*kd << 1) - 1) {
 			    i__2 = *kd - 1;
@@ -237,11 +255,11 @@
 		    if (k > 2) {
 			if (k <= *n - i__ + 1) {
 
-/*                       generate plane rotation to annihilate a(i,i+k-1)   
-                         within the band */
+/*                       generate plane rotation to annihilate a(i,i+k-1) */
+/*                       within the band */
 
 			    slartg_(&ab[*kd - k + 3 + (i__ + k - 2) * ab_dim1]
-				    , &ab[*kd - k + 2 + (i__ + k - 1) * 
+, &ab[*kd - k + 2 + (i__ + k - 1) * 
 				    ab_dim1], &d__[i__ + k - 1], &work[i__ + 
 				    k - 1], &temp);
 			    ab[*kd - k + 3 + (i__ + k - 2) * ab_dim1] = temp;
@@ -258,12 +276,12 @@
 			j1 = j1 - kdn - 1;
 		    }
 
-/*                 apply plane rotations from both sides to diagonal   
-                   blocks */
+/*                 apply plane rotations from both sides to diagonal */
+/*                 blocks */
 
 		    if (nr > 0) {
 			slar2v_(&nr, &ab[kd1 + (j1 - 1) * ab_dim1], &ab[kd1 + 
-				j1 * ab_dim1], &ab[*kd + j1 * ab_dim1], &inca,
+				j1 * ab_dim1], &ab[*kd + j1 * ab_dim1], &inca, 
 				 &d__[j1], &work[j1], &kd1);
 		    }
 
@@ -272,8 +290,8 @@
 		    if (nr > 0) {
 			if ((*kd << 1) - 1 < nr) {
 
-/*                    Dependent on the the number of diagonals either   
-                      SLARTV or SROT is used */
+/*                    Dependent on the the number of diagonals either */
+/*                    SLARTV or SROT is used */
 
 			    i__3 = *kd - 1;
 			    for (l = 1; l <= i__3; ++l) {
@@ -324,8 +342,8 @@
 
 			if (initq) {
 
-/*                 take advantage of the fact that Q was   
-                   initially the Identity matrix */
+/*                 take advantage of the fact that Q was */
+/*                 initially the Identity matrix */
 
 			    iqend = max(iqend,j2);
 /* Computing MAX */
@@ -382,8 +400,8 @@
 		    for (j = j1; i__3 < 0 ? j >= i__2 : j <= i__2; j += i__3) 
 			    {
 
-/*                    create nonzero element a(j-1,j+kd) outside the band   
-                      and store it in WORK */
+/*                    create nonzero element a(j-1,j+kd) outside the band */
+/*                    and store it in WORK */
 
 			work[j + *kd] = work[j] * ab[(j + *kd) * ab_dim1 + 1];
 			ab[(j + *kd) * ab_dim1 + 1] = d__[j] * ab[(j + *kd) * 
@@ -445,17 +463,17 @@
 
 		    if (nr > 0) {
 
-/*                    generate plane rotations to annihilate nonzero   
-                      elements which have been created outside the band */
+/*                    generate plane rotations to annihilate nonzero */
+/*                    elements which have been created outside the band */
 
 			slargv_(&nr, &ab[kd1 + (j1 - kd1) * ab_dim1], &inca, &
 				work[j1], &kd1, &d__[j1], &kd1);
 
-/*                    apply plane rotations from one side   
+/*                    apply plane rotations from one side */
 
 
-                      Dependent on the the number of diagonals either   
-                      SLARTV or SROT is used */
+/*                    Dependent on the the number of diagonals either */
+/*                    SLARTV or SROT is used */
 
 			if (nr > (*kd << 1) - 1) {
 			    i__3 = *kd - 1;
@@ -485,8 +503,8 @@
 		    if (k > 2) {
 			if (k <= *n - i__ + 1) {
 
-/*                       generate plane rotation to annihilate a(i+k-1,i)   
-                         within the band */
+/*                       generate plane rotation to annihilate a(i+k-1,i) */
+/*                       within the band */
 
 			    slartg_(&ab[k - 1 + i__ * ab_dim1], &ab[k + i__ * 
 				    ab_dim1], &d__[i__ + k - 1], &work[i__ + 
@@ -507,8 +525,8 @@
 			j1 = j1 - kdn - 1;
 		    }
 
-/*                 apply plane rotations from both sides to diagonal   
-                   blocks */
+/*                 apply plane rotations from both sides to diagonal */
+/*                 blocks */
 
 		    if (nr > 0) {
 			slar2v_(&nr, &ab[(j1 - 1) * ab_dim1 + 1], &ab[j1 * 
@@ -516,11 +534,11 @@
 				inca, &d__[j1], &work[j1], &kd1);
 		    }
 
-/*                 apply plane rotations from the right   
+/*                 apply plane rotations from the right */
 
 
-                      Dependent on the the number of diagonals either   
-                      SLARTV or SROT is used */
+/*                    Dependent on the the number of diagonals either */
+/*                    SLARTV or SROT is used */
 
 		    if (nr > 0) {
 			if (nr > (*kd << 1) - 1) {
@@ -573,8 +591,8 @@
 
 			if (initq) {
 
-/*                 take advantage of the fact that Q was   
-                   initially the Identity matrix */
+/*                 take advantage of the fact that Q was */
+/*                 initially the Identity matrix */
 
 			    iqend = max(iqend,j2);
 /* Computing MAX */
@@ -630,8 +648,8 @@
 		    for (j = j1; i__2 < 0 ? j >= i__3 : j <= i__3; j += i__2) 
 			    {
 
-/*                    create nonzero element a(j+kd,j-1) outside the   
-                      band and store it in WORK */
+/*                    create nonzero element a(j+kd,j-1) outside the */
+/*                    band and store it in WORK */
 
 			work[j + *kd] = work[j] * ab[kd1 + j * ab_dim1];
 			ab[kd1 + j * ab_dim1] = d__[j] * ab[kd1 + j * ab_dim1]
