@@ -1,267 +1,286 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static logical c_true = TRUE_;
+static integer c__2 = 2;
+static real c_b34 = 1.f;
+static integer c__1 = 1;
+static real c_b36 = 0.f;
+static logical c_false = FALSE_;
 
 /* Subroutine */ int stgevc_(char *side, char *howmny, logical *select, 
 	integer *n, real *s, integer *lds, real *p, integer *ldp, real *vl, 
 	integer *ldvl, real *vr, integer *ldvr, integer *mm, integer *m, real 
 	*work, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-
-    Purpose   
-    =======   
-
-    STGEVC computes some or all of the right and/or left eigenvectors of   
-    a pair of real matrices (S,P), where S is a quasi-triangular matrix   
-    and P is upper triangular.  Matrix pairs of this type are produced by   
-    the generalized Schur factorization of a matrix pair (A,B):   
-
-       A = Q*S*Z**T,  B = Q*P*Z**T   
-
-    as computed by SGGHRD + SHGEQZ.   
-
-    The right eigenvector x and the left eigenvector y of (S,P)   
-    corresponding to an eigenvalue w are defined by:   
-
-       S*x = w*P*x,  (y**H)*S = w*(y**H)*P,   
-
-    where y**H denotes the conjugate tranpose of y.   
-    The eigenvalues are not input to this routine, but are computed   
-    directly from the diagonal blocks of S and P.   
-
-    This routine returns the matrices X and/or Y of right and left   
-    eigenvectors of (S,P), or the products Z*X and/or Q*Y,   
-    where Z and Q are input matrices.   
-    If Q and Z are the orthogonal factors from the generalized Schur   
-    factorization of a matrix pair (A,B), then Z*X and Q*Y   
-    are the matrices of right and left eigenvectors of (A,B).   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'R': compute right eigenvectors only;   
-            = 'L': compute left eigenvectors only;   
-            = 'B': compute both right and left eigenvectors.   
-
-    HOWMNY  (input) CHARACTER*1   
-            = 'A': compute all right and/or left eigenvectors;   
-            = 'B': compute all right and/or left eigenvectors,   
-                   backtransformed by the matrices in VR and/or VL;   
-            = 'S': compute selected right and/or left eigenvectors,   
-                   specified by the logical array SELECT.   
-
-    SELECT  (input) LOGICAL array, dimension (N)   
-            If HOWMNY='S', SELECT specifies the eigenvectors to be   
-            computed.  If w(j) is a real eigenvalue, the corresponding   
-            real eigenvector is computed if SELECT(j) is .TRUE..   
-            If w(j) and w(j+1) are the real and imaginary parts of a   
-            complex eigenvalue, the corresponding complex eigenvector   
-            is computed if either SELECT(j) or SELECT(j+1) is .TRUE.,   
-            and on exit SELECT(j) is set to .TRUE. and SELECT(j+1) is   
-            set to .FALSE..   
-            Not referenced if HOWMNY = 'A' or 'B'.   
-
-    N       (input) INTEGER   
-            The order of the matrices S and P.  N >= 0.   
-
-    S       (input) REAL array, dimension (LDS,N)   
-            The upper quasi-triangular matrix S from a generalized Schur   
-            factorization, as computed by SHGEQZ.   
-
-    LDS     (input) INTEGER   
-            The leading dimension of array S.  LDS >= max(1,N).   
-
-    P       (input) REAL array, dimension (LDP,N)   
-            The upper triangular matrix P from a generalized Schur   
-            factorization, as computed by SHGEQZ.   
-            2-by-2 diagonal blocks of P corresponding to 2-by-2 blocks   
-            of S must be in positive diagonal form.   
-
-    LDP     (input) INTEGER   
-            The leading dimension of array P.  LDP >= max(1,N).   
-
-    VL      (input/output) REAL array, dimension (LDVL,MM)   
-            On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must   
-            contain an N-by-N matrix Q (usually the orthogonal matrix Q   
-            of left Schur vectors returned by SHGEQZ).   
-            On exit, if SIDE = 'L' or 'B', VL contains:   
-            if HOWMNY = 'A', the matrix Y of left eigenvectors of (S,P);   
-            if HOWMNY = 'B', the matrix Q*Y;   
-            if HOWMNY = 'S', the left eigenvectors of (S,P) specified by   
-                        SELECT, stored consecutively in the columns of   
-                        VL, in the same order as their eigenvalues.   
-
-            A complex eigenvector corresponding to a complex eigenvalue   
-            is stored in two consecutive columns, the first holding the   
-            real part, and the second the imaginary part.   
-
-            Not referenced if SIDE = 'R'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of array VL.  LDVL >= 1, and if   
-            SIDE = 'L' or 'B', LDVL >= N.   
-
-    VR      (input/output) REAL array, dimension (LDVR,MM)   
-            On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must   
-            contain an N-by-N matrix Z (usually the orthogonal matrix Z   
-            of right Schur vectors returned by SHGEQZ).   
-
-            On exit, if SIDE = 'R' or 'B', VR contains:   
-            if HOWMNY = 'A', the matrix X of right eigenvectors of (S,P);   
-            if HOWMNY = 'B' or 'b', the matrix Z*X;   
-            if HOWMNY = 'S' or 's', the right eigenvectors of (S,P)   
-                        specified by SELECT, stored consecutively in the   
-                        columns of VR, in the same order as their   
-                        eigenvalues.   
-
-            A complex eigenvector corresponding to a complex eigenvalue   
-            is stored in two consecutive columns, the first holding the   
-            real part and the second the imaginary part.   
-
-            Not referenced if SIDE = 'L'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the array VR.  LDVR >= 1, and if   
-            SIDE = 'R' or 'B', LDVR >= N.   
-
-    MM      (input) INTEGER   
-            The number of columns in the arrays VL and/or VR. MM >= M.   
-
-    M       (output) INTEGER   
-            The number of columns in the arrays VL and/or VR actually   
-            used to store the eigenvectors.  If HOWMNY = 'A' or 'B', M   
-            is set to N.  Each selected real eigenvector occupies one   
-            column and each selected complex eigenvector occupies two   
-            columns.   
-
-    WORK    (workspace) REAL array, dimension (6*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit.   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  the 2-by-2 block (INFO:INFO+1) does not have a complex   
-                  eigenvalue.   
-
-    Further Details   
-    ===============   
-
-    Allocation of workspace:   
-    ---------- -- ---------   
-
-       WORK( j ) = 1-norm of j-th column of A, above the diagonal   
-       WORK( N+j ) = 1-norm of j-th column of B, above the diagonal   
-       WORK( 2*N+1:3*N ) = real part of eigenvector   
-       WORK( 3*N+1:4*N ) = imaginary part of eigenvector   
-       WORK( 4*N+1:5*N ) = real part of back-transformed eigenvector   
-       WORK( 5*N+1:6*N ) = imaginary part of back-transformed eigenvector   
-
-    Rowwise vs. columnwise solution methods:   
-    ------- --  ---------- -------- -------   
-
-    Finding a generalized eigenvector consists basically of solving the   
-    singular triangular system   
-
-     (A - w B) x = 0     (for right) or:   (A - w B)**H y = 0  (for left)   
-
-    Consider finding the i-th right eigenvector (assume all eigenvalues   
-    are real). The equation to be solved is:   
-         n                   i   
-    0 = sum  C(j,k) v(k)  = sum  C(j,k) v(k)     for j = i,. . .,1   
-        k=j                 k=j   
-
-    where  C = (A - w B)  (The components v(i+1:n) are 0.)   
-
-    The "rowwise" method is:   
-
-    (1)  v(i) := 1   
-    for j = i-1,. . .,1:   
-                            i   
-        (2) compute  s = - sum C(j,k) v(k)   and   
-                          k=j+1   
-
-        (3) v(j) := s / C(j,j)   
-
-    Step 2 is sometimes called the "dot product" step, since it is an   
-    inner product between the j-th row and the portion of the eigenvector   
-    that has been computed so far.   
-
-    The "columnwise" method consists basically in doing the sums   
-    for all the rows in parallel.  As each v(j) is computed, the   
-    contribution of v(j) times the j-th column of C is added to the   
-    partial sums.  Since FORTRAN arrays are stored columnwise, this has   
-    the advantage that at each step, the elements of C that are accessed   
-    are adjacent to one another, whereas with the rowwise method, the   
-    elements accessed at a step are spaced LDS (and LDP) words apart.   
-
-    When finding left eigenvectors, the matrix in question is the   
-    transpose of the one in storage, so the rowwise method then   
-    actually accesses columns of A and B at each step, and so is the   
-    preferred method.   
-
-    =====================================================================   
-
-
-       Decode and Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static logical c_true = TRUE_;
-    static integer c__2 = 2;
-    static real c_b34 = 1.f;
-    static integer c__1 = 1;
-    static real c_b36 = 0.f;
-    static logical c_false = FALSE_;
-    
     /* System generated locals */
     integer p_dim1, p_offset, s_dim1, s_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2, r__3, r__4, r__5, r__6;
+
     /* Local variables */
-    static integer i__, j, ja, jc, je, na, im, jr, jw, nw;
-    static real big;
-    static logical lsa, lsb;
-    static real ulp, sum[4]	/* was [2][2] */;
-    static integer ibeg, ieig, iend;
-    static real dmin__, temp, xmax, sump[4]	/* was [2][2] */, sums[4]	
-	    /* was [2][2] */, cim2a, cim2b, cre2a, cre2b;
+    integer i__, j, ja, jc, je, na, im, jr, jw, nw;
+    real big;
+    logical lsa, lsb;
+    real ulp, sum[4]	/* was [2][2] */;
+    integer ibeg, ieig, iend;
+    real dmin__, temp, xmax, sump[4]	/* was [2][2] */, sums[4]	/* 
+	    was [2][2] */, cim2a, cim2b, cre2a, cre2b;
     extern /* Subroutine */ int slag2_(real *, integer *, real *, integer *, 
 	    real *, real *, real *, real *, real *, real *);
-    static real temp2, bdiag[2], acoef, scale;
-    static logical ilall;
-    static integer iside;
-    static real sbeta;
+    real temp2, bdiag[2], acoef, scale;
+    logical ilall;
+    integer iside;
+    real sbeta;
     extern logical lsame_(char *, char *);
-    static logical il2by2;
-    static integer iinfo;
-    static real small;
-    static logical compl;
-    static real anorm, bnorm;
-    static logical compr;
+    logical il2by2;
+    integer iinfo;
+    real small;
+    logical compl;
+    real anorm, bnorm;
+    logical compr;
     extern /* Subroutine */ int sgemv_(char *, integer *, integer *, real *, 
 	    real *, integer *, real *, integer *, real *, real *, integer *), slaln2_(logical *, integer *, integer *, real *, real *, 
 	    real *, integer *, real *, real *, real *, integer *, real *, 
 	    real *, real *, integer *, real *, real *, integer *);
-    static real temp2i, temp2r;
-    static logical ilabad, ilbbad;
-    static real acoefa, bcoefa, cimaga, cimagb;
-    static logical ilback;
+    real temp2i, temp2r;
+    logical ilabad, ilbbad;
+    real acoefa, bcoefa, cimaga, cimagb;
+    logical ilback;
     extern /* Subroutine */ int slabad_(real *, real *);
-    static real bcoefi, ascale, bscale, creala, crealb, bcoefr;
+    real bcoefi, ascale, bscale, creala, crealb, bcoefr;
     extern doublereal slamch_(char *);
-    static real salfar, safmin;
+    real salfar, safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static real xscale, bignum;
-    static logical ilcomp, ilcplx;
+    real xscale, bignum;
+    logical ilcomp, ilcplx;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *);
-    static integer ihwmny;
+    integer ihwmny;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+
+/*  Purpose */
+/*  ======= */
+
+/*  STGEVC computes some or all of the right and/or left eigenvectors of */
+/*  a pair of real matrices (S,P), where S is a quasi-triangular matrix */
+/*  and P is upper triangular.  Matrix pairs of this type are produced by */
+/*  the generalized Schur factorization of a matrix pair (A,B): */
+
+/*     A = Q*S*Z**T,  B = Q*P*Z**T */
+
+/*  as computed by SGGHRD + SHGEQZ. */
+
+/*  The right eigenvector x and the left eigenvector y of (S,P) */
+/*  corresponding to an eigenvalue w are defined by: */
+
+/*     S*x = w*P*x,  (y**H)*S = w*(y**H)*P, */
+
+/*  where y**H denotes the conjugate tranpose of y. */
+/*  The eigenvalues are not input to this routine, but are computed */
+/*  directly from the diagonal blocks of S and P. */
+
+/*  This routine returns the matrices X and/or Y of right and left */
+/*  eigenvectors of (S,P), or the products Z*X and/or Q*Y, */
+/*  where Z and Q are input matrices. */
+/*  If Q and Z are the orthogonal factors from the generalized Schur */
+/*  factorization of a matrix pair (A,B), then Z*X and Q*Y */
+/*  are the matrices of right and left eigenvectors of (A,B). */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'R': compute right eigenvectors only; */
+/*          = 'L': compute left eigenvectors only; */
+/*          = 'B': compute both right and left eigenvectors. */
+
+/*  HOWMNY  (input) CHARACTER*1 */
+/*          = 'A': compute all right and/or left eigenvectors; */
+/*          = 'B': compute all right and/or left eigenvectors, */
+/*                 backtransformed by the matrices in VR and/or VL; */
+/*          = 'S': compute selected right and/or left eigenvectors, */
+/*                 specified by the logical array SELECT. */
+
+/*  SELECT  (input) LOGICAL array, dimension (N) */
+/*          If HOWMNY='S', SELECT specifies the eigenvectors to be */
+/*          computed.  If w(j) is a real eigenvalue, the corresponding */
+/*          real eigenvector is computed if SELECT(j) is .TRUE.. */
+/*          If w(j) and w(j+1) are the real and imaginary parts of a */
+/*          complex eigenvalue, the corresponding complex eigenvector */
+/*          is computed if either SELECT(j) or SELECT(j+1) is .TRUE., */
+/*          and on exit SELECT(j) is set to .TRUE. and SELECT(j+1) is */
+/*          set to .FALSE.. */
+/*          Not referenced if HOWMNY = 'A' or 'B'. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices S and P.  N >= 0. */
+
+/*  S       (input) REAL array, dimension (LDS,N) */
+/*          The upper quasi-triangular matrix S from a generalized Schur */
+/*          factorization, as computed by SHGEQZ. */
+
+/*  LDS     (input) INTEGER */
+/*          The leading dimension of array S.  LDS >= max(1,N). */
+
+/*  P       (input) REAL array, dimension (LDP,N) */
+/*          The upper triangular matrix P from a generalized Schur */
+/*          factorization, as computed by SHGEQZ. */
+/*          2-by-2 diagonal blocks of P corresponding to 2-by-2 blocks */
+/*          of S must be in positive diagonal form. */
+
+/*  LDP     (input) INTEGER */
+/*          The leading dimension of array P.  LDP >= max(1,N). */
+
+/*  VL      (input/output) REAL array, dimension (LDVL,MM) */
+/*          On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must */
+/*          contain an N-by-N matrix Q (usually the orthogonal matrix Q */
+/*          of left Schur vectors returned by SHGEQZ). */
+/*          On exit, if SIDE = 'L' or 'B', VL contains: */
+/*          if HOWMNY = 'A', the matrix Y of left eigenvectors of (S,P); */
+/*          if HOWMNY = 'B', the matrix Q*Y; */
+/*          if HOWMNY = 'S', the left eigenvectors of (S,P) specified by */
+/*                      SELECT, stored consecutively in the columns of */
+/*                      VL, in the same order as their eigenvalues. */
+
+/*          A complex eigenvector corresponding to a complex eigenvalue */
+/*          is stored in two consecutive columns, the first holding the */
+/*          real part, and the second the imaginary part. */
+
+/*          Not referenced if SIDE = 'R'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of array VL.  LDVL >= 1, and if */
+/*          SIDE = 'L' or 'B', LDVL >= N. */
+
+/*  VR      (input/output) REAL array, dimension (LDVR,MM) */
+/*          On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must */
+/*          contain an N-by-N matrix Z (usually the orthogonal matrix Z */
+/*          of right Schur vectors returned by SHGEQZ). */
+
+/*          On exit, if SIDE = 'R' or 'B', VR contains: */
+/*          if HOWMNY = 'A', the matrix X of right eigenvectors of (S,P); */
+/*          if HOWMNY = 'B' or 'b', the matrix Z*X; */
+/*          if HOWMNY = 'S' or 's', the right eigenvectors of (S,P) */
+/*                      specified by SELECT, stored consecutively in the */
+/*                      columns of VR, in the same order as their */
+/*                      eigenvalues. */
+
+/*          A complex eigenvector corresponding to a complex eigenvalue */
+/*          is stored in two consecutive columns, the first holding the */
+/*          real part and the second the imaginary part. */
+
+/*          Not referenced if SIDE = 'L'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the array VR.  LDVR >= 1, and if */
+/*          SIDE = 'R' or 'B', LDVR >= N. */
+
+/*  MM      (input) INTEGER */
+/*          The number of columns in the arrays VL and/or VR. MM >= M. */
+
+/*  M       (output) INTEGER */
+/*          The number of columns in the arrays VL and/or VR actually */
+/*          used to store the eigenvectors.  If HOWMNY = 'A' or 'B', M */
+/*          is set to N.  Each selected real eigenvector occupies one */
+/*          column and each selected complex eigenvector occupies two */
+/*          columns. */
+
+/*  WORK    (workspace) REAL array, dimension (6*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit. */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  the 2-by-2 block (INFO:INFO+1) does not have a complex */
+/*                eigenvalue. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Allocation of workspace: */
+/*  ---------- -- --------- */
+
+/*     WORK( j ) = 1-norm of j-th column of A, above the diagonal */
+/*     WORK( N+j ) = 1-norm of j-th column of B, above the diagonal */
+/*     WORK( 2*N+1:3*N ) = real part of eigenvector */
+/*     WORK( 3*N+1:4*N ) = imaginary part of eigenvector */
+/*     WORK( 4*N+1:5*N ) = real part of back-transformed eigenvector */
+/*     WORK( 5*N+1:6*N ) = imaginary part of back-transformed eigenvector */
+
+/*  Rowwise vs. columnwise solution methods: */
+/*  ------- --  ---------- -------- ------- */
+
+/*  Finding a generalized eigenvector consists basically of solving the */
+/*  singular triangular system */
+
+/*   (A - w B) x = 0     (for right) or:   (A - w B)**H y = 0  (for left) */
+
+/*  Consider finding the i-th right eigenvector (assume all eigenvalues */
+/*  are real). The equation to be solved is: */
+/*       n                   i */
+/*  0 = sum  C(j,k) v(k)  = sum  C(j,k) v(k)     for j = i,. . .,1 */
+/*      k=j                 k=j */
+
+/*  where  C = (A - w B)  (The components v(i+1:n) are 0.) */
+
+/*  The "rowwise" method is: */
+
+/*  (1)  v(i) := 1 */
+/*  for j = i-1,. . .,1: */
+/*                          i */
+/*      (2) compute  s = - sum C(j,k) v(k)   and */
+/*                        k=j+1 */
+
+/*      (3) v(j) := s / C(j,j) */
+
+/*  Step 2 is sometimes called the "dot product" step, since it is an */
+/*  inner product between the j-th row and the portion of the eigenvector */
+/*  that has been computed so far. */
+
+/*  The "columnwise" method consists basically in doing the sums */
+/*  for all the rows in parallel.  As each v(j) is computed, the */
+/*  contribution of v(j) times the j-th column of C is added to the */
+/*  partial sums.  Since FORTRAN arrays are stored columnwise, this has */
+/*  the advantage that at each step, the elements of C that are accessed */
+/*  are adjacent to one another, whereas with the rowwise method, the */
+/*  elements accessed at a step are spaced LDS (and LDP) words apart. */
+
+/*  When finding left eigenvectors, the matrix in question is the */
+/*  transpose of the one in storage, so the rowwise method then */
+/*  actually accesses columns of A and B at each step, and so is the */
+/*  preferred method. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and Test the input parameters */
+
+    /* Parameter adjustments */
     --select;
     s_dim1 = *lds;
     s_offset = 1 + s_dim1;
@@ -415,10 +434,10 @@ L10:
     big = 1.f / small;
     bignum = 1.f / (safmin * *n);
 
-/*     Compute the 1-norm of each column of the strictly upper triangular   
-       part (i.e., excluding all elements belonging to the diagonal   
-       blocks) of A and B to check for possible overflow in the   
-       triangular solver. */
+/*     Compute the 1-norm of each column of the strictly upper triangular */
+/*     part (i.e., excluding all elements belonging to the diagonal */
+/*     blocks) of A and B to check for possible overflow in the */
+/*     triangular solver. */
 
     anorm = (r__1 = s[s_dim1 + 1], dabs(r__1));
     if (*n > 1) {
@@ -472,10 +491,10 @@ L10:
 	i__1 = *n;
 	for (je = 1; je <= i__1; ++je) {
 
-/*           Skip this iteration if (a) HOWMNY='S' and SELECT=.FALSE., or   
-             (b) this would be the second of a complex pair.   
-             Check for complex eigenvalue, so as to be sure of which   
-             entry(-ies) of SELECT to look at. */
+/*           Skip this iteration if (a) HOWMNY='S' and SELECT=.FALSE., or */
+/*           (b) this would be the second of a complex pair. */
+/*           Check for complex eigenvalue, so as to be sure of which */
+/*           entry(-ies) of SELECT to look at. */
 
 	    if (ilcplx) {
 		ilcplx = FALSE_;
@@ -499,8 +518,8 @@ L10:
 		goto L220;
 	    }
 
-/*           Decide if (a) singular pencil, (b) real eigenvalue, or   
-             (c) complex eigenvalue. */
+/*           Decide if (a) singular pencil, (b) real eigenvalue, or */
+/*           (c) complex eigenvalue. */
 
 	    if (! ilcplx) {
 		if ((r__1 = s[je + je * s_dim1], dabs(r__1)) <= safmin && (
@@ -526,16 +545,16 @@ L10:
 		work[(*n << 1) + jr] = 0.f;
 /* L70: */
 	    }
-/*                                                 T   
-             Compute coefficients in  ( a A - b B )  y = 0   
-                a  is  ACOEF   
-                b  is  BCOEFR + i*BCOEFI */
+/*                                                 T */
+/*           Compute coefficients in  ( a A - b B )  y = 0 */
+/*              a  is  ACOEF */
+/*              b  is  BCOEFR + i*BCOEFI */
 
 	    if (! ilcplx) {
 
-/*              Real eigenvalue   
+/*              Real eigenvalue */
 
-   Computing MAX */
+/* Computing MAX */
 		r__3 = (r__1 = s[je + je * s_dim1], dabs(r__1)) * ascale, 
 			r__4 = (r__2 = p[je + je * p_dim1], dabs(r__2)) * 
 			bscale, r__3 = max(r__3,r__4);
@@ -561,8 +580,8 @@ L10:
 		    scale = dmax(r__1,r__2);
 		}
 		if (lsa || lsb) {
-/* Computing MIN   
-   Computing MAX */
+/* Computing MIN */
+/* Computing MAX */
 		    r__3 = 1.f, r__4 = dabs(acoef), r__3 = max(r__3,r__4), 
 			    r__4 = dabs(bcoefr);
 		    r__1 = scale, r__2 = 1.f / (safmin * dmax(r__3,r__4));
@@ -661,11 +680,11 @@ L10:
 		    max(r__1,r__2);
 	    dmin__ = dmax(r__1,safmin);
 
-/*                                           T   
-             Triangular solve of  (a A - b B)  y = 0   
+/*                                           T */
+/*           Triangular solve of  (a A - b B)  y = 0 */
 
-                                     T   
-             (rowwise in  (a A - b B) , or columnwise in (a A - b B) ) */
+/*                                   T */
+/*           (rowwise in  (a A - b B) , or columnwise in (a A - b B) ) */
 
 	    il2by2 = FALSE_;
 
@@ -715,51 +734,51 @@ L10:
 		    xmax *= xscale;
 		}
 
-/*              Compute dot products   
+/*              Compute dot products */
 
-                      j-1   
-                SUM = sum  conjg( a*S(k,j) - b*P(k,j) )*x(k)   
-                      k=je   
+/*                    j-1 */
+/*              SUM = sum  conjg( a*S(k,j) - b*P(k,j) )*x(k) */
+/*                    k=je */
 
-                To reduce the op count, this is done as   
+/*              To reduce the op count, this is done as */
 
-                _        j-1                  _        j-1   
-                a*conjg( sum  S(k,j)*x(k) ) - b*conjg( sum  P(k,j)*x(k) )   
-                         k=je                          k=je   
+/*              _        j-1                  _        j-1 */
+/*              a*conjg( sum  S(k,j)*x(k) ) - b*conjg( sum  P(k,j)*x(k) ) */
+/*                       k=je                          k=je */
 
-                which may cause underflow problems if A or B are close   
-                to underflow.  (E.g., less than SMALL.)   
+/*              which may cause underflow problems if A or B are close */
+/*              to underflow.  (E.g., less than SMALL.) */
 
 
-                A series of compiler directives to defeat vectorization   
-                for the next loop   
+/*              A series of compiler directives to defeat vectorization */
+/*              for the next loop */
 
-   $PL$ CMCHAR=' '   
-   DIR$          NEXTSCALAR   
-   $DIR          SCALAR   
-   DIR$          NEXT SCALAR   
-   VD$L          NOVECTOR   
-   DEC$          NOVECTOR   
-   VD$           NOVECTOR   
-   VDIR          NOVECTOR   
-   VOCL          LOOP,SCALAR   
-   IBM           PREFER SCALAR   
-   $PL$ CMCHAR='*' */
+/* $PL$ CMCHAR=' ' */
+/* DIR$          NEXTSCALAR */
+/* $DIR          SCALAR */
+/* DIR$          NEXT SCALAR */
+/* VD$L          NOVECTOR */
+/* DEC$          NOVECTOR */
+/* VD$           NOVECTOR */
+/* VDIR          NOVECTOR */
+/* VOCL          LOOP,SCALAR */
+/* IBM           PREFER SCALAR */
+/* $PL$ CMCHAR='*' */
 
 		i__3 = nw;
 		for (jw = 1; jw <= i__3; ++jw) {
 
-/* $PL$ CMCHAR=' '   
-   DIR$             NEXTSCALAR   
-   $DIR             SCALAR   
-   DIR$             NEXT SCALAR   
-   VD$L             NOVECTOR   
-   DEC$             NOVECTOR   
-   VD$              NOVECTOR   
-   VDIR             NOVECTOR   
-   VOCL             LOOP,SCALAR   
-   IBM              PREFER SCALAR   
-   $PL$ CMCHAR='*' */
+/* $PL$ CMCHAR=' ' */
+/* DIR$             NEXTSCALAR */
+/* $DIR             SCALAR */
+/* DIR$             NEXT SCALAR */
+/* VD$L             NOVECTOR */
+/* DEC$             NOVECTOR */
+/* VD$              NOVECTOR */
+/* VDIR             NOVECTOR */
+/* VOCL             LOOP,SCALAR */
+/* IBM              PREFER SCALAR */
+/* $PL$ CMCHAR='*' */
 
 		    i__4 = na;
 		    for (ja = 1; ja <= i__4; ++ja) {
@@ -779,17 +798,17 @@ L10:
 /* L120: */
 		}
 
-/* $PL$ CMCHAR=' '   
-   DIR$          NEXTSCALAR   
-   $DIR          SCALAR   
-   DIR$          NEXT SCALAR   
-   VD$L          NOVECTOR   
-   DEC$          NOVECTOR   
-   VD$           NOVECTOR   
-   VDIR          NOVECTOR   
-   VOCL          LOOP,SCALAR   
-   IBM           PREFER SCALAR   
-   $PL$ CMCHAR='*' */
+/* $PL$ CMCHAR=' ' */
+/* DIR$          NEXTSCALAR */
+/* $DIR          SCALAR */
+/* DIR$          NEXT SCALAR */
+/* VD$L          NOVECTOR */
+/* DEC$          NOVECTOR */
+/* VD$           NOVECTOR */
+/* VDIR          NOVECTOR */
+/* VOCL          LOOP,SCALAR */
+/* IBM           PREFER SCALAR */
+/* $PL$ CMCHAR='*' */
 
 		i__3 = na;
 		for (ja = 1; ja <= i__3; ++ja) {
@@ -805,12 +824,12 @@ L10:
 /* L130: */
 		}
 
-/*                                  T   
-                Solve  ( a A - b B )  y = SUM(,)   
-                with scaling and perturbation of the denominator */
+/*                                  T */
+/*              Solve  ( a A - b B )  y = SUM(,) */
+/*              with scaling and perturbation of the denominator */
 
 		slaln2_(&c_true, &na, &nw, &dmin__, &acoef, &s[j + j * s_dim1]
-			, lds, bdiag, &bdiag[1], sum, &c__2, &bcoefr, &bcoefi,
+, lds, bdiag, &bdiag[1], sum, &c__2, &bcoefr, &bcoefi, 
 			 &work[(*n << 1) + j], n, &scale, &temp, &iinfo);
 		if (scale < 1.f) {
 		    i__3 = nw - 1;
@@ -830,8 +849,8 @@ L160:
 		;
 	    }
 
-/*           Copy eigenvector to VL, back transforming if   
-             HOWMNY='B'. */
+/*           Copy eigenvector to VL, back transforming if */
+/*           HOWMNY='B'. */
 
 	    ++ieig;
 	    if (ilback) {
@@ -907,13 +926,13 @@ L220:
 	ilcplx = FALSE_;
 	for (je = *n; je >= 1; --je) {
 
-/*           Skip this iteration if (a) HOWMNY='S' and SELECT=.FALSE., or   
-             (b) this would be the second of a complex pair.   
-             Check for complex eigenvalue, so as to be sure of which   
-             entry(-ies) of SELECT to look at -- if complex, SELECT(JE)   
-             or SELECT(JE-1).   
-             If this is a complex pair, the 2-by-2 diagonal block   
-             corresponding to the eigenvalue is in rows/columns JE-1:JE */
+/*           Skip this iteration if (a) HOWMNY='S' and SELECT=.FALSE., or */
+/*           (b) this would be the second of a complex pair. */
+/*           Check for complex eigenvalue, so as to be sure of which */
+/*           entry(-ies) of SELECT to look at -- if complex, SELECT(JE) */
+/*           or SELECT(JE-1). */
+/*           If this is a complex pair, the 2-by-2 diagonal block */
+/*           corresponding to the eigenvalue is in rows/columns JE-1:JE */
 
 	    if (ilcplx) {
 		ilcplx = FALSE_;
@@ -937,8 +956,8 @@ L220:
 		goto L500;
 	    }
 
-/*           Decide if (a) singular pencil, (b) real eigenvalue, or   
-             (c) complex eigenvalue. */
+/*           Decide if (a) singular pencil, (b) real eigenvalue, or */
+/*           (c) complex eigenvalue. */
 
 	    if (! ilcplx) {
 		if ((r__1 = s[je + je * s_dim1], dabs(r__1)) <= safmin && (
@@ -969,15 +988,15 @@ L220:
 /* L250: */
 	    }
 
-/*           Compute coefficients in  ( a A - b B ) x = 0   
-                a  is  ACOEF   
-                b  is  BCOEFR + i*BCOEFI */
+/*           Compute coefficients in  ( a A - b B ) x = 0 */
+/*              a  is  ACOEF */
+/*              b  is  BCOEFR + i*BCOEFI */
 
 	    if (! ilcplx) {
 
-/*              Real eigenvalue   
+/*              Real eigenvalue */
 
-   Computing MAX */
+/* Computing MAX */
 		r__3 = (r__1 = s[je + je * s_dim1], dabs(r__1)) * ascale, 
 			r__4 = (r__2 = p[je + je * p_dim1], dabs(r__2)) * 
 			bscale, r__3 = max(r__3,r__4);
@@ -1003,8 +1022,8 @@ L220:
 		    scale = dmax(r__1,r__2);
 		}
 		if (lsa || lsb) {
-/* Computing MIN   
-   Computing MAX */
+/* Computing MIN */
+/* Computing MAX */
 		    r__3 = 1.f, r__4 = dabs(acoef), r__3 = max(r__3,r__4), 
 			    r__4 = dabs(bcoefr);
 		    r__1 = scale, r__2 = 1.f / (safmin * dmax(r__3,r__4));
@@ -1028,8 +1047,8 @@ L220:
 		work[(*n << 1) + je] = 1.f;
 		xmax = 1.f;
 
-/*              Compute contribution from column JE of A and B to sum   
-                (See "Further Details", above.) */
+/*              Compute contribution from column JE of A and B to sum */
+/*              (See "Further Details", above.) */
 
 		i__1 = je - 1;
 		for (jr = 1; jr <= i__1; ++jr) {
@@ -1079,8 +1098,8 @@ L220:
 		    bcoefa = dabs(bcoefr) + dabs(bcoefi);
 		}
 
-/*              Compute first two components of eigenvector   
-                and contribution to sums */
+/*              Compute first two components of eigenvector */
+/*              and contribution to sums */
 
 		temp = acoef * s[je + (je - 1) * s_dim1];
 		temp2r = acoef * s[je + je * s_dim1] - bcoefr * p[je + je * 
@@ -1109,8 +1128,8 @@ L220:
 			+ je - 1], dabs(r__4));
 		xmax = dmax(r__5,r__6);
 
-/*              Compute contribution from columns JE and JE-1   
-                of A and B to the sums. */
+/*              Compute contribution from columns JE and JE-1 */
+/*              of A and B to the sums. */
 
 		creala = acoef * work[(*n << 1) + je - 1];
 		cimaga = acoef * work[*n * 3 + je - 1];
@@ -1146,8 +1165,8 @@ L220:
 	    il2by2 = FALSE_;
 	    for (j = je - nw; j >= 1; --j) {
 
-/*              If a 2-by-2 block, is in position j-1:j, wait until   
-                next iteration to process it (when it will be j:j+1) */
+/*              If a 2-by-2 block, is in position j-1:j, wait until */
+/*              next iteration to process it (when it will be j:j+1) */
 
 		if (! il2by2 && j > 1) {
 		    if (s[j + (j - 1) * s_dim1] != 0.f) {
@@ -1229,9 +1248,9 @@ L220:
 			xmax *= xscale;
 		    }
 
-/*                 Compute the contributions of the off-diagonals of   
-                   column j (and j+1, if 2-by-2 block) of A and B to the   
-                   sums. */
+/*                 Compute the contributions of the off-diagonals of */
+/*                 column j (and j+1, if 2-by-2 block) of A and B to the */
+/*                 sums. */
 
 
 		    i__1 = na;
@@ -1276,8 +1295,8 @@ L370:
 		;
 	    }
 
-/*           Copy eigenvector to VR, back transforming if   
-             HOWMNY='B'. */
+/*           Copy eigenvector to VR, back transforming if */
+/*           HOWMNY='B'. */
 
 	    ieig -= nw;
 	    if (ilback) {
@@ -1291,8 +1310,8 @@ L370:
 /* L380: */
 		    }
 
-/*                 A series of compiler directives to defeat   
-                   vectorization for the next loop */
+/*                 A series of compiler directives to defeat */
+/*                 vectorization for the next loop */
 
 
 		    i__2 = je;
