@@ -1,197 +1,218 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__4 = 4;
+static real c_b5 = 0.f;
+static integer c__1 = 1;
+static integer c__2 = 2;
+static real c_b42 = 1.f;
+static real c_b48 = -1.f;
+static integer c__0 = 0;
 
 /* Subroutine */ int stgex2_(logical *wantq, logical *wantz, integer *n, real 
 	*a, integer *lda, real *b, integer *ldb, real *q, integer *ldq, real *
 	z__, integer *ldz, integer *j1, integer *n1, integer *n2, real *work, 
 	integer *lwork, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    STGEX2 swaps adjacent diagonal blocks (A11, B11) and (A22, B22)   
-    of size 1-by-1 or 2-by-2 in an upper (quasi) triangular matrix pair   
-    (A, B) by an orthogonal equivalence transformation.   
-
-    (A, B) must be in generalized real Schur canonical form (as returned   
-    by SGGES), i.e. A is block upper triangular with 1-by-1 and 2-by-2   
-    diagonal blocks. B is upper triangular.   
-
-    Optionally, the matrices Q and Z of generalized Schur vectors are   
-    updated.   
-
-           Q(in) * A(in) * Z(in)' = Q(out) * A(out) * Z(out)'   
-           Q(in) * B(in) * Z(in)' = Q(out) * B(out) * Z(out)'   
-
-
-    Arguments   
-    =========   
-
-    WANTQ   (input) LOGICAL   
-            .TRUE. : update the left transformation matrix Q;   
-            .FALSE.: do not update Q.   
-
-    WANTZ   (input) LOGICAL   
-            .TRUE. : update the right transformation matrix Z;   
-            .FALSE.: do not update Z.   
-
-    N       (input) INTEGER   
-            The order of the matrices A and B. N >= 0.   
-
-    A      (input/output) REAL arrays, dimensions (LDA,N)   
-            On entry, the matrix A in the pair (A, B).   
-            On exit, the updated matrix A.   
-
-    LDA     (input)  INTEGER   
-            The leading dimension of the array A. LDA >= max(1,N).   
-
-    B      (input/output) REAL arrays, dimensions (LDB,N)   
-            On entry, the matrix B in the pair (A, B).   
-            On exit, the updated matrix B.   
-
-    LDB     (input)  INTEGER   
-            The leading dimension of the array B. LDB >= max(1,N).   
-
-    Q       (input/output) REAL array, dimension (LDZ,N)   
-            On entry, if WANTQ = .TRUE., the orthogonal matrix Q.   
-            On exit, the updated matrix Q.   
-            Not referenced if WANTQ = .FALSE..   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of the array Q. LDQ >= 1.   
-            If WANTQ = .TRUE., LDQ >= N.   
-
-    Z       (input/output) REAL array, dimension (LDZ,N)   
-            On entry, if WANTZ =.TRUE., the orthogonal matrix Z.   
-            On exit, the updated matrix Z.   
-            Not referenced if WANTZ = .FALSE..   
-
-    LDZ     (input) INTEGER   
-            The leading dimension of the array Z. LDZ >= 1.   
-            If WANTZ = .TRUE., LDZ >= N.   
-
-    J1      (input) INTEGER   
-            The index to the first block (A11, B11). 1 <= J1 <= N.   
-
-    N1      (input) INTEGER   
-            The order of the first block (A11, B11). N1 = 0, 1 or 2.   
-
-    N2      (input) INTEGER   
-            The order of the second block (A22, B22). N2 = 0, 1 or 2.   
-
-    WORK    (workspace) REAL array, dimension (MAX(1,LWORK)).   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.   
-            LWORK >=  MAX( N*(N2+N1), (N2+N1)*(N2+N1)*2 )   
-
-    INFO    (output) INTEGER   
-              =0: Successful exit   
-              >0: If INFO = 1, the transformed matrix (A, B) would be   
-                  too far from generalized Schur form; the blocks are   
-                  not swapped and (A, B) and (Q, Z) are unchanged.   
-                  The problem of swapping is too ill-conditioned.   
-              <0: If INFO = -16: LWORK is too small. Appropriate value   
-                  for LWORK is returned in WORK(1).   
-
-    Further Details   
-    ===============   
-
-    Based on contributions by   
-       Bo Kagstrom and Peter Poromaa, Department of Computing Science,   
-       Umea University, S-901 87 Umea, Sweden.   
-
-    In the current code both weak and strong stability tests are   
-    performed. The user can omit the strong stability test by changing   
-    the internal logical parameter WANDS to .FALSE.. See ref. [2] for   
-    details.   
-
-    [1] B. Kagstrom; A Direct Method for Reordering Eigenvalues in the   
-        Generalized Real Schur Form of a Regular Matrix Pair (A, B), in   
-        M.S. Moonen et al (eds), Linear Algebra for Large Scale and   
-        Real-Time Applications, Kluwer Academic Publ. 1993, pp 195-218.   
-
-    [2] B. Kagstrom and P. Poromaa; Computing Eigenspaces with Specified   
-        Eigenvalues of a Regular Matrix Pair (A, B) and Condition   
-        Estimation: Theory, Algorithms and Software,   
-        Report UMINF - 94.04, Department of Computing Science, Umea   
-        University, S-901 87 Umea, Sweden, 1994. Also as LAPACK Working   
-        Note 87. To appear in Numerical Algorithms, 1996.   
-
-    =====================================================================   
-    Replaced various illegal calls to SCOPY by calls to SLASET, or by DO   
-    loops. Sven Hammarling, 1/5/02.   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__4 = 4;
-    static real c_b5 = 0.f;
-    static integer c__1 = 1;
-    static integer c__2 = 2;
-    static real c_b42 = 1.f;
-    static real c_b48 = -1.f;
-    static integer c__0 = 0;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, q_dim1, q_offset, z_dim1, 
 	    z_offset, i__1, i__2;
     real r__1;
+
     /* Builtin functions */
     double sqrt(doublereal);
+
     /* Local variables */
-    static real f, g;
-    static integer i__, m;
-    static real s[16]	/* was [4][4] */, t[16]	/* was [4][4] */, be[2], ai[2]
-	    , ar[2], sa, sb, li[16]	/* was [4][4] */, ir[16]	/* 
-	    was [4][4] */, ss, ws, eps;
-    static logical weak;
-    static real ddum;
-    static integer idum;
-    static real taul[4], dsum, taur[4], scpy[16]	/* was [4][4] */, 
-	    tcpy[16]	/* was [4][4] */;
+    real f, g;
+    integer i__, m;
+    real s[16]	/* was [4][4] */, t[16]	/* was [4][4] */, be[2], ai[2], ar[2],
+	     sa, sb, li[16]	/* was [4][4] */, ir[16]	/* was [4][4] 
+	    */, ss, ws, eps;
+    logical weak;
+    real ddum;
+    integer idum;
+    real taul[4], dsum, taur[4], scpy[16]	/* was [4][4] */, tcpy[16]	
+	    /* was [4][4] */;
     extern /* Subroutine */ int srot_(integer *, real *, integer *, real *, 
 	    integer *, real *, real *);
-    static real scale, bqra21, brqa21;
+    real scale, bqra21, brqa21;
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static real licop[16]	/* was [4][4] */;
-    static integer linfo;
+    real licop[16]	/* was [4][4] */;
+    integer linfo;
     extern /* Subroutine */ int sgemm_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *);
-    static real ircop[16]	/* was [4][4] */, dnorm;
-    static integer iwork[4];
+    real ircop[16]	/* was [4][4] */, dnorm;
+    integer iwork[4];
     extern /* Subroutine */ int slagv2_(real *, integer *, real *, integer *, 
 	    real *, real *, real *, real *, real *, real *, real *), sgeqr2_(
-	    integer *, integer *, real *, integer *, real *, real *, integer * 	    ), sgerq2_(integer *, integer *, real *, integer *, real *, real *
-	    , integer *), sorg2r_(integer *, integer *, integer *, real *, 
+	    integer *, integer *, real *, integer *, real *, real *, integer *
+), sgerq2_(integer *, integer *, real *, integer *, real *, real *
+, integer *), sorg2r_(integer *, integer *, integer *, real *, 
 	    integer *, real *, real *, integer *), sorgr2_(integer *, integer 
 	    *, integer *, real *, integer *, real *, real *, integer *), 
 	    sorm2r_(char *, char *, integer *, integer *, integer *, real *, 
 	    integer *, real *, real *, integer *, real *, integer *), sormr2_(char *, char *, integer *, integer *, integer *, 
 	    real *, integer *, real *, real *, integer *, real *, integer *);
-    static real dscale;
+    real dscale;
     extern /* Subroutine */ int stgsy2_(char *, integer *, integer *, integer 
 	    *, real *, integer *, real *, integer *, real *, integer *, real *
-	    , integer *, real *, integer *, real *, integer *, real *, real *,
+, integer *, real *, integer *, real *, integer *, real *, real *, 
 	     real *, integer *, integer *, integer *);
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), slartg_(real *, real *, 
 	    real *, real *, real *);
-    static real thresh;
+    real thresh;
     extern /* Subroutine */ int slaset_(char *, integer *, integer *, real *, 
 	    real *, real *, integer *), slassq_(integer *, real *, 
 	    integer *, real *, real *);
-    static real smlnum;
-    static logical strong;
+    real smlnum;
+    logical strong;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  STGEX2 swaps adjacent diagonal blocks (A11, B11) and (A22, B22) */
+/*  of size 1-by-1 or 2-by-2 in an upper (quasi) triangular matrix pair */
+/*  (A, B) by an orthogonal equivalence transformation. */
+
+/*  (A, B) must be in generalized real Schur canonical form (as returned */
+/*  by SGGES), i.e. A is block upper triangular with 1-by-1 and 2-by-2 */
+/*  diagonal blocks. B is upper triangular. */
+
+/*  Optionally, the matrices Q and Z of generalized Schur vectors are */
+/*  updated. */
+
+/*         Q(in) * A(in) * Z(in)' = Q(out) * A(out) * Z(out)' */
+/*         Q(in) * B(in) * Z(in)' = Q(out) * B(out) * Z(out)' */
+
+
+/*  Arguments */
+/*  ========= */
+
+/*  WANTQ   (input) LOGICAL */
+/*          .TRUE. : update the left transformation matrix Q; */
+/*          .FALSE.: do not update Q. */
+
+/*  WANTZ   (input) LOGICAL */
+/*          .TRUE. : update the right transformation matrix Z; */
+/*          .FALSE.: do not update Z. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A and B. N >= 0. */
+
+/*  A      (input/output) REAL arrays, dimensions (LDA,N) */
+/*          On entry, the matrix A in the pair (A, B). */
+/*          On exit, the updated matrix A. */
+
+/*  LDA     (input)  INTEGER */
+/*          The leading dimension of the array A. LDA >= max(1,N). */
+
+/*  B      (input/output) REAL arrays, dimensions (LDB,N) */
+/*          On entry, the matrix B in the pair (A, B). */
+/*          On exit, the updated matrix B. */
+
+/*  LDB     (input)  INTEGER */
+/*          The leading dimension of the array B. LDB >= max(1,N). */
+
+/*  Q       (input/output) REAL array, dimension (LDZ,N) */
+/*          On entry, if WANTQ = .TRUE., the orthogonal matrix Q. */
+/*          On exit, the updated matrix Q. */
+/*          Not referenced if WANTQ = .FALSE.. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of the array Q. LDQ >= 1. */
+/*          If WANTQ = .TRUE., LDQ >= N. */
+
+/*  Z       (input/output) REAL array, dimension (LDZ,N) */
+/*          On entry, if WANTZ =.TRUE., the orthogonal matrix Z. */
+/*          On exit, the updated matrix Z. */
+/*          Not referenced if WANTZ = .FALSE.. */
+
+/*  LDZ     (input) INTEGER */
+/*          The leading dimension of the array Z. LDZ >= 1. */
+/*          If WANTZ = .TRUE., LDZ >= N. */
+
+/*  J1      (input) INTEGER */
+/*          The index to the first block (A11, B11). 1 <= J1 <= N. */
+
+/*  N1      (input) INTEGER */
+/*          The order of the first block (A11, B11). N1 = 0, 1 or 2. */
+
+/*  N2      (input) INTEGER */
+/*          The order of the second block (A22, B22). N2 = 0, 1 or 2. */
+
+/*  WORK    (workspace) REAL array, dimension (MAX(1,LWORK)). */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK. */
+/*          LWORK >=  MAX( N*(N2+N1), (N2+N1)*(N2+N1)*2 ) */
+
+/*  INFO    (output) INTEGER */
+/*            =0: Successful exit */
+/*            >0: If INFO = 1, the transformed matrix (A, B) would be */
+/*                too far from generalized Schur form; the blocks are */
+/*                not swapped and (A, B) and (Q, Z) are unchanged. */
+/*                The problem of swapping is too ill-conditioned. */
+/*            <0: If INFO = -16: LWORK is too small. Appropriate value */
+/*                for LWORK is returned in WORK(1). */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Based on contributions by */
+/*     Bo Kagstrom and Peter Poromaa, Department of Computing Science, */
+/*     Umea University, S-901 87 Umea, Sweden. */
+
+/*  In the current code both weak and strong stability tests are */
+/*  performed. The user can omit the strong stability test by changing */
+/*  the internal logical parameter WANDS to .FALSE.. See ref. [2] for */
+/*  details. */
+
+/*  [1] B. Kagstrom; A Direct Method for Reordering Eigenvalues in the */
+/*      Generalized Real Schur Form of a Regular Matrix Pair (A, B), in */
+/*      M.S. Moonen et al (eds), Linear Algebra for Large Scale and */
+/*      Real-Time Applications, Kluwer Academic Publ. 1993, pp 195-218. */
+
+/*  [2] B. Kagstrom and P. Poromaa; Computing Eigenspaces with Specified */
+/*      Eigenvalues of a Regular Matrix Pair (A, B) and Condition */
+/*      Estimation: Theory, Algorithms and Software, */
+/*      Report UMINF - 94.04, Department of Computing Science, Umea */
+/*      University, S-901 87 Umea, Sweden, 1994. Also as LAPACK Working */
+/*      Note 87. To appear in Numerical Algorithms, 1996. */
+
+/*  ===================================================================== */
+/*  Replaced various illegal calls to SCOPY by calls to SLASET, or by DO */
+/*  loops. Sven Hammarling, 1/5/02. */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -257,10 +278,10 @@
 
     if (m == 2) {
 
-/*        CASE 1: Swap 1-by-1 and 1-by-1 blocks.   
+/*        CASE 1: Swap 1-by-1 and 1-by-1 blocks. */
 
-          Compute orthogonal QL and RQ that swap 1-by-1 and 1-by-1 blocks   
-          using Givens rotations and perform the swap tentatively. */
+/*        Compute orthogonal QL and RQ that swap 1-by-1 and 1-by-1 blocks */
+/*        using Givens rotations and perform the swap tentatively. */
 
 	f = s[5] * t[0] - t[5] * s[0];
 	g = s[5] * t[4] - t[5] * s[4];
@@ -281,8 +302,8 @@
 	li[5] = li[0];
 	li[4] = -li[1];
 
-/*        Weak stability test:   
-             |S21| + |T21| <= O(EPS * F-norm((S, T))) */
+/*        Weak stability test: */
+/*           |S21| + |T21| <= O(EPS * F-norm((S, T))) */
 
 	ws = dabs(s[1]) + dabs(t[1]);
 	weak = ws <= thresh;
@@ -292,8 +313,8 @@
 
 	if (TRUE_) {
 
-/*           Strong stability test:   
-               F-norm((A-QL'*S*QR, B-QL'*T*QR)) <= O(EPS*F-norm((A,B))) */
+/*           Strong stability test: */
+/*             F-norm((A-QL'*S*QR, B-QL'*T*QR)) <= O(EPS*F-norm((A,B))) */
 
 	    slacpy_("Full", &m, &m, &a[*j1 + *j1 * a_dim1], lda, &work[m * m 
 		    + 1], &m);
@@ -321,8 +342,8 @@
 	    }
 	}
 
-/*        Update (A(J1:J1+M-1, M+J1:N), B(J1:J1+M-1, M+J1:N)) and   
-                 (A(1:J1-1, J1:J1+M), B(1:J1-1, J1:J1+M)). */
+/*        Update (A(J1:J1+M-1, M+J1:N), B(J1:J1+M-1, M+J1:N)) and */
+/*               (A(1:J1-1, J1:J1+M), B(1:J1-1, J1:J1+M)). */
 
 	i__1 = *j1 + 1;
 	srot_(&i__1, &a[*j1 * a_dim1 + 1], &c__1, &a[(*j1 + 1) * a_dim1 + 1], 
@@ -359,29 +380,29 @@
 
     } else {
 
-/*        CASE 2: Swap 1-by-1 and 2-by-2 blocks, or 2-by-2   
-                  and 2-by-2 blocks.   
+/*        CASE 2: Swap 1-by-1 and 2-by-2 blocks, or 2-by-2 */
+/*                and 2-by-2 blocks. */
 
-          Solve the generalized Sylvester equation   
-                   S11 * R - L * S22 = SCALE * S12   
-                   T11 * R - L * T22 = SCALE * T12   
-          for R and L. Solutions in LI and IR. */
+/*        Solve the generalized Sylvester equation */
+/*                 S11 * R - L * S22 = SCALE * S12 */
+/*                 T11 * R - L * T22 = SCALE * T12 */
+/*        for R and L. Solutions in LI and IR. */
 
 	slacpy_("Full", n1, n2, &t[(*n1 + 1 << 2) - 4], &c__4, li, &c__4);
 	slacpy_("Full", n1, n2, &s[(*n1 + 1 << 2) - 4], &c__4, &ir[*n2 + 1 + (
 		*n1 + 1 << 2) - 5], &c__4);
 	stgsy2_("N", &c__0, n1, n2, s, &c__4, &s[*n1 + 1 + (*n1 + 1 << 2) - 5]
-		, &c__4, &ir[*n2 + 1 + (*n1 + 1 << 2) - 5], &c__4, t, &c__4, &
+, &c__4, &ir[*n2 + 1 + (*n1 + 1 << 2) - 5], &c__4, t, &c__4, &
 		t[*n1 + 1 + (*n1 + 1 << 2) - 5], &c__4, li, &c__4, &scale, &
 		dsum, &dscale, iwork, &idum, &linfo);
 
-/*        Compute orthogonal matrix QL:   
+/*        Compute orthogonal matrix QL: */
 
-                      QL' * LI = [ TL ]   
-                                 [ 0  ]   
-          where   
-                      LI =  [      -L              ]   
-                            [ SCALE * identity(N2) ] */
+/*                    QL' * LI = [ TL ] */
+/*                               [ 0  ] */
+/*        where */
+/*                    LI =  [      -L              ] */
+/*                          [ SCALE * identity(N2) ] */
 
 	i__1 = *n2;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -398,11 +419,11 @@
 	    goto L70;
 	}
 
-/*        Compute orthogonal matrix RQ:   
+/*        Compute orthogonal matrix RQ: */
 
-                      IR * RQ' =   [ 0  TR],   
+/*                    IR * RQ' =   [ 0  TR], */
 
-           where IR = [ SCALE * identity(N1), R ] */
+/*         where IR = [ SCALE * identity(N1), R ] */
 
 	i__1 = *n1;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -433,8 +454,8 @@
 	slacpy_("F", &m, &m, ir, &c__4, ircop, &c__4);
 	slacpy_("F", &m, &m, li, &c__4, licop, &c__4);
 
-/*        Triangularize the B-part by an RQ factorization.   
-          Apply transformation (from left) to A-part, giving S. */
+/*        Triangularize the B-part by an RQ factorization. */
+/*        Apply transformation (from left) to A-part, giving S. */
 
 	sgerq2_(&m, &m, t, &c__4, taur, &work[1], &linfo);
 	if (linfo != 0) {
@@ -462,15 +483,15 @@
 	}
 	brqa21 = dscale * sqrt(dsum);
 
-/*        Triangularize the B-part by a QR factorization.   
-          Apply transformation (from right) to A-part, giving S. */
+/*        Triangularize the B-part by a QR factorization. */
+/*        Apply transformation (from right) to A-part, giving S. */
 
 	sgeqr2_(&m, &m, tcpy, &c__4, taul, &work[1], &linfo);
 	if (linfo != 0) {
 	    goto L70;
 	}
 	sorm2r_("L", "T", &m, &m, &m, tcpy, &c__4, taul, scpy, &c__4, &work[1]
-		, info);
+, info);
 	sorm2r_("R", "N", &m, &m, &m, tcpy, &c__4, taul, licop, &c__4, &work[
 		1], info);
 	if (linfo != 0) {
@@ -489,9 +510,9 @@
 	}
 	bqra21 = dscale * sqrt(dsum);
 
-/*        Decide which method to use.   
-            Weak stability test:   
-               F-norm(S21) <= O(EPS * F-norm((S, T))) */
+/*        Decide which method to use. */
+/*          Weak stability test: */
+/*             F-norm(S21) <= O(EPS * F-norm((S, T))) */
 
 	if (bqra21 <= brqa21 && bqra21 <= thresh) {
 	    slacpy_("F", &m, &m, scpy, &c__4, s, &c__4);
@@ -510,8 +531,8 @@
 
 	if (TRUE_) {
 
-/*           Strong stability test:   
-                F-norm((A-QL*S*QR', B-QL*T*QR')) <= O(EPS*F-norm((A,B))) */
+/*           Strong stability test: */
+/*              F-norm((A-QL*S*QR', B-QL*T*QR')) <= O(EPS*F-norm((A,B))) */
 
 	    slacpy_("Full", &m, &m, &a[*j1 + *j1 * a_dim1], lda, &work[m * m 
 		    + 1], &m);
@@ -540,8 +561,8 @@
 
 	}
 
-/*        If the swap is accepted ("weakly" and "strongly"), apply the   
-          transformations and set N1-by-N2 (2,1)-block to zero. */
+/*        If the swap is accepted ("weakly" and "strongly"), apply the */
+/*        transformations and set N1-by-N2 (2,1)-block to zero. */
 
 	slaset_("Full", n1, n2, &c_b5, &c_b5, &s[*n2], &c__4);
 
@@ -625,8 +646,8 @@
 
 	}
 
-/*        Update (A(J1:J1+M-1, M+J1:N), B(J1:J1+M-1, M+J1:N)) and   
-                  (A(1:J1-1, J1:J1+M), B(1:J1-1, J1:J1+M)). */
+/*        Update (A(J1:J1+M-1, M+J1:N), B(J1:J1+M-1, M+J1:N)) and */
+/*                (A(1:J1-1, J1:J1+M), B(1:J1-1, J1:J1+M)). */
 
 	i__ = *j1 + m;
 	if (i__ <= *n) {
