@@ -1,5 +1,13 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__8 = 8;
+static integer c__1 = 1;
+static real c_b27 = -1.f;
+static real c_b42 = 1.f;
+static real c_b56 = 0.f;
 
 /* Subroutine */ int stgsy2_(char *trans, integer *ijob, integer *m, integer *
 	n, real *a, integer *lda, real *b, integer *ldb, real *c__, integer *
@@ -7,193 +15,20 @@
 	*ldf, real *scale, real *rdsum, real *rdscal, integer *iwork, integer 
 	*pq, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
-
-
-    Purpose   
-    =======   
-
-    STGSY2 solves the generalized Sylvester equation:   
-
-                A * R - L * B = scale * C                (1)   
-                D * R - L * E = scale * F,   
-
-    using Level 1 and 2 BLAS. where R and L are unknown M-by-N matrices,   
-    (A, D), (B, E) and (C, F) are given matrix pairs of size M-by-M,   
-    N-by-N and M-by-N, respectively, with real entries. (A, D) and (B, E)   
-    must be in generalized Schur canonical form, i.e. A, B are upper   
-    quasi triangular and D, E are upper triangular. The solution (R, L)   
-    overwrites (C, F). 0 <= SCALE <= 1 is an output scaling factor   
-    chosen to avoid overflow.   
-
-    In matrix notation solving equation (1) corresponds to solve   
-    Z*x = scale*b, where Z is defined as   
-
-           Z = [ kron(In, A)  -kron(B', Im) ]             (2)   
-               [ kron(In, D)  -kron(E', Im) ],   
-
-    Ik is the identity matrix of size k and X' is the transpose of X.   
-    kron(X, Y) is the Kronecker product between the matrices X and Y.   
-    In the process of solving (1), we solve a number of such systems   
-    where Dim(In), Dim(In) = 1 or 2.   
-
-    If TRANS = 'T', solve the transposed system Z'*y = scale*b for y,   
-    which is equivalent to solve for R and L in   
-
-                A' * R  + D' * L   = scale *  C           (3)   
-                R  * B' + L  * E'  = scale * -F   
-
-    This case is used to compute an estimate of Dif[(A, D), (B, E)] =   
-    sigma_min(Z) using reverse communicaton with SLACON.   
-
-    STGSY2 also (IJOB >= 1) contributes to the computation in STGSYL   
-    of an upper bound on the separation between to matrix pairs. Then   
-    the input (A, D), (B, E) are sub-pencils of the matrix pair in   
-    STGSYL. See STGSYL for details.   
-
-    Arguments   
-    =========   
-
-    TRANS   (input) CHARACTER*1   
-            = 'N', solve the generalized Sylvester equation (1).   
-            = 'T': solve the 'transposed' system (3).   
-
-    IJOB    (input) INTEGER   
-            Specifies what kind of functionality to be performed.   
-            = 0: solve (1) only.   
-            = 1: A contribution from this subsystem to a Frobenius   
-                 norm-based estimate of the separation between two matrix   
-                 pairs is computed. (look ahead strategy is used).   
-            = 2: A contribution from this subsystem to a Frobenius   
-                 norm-based estimate of the separation between two matrix   
-                 pairs is computed. (SGECON on sub-systems is used.)   
-            Not referenced if TRANS = 'T'.   
-
-    M       (input) INTEGER   
-            On entry, M specifies the order of A and D, and the row   
-            dimension of C, F, R and L.   
-
-    N       (input) INTEGER   
-            On entry, N specifies the order of B and E, and the column   
-            dimension of C, F, R and L.   
-
-    A       (input) REAL array, dimension (LDA, M)   
-            On entry, A contains an upper quasi triangular matrix.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the matrix A. LDA >= max(1, M).   
-
-    B       (input) REAL array, dimension (LDB, N)   
-            On entry, B contains an upper quasi triangular matrix.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the matrix B. LDB >= max(1, N).   
-
-    C       (input/output) REAL array, dimension (LDC, N)   
-            On entry, C contains the right-hand-side of the first matrix   
-            equation in (1).   
-            On exit, if IJOB = 0, C has been overwritten by the   
-            solution R.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the matrix C. LDC >= max(1, M).   
-
-    D       (input) REAL array, dimension (LDD, M)   
-            On entry, D contains an upper triangular matrix.   
-
-    LDD     (input) INTEGER   
-            The leading dimension of the matrix D. LDD >= max(1, M).   
-
-    E       (input) REAL array, dimension (LDE, N)   
-            On entry, E contains an upper triangular matrix.   
-
-    LDE     (input) INTEGER   
-            The leading dimension of the matrix E. LDE >= max(1, N).   
-
-    F       (input/output) REAL array, dimension (LDF, N)   
-            On entry, F contains the right-hand-side of the second matrix   
-            equation in (1).   
-            On exit, if IJOB = 0, F has been overwritten by the   
-            solution L.   
-
-    LDF     (input) INTEGER   
-            The leading dimension of the matrix F. LDF >= max(1, M).   
-
-    SCALE   (output) REAL   
-            On exit, 0 <= SCALE <= 1. If 0 < SCALE < 1, the solutions   
-            R and L (C and F on entry) will hold the solutions to a   
-            slightly perturbed system but the input matrices A, B, D and   
-            E have not been changed. If SCALE = 0, R and L will hold the   
-            solutions to the homogeneous system with C = F = 0. Normally,   
-            SCALE = 1.   
-
-    RDSUM   (input/output) REAL   
-            On entry, the sum of squares of computed contributions to   
-            the Dif-estimate under computation by STGSYL, where the   
-            scaling factor RDSCAL (see below) has been factored out.   
-            On exit, the corresponding sum of squares updated with the   
-            contributions from the current sub-system.   
-            If TRANS = 'T' RDSUM is not touched.   
-            NOTE: RDSUM only makes sense when STGSY2 is called by STGSYL.   
-
-    RDSCAL  (input/output) REAL   
-            On entry, scaling factor used to prevent overflow in RDSUM.   
-            On exit, RDSCAL is updated w.r.t. the current contributions   
-            in RDSUM.   
-            If TRANS = 'T', RDSCAL is not touched.   
-            NOTE: RDSCAL only makes sense when STGSY2 is called by   
-                  STGSYL.   
-
-    IWORK   (workspace) INTEGER array, dimension (M+N+2)   
-
-    PQ      (output) INTEGER   
-            On exit, the number of subsystems (of size 2-by-2, 4-by-4 and   
-            8-by-8) solved by this routine.   
-
-    INFO    (output) INTEGER   
-            On exit, if INFO is set to   
-              =0: Successful exit   
-              <0: If INFO = -i, the i-th argument had an illegal value.   
-              >0: The matrix pairs (A, D) and (B, E) have common or very   
-                  close eigenvalues.   
-
-    Further Details   
-    ===============   
-
-    Based on contributions by   
-       Bo Kagstrom and Peter Poromaa, Department of Computing Science,   
-       Umea University, S-901 87 Umea, Sweden.   
-
-    =====================================================================   
-    Replaced various illegal calls to SCOPY by calls to SLASET.   
-    Sven Hammarling, 27/5/02.   
-
-
-       Decode and test input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__8 = 8;
-    static integer c__1 = 1;
-    static real c_b27 = -1.f;
-    static real c_b42 = 1.f;
-    static real c_b56 = 0.f;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, c_dim1, c_offset, d_dim1, 
 	    d_offset, e_dim1, e_offset, f_dim1, f_offset, i__1, i__2, i__3;
+
     /* Local variables */
-    static integer i__, j, k, p, q;
-    static real z__[64]	/* was [8][8] */;
-    static integer ie, je, mb, nb, ii, jj, is, js;
-    static real rhs[8];
-    static integer isp1, jsp1;
+    integer i__, j, k, p, q;
+    real z__[64]	/* was [8][8] */;
+    integer ie, je, mb, nb, ii, jj, is, js;
+    real rhs[8];
+    integer isp1, jsp1;
     extern /* Subroutine */ int sger_(integer *, integer *, real *, real *, 
 	    integer *, real *, integer *, real *, integer *);
-    static integer ierr, zdim, ipiv[8], jpiv[8];
-    static real alpha;
+    integer ierr, zdim, ipiv[8], jpiv[8];
+    real alpha;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *), 
 	    sgemm_(char *, char *, integer *, integer *, integer *, real *, 
@@ -201,16 +36,200 @@
 	    real *, integer *, real *, integer *, real *, real *, integer *), scopy_(integer *, real *, integer *, real *, integer *), 
 	    saxpy_(integer *, real *, real *, integer *, real *, integer *), 
 	    sgesc2_(integer *, real *, integer *, real *, integer *, integer *
-	    , real *), sgetc2_(integer *, real *, integer *, integer *, 
+, real *), sgetc2_(integer *, real *, integer *, integer *, 
 	    integer *, integer *);
-    static real scaloc;
+    real scaloc;
     extern /* Subroutine */ int slatdf_(integer *, integer *, real *, integer 
 	    *, real *, real *, real *, integer *, integer *), xerbla_(char *, 
 	    integer *), slaset_(char *, integer *, integer *, real *, 
 	    real *, real *, integer *);
-    static logical notran;
+    logical notran;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  STGSY2 solves the generalized Sylvester equation: */
+
+/*              A * R - L * B = scale * C                (1) */
+/*              D * R - L * E = scale * F, */
+
+/*  using Level 1 and 2 BLAS. where R and L are unknown M-by-N matrices, */
+/*  (A, D), (B, E) and (C, F) are given matrix pairs of size M-by-M, */
+/*  N-by-N and M-by-N, respectively, with real entries. (A, D) and (B, E) */
+/*  must be in generalized Schur canonical form, i.e. A, B are upper */
+/*  quasi triangular and D, E are upper triangular. The solution (R, L) */
+/*  overwrites (C, F). 0 <= SCALE <= 1 is an output scaling factor */
+/*  chosen to avoid overflow. */
+
+/*  In matrix notation solving equation (1) corresponds to solve */
+/*  Z*x = scale*b, where Z is defined as */
+
+/*         Z = [ kron(In, A)  -kron(B', Im) ]             (2) */
+/*             [ kron(In, D)  -kron(E', Im) ], */
+
+/*  Ik is the identity matrix of size k and X' is the transpose of X. */
+/*  kron(X, Y) is the Kronecker product between the matrices X and Y. */
+/*  In the process of solving (1), we solve a number of such systems */
+/*  where Dim(In), Dim(In) = 1 or 2. */
+
+/*  If TRANS = 'T', solve the transposed system Z'*y = scale*b for y, */
+/*  which is equivalent to solve for R and L in */
+
+/*              A' * R  + D' * L   = scale *  C           (3) */
+/*              R  * B' + L  * E'  = scale * -F */
+
+/*  This case is used to compute an estimate of Dif[(A, D), (B, E)] = */
+/*  sigma_min(Z) using reverse communicaton with SLACON. */
+
+/*  STGSY2 also (IJOB >= 1) contributes to the computation in STGSYL */
+/*  of an upper bound on the separation between to matrix pairs. Then */
+/*  the input (A, D), (B, E) are sub-pencils of the matrix pair in */
+/*  STGSYL. See STGSYL for details. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          = 'N', solve the generalized Sylvester equation (1). */
+/*          = 'T': solve the 'transposed' system (3). */
+
+/*  IJOB    (input) INTEGER */
+/*          Specifies what kind of functionality to be performed. */
+/*          = 0: solve (1) only. */
+/*          = 1: A contribution from this subsystem to a Frobenius */
+/*               norm-based estimate of the separation between two matrix */
+/*               pairs is computed. (look ahead strategy is used). */
+/*          = 2: A contribution from this subsystem to a Frobenius */
+/*               norm-based estimate of the separation between two matrix */
+/*               pairs is computed. (SGECON on sub-systems is used.) */
+/*          Not referenced if TRANS = 'T'. */
+
+/*  M       (input) INTEGER */
+/*          On entry, M specifies the order of A and D, and the row */
+/*          dimension of C, F, R and L. */
+
+/*  N       (input) INTEGER */
+/*          On entry, N specifies the order of B and E, and the column */
+/*          dimension of C, F, R and L. */
+
+/*  A       (input) REAL array, dimension (LDA, M) */
+/*          On entry, A contains an upper quasi triangular matrix. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the matrix A. LDA >= max(1, M). */
+
+/*  B       (input) REAL array, dimension (LDB, N) */
+/*          On entry, B contains an upper quasi triangular matrix. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the matrix B. LDB >= max(1, N). */
+
+/*  C       (input/output) REAL array, dimension (LDC, N) */
+/*          On entry, C contains the right-hand-side of the first matrix */
+/*          equation in (1). */
+/*          On exit, if IJOB = 0, C has been overwritten by the */
+/*          solution R. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the matrix C. LDC >= max(1, M). */
+
+/*  D       (input) REAL array, dimension (LDD, M) */
+/*          On entry, D contains an upper triangular matrix. */
+
+/*  LDD     (input) INTEGER */
+/*          The leading dimension of the matrix D. LDD >= max(1, M). */
+
+/*  E       (input) REAL array, dimension (LDE, N) */
+/*          On entry, E contains an upper triangular matrix. */
+
+/*  LDE     (input) INTEGER */
+/*          The leading dimension of the matrix E. LDE >= max(1, N). */
+
+/*  F       (input/output) REAL array, dimension (LDF, N) */
+/*          On entry, F contains the right-hand-side of the second matrix */
+/*          equation in (1). */
+/*          On exit, if IJOB = 0, F has been overwritten by the */
+/*          solution L. */
+
+/*  LDF     (input) INTEGER */
+/*          The leading dimension of the matrix F. LDF >= max(1, M). */
+
+/*  SCALE   (output) REAL */
+/*          On exit, 0 <= SCALE <= 1. If 0 < SCALE < 1, the solutions */
+/*          R and L (C and F on entry) will hold the solutions to a */
+/*          slightly perturbed system but the input matrices A, B, D and */
+/*          E have not been changed. If SCALE = 0, R and L will hold the */
+/*          solutions to the homogeneous system with C = F = 0. Normally, */
+/*          SCALE = 1. */
+
+/*  RDSUM   (input/output) REAL */
+/*          On entry, the sum of squares of computed contributions to */
+/*          the Dif-estimate under computation by STGSYL, where the */
+/*          scaling factor RDSCAL (see below) has been factored out. */
+/*          On exit, the corresponding sum of squares updated with the */
+/*          contributions from the current sub-system. */
+/*          If TRANS = 'T' RDSUM is not touched. */
+/*          NOTE: RDSUM only makes sense when STGSY2 is called by STGSYL. */
+
+/*  RDSCAL  (input/output) REAL */
+/*          On entry, scaling factor used to prevent overflow in RDSUM. */
+/*          On exit, RDSCAL is updated w.r.t. the current contributions */
+/*          in RDSUM. */
+/*          If TRANS = 'T', RDSCAL is not touched. */
+/*          NOTE: RDSCAL only makes sense when STGSY2 is called by */
+/*                STGSYL. */
+
+/*  IWORK   (workspace) INTEGER array, dimension (M+N+2) */
+
+/*  PQ      (output) INTEGER */
+/*          On exit, the number of subsystems (of size 2-by-2, 4-by-4 and */
+/*          8-by-8) solved by this routine. */
+
+/*  INFO    (output) INTEGER */
+/*          On exit, if INFO is set to */
+/*            =0: Successful exit */
+/*            <0: If INFO = -i, the i-th argument had an illegal value. */
+/*            >0: The matrix pairs (A, D) and (B, E) have common or very */
+/*                close eigenvalues. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Based on contributions by */
+/*     Bo Kagstrom and Peter Poromaa, Department of Computing Science, */
+/*     Umea University, S-901 87 Umea, Sweden. */
+
+/*  ===================================================================== */
+/*  Replaced various illegal calls to SCOPY by calls to SLASET. */
+/*  Sven Hammarling, 27/5/02. */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and test input parameters */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -315,10 +334,10 @@ L40:
 
     if (notran) {
 
-/*        Solve (I, J) - subsystem   
-             A(I, I) * R(I, J) - L(I, J) * B(J, J) = C(I, J)   
-             D(I, I) * R(I, J) - L(I, J) * E(J, J) = F(I, J)   
-          for I = P, P - 1, ..., 1; J = 1, 2, ..., Q */
+/*        Solve (I, J) - subsystem */
+/*           A(I, I) * R(I, J) - L(I, J) * B(J, J) = C(I, J) */
+/*           D(I, I) * R(I, J) - L(I, J) * E(J, J) = F(I, J) */
+/*        for I = P, P - 1, ..., 1; J = 1, 2, ..., Q */
 
 	*scale = 1.f;
 	scaloc = 1.f;
@@ -379,8 +398,8 @@ L40:
 		    c__[is + js * c_dim1] = rhs[0];
 		    f[is + js * f_dim1] = rhs[1];
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (i__ > 1) {
 			alpha = -rhs[0];
@@ -462,8 +481,8 @@ L40:
 		    f[is + js * f_dim1] = rhs[2];
 		    f[is + jsp1 * f_dim1] = rhs[3];
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (i__ > 1) {
 			i__2 = is - 1;
@@ -549,8 +568,8 @@ L40:
 		    f[is + js * f_dim1] = rhs[2];
 		    f[isp1 + js * f_dim1] = rhs[3];
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (i__ > 1) {
 			i__2 = is - 1;
@@ -668,8 +687,8 @@ L40:
 /* L100: */
 		    }
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (i__ > 1) {
 			i__2 = is - 1;
@@ -701,10 +720,10 @@ L40:
 	}
     } else {
 
-/*        Solve (I, J) - subsystem   
-               A(I, I)' * R(I, J) + D(I, I)' * L(J, J)  =  C(I, J)   
-               R(I, I)  * B(J, J) + L(I, J)  * E(J, J)  = -F(I, J)   
-          for I = 1, 2, ..., P, J = Q, Q - 1, ..., 1 */
+/*        Solve (I, J) - subsystem */
+/*             A(I, I)' * R(I, J) + D(I, I)' * L(J, J)  =  C(I, J) */
+/*             R(I, I)  * B(J, J) + L(I, J)  * E(J, J)  = -F(I, J) */
+/*        for I = 1, 2, ..., P, J = Q, Q - 1, ..., 1 */
 
 	*scale = 1.f;
 	scaloc = 1.f;
@@ -760,8 +779,8 @@ L40:
 		    c__[is + js * c_dim1] = rhs[0];
 		    f[is + js * f_dim1] = rhs[1];
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (j > p + 2) {
 			alpha = rhs[0];
@@ -839,8 +858,8 @@ L40:
 		    f[is + js * f_dim1] = rhs[2];
 		    f[is + jsp1 * f_dim1] = rhs[3];
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (j > p + 2) {
 			i__3 = js - 1;
@@ -923,8 +942,8 @@ L40:
 		    f[is + js * f_dim1] = rhs[2];
 		    f[isp1 + js * f_dim1] = rhs[3];
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (j > p + 2) {
 			i__3 = js - 1;
@@ -1036,8 +1055,8 @@ L40:
 /* L180: */
 		    }
 
-/*                 Substitute R(I, J) and L(I, J) into remaining   
-                   equation. */
+/*                 Substitute R(I, J) and L(I, J) into remaining */
+/*                 equation. */
 
 		    if (j > p + 2) {
 			i__3 = js - 1;
