@@ -1,136 +1,155 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static logical c_false = FALSE_;
+static integer c__2 = 2;
+static real c_b26 = 1.f;
+static real c_b30 = 0.f;
+static logical c_true = TRUE_;
 
 /* Subroutine */ int strsyl_(char *trana, char *tranb, integer *isgn, integer 
 	*m, integer *n, real *a, integer *lda, real *b, integer *ldb, real *
 	c__, integer *ldc, real *scale, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    STRSYL solves the real Sylvester matrix equation:   
-
-       op(A)*X + X*op(B) = scale*C or   
-       op(A)*X - X*op(B) = scale*C,   
-
-    where op(A) = A or A**T, and  A and B are both upper quasi-   
-    triangular. A is M-by-M and B is N-by-N; the right hand side C and   
-    the solution X are M-by-N; and scale is an output scale factor, set   
-    <= 1 to avoid overflow in X.   
-
-    A and B must be in Schur canonical form (as returned by SHSEQR), that   
-    is, block upper triangular with 1-by-1 and 2-by-2 diagonal blocks;   
-    each 2-by-2 diagonal block has its diagonal elements equal and its   
-    off-diagonal elements of opposite sign.   
-
-    Arguments   
-    =========   
-
-    TRANA   (input) CHARACTER*1   
-            Specifies the option op(A):   
-            = 'N': op(A) = A    (No transpose)   
-            = 'T': op(A) = A**T (Transpose)   
-            = 'C': op(A) = A**H (Conjugate transpose = Transpose)   
-
-    TRANB   (input) CHARACTER*1   
-            Specifies the option op(B):   
-            = 'N': op(B) = B    (No transpose)   
-            = 'T': op(B) = B**T (Transpose)   
-            = 'C': op(B) = B**H (Conjugate transpose = Transpose)   
-
-    ISGN    (input) INTEGER   
-            Specifies the sign in the equation:   
-            = +1: solve op(A)*X + X*op(B) = scale*C   
-            = -1: solve op(A)*X - X*op(B) = scale*C   
-
-    M       (input) INTEGER   
-            The order of the matrix A, and the number of rows in the   
-            matrices X and C. M >= 0.   
-
-    N       (input) INTEGER   
-            The order of the matrix B, and the number of columns in the   
-            matrices X and C. N >= 0.   
-
-    A       (input) REAL array, dimension (LDA,M)   
-            The upper quasi-triangular matrix A, in Schur canonical form.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A. LDA >= max(1,M).   
-
-    B       (input) REAL array, dimension (LDB,N)   
-            The upper quasi-triangular matrix B, in Schur canonical form.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B. LDB >= max(1,N).   
-
-    C       (input/output) REAL array, dimension (LDC,N)   
-            On entry, the M-by-N right hand side matrix C.   
-            On exit, C is overwritten by the solution matrix X.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C. LDC >= max(1,M)   
-
-    SCALE   (output) REAL   
-            The scale factor, scale, set <= 1 to avoid overflow in X.   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            < 0: if INFO = -i, the i-th argument had an illegal value   
-            = 1: A and B have common or very close eigenvalues; perturbed   
-                 values were used to solve the equation (but the matrices   
-                 A and B are unchanged).   
-
-    =====================================================================   
-
-
-       Decode and Test input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static logical c_false = FALSE_;
-    static integer c__2 = 2;
-    static real c_b26 = 1.f;
-    static real c_b30 = 0.f;
-    static logical c_true = TRUE_;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, c_dim1, c_offset, i__1, i__2, 
 	    i__3, i__4;
     real r__1, r__2;
+
     /* Local variables */
-    static integer j, k, l;
-    static real x[4]	/* was [2][2] */;
-    static integer k1, k2, l1, l2;
-    static real a11, db, da11, vec[4]	/* was [2][2] */, dum[1], eps, sgn;
-    static integer ierr;
-    static real smin;
+    integer j, k, l;
+    real x[4]	/* was [2][2] */;
+    integer k1, k2, l1, l2;
+    real a11, db, da11, vec[4]	/* was [2][2] */, dum[1], eps, sgn;
+    integer ierr;
+    real smin;
     extern doublereal sdot_(integer *, real *, integer *, real *, integer *);
-    static real suml, sumr;
+    real suml, sumr;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static integer knext, lnext;
-    static real xnorm;
+    integer knext, lnext;
+    real xnorm;
     extern /* Subroutine */ int slaln2_(logical *, integer *, integer *, real 
 	    *, real *, real *, integer *, real *, real *, real *, integer *, 
 	    real *, real *, real *, integer *, real *, real *, integer *), 
 	    slasy2_(logical *, logical *, integer *, integer *, integer *, 
 	    real *, integer *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *, real *, integer *), slabad_(real *, real *);
-    static real scaloc;
+    real scaloc;
     extern doublereal slamch_(char *), slange_(char *, integer *, 
 	    integer *, real *, integer *, real *);
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static real bignum;
-    static logical notrna, notrnb;
-    static real smlnum;
+    real bignum;
+    logical notrna, notrnb;
+    real smlnum;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  STRSYL solves the real Sylvester matrix equation: */
+
+/*     op(A)*X + X*op(B) = scale*C or */
+/*     op(A)*X - X*op(B) = scale*C, */
+
+/*  where op(A) = A or A**T, and  A and B are both upper quasi- */
+/*  triangular. A is M-by-M and B is N-by-N; the right hand side C and */
+/*  the solution X are M-by-N; and scale is an output scale factor, set */
+/*  <= 1 to avoid overflow in X. */
+
+/*  A and B must be in Schur canonical form (as returned by SHSEQR), that */
+/*  is, block upper triangular with 1-by-1 and 2-by-2 diagonal blocks; */
+/*  each 2-by-2 diagonal block has its diagonal elements equal and its */
+/*  off-diagonal elements of opposite sign. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  TRANA   (input) CHARACTER*1 */
+/*          Specifies the option op(A): */
+/*          = 'N': op(A) = A    (No transpose) */
+/*          = 'T': op(A) = A**T (Transpose) */
+/*          = 'C': op(A) = A**H (Conjugate transpose = Transpose) */
+
+/*  TRANB   (input) CHARACTER*1 */
+/*          Specifies the option op(B): */
+/*          = 'N': op(B) = B    (No transpose) */
+/*          = 'T': op(B) = B**T (Transpose) */
+/*          = 'C': op(B) = B**H (Conjugate transpose = Transpose) */
+
+/*  ISGN    (input) INTEGER */
+/*          Specifies the sign in the equation: */
+/*          = +1: solve op(A)*X + X*op(B) = scale*C */
+/*          = -1: solve op(A)*X - X*op(B) = scale*C */
+
+/*  M       (input) INTEGER */
+/*          The order of the matrix A, and the number of rows in the */
+/*          matrices X and C. M >= 0. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix B, and the number of columns in the */
+/*          matrices X and C. N >= 0. */
+
+/*  A       (input) REAL array, dimension (LDA,M) */
+/*          The upper quasi-triangular matrix A, in Schur canonical form. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A. LDA >= max(1,M). */
+
+/*  B       (input) REAL array, dimension (LDB,N) */
+/*          The upper quasi-triangular matrix B, in Schur canonical form. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B. LDB >= max(1,N). */
+
+/*  C       (input/output) REAL array, dimension (LDC,N) */
+/*          On entry, the M-by-N right hand side matrix C. */
+/*          On exit, C is overwritten by the solution matrix X. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. LDC >= max(1,M) */
+
+/*  SCALE   (output) REAL */
+/*          The scale factor, scale, set <= 1 to avoid overflow in X. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          < 0: if INFO = -i, the i-th argument had an illegal value */
+/*          = 1: A and B have common or very close eigenvalues; perturbed */
+/*               values were used to solve the equation (but the matrices */
+/*               A and B are unchanged). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and Test input parameters */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -196,20 +215,20 @@
 
     if (notrna && notrnb) {
 
-/*        Solve    A*X + ISGN*X*B = scale*C.   
+/*        Solve    A*X + ISGN*X*B = scale*C. */
 
-          The (K,L)th block of X is determined starting from   
-          bottom-left corner column by column by   
+/*        The (K,L)th block of X is determined starting from */
+/*        bottom-left corner column by column by */
 
-           A(K,K)*X(K,L) + ISGN*X(K,L)*B(L,L) = C(K,L) - R(K,L)   
+/*         A(K,K)*X(K,L) + ISGN*X(K,L)*B(L,L) = C(K,L) - R(K,L) */
 
-          Where   
-                    M                         L-1   
-          R(K,L) = SUM [A(K,I)*X(I,L)] + ISGN*SUM [X(K,J)*B(J,L)].   
-                  I=K+1                       J=1   
+/*        Where */
+/*                  M                         L-1 */
+/*        R(K,L) = SUM [A(K,I)*X(I,L)] + ISGN*SUM [X(K,J)*B(J,L)]. */
+/*                I=K+1                       J=1 */
 
-          Start column loop (index = L)   
-          L1 (L2) : column index of the first (first) row of X(K,L). */
+/*        Start column loop (index = L) */
+/*        L1 (L2) : column index of the first (first) row of X(K,L). */
 
 	lnext = 1;
 	i__1 = *n;
@@ -232,8 +251,8 @@
 		}
 	    }
 
-/*           Start row loop (index = K)   
-             K1 (K2): row index of the first (last) row of X(K,L). */
+/*           Start row loop (index = K) */
+/*           K1 (K2): row index of the first (last) row of X(K,L). */
 
 	    knext = *m;
 	    for (k = *m; k >= 1; --k) {
@@ -322,7 +341,7 @@
 
 		    r__1 = -sgn * b[l1 + l1 * b_dim1];
 		    slaln2_(&c_false, &c__2, &c__1, &smin, &c_b26, &a[k1 + k1 
-			    * a_dim1], lda, &c_b26, &c_b26, vec, &c__2, &r__1,
+			    * a_dim1], lda, &c_b26, &c_b26, vec, &c__2, &r__1, 
 			     &c_b30, x, &c__2, &scaloc, &xnorm, &ierr);
 		    if (ierr != 0) {
 			*info = 1;
@@ -437,7 +456,7 @@
 		    vec[3] = c__[k2 + l2 * c_dim1] - (suml + sgn * sumr);
 
 		    slasy2_(&c_false, &c_false, isgn, &c__2, &c__2, &a[k1 + 
-			    k1 * a_dim1], lda, &b[l1 + l1 * b_dim1], ldb, vec,
+			    k1 * a_dim1], lda, &b[l1 + l1 * b_dim1], ldb, vec, 
 			     &c__2, &scaloc, x, &c__2, &xnorm, &ierr);
 		    if (ierr != 0) {
 			*info = 1;
@@ -467,20 +486,20 @@ L70:
 
     } else if (! notrna && notrnb) {
 
-/*        Solve    A' *X + ISGN*X*B = scale*C.   
+/*        Solve    A' *X + ISGN*X*B = scale*C. */
 
-          The (K,L)th block of X is determined starting from   
-          upper-left corner column by column by   
+/*        The (K,L)th block of X is determined starting from */
+/*        upper-left corner column by column by */
 
-            A(K,K)'*X(K,L) + ISGN*X(K,L)*B(L,L) = C(K,L) - R(K,L)   
+/*          A(K,K)'*X(K,L) + ISGN*X(K,L)*B(L,L) = C(K,L) - R(K,L) */
 
-          Where   
-                     K-1                        L-1   
-            R(K,L) = SUM [A(I,K)'*X(I,L)] +ISGN*SUM [X(K,J)*B(J,L)]   
-                     I=1                        J=1   
+/*        Where */
+/*                   K-1                        L-1 */
+/*          R(K,L) = SUM [A(I,K)'*X(I,L)] +ISGN*SUM [X(K,J)*B(J,L)] */
+/*                   I=1                        J=1 */
 
-          Start column loop (index = L)   
-          L1 (L2): column index of the first (last) row of X(K,L) */
+/*        Start column loop (index = L) */
+/*        L1 (L2): column index of the first (last) row of X(K,L) */
 
 	lnext = 1;
 	i__1 = *n;
@@ -503,8 +522,8 @@ L70:
 		}
 	    }
 
-/*           Start row loop (index = K)   
-             K1 (K2): row index of the first (last) row of X(K,L) */
+/*           Start row loop (index = K) */
+/*           K1 (K2): row index of the first (last) row of X(K,L) */
 
 	    knext = 1;
 	    i__2 = *m;
@@ -702,20 +721,20 @@ L130:
 
     } else if (! notrna && ! notrnb) {
 
-/*        Solve    A'*X + ISGN*X*B' = scale*C.   
+/*        Solve    A'*X + ISGN*X*B' = scale*C. */
 
-          The (K,L)th block of X is determined starting from   
-          top-right corner column by column by   
+/*        The (K,L)th block of X is determined starting from */
+/*        top-right corner column by column by */
 
-             A(K,K)'*X(K,L) + ISGN*X(K,L)*B(L,L)' = C(K,L) - R(K,L)   
+/*           A(K,K)'*X(K,L) + ISGN*X(K,L)*B(L,L)' = C(K,L) - R(K,L) */
 
-          Where   
-                       K-1                          N   
-              R(K,L) = SUM [A(I,K)'*X(I,L)] + ISGN*SUM [X(K,J)*B(L,J)'].   
-                       I=1                        J=L+1   
+/*        Where */
+/*                     K-1                          N */
+/*            R(K,L) = SUM [A(I,K)'*X(I,L)] + ISGN*SUM [X(K,J)*B(L,J)']. */
+/*                     I=1                        J=L+1 */
 
-          Start column loop (index = L)   
-          L1 (L2): column index of the first (last) row of X(K,L) */
+/*        Start column loop (index = L) */
+/*        L1 (L2): column index of the first (last) row of X(K,L) */
 
 	lnext = *n;
 	for (l = *n; l >= 1; --l) {
@@ -737,8 +756,8 @@ L130:
 		}
 	    }
 
-/*           Start row loop (index = K)   
-             K1 (K2): row index of the first (last) row of X(K,L) */
+/*           Start row loop (index = K) */
+/*           K1 (K2): row index of the first (last) row of X(K,L) */
 
 	    knext = 1;
 	    i__1 = *m;
@@ -875,7 +894,7 @@ L130:
 
 		    r__1 = -sgn * a[k1 + k1 * a_dim1];
 		    slaln2_(&c_false, &c__2, &c__1, &smin, &c_b26, &b[l1 + l1 
-			    * b_dim1], ldb, &c_b26, &c_b26, vec, &c__2, &r__1,
+			    * b_dim1], ldb, &c_b26, &c_b26, vec, &c__2, &r__1, 
 			     &c_b30, x, &c__2, &scaloc, &xnorm, &ierr);
 		    if (ierr != 0) {
 			*info = 1;
@@ -972,20 +991,20 @@ L190:
 
     } else if (notrna && ! notrnb) {
 
-/*        Solve    A*X + ISGN*X*B' = scale*C.   
+/*        Solve    A*X + ISGN*X*B' = scale*C. */
 
-          The (K,L)th block of X is determined starting from   
-          bottom-right corner column by column by   
+/*        The (K,L)th block of X is determined starting from */
+/*        bottom-right corner column by column by */
 
-              A(K,K)*X(K,L) + ISGN*X(K,L)*B(L,L)' = C(K,L) - R(K,L)   
+/*            A(K,K)*X(K,L) + ISGN*X(K,L)*B(L,L)' = C(K,L) - R(K,L) */
 
-          Where   
-                        M                          N   
-              R(K,L) = SUM [A(K,I)*X(I,L)] + ISGN*SUM [X(K,J)*B(L,J)'].   
-                      I=K+1                      J=L+1   
+/*        Where */
+/*                      M                          N */
+/*            R(K,L) = SUM [A(K,I)*X(I,L)] + ISGN*SUM [X(K,J)*B(L,J)']. */
+/*                    I=K+1                      J=L+1 */
 
-          Start column loop (index = L)   
-          L1 (L2): column index of the first (last) row of X(K,L) */
+/*        Start column loop (index = L) */
+/*        L1 (L2): column index of the first (last) row of X(K,L) */
 
 	lnext = *n;
 	for (l = *n; l >= 1; --l) {
@@ -1007,8 +1026,8 @@ L190:
 		}
 	    }
 
-/*           Start row loop (index = K)   
-             K1 (K2): row index of the first (last) row of X(K,L) */
+/*           Start row loop (index = K) */
+/*           K1 (K2): row index of the first (last) row of X(K,L) */
 
 	    knext = *m;
 	    for (k = *m; k >= 1; --k) {
@@ -1109,7 +1128,7 @@ L190:
 
 		    r__1 = -sgn * b[l1 + l1 * b_dim1];
 		    slaln2_(&c_false, &c__2, &c__1, &smin, &c_b26, &a[k1 + k1 
-			    * a_dim1], lda, &c_b26, &c_b26, vec, &c__2, &r__1,
+			    * a_dim1], lda, &c_b26, &c_b26, vec, &c__2, &r__1, 
 			     &c_b30, x, &c__2, &scaloc, &xnorm, &ierr);
 		    if (ierr != 0) {
 			*info = 1;
@@ -1164,7 +1183,7 @@ L190:
 
 		    r__1 = -sgn * a[k1 + k1 * a_dim1];
 		    slaln2_(&c_false, &c__2, &c__1, &smin, &c_b26, &b[l1 + l1 
-			    * b_dim1], ldb, &c_b26, &c_b26, vec, &c__2, &r__1,
+			    * b_dim1], ldb, &c_b26, &c_b26, vec, &c__2, &r__1, 
 			     &c_b30, x, &c__2, &scaloc, &xnorm, &ierr);
 		    if (ierr != 0) {
 			*info = 1;
