@@ -3,10 +3,10 @@
 
 /* Subroutine */ int xerbla_(char *srname, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
+/*  -- LAPACK auxiliary routine (version 2.0) --   
        Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,   
        Courant Institute, Argonne National Lab, and Rice University   
-       November 2006
+       September 30, 1994   
 
 
     Purpose   
@@ -27,6 +27,7 @@
 
     INFO    (input) INTEGER   
             The position of the invalid parameter in the parameter list   
+
             of the calling routine.   
 
    ===================================================================== 
