@@ -1,184 +1,50 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublereal c_b15 = -.125;
+static integer c__1 = 1;
+static doublereal c_b49 = 1.;
+static doublereal c_b72 = -1.;
 
 /* Subroutine */ int zbdsqr_(char *uplo, integer *n, integer *ncvt, integer *
 	nru, integer *ncc, doublereal *d__, doublereal *e, doublecomplex *vt, 
 	integer *ldvt, doublecomplex *u, integer *ldu, doublecomplex *c__, 
 	integer *ldc, doublereal *rwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZBDSQR computes the singular values and, optionally, the right and/or   
-    left singular vectors from the singular value decomposition (SVD) of   
-    a real N-by-N (upper or lower) bidiagonal matrix B using the implicit   
-    zero-shift QR algorithm.  The SVD of B has the form   
-
-       B = Q * S * P**H   
-
-    where S is the diagonal matrix of singular values, Q is an orthogonal   
-    matrix of left singular vectors, and P is an orthogonal matrix of   
-    right singular vectors.  If left singular vectors are requested, this   
-    subroutine actually returns U*Q instead of Q, and, if right singular   
-    vectors are requested, this subroutine returns P**H*VT instead of   
-    P**H, for given complex input matrices U and VT.  When U and VT are   
-    the unitary matrices that reduce a general matrix A to bidiagonal   
-    form: A = U*B*VT, as computed by ZGEBRD, then   
-
-       A = (U*Q) * S * (P**H*VT)   
-
-    is the SVD of A.  Optionally, the subroutine may also compute Q**H*C   
-    for a given complex input matrix C.   
-
-    See "Computing  Small Singular Values of Bidiagonal Matrices With   
-    Guaranteed High Relative Accuracy," by J. Demmel and W. Kahan,   
-    LAPACK Working Note #3 (or SIAM J. Sci. Statist. Comput. vol. 11,   
-    no. 5, pp. 873-912, Sept 1990) and   
-    "Accurate singular values and differential qd algorithms," by   
-    B. Parlett and V. Fernando, Technical Report CPAM-554, Mathematics   
-    Department, University of California at Berkeley, July 1992   
-    for a detailed description of the algorithm.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            = 'U':  B is upper bidiagonal;   
-            = 'L':  B is lower bidiagonal.   
-
-    N       (input) INTEGER   
-            The order of the matrix B.  N >= 0.   
-
-    NCVT    (input) INTEGER   
-            The number of columns of the matrix VT. NCVT >= 0.   
-
-    NRU     (input) INTEGER   
-            The number of rows of the matrix U. NRU >= 0.   
-
-    NCC     (input) INTEGER   
-            The number of columns of the matrix C. NCC >= 0.   
-
-    D       (input/output) DOUBLE PRECISION array, dimension (N)   
-            On entry, the n diagonal elements of the bidiagonal matrix B.   
-            On exit, if INFO=0, the singular values of B in decreasing   
-            order.   
-
-    E       (input/output) DOUBLE PRECISION array, dimension (N-1)   
-            On entry, the N-1 offdiagonal elements of the bidiagonal   
-            matrix B.   
-            On exit, if INFO = 0, E is destroyed; if INFO > 0, D and E   
-            will contain the diagonal and superdiagonal elements of a   
-            bidiagonal matrix orthogonally equivalent to the one given   
-            as input.   
-
-    VT      (input/output) COMPLEX*16 array, dimension (LDVT, NCVT)   
-            On entry, an N-by-NCVT matrix VT.   
-            On exit, VT is overwritten by P**H * VT.   
-            Not referenced if NCVT = 0.   
-
-    LDVT    (input) INTEGER   
-            The leading dimension of the array VT.   
-            LDVT >= max(1,N) if NCVT > 0; LDVT >= 1 if NCVT = 0.   
-
-    U       (input/output) COMPLEX*16 array, dimension (LDU, N)   
-            On entry, an NRU-by-N matrix U.   
-            On exit, U is overwritten by U * Q.   
-            Not referenced if NRU = 0.   
-
-    LDU     (input) INTEGER   
-            The leading dimension of the array U.  LDU >= max(1,NRU).   
-
-    C       (input/output) COMPLEX*16 array, dimension (LDC, NCC)   
-            On entry, an N-by-NCC matrix C.   
-            On exit, C is overwritten by Q**H * C.   
-            Not referenced if NCC = 0.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C.   
-            LDC >= max(1,N) if NCC > 0; LDC >=1 if NCC = 0.   
-
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (2*N)   
-            if NCVT = NRU = NCC = 0, (max(1, 4*N-4)) otherwise   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  If INFO = -i, the i-th argument had an illegal value   
-            > 0:  the algorithm did not converge; D and E contain the   
-                  elements of a bidiagonal matrix which is orthogonally   
-                  similar to the input matrix B;  if INFO = i, i   
-                  elements of E have not converged to zero.   
-
-    Internal Parameters   
-    ===================   
-
-    TOLMUL  DOUBLE PRECISION, default = max(10,min(100,EPS**(-1/8)))   
-            TOLMUL controls the convergence criterion of the QR loop.   
-            If it is positive, TOLMUL*EPS is the desired relative   
-               precision in the computed singular values.   
-            If it is negative, abs(TOLMUL*EPS*sigma_max) is the   
-               desired absolute accuracy in the computed singular   
-               values (corresponds to relative accuracy   
-               abs(TOLMUL*EPS) in the largest singular value.   
-            abs(TOLMUL) should be between 1 and 1/EPS, and preferably   
-               between 10 (for fast convergence) and .1/EPS   
-               (for there to be some accuracy in the results).   
-            Default is to lose at either one eighth or 2 of the   
-               available decimal digits in each computed singular value   
-               (whichever is smaller).   
-
-    MAXITR  INTEGER, default = 6   
-            MAXITR controls the maximum number of passes of the   
-            algorithm through its inner loop. The algorithms stops   
-            (and so fails to converge) if the number of passes   
-            through the inner loop exceeds MAXITR*N**2.   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublereal c_b15 = -.125;
-    static integer c__1 = 1;
-    static doublereal c_b49 = 1.;
-    static doublereal c_b72 = -1.;
-    
     /* System generated locals */
     integer c_dim1, c_offset, u_dim1, u_offset, vt_dim1, vt_offset, i__1, 
 	    i__2;
     doublereal d__1, d__2, d__3, d__4;
+
     /* Builtin functions */
     double pow_dd(doublereal *, doublereal *), sqrt(doublereal), d_sign(
 	    doublereal *, doublereal *);
+
     /* Local variables */
-    static doublereal f, g, h__;
-    static integer i__, j, m;
-    static doublereal r__, cs;
-    static integer ll;
-    static doublereal sn, mu;
-    static integer nm1, nm12, nm13, lll;
-    static doublereal eps, sll, tol, abse;
-    static integer idir;
-    static doublereal abss;
-    static integer oldm;
-    static doublereal cosl;
-    static integer isub, iter;
-    static doublereal unfl, sinl, cosr, smin, smax, sinr;
+    doublereal f, g, h__;
+    integer i__, j, m;
+    doublereal r__, cs;
+    integer ll;
+    doublereal sn, mu;
+    integer nm1, nm12, nm13, lll;
+    doublereal eps, sll, tol, abse;
+    integer idir;
+    doublereal abss;
+    integer oldm;
+    doublereal cosl;
+    integer isub, iter;
+    doublereal unfl, sinl, cosr, smin, smax, sinr;
     extern /* Subroutine */ int dlas2_(doublereal *, doublereal *, doublereal 
 	    *, doublereal *, doublereal *);
     extern logical lsame_(char *, char *);
-    static doublereal oldcs;
-    static integer oldll;
-    static doublereal shift, sigmn, oldsn;
-    static integer maxit;
-    static doublereal sminl, sigmx;
-    static logical lower;
+    doublereal oldcs;
+    integer oldll;
+    doublereal shift, sigmn, oldsn;
+    integer maxit;
+    doublereal sminl, sigmx;
+    logical lower;
     extern /* Subroutine */ int zlasr_(char *, char *, char *, integer *, 
 	    integer *, doublereal *, doublereal *, doublecomplex *, integer *), zdrot_(integer *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublereal *, doublereal *)
@@ -192,11 +58,163 @@
 	    doublereal *, doublereal *, doublereal *), xerbla_(char *, 
 	    integer *), zdscal_(integer *, doublereal *, 
 	    doublecomplex *, integer *);
-    static doublereal sminoa, thresh;
-    static logical rotate;
-    static doublereal tolmul;
+    doublereal sminoa, thresh;
+    logical rotate;
+    doublereal tolmul;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZBDSQR computes the singular values and, optionally, the right and/or */
+/*  left singular vectors from the singular value decomposition (SVD) of */
+/*  a real N-by-N (upper or lower) bidiagonal matrix B using the implicit */
+/*  zero-shift QR algorithm.  The SVD of B has the form */
+
+/*     B = Q * S * P**H */
+
+/*  where S is the diagonal matrix of singular values, Q is an orthogonal */
+/*  matrix of left singular vectors, and P is an orthogonal matrix of */
+/*  right singular vectors.  If left singular vectors are requested, this */
+/*  subroutine actually returns U*Q instead of Q, and, if right singular */
+/*  vectors are requested, this subroutine returns P**H*VT instead of */
+/*  P**H, for given complex input matrices U and VT.  When U and VT are */
+/*  the unitary matrices that reduce a general matrix A to bidiagonal */
+/*  form: A = U*B*VT, as computed by ZGEBRD, then */
+
+/*     A = (U*Q) * S * (P**H*VT) */
+
+/*  is the SVD of A.  Optionally, the subroutine may also compute Q**H*C */
+/*  for a given complex input matrix C. */
+
+/*  See "Computing  Small Singular Values of Bidiagonal Matrices With */
+/*  Guaranteed High Relative Accuracy," by J. Demmel and W. Kahan, */
+/*  LAPACK Working Note #3 (or SIAM J. Sci. Statist. Comput. vol. 11, */
+/*  no. 5, pp. 873-912, Sept 1990) and */
+/*  "Accurate singular values and differential qd algorithms," by */
+/*  B. Parlett and V. Fernando, Technical Report CPAM-554, Mathematics */
+/*  Department, University of California at Berkeley, July 1992 */
+/*  for a detailed description of the algorithm. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          = 'U':  B is upper bidiagonal; */
+/*          = 'L':  B is lower bidiagonal. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix B.  N >= 0. */
+
+/*  NCVT    (input) INTEGER */
+/*          The number of columns of the matrix VT. NCVT >= 0. */
+
+/*  NRU     (input) INTEGER */
+/*          The number of rows of the matrix U. NRU >= 0. */
+
+/*  NCC     (input) INTEGER */
+/*          The number of columns of the matrix C. NCC >= 0. */
+
+/*  D       (input/output) DOUBLE PRECISION array, dimension (N) */
+/*          On entry, the n diagonal elements of the bidiagonal matrix B. */
+/*          On exit, if INFO=0, the singular values of B in decreasing */
+/*          order. */
+
+/*  E       (input/output) DOUBLE PRECISION array, dimension (N-1) */
+/*          On entry, the N-1 offdiagonal elements of the bidiagonal */
+/*          matrix B. */
+/*          On exit, if INFO = 0, E is destroyed; if INFO > 0, D and E */
+/*          will contain the diagonal and superdiagonal elements of a */
+/*          bidiagonal matrix orthogonally equivalent to the one given */
+/*          as input. */
+
+/*  VT      (input/output) COMPLEX*16 array, dimension (LDVT, NCVT) */
+/*          On entry, an N-by-NCVT matrix VT. */
+/*          On exit, VT is overwritten by P**H * VT. */
+/*          Not referenced if NCVT = 0. */
+
+/*  LDVT    (input) INTEGER */
+/*          The leading dimension of the array VT. */
+/*          LDVT >= max(1,N) if NCVT > 0; LDVT >= 1 if NCVT = 0. */
+
+/*  U       (input/output) COMPLEX*16 array, dimension (LDU, N) */
+/*          On entry, an NRU-by-N matrix U. */
+/*          On exit, U is overwritten by U * Q. */
+/*          Not referenced if NRU = 0. */
+
+/*  LDU     (input) INTEGER */
+/*          The leading dimension of the array U.  LDU >= max(1,NRU). */
+
+/*  C       (input/output) COMPLEX*16 array, dimension (LDC, NCC) */
+/*          On entry, an N-by-NCC matrix C. */
+/*          On exit, C is overwritten by Q**H * C. */
+/*          Not referenced if NCC = 0. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. */
+/*          LDC >= max(1,N) if NCC > 0; LDC >=1 if NCC = 0. */
+
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (2*N) */
+/*          if NCVT = NRU = NCC = 0, (max(1, 4*N-4)) otherwise */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  If INFO = -i, the i-th argument had an illegal value */
+/*          > 0:  the algorithm did not converge; D and E contain the */
+/*                elements of a bidiagonal matrix which is orthogonally */
+/*                similar to the input matrix B;  if INFO = i, i */
+/*                elements of E have not converged to zero. */
+
+/*  Internal Parameters */
+/*  =================== */
+
+/*  TOLMUL  DOUBLE PRECISION, default = max(10,min(100,EPS**(-1/8))) */
+/*          TOLMUL controls the convergence criterion of the QR loop. */
+/*          If it is positive, TOLMUL*EPS is the desired relative */
+/*             precision in the computed singular values. */
+/*          If it is negative, abs(TOLMUL*EPS*sigma_max) is the */
+/*             desired absolute accuracy in the computed singular */
+/*             values (corresponds to relative accuracy */
+/*             abs(TOLMUL*EPS) in the largest singular value. */
+/*          abs(TOLMUL) should be between 1 and 1/EPS, and preferably */
+/*             between 10 (for fast convergence) and .1/EPS */
+/*             (for there to be some accuracy in the results). */
+/*          Default is to lose at either one eighth or 2 of the */
+/*             available decimal digits in each computed singular value */
+/*             (whichever is smaller). */
+
+/*  MAXITR  INTEGER, default = 6 */
+/*          MAXITR controls the maximum number of passes of the */
+/*          algorithm through its inner loop. The algorithms stops */
+/*          (and so fails to converge) if the number of passes */
+/*          through the inner loop exceeds MAXITR*N**2. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     --d__;
     --e;
     vt_dim1 = *ldvt;
@@ -263,8 +281,8 @@
     eps = dlamch_("Epsilon");
     unfl = dlamch_("Safe minimum");
 
-/*     If matrix lower bidiagonal, rotate to be upper bidiagonal   
-       by applying Givens rotations on the left */
+/*     If matrix lower bidiagonal, rotate to be upper bidiagonal */
+/*     by applying Givens rotations on the left */
 
     if (lower) {
 	i__1 = *n - 1;
@@ -281,7 +299,7 @@
 /*        Update singular vectors if desired */
 
 	if (*nru > 0) {
-	    zlasr_("R", "V", "F", nru, n, &rwork[1], &rwork[*n], &u[u_offset],
+	    zlasr_("R", "V", "F", nru, n, &rwork[1], &rwork[*n], &u[u_offset], 
 		     ldu);
 	}
 	if (*ncc > 0) {
@@ -290,12 +308,12 @@
 	}
     }
 
-/*     Compute singular values to relative accuracy TOL   
-       (By setting TOL to be negative, algorithm will compute   
-       singular values to absolute accuracy ABS(TOL)*norm(input matrix))   
+/*     Compute singular values to relative accuracy TOL */
+/*     (By setting TOL to be negative, algorithm will compute */
+/*     singular values to absolute accuracy ABS(TOL)*norm(input matrix)) */
 
-   Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
     d__3 = 100., d__4 = pow_dd(&eps, &c_b15);
     d__1 = 10., d__2 = min(d__3,d__4);
     tolmul = max(d__1,d__2);
@@ -345,16 +363,16 @@ L50:
 	thresh = max(d__1,d__2);
     } else {
 
-/*        Absolute accuracy desired   
+/*        Absolute accuracy desired */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = abs(tol) * smax, d__2 = *n * 6 * *n * unfl;
 	thresh = max(d__1,d__2);
     }
 
-/*     Prepare for main iteration loop for the singular values   
-       (MAXIT is the maximum number of passes through the inner   
-       loop permitted before nonconvergence signalled.) */
+/*     Prepare for main iteration loop for the singular values */
+/*     (MAXIT is the maximum number of passes through the inner */
+/*     loop permitted before nonconvergence signalled.) */
 
     maxit = *n * 6 * *n;
     iter = 0;
@@ -425,7 +443,7 @@ L90:
 
 /*        2 by 2 block, handle separately */
 
-	dlasv2_(&d__[m - 1], &e[m - 1], &d__[m], &sigmn, &sigmx, &sinr, &cosr,
+	dlasv2_(&d__[m - 1], &e[m - 1], &d__[m], &sigmn, &sigmx, &sinr, &cosr, 
 		 &sinl, &cosl);
 	d__[m - 1] = sigmx;
 	e[m - 1] = 0.;
@@ -449,8 +467,8 @@ L90:
 	goto L60;
     }
 
-/*     If working on new submatrix, choose shift direction   
-       (from larger end diagonal element towards smaller) */
+/*     If working on new submatrix, choose shift direction */
+/*     (from larger end diagonal element towards smaller) */
 
     if (ll > oldm || m < oldll) {
 	if ((d__1 = d__[ll], abs(d__1)) >= (d__2 = d__[m], abs(d__2))) {
@@ -470,8 +488,8 @@ L90:
 
     if (idir == 1) {
 
-/*        Run convergence test in forward direction   
-          First apply standard test to bottom of matrix */
+/*        Run convergence test in forward direction */
+/*        First apply standard test to bottom of matrix */
 
 	if ((d__2 = e[m - 1], abs(d__2)) <= abs(tol) * (d__1 = d__[m], abs(
 		d__1)) || tol < 0. && (d__3 = e[m - 1], abs(d__3)) <= thresh) 
@@ -482,8 +500,8 @@ L90:
 
 	if (tol >= 0.) {
 
-/*           If relative accuracy desired,   
-             apply convergence criterion forward */
+/*           If relative accuracy desired, */
+/*           apply convergence criterion forward */
 
 	    mu = (d__1 = d__[ll], abs(d__1));
 	    sminl = mu;
@@ -502,18 +520,19 @@ L90:
 
     } else {
 
-/*        Run convergence test in backward direction   
-          First apply standard test to top of matrix */
+/*        Run convergence test in backward direction */
+/*        First apply standard test to top of matrix */
 
-	if ((d__2 = e[ll], abs(d__2)) <= abs(tol) * (d__1 = d__[ll], abs(d__1) 		) || tol < 0. && (d__3 = e[ll], abs(d__3)) <= thresh) {
+	if ((d__2 = e[ll], abs(d__2)) <= abs(tol) * (d__1 = d__[ll], abs(d__1)
+		) || tol < 0. && (d__3 = e[ll], abs(d__3)) <= thresh) {
 	    e[ll] = 0.;
 	    goto L60;
 	}
 
 	if (tol >= 0.) {
 
-/*           If relative accuracy desired,   
-             apply convergence criterion backward */
+/*           If relative accuracy desired, */
+/*           apply convergence criterion backward */
 
 	    mu = (d__1 = d__[m], abs(d__1));
 	    sminl = mu;
@@ -533,10 +552,10 @@ L90:
     oldll = ll;
     oldm = m;
 
-/*     Compute shift.  First, test if shifting would ruin relative   
-       accuracy, and if so set the shift to zero.   
+/*     Compute shift.  First, test if shifting would ruin relative */
+/*     accuracy, and if so set the shift to zero. */
 
-   Computing MAX */
+/* Computing MAX */
     d__1 = eps, d__2 = tol * .01;
     if (tol >= 0. && *n * tol * (sminl / smax) <= max(d__1,d__2)) {
 
@@ -575,8 +594,8 @@ L90:
     if (shift == 0.) {
 	if (idir == 1) {
 
-/*           Chase bulge from top to bottom   
-             Save cosines and sines for later singular vector updates */
+/*           Chase bulge from top to bottom */
+/*           Save cosines and sines for later singular vector updates */
 
 	    cs = 1.;
 	    oldcs = 1.;
@@ -626,8 +645,8 @@ L90:
 
 	} else {
 
-/*           Chase bulge from bottom to top   
-             Save cosines and sines for later singular vector updates */
+/*           Chase bulge from bottom to top */
+/*           Save cosines and sines for later singular vector updates */
 
 	    cs = 1.;
 	    oldcs = 1.;
@@ -681,8 +700,8 @@ L90:
 
 	if (idir == 1) {
 
-/*           Chase bulge from top to bottom   
-             Save cosines and sines for later singular vector updates */
+/*           Chase bulge from top to bottom */
+/*           Save cosines and sines for later singular vector updates */
 
 	    f = ((d__1 = d__[ll], abs(d__1)) - shift) * (d_sign(&c_b49, &d__[
 		    ll]) + shift / d__[ll]);
@@ -739,10 +758,11 @@ L90:
 
 	} else {
 
-/*           Chase bulge from bottom to top   
-             Save cosines and sines for later singular vector updates */
+/*           Chase bulge from bottom to top */
+/*           Save cosines and sines for later singular vector updates */
 
-	    f = ((d__1 = d__[m], abs(d__1)) - shift) * (d_sign(&c_b49, &d__[m] 		    ) + shift / d__[m]);
+	    f = ((d__1 = d__[m], abs(d__1)) - shift) * (d_sign(&c_b49, &d__[m]
+		    ) + shift / d__[m]);
 	    g = e[m - 1];
 	    i__1 = ll + 1;
 	    for (i__ = m; i__ >= i__1; --i__) {
@@ -817,8 +837,8 @@ L160:
 /* L170: */
     }
 
-/*     Sort the singular values into decreasing order (insertion sort on   
-       singular values, but only one transposition per singular vector) */
+/*     Sort the singular values into decreasing order (insertion sort on */
+/*     singular values, but only one transposition per singular vector) */
 
     i__1 = *n - 1;
     for (i__ = 1; i__ <= i__1; ++i__) {
