@@ -1,150 +1,168 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
-/* Subroutine */ int zgbbrd_(char *vect, integer *m, integer *n, integer *ncc,
+/* Table of constant values */
+
+static doublecomplex c_b1 = {0.,0.};
+static doublecomplex c_b2 = {1.,0.};
+static integer c__1 = 1;
+
+/* Subroutine */ int zgbbrd_(char *vect, integer *m, integer *n, integer *ncc, 
 	 integer *kl, integer *ku, doublecomplex *ab, integer *ldab, 
 	doublereal *d__, doublereal *e, doublecomplex *q, integer *ldq, 
 	doublecomplex *pt, integer *ldpt, doublecomplex *c__, integer *ldc, 
-	doublecomplex *work, doublereal *rwork, integer *info  	)
+	doublecomplex *work, doublereal *rwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZGBBRD reduces a complex general m-by-n band matrix A to real upper   
-    bidiagonal form B by a unitary transformation: Q' * A * P = B.   
-
-    The routine computes B, and optionally forms Q or P', or computes   
-    Q'*C for a given matrix C.   
-
-    Arguments   
-    =========   
-
-    VECT    (input) CHARACTER*1   
-            Specifies whether or not the matrices Q and P' are to be   
-            formed.   
-            = 'N': do not form Q or P';   
-            = 'Q': form Q only;   
-            = 'P': form P' only;   
-            = 'B': form both.   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix A.  M >= 0.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix A.  N >= 0.   
-
-    NCC     (input) INTEGER   
-            The number of columns of the matrix C.  NCC >= 0.   
-
-    KL      (input) INTEGER   
-            The number of subdiagonals of the matrix A. KL >= 0.   
-
-    KU      (input) INTEGER   
-            The number of superdiagonals of the matrix A. KU >= 0.   
-
-    AB      (input/output) COMPLEX*16 array, dimension (LDAB,N)   
-            On entry, the m-by-n band matrix A, stored in rows 1 to   
-            KL+KU+1. The j-th column of A is stored in the j-th column of   
-            the array AB as follows:   
-            AB(ku+1+i-j,j) = A(i,j) for max(1,j-ku)<=i<=min(m,j+kl).   
-            On exit, A is overwritten by values generated during the   
-            reduction.   
-
-    LDAB    (input) INTEGER   
-            The leading dimension of the array A. LDAB >= KL+KU+1.   
-
-    D       (output) DOUBLE PRECISION array, dimension (min(M,N))   
-            The diagonal elements of the bidiagonal matrix B.   
-
-    E       (output) DOUBLE PRECISION array, dimension (min(M,N)-1)   
-            The superdiagonal elements of the bidiagonal matrix B.   
-
-    Q       (output) COMPLEX*16 array, dimension (LDQ,M)   
-            If VECT = 'Q' or 'B', the m-by-m unitary matrix Q.   
-            If VECT = 'N' or 'P', the array Q is not referenced.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of the array Q.   
-            LDQ >= max(1,M) if VECT = 'Q' or 'B'; LDQ >= 1 otherwise.   
-
-    PT      (output) COMPLEX*16 array, dimension (LDPT,N)   
-            If VECT = 'P' or 'B', the n-by-n unitary matrix P'.   
-            If VECT = 'N' or 'Q', the array PT is not referenced.   
-
-    LDPT    (input) INTEGER   
-            The leading dimension of the array PT.   
-            LDPT >= max(1,N) if VECT = 'P' or 'B'; LDPT >= 1 otherwise.   
-
-    C       (input/output) COMPLEX*16 array, dimension (LDC,NCC)   
-            On entry, an m-by-ncc matrix C.   
-            On exit, C is overwritten by Q'*C.   
-            C is not referenced if NCC = 0.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C.   
-            LDC >= max(1,M) if NCC > 0; LDC >= 1 if NCC = 0.   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (max(M,N))   
-
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (max(M,N))   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit.   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-
-    =====================================================================   
-
-
-       Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {0.,0.};
-    static doublecomplex c_b2 = {1.,0.};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer ab_dim1, ab_offset, c_dim1, c_offset, pt_dim1, pt_offset, q_dim1, 
 	    q_offset, i__1, i__2, i__3, i__4, i__5, i__6, i__7;
     doublecomplex z__1, z__2, z__3;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
     double z_abs(doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, l;
-    static doublecomplex t;
-    static integer j1, j2, kb;
-    static doublecomplex ra, rb;
-    static doublereal rc;
-    static integer kk, ml, nr, mu;
-    static doublecomplex rs;
-    static integer kb1, ml0, mu0, klm, kun, nrt, klu1, inca;
-    static doublereal abst;
+    integer i__, j, l;
+    doublecomplex t;
+    integer j1, j2, kb;
+    doublecomplex ra, rb;
+    doublereal rc;
+    integer kk, ml, nr, mu;
+    doublecomplex rs;
+    integer kb1, ml0, mu0, klm, kun, nrt, klu1, inca;
+    doublereal abst;
     extern /* Subroutine */ int zrot_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublecomplex *);
     extern logical lsame_(char *, char *);
-    static logical wantb, wantc;
+    logical wantb, wantc;
     extern /* Subroutine */ int zscal_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *);
-    static integer minmn;
-    static logical wantq;
+    integer minmn;
+    logical wantq;
     extern /* Subroutine */ int xerbla_(char *, integer *), zlaset_(
 	    char *, integer *, integer *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, integer *), zlartg_(doublecomplex *, 
 	    doublecomplex *, doublereal *, doublecomplex *, doublecomplex *), 
 	    zlargv_(integer *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublereal *, integer *);
-    static logical wantpt;
-    extern /* Subroutine */ int zlartv_(integer *, doublecomplex *, integer *,
+    logical wantpt;
+    extern /* Subroutine */ int zlartv_(integer *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, doublereal *, doublecomplex *, 
 	    integer *);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZGBBRD reduces a complex general m-by-n band matrix A to real upper */
+/*  bidiagonal form B by a unitary transformation: Q' * A * P = B. */
+
+/*  The routine computes B, and optionally forms Q or P', or computes */
+/*  Q'*C for a given matrix C. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  VECT    (input) CHARACTER*1 */
+/*          Specifies whether or not the matrices Q and P' are to be */
+/*          formed. */
+/*          = 'N': do not form Q or P'; */
+/*          = 'Q': form Q only; */
+/*          = 'P': form P' only; */
+/*          = 'B': form both. */
+
+/*  M       (input) INTEGER */
+/*          The number of rows of the matrix A.  M >= 0. */
+
+/*  N       (input) INTEGER */
+/*          The number of columns of the matrix A.  N >= 0. */
+
+/*  NCC     (input) INTEGER */
+/*          The number of columns of the matrix C.  NCC >= 0. */
+
+/*  KL      (input) INTEGER */
+/*          The number of subdiagonals of the matrix A. KL >= 0. */
+
+/*  KU      (input) INTEGER */
+/*          The number of superdiagonals of the matrix A. KU >= 0. */
+
+/*  AB      (input/output) COMPLEX*16 array, dimension (LDAB,N) */
+/*          On entry, the m-by-n band matrix A, stored in rows 1 to */
+/*          KL+KU+1. The j-th column of A is stored in the j-th column of */
+/*          the array AB as follows: */
+/*          AB(ku+1+i-j,j) = A(i,j) for max(1,j-ku)<=i<=min(m,j+kl). */
+/*          On exit, A is overwritten by values generated during the */
+/*          reduction. */
+
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array A. LDAB >= KL+KU+1. */
+
+/*  D       (output) DOUBLE PRECISION array, dimension (min(M,N)) */
+/*          The diagonal elements of the bidiagonal matrix B. */
+
+/*  E       (output) DOUBLE PRECISION array, dimension (min(M,N)-1) */
+/*          The superdiagonal elements of the bidiagonal matrix B. */
+
+/*  Q       (output) COMPLEX*16 array, dimension (LDQ,M) */
+/*          If VECT = 'Q' or 'B', the m-by-m unitary matrix Q. */
+/*          If VECT = 'N' or 'P', the array Q is not referenced. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of the array Q. */
+/*          LDQ >= max(1,M) if VECT = 'Q' or 'B'; LDQ >= 1 otherwise. */
+
+/*  PT      (output) COMPLEX*16 array, dimension (LDPT,N) */
+/*          If VECT = 'P' or 'B', the n-by-n unitary matrix P'. */
+/*          If VECT = 'N' or 'Q', the array PT is not referenced. */
+
+/*  LDPT    (input) INTEGER */
+/*          The leading dimension of the array PT. */
+/*          LDPT >= max(1,N) if VECT = 'P' or 'B'; LDPT >= 1 otherwise. */
+
+/*  C       (input/output) COMPLEX*16 array, dimension (LDC,NCC) */
+/*          On entry, an m-by-ncc matrix C. */
+/*          On exit, C is overwritten by Q'*C. */
+/*          C is not referenced if NCC = 0. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. */
+/*          LDC >= max(1,M) if NCC > 0; LDC >= 1 if NCC = 0. */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (max(M,N)) */
+
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (max(M,N)) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit. */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters */
+
+    /* Parameter adjustments */
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
     ab -= ab_offset;
@@ -215,9 +233,9 @@
 
     if (*kl + *ku > 1) {
 
-/*        Reduce to upper bidiagonal form if KU > 0; if KU = 0, reduce   
-          first to lower bidiagonal form and then transform to upper   
-          bidiagonal */
+/*        Reduce to upper bidiagonal form if KU > 0; if KU = 0, reduce */
+/*        first to lower bidiagonal form and then transform to upper */
+/*        bidiagonal */
 
 	if (*ku > 0) {
 	    ml0 = 1;
@@ -227,13 +245,13 @@
 	    mu0 = 1;
 	}
 
-/*        Wherever possible, plane rotations are generated and applied in   
-          vector operations of length NR over the index set J1:J2:KLU1.   
+/*        Wherever possible, plane rotations are generated and applied in */
+/*        vector operations of length NR over the index set J1:J2:KLU1. */
 
-          The complex sines of the plane rotations are stored in WORK,   
-          and the real cosines in RWORK.   
+/*        The complex sines of the plane rotations are stored in WORK, */
+/*        and the real cosines in RWORK. */
 
-   Computing MIN */
+/* Computing MIN */
 	i__1 = *m - 1;
 	klm = min(i__1,*kl);
 /* Computing MIN */
@@ -258,8 +276,8 @@
 		j1 += kb;
 		j2 += kb;
 
-/*              generate plane rotations to annihilate nonzero elements   
-                which have been created below the band */
+/*              generate plane rotations to annihilate nonzero elements */
+/*              which have been created below the band */
 
 		if (nr > 0) {
 		    zlargv_(&nr, &ab[klu1 + (j1 - klm - 1) * ab_dim1], &inca, 
@@ -287,8 +305,8 @@
 		if (ml > ml0) {
 		    if (ml <= *m - i__ + 1) {
 
-/*                    generate plane rotation to annihilate a(i+ml-1,i)   
-                      within the band, and apply rotation from the left */
+/*                    generate plane rotation to annihilate a(i+ml-1,i) */
+/*                    within the band, and apply rotation from the left */
 
 			zlartg_(&ab[*ku + ml - 1 + i__ * ab_dim1], &ab[*ku + 
 				ml + i__ * ab_dim1], &rwork[i__ + ml - 1], &
@@ -335,7 +353,7 @@
 		    for (j = j1; i__3 < 0 ? j >= i__4 : j <= i__4; j += i__3) 
 			    {
 			zrot_(ncc, &c__[j - 1 + c_dim1], ldc, &c__[j + c_dim1]
-				, ldc, &rwork[j], &work[j]);
+, ldc, &rwork[j], &work[j]);
 /* L30: */
 		    }
 		}
@@ -352,8 +370,8 @@
 		i__4 = kb1;
 		for (j = j1; i__4 < 0 ? j >= i__3 : j <= i__3; j += i__4) {
 
-/*                 create nonzero element a(j-1,j+ku) above the band   
-                   and store it in WORK(n+1:2*n) */
+/*                 create nonzero element a(j-1,j+ku) above the band */
+/*                 and store it in WORK(n+1:2*n) */
 
 		    i__5 = j + kun;
 		    i__6 = j;
@@ -371,8 +389,8 @@
 /* L40: */
 		}
 
-/*              generate plane rotations to annihilate nonzero elements   
-                which have been generated above the band */
+/*              generate plane rotations to annihilate nonzero elements */
+/*              which have been generated above the band */
 
 		if (nr > 0) {
 		    zlargv_(&nr, &ab[(j1 + kun - 1) * ab_dim1 + 1], &inca, &
@@ -399,8 +417,8 @@
 		if (ml == ml0 && mu > mu0) {
 		    if (mu <= *n - i__ + 1) {
 
-/*                    generate plane rotation to annihilate a(i,i+mu-1)   
-                      within the band, and apply rotation from the right */
+/*                    generate plane rotation to annihilate a(i,i+mu-1) */
+/*                    within the band, and apply rotation from the right */
 
 			zlartg_(&ab[*ku - mu + 3 + (i__ + mu - 2) * ab_dim1], 
 				&ab[*ku - mu + 2 + (i__ + mu - 1) * ab_dim1], 
@@ -447,8 +465,8 @@
 		i__4 = kb1;
 		for (j = j1; i__4 < 0 ? j >= i__3 : j <= i__3; j += i__4) {
 
-/*                 create nonzero element a(j+kl+ku,j+ku-1) below the   
-                   band and store it in WORK(1:n) */
+/*                 create nonzero element a(j+kl+ku,j+ku-1) below the */
+/*                 band and store it in WORK(1:n) */
 
 		    i__5 = j + kb;
 		    i__6 = j + kun;
@@ -479,13 +497,13 @@
 
     if (*ku == 0 && *kl > 0) {
 
-/*        A has been reduced to complex lower bidiagonal form   
+/*        A has been reduced to complex lower bidiagonal form */
 
-          Transform lower bidiagonal form to upper bidiagonal by applying   
-          plane rotations from the left, overwriting superdiagonal   
-          elements on subdiagonal elements   
+/*        Transform lower bidiagonal form to upper bidiagonal by applying */
+/*        plane rotations from the left, overwriting superdiagonal */
+/*        elements on subdiagonal elements */
 
-   Computing MIN */
+/* Computing MIN */
 	i__2 = *m - 1;
 	i__1 = min(i__2,*n);
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -517,13 +535,13 @@
 	}
     } else {
 
-/*        A has been reduced to complex upper bidiagonal form or is   
-          diagonal */
+/*        A has been reduced to complex upper bidiagonal form or is */
+/*        diagonal */
 
 	if (*ku > 0 && *m < *n) {
 
-/*           Annihilate a(m,m+1) by applying plane rotations from the   
-             right */
+/*           Annihilate a(m,m+1) by applying plane rotations from the */
+/*           right */
 
 	    i__1 = *ku + (*m + 1) * ab_dim1;
 	    rb.r = ab[i__1].r, rb.i = ab[i__1].i;
@@ -554,8 +572,8 @@
 	}
     }
 
-/*     Make diagonal and superdiagonal elements real, storing them in D   
-       and E */
+/*     Make diagonal and superdiagonal elements real, storing them in D */
+/*     and E */
 
     i__1 = *ku + 1 + ab_dim1;
     t.r = ab[i__1].r, t.i = ab[i__1].i;
