@@ -1,265 +1,84 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {0.,0.};
+static doublecomplex c_b2 = {1.,0.};
+static integer c__1 = 1;
+static integer c_n1 = -1;
+static doublereal c_b29 = 1.;
 
 /* Subroutine */ int zgegv_(char *jobvl, char *jobvr, integer *n, 
 	doublecomplex *a, integer *lda, doublecomplex *b, integer *ldb, 
 	doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, integer 
-	*ldvl, doublecomplex *vr, integer *ldvr, doublecomplex *work, integer  	*lwork, doublereal *rwork, integer *info  	)
+	*ldvl, doublecomplex *vr, integer *ldvr, doublecomplex *work, integer 
+	*lwork, doublereal *rwork, integer *info)
 {
-/*  -- LAPACK driver routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    This routine is deprecated and has been replaced by routine ZGGEV.   
-
-    ZGEGV computes the eigenvalues and, optionally, the left and/or right   
-    eigenvectors of a complex matrix pair (A,B).   
-    Given two square matrices A and B,   
-    the generalized nonsymmetric eigenvalue problem (GNEP) is to find the   
-    eigenvalues lambda and corresponding (non-zero) eigenvectors x such   
-    that   
-       A*x = lambda*B*x.   
-
-    An alternate form is to find the eigenvalues mu and corresponding   
-    eigenvectors y such that   
-       mu*A*y = B*y.   
-
-    These two forms are equivalent with mu = 1/lambda and x = y if   
-    neither lambda nor mu is zero.  In order to deal with the case that   
-    lambda or mu is zero or small, two values alpha and beta are returned   
-    for each eigenvalue, such that lambda = alpha/beta and   
-    mu = beta/alpha.   
-
-    The vectors x and y in the above equations are right eigenvectors of   
-    the matrix pair (A,B).  Vectors u and v satisfying   
-       u**H*A = lambda*u**H*B  or  mu*v**H*A = v**H*B   
-    are left eigenvectors of (A,B).   
-
-    Note: this routine performs "full balancing" on A and B -- see   
-    "Further Details", below.   
-
-    Arguments   
-    =========   
-
-    JOBVL   (input) CHARACTER*1   
-            = 'N':  do not compute the left generalized eigenvectors;   
-            = 'V':  compute the left generalized eigenvectors (returned   
-                    in VL).   
-
-    JOBVR   (input) CHARACTER*1   
-            = 'N':  do not compute the right generalized eigenvectors;   
-            = 'V':  compute the right generalized eigenvectors (returned   
-                    in VR).   
-
-    N       (input) INTEGER   
-            The order of the matrices A, B, VL, and VR.  N >= 0.   
-
-    A       (input/output) COMPLEX*16 array, dimension (LDA, N)   
-            On entry, the matrix A.   
-            If JOBVL = 'V' or JOBVR = 'V', then on exit A   
-            contains the Schur form of A from the generalized Schur   
-            factorization of the pair (A,B) after balancing.  If no   
-            eigenvectors were computed, then only the diagonal elements   
-            of the Schur form will be correct.  See ZGGHRD and ZHGEQZ   
-            for details.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A.  LDA >= max(1,N).   
-
-    B       (input/output) COMPLEX*16 array, dimension (LDB, N)   
-            On entry, the matrix B.   
-            If JOBVL = 'V' or JOBVR = 'V', then on exit B contains the   
-            upper triangular matrix obtained from B in the generalized   
-            Schur factorization of the pair (A,B) after balancing.   
-            If no eigenvectors were computed, then only the diagonal   
-            elements of B will be correct.  See ZGGHRD and ZHGEQZ for   
-            details.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of B.  LDB >= max(1,N).   
-
-    ALPHA   (output) COMPLEX*16 array, dimension (N)   
-            The complex scalars alpha that define the eigenvalues of   
-            GNEP.   
-
-    BETA    (output) COMPLEX*16 array, dimension (N)   
-            The complex scalars beta that define the eigenvalues of GNEP.   
-
-            Together, the quantities alpha = ALPHA(j) and beta = BETA(j)   
-            represent the j-th eigenvalue of the matrix pair (A,B), in   
-            one of the forms lambda = alpha/beta or mu = beta/alpha.   
-            Since either lambda or mu may overflow, they should not,   
-            in general, be computed.   
-
-    VL      (output) COMPLEX*16 array, dimension (LDVL,N)   
-            If JOBVL = 'V', the left eigenvectors u(j) are stored   
-            in the columns of VL, in the same order as their eigenvalues.   
-            Each eigenvector is scaled so that its largest component has   
-            abs(real part) + abs(imag. part) = 1, except for eigenvectors   
-            corresponding to an eigenvalue with alpha = beta = 0, which   
-            are set to zero.   
-            Not referenced if JOBVL = 'N'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of the matrix VL. LDVL >= 1, and   
-            if JOBVL = 'V', LDVL >= N.   
-
-    VR      (output) COMPLEX*16 array, dimension (LDVR,N)   
-            If JOBVR = 'V', the right eigenvectors x(j) are stored   
-            in the columns of VR, in the same order as their eigenvalues.   
-            Each eigenvector is scaled so that its largest component has   
-            abs(real part) + abs(imag. part) = 1, except for eigenvectors   
-            corresponding to an eigenvalue with alpha = beta = 0, which   
-            are set to zero.   
-            Not referenced if JOBVR = 'N'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the matrix VR. LDVR >= 1, and   
-            if JOBVR = 'V', LDVR >= N.   
-
-    WORK    (workspace/output) COMPLEX*16 array, dimension (MAX(1,LWORK))   
-            On exit, if INFO = 0, WORK(1) returns the optimal LWORK.   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= max(1,2*N).   
-            For good performance, LWORK must generally be larger.   
-            To compute the optimal value of LWORK, call ILAENV to get   
-            blocksizes (for ZGEQRF, ZUNMQR, and ZUNGQR.)  Then compute:   
-            NB  -- MAX of the blocksizes for ZGEQRF, ZUNMQR, and ZUNGQR;   
-            The optimal LWORK is  MAX( 2*N, N*(NB+1) ).   
-
-            If LWORK = -1, then a workspace query is assumed; the routine   
-            only calculates the optimal size of the WORK array, returns   
-            this value as the first entry of the WORK array, and no error   
-            message related to LWORK is issued by XERBLA.   
-
-    RWORK   (workspace/output) DOUBLE PRECISION array, dimension (8*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            =1,...,N:   
-                  The QZ iteration failed.  No eigenvectors have been   
-                  calculated, but ALPHA(j) and BETA(j) should be   
-                  correct for j=INFO+1,...,N.   
-            > N:  errors that usually indicate LAPACK problems:   
-                  =N+1: error return from ZGGBAL   
-                  =N+2: error return from ZGEQRF   
-                  =N+3: error return from ZUNMQR   
-                  =N+4: error return from ZUNGQR   
-                  =N+5: error return from ZGGHRD   
-                  =N+6: error return from ZHGEQZ (other than failed   
-                                                 iteration)   
-                  =N+7: error return from ZTGEVC   
-                  =N+8: error return from ZGGBAK (computing VL)   
-                  =N+9: error return from ZGGBAK (computing VR)   
-                  =N+10: error return from ZLASCL (various calls)   
-
-    Further Details   
-    ===============   
-
-    Balancing   
-    ---------   
-
-    This driver calls ZGGBAL to both permute and scale rows and columns   
-    of A and B.  The permutations PL and PR are chosen so that PL*A*PR   
-    and PL*B*R will be upper triangular except for the diagonal blocks   
-    A(i:j,i:j) and B(i:j,i:j), with i and j as close together as   
-    possible.  The diagonal scaling matrices DL and DR are chosen so   
-    that the pair  DL*PL*A*PR*DR, DL*PL*B*PR*DR have elements close to   
-    one (except for the elements that start out zero.)   
-
-    After the eigenvalues and eigenvectors of the balanced matrices   
-    have been computed, ZGGBAK transforms the eigenvectors back to what   
-    they would have been (in perfect arithmetic) if they had not been   
-    balanced.   
-
-    Contents of A and B on Exit   
-    -------- -- - --- - -- ----   
-
-    If any eigenvectors are computed (either JOBVL='V' or JOBVR='V' or   
-    both), then on exit the arrays A and B will contain the complex Schur   
-    form[*] of the "balanced" versions of A and B.  If no eigenvectors   
-    are computed, then only the diagonal blocks will be correct.   
-
-    [*] In other words, upper triangular form.   
-
-    =====================================================================   
-
-
-       Decode the input arguments   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {0.,0.};
-    static doublecomplex c_b2 = {1.,0.};
-    static integer c__1 = 1;
-    static integer c_n1 = -1;
-    static doublereal c_b29 = 1.;
-    
     /* System generated locals */
     integer a_dim1, a_offset, b_dim1, b_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2, i__3, i__4;
     doublereal d__1, d__2, d__3, d__4;
     doublecomplex z__1, z__2;
+
     /* Builtin functions */
     double d_imag(doublecomplex *);
+
     /* Local variables */
-    static integer jc, nb, in, jr, nb1, nb2, nb3, ihi, ilo;
-    static doublereal eps;
-    static logical ilv;
-    static doublereal absb, anrm, bnrm;
-    static integer itau;
-    static doublereal temp;
-    static logical ilvl, ilvr;
-    static integer lopt;
-    static doublereal anrm1, anrm2, bnrm1, bnrm2, absai, scale, absar, sbeta;
+    integer jc, nb, in, jr, nb1, nb2, nb3, ihi, ilo;
+    doublereal eps;
+    logical ilv;
+    doublereal absb, anrm, bnrm;
+    integer itau;
+    doublereal temp;
+    logical ilvl, ilvr;
+    integer lopt;
+    doublereal anrm1, anrm2, bnrm1, bnrm2, absai, scale, absar, sbeta;
     extern logical lsame_(char *, char *);
-    static integer ileft, iinfo, icols, iwork, irows;
+    integer ileft, iinfo, icols, iwork, irows;
     extern doublereal dlamch_(char *);
-    static doublereal salfai;
+    doublereal salfai;
     extern /* Subroutine */ int zggbak_(char *, char *, integer *, integer *, 
-	    integer *, doublereal *, doublereal *, integer *, doublecomplex *,
-	     integer *, integer *), zggbal_(char *, integer *,
+	    integer *, doublereal *, doublereal *, integer *, doublecomplex *, 
+	     integer *, integer *), zggbal_(char *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, integer *
-	    , integer *, doublereal *, doublereal *, doublereal *, integer *);
-    static doublereal salfar, safmin;
+, integer *, doublereal *, doublereal *, doublereal *, integer *);
+    doublereal salfar, safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static doublereal safmax;
-    static char chtemp[1];
-    static logical ldumma[1];
+    doublereal safmax;
+    char chtemp[1];
+    logical ldumma[1];
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern doublereal zlange_(char *, integer *, integer *, doublecomplex *, 
 	    integer *, doublereal *);
-    static integer ijobvl, iright;
-    static logical ilimit;
+    integer ijobvl, iright;
+    logical ilimit;
     extern /* Subroutine */ int zgghrd_(char *, char *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 	     doublecomplex *, integer *, doublecomplex *, integer *, integer * 	    ), zlascl_(char *, integer *, integer *, 
-	    doublereal *, doublereal *, integer *, integer *, doublecomplex *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
+	     doublecomplex *, integer *, doublecomplex *, integer *, integer *
+), zlascl_(char *, integer *, integer *, 
+	    doublereal *, doublereal *, integer *, integer *, doublecomplex *, 
 	     integer *, integer *);
-    static integer ijobvr;
-    extern /* Subroutine */ int zgeqrf_(integer *, integer *, doublecomplex *,
-	     integer *, doublecomplex *, doublecomplex *, integer *, integer * );
-    static integer lwkmin;
+    integer ijobvr;
+    extern /* Subroutine */ int zgeqrf_(integer *, integer *, doublecomplex *, 
+	     integer *, doublecomplex *, doublecomplex *, integer *, integer *
+);
+    integer lwkmin;
     extern /* Subroutine */ int zlacpy_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), 
 	    zlaset_(char *, integer *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, integer *), ztgevc_(
 	    char *, char *, logical *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublecomplex *, integer *, integer *, integer *, doublecomplex *,
-	     doublereal *, integer *), zhgeqz_(char *, char *,
+	    doublecomplex *, integer *, integer *, integer *, doublecomplex *, 
+	     doublereal *, integer *), zhgeqz_(char *, char *, 
 	     char *, integer *, integer *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublereal *, integer *);
-    static integer irwork, lwkopt;
-    static logical lquery;
+    integer irwork, lwkopt;
+    logical lquery;
     extern /* Subroutine */ int zungqr_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, integer *), zunmqr_(char *, char *, integer *, integer 
@@ -267,6 +86,215 @@
 	    doublecomplex *, integer *, doublecomplex *, integer *, integer *);
 
 
+/*  -- LAPACK driver routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  This routine is deprecated and has been replaced by routine ZGGEV. */
+
+/*  ZGEGV computes the eigenvalues and, optionally, the left and/or right */
+/*  eigenvectors of a complex matrix pair (A,B). */
+/*  Given two square matrices A and B, */
+/*  the generalized nonsymmetric eigenvalue problem (GNEP) is to find the */
+/*  eigenvalues lambda and corresponding (non-zero) eigenvectors x such */
+/*  that */
+/*     A*x = lambda*B*x. */
+
+/*  An alternate form is to find the eigenvalues mu and corresponding */
+/*  eigenvectors y such that */
+/*     mu*A*y = B*y. */
+
+/*  These two forms are equivalent with mu = 1/lambda and x = y if */
+/*  neither lambda nor mu is zero.  In order to deal with the case that */
+/*  lambda or mu is zero or small, two values alpha and beta are returned */
+/*  for each eigenvalue, such that lambda = alpha/beta and */
+/*  mu = beta/alpha. */
+
+/*  The vectors x and y in the above equations are right eigenvectors of */
+/*  the matrix pair (A,B).  Vectors u and v satisfying */
+/*     u**H*A = lambda*u**H*B  or  mu*v**H*A = v**H*B */
+/*  are left eigenvectors of (A,B). */
+
+/*  Note: this routine performs "full balancing" on A and B -- see */
+/*  "Further Details", below. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  JOBVL   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the left generalized eigenvectors; */
+/*          = 'V':  compute the left generalized eigenvectors (returned */
+/*                  in VL). */
+
+/*  JOBVR   (input) CHARACTER*1 */
+/*          = 'N':  do not compute the right generalized eigenvectors; */
+/*          = 'V':  compute the right generalized eigenvectors (returned */
+/*                  in VR). */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A, B, VL, and VR.  N >= 0. */
+
+/*  A       (input/output) COMPLEX*16 array, dimension (LDA, N) */
+/*          On entry, the matrix A. */
+/*          If JOBVL = 'V' or JOBVR = 'V', then on exit A */
+/*          contains the Schur form of A from the generalized Schur */
+/*          factorization of the pair (A,B) after balancing.  If no */
+/*          eigenvectors were computed, then only the diagonal elements */
+/*          of the Schur form will be correct.  See ZGGHRD and ZHGEQZ */
+/*          for details. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A.  LDA >= max(1,N). */
+
+/*  B       (input/output) COMPLEX*16 array, dimension (LDB, N) */
+/*          On entry, the matrix B. */
+/*          If JOBVL = 'V' or JOBVR = 'V', then on exit B contains the */
+/*          upper triangular matrix obtained from B in the generalized */
+/*          Schur factorization of the pair (A,B) after balancing. */
+/*          If no eigenvectors were computed, then only the diagonal */
+/*          elements of B will be correct.  See ZGGHRD and ZHGEQZ for */
+/*          details. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B.  LDB >= max(1,N). */
+
+/*  ALPHA   (output) COMPLEX*16 array, dimension (N) */
+/*          The complex scalars alpha that define the eigenvalues of */
+/*          GNEP. */
+
+/*  BETA    (output) COMPLEX*16 array, dimension (N) */
+/*          The complex scalars beta that define the eigenvalues of GNEP. */
+
+/*          Together, the quantities alpha = ALPHA(j) and beta = BETA(j) */
+/*          represent the j-th eigenvalue of the matrix pair (A,B), in */
+/*          one of the forms lambda = alpha/beta or mu = beta/alpha. */
+/*          Since either lambda or mu may overflow, they should not, */
+/*          in general, be computed. */
+
+/*  VL      (output) COMPLEX*16 array, dimension (LDVL,N) */
+/*          If JOBVL = 'V', the left eigenvectors u(j) are stored */
+/*          in the columns of VL, in the same order as their eigenvalues. */
+/*          Each eigenvector is scaled so that its largest component has */
+/*          abs(real part) + abs(imag. part) = 1, except for eigenvectors */
+/*          corresponding to an eigenvalue with alpha = beta = 0, which */
+/*          are set to zero. */
+/*          Not referenced if JOBVL = 'N'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of the matrix VL. LDVL >= 1, and */
+/*          if JOBVL = 'V', LDVL >= N. */
+
+/*  VR      (output) COMPLEX*16 array, dimension (LDVR,N) */
+/*          If JOBVR = 'V', the right eigenvectors x(j) are stored */
+/*          in the columns of VR, in the same order as their eigenvalues. */
+/*          Each eigenvector is scaled so that its largest component has */
+/*          abs(real part) + abs(imag. part) = 1, except for eigenvectors */
+/*          corresponding to an eigenvalue with alpha = beta = 0, which */
+/*          are set to zero. */
+/*          Not referenced if JOBVR = 'N'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the matrix VR. LDVR >= 1, and */
+/*          if JOBVR = 'V', LDVR >= N. */
+
+/*  WORK    (workspace/output) COMPLEX*16 array, dimension (MAX(1,LWORK)) */
+/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= max(1,2*N). */
+/*          For good performance, LWORK must generally be larger. */
+/*          To compute the optimal value of LWORK, call ILAENV to get */
+/*          blocksizes (for ZGEQRF, ZUNMQR, and ZUNGQR.)  Then compute: */
+/*          NB  -- MAX of the blocksizes for ZGEQRF, ZUNMQR, and ZUNGQR; */
+/*          The optimal LWORK is  MAX( 2*N, N*(NB+1) ). */
+
+/*          If LWORK = -1, then a workspace query is assumed; the routine */
+/*          only calculates the optimal size of the WORK array, returns */
+/*          this value as the first entry of the WORK array, and no error */
+/*          message related to LWORK is issued by XERBLA. */
+
+/*  RWORK   (workspace/output) DOUBLE PRECISION array, dimension (8*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          =1,...,N: */
+/*                The QZ iteration failed.  No eigenvectors have been */
+/*                calculated, but ALPHA(j) and BETA(j) should be */
+/*                correct for j=INFO+1,...,N. */
+/*          > N:  errors that usually indicate LAPACK problems: */
+/*                =N+1: error return from ZGGBAL */
+/*                =N+2: error return from ZGEQRF */
+/*                =N+3: error return from ZUNMQR */
+/*                =N+4: error return from ZUNGQR */
+/*                =N+5: error return from ZGGHRD */
+/*                =N+6: error return from ZHGEQZ (other than failed */
+/*                                               iteration) */
+/*                =N+7: error return from ZTGEVC */
+/*                =N+8: error return from ZGGBAK (computing VL) */
+/*                =N+9: error return from ZGGBAK (computing VR) */
+/*                =N+10: error return from ZLASCL (various calls) */
+
+/*  Further Details */
+/*  =============== */
+
+/*  Balancing */
+/*  --------- */
+
+/*  This driver calls ZGGBAL to both permute and scale rows and columns */
+/*  of A and B.  The permutations PL and PR are chosen so that PL*A*PR */
+/*  and PL*B*R will be upper triangular except for the diagonal blocks */
+/*  A(i:j,i:j) and B(i:j,i:j), with i and j as close together as */
+/*  possible.  The diagonal scaling matrices DL and DR are chosen so */
+/*  that the pair  DL*PL*A*PR*DR, DL*PL*B*PR*DR have elements close to */
+/*  one (except for the elements that start out zero.) */
+
+/*  After the eigenvalues and eigenvectors of the balanced matrices */
+/*  have been computed, ZGGBAK transforms the eigenvectors back to what */
+/*  they would have been (in perfect arithmetic) if they had not been */
+/*  balanced. */
+
+/*  Contents of A and B on Exit */
+/*  -------- -- - --- - -- ---- */
+
+/*  If any eigenvectors are computed (either JOBVL='V' or JOBVR='V' or */
+/*  both), then on exit the arrays A and B will contain the complex Schur */
+/*  form[*] of the "balanced" versions of A and B.  If no eigenvectors */
+/*  are computed, then only the diagonal blocks will be correct. */
+
+/*  [*] In other words, upper triangular form. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode the input arguments */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -308,9 +336,9 @@
     }
     ilv = ilvl || ilvr;
 
-/*     Test the input arguments   
+/*     Test the input arguments */
 
-   Computing MAX */
+/* Computing MAX */
     i__1 = *n << 1;
     lwkmin = max(i__1,1);
     lwkopt = lwkmin;
@@ -336,12 +364,9 @@
     }
 
     if (*info == 0) {
-	nb1 = ilaenv_(&c__1, "ZGEQRF", " ", n, n, &c_n1, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-	nb2 = ilaenv_(&c__1, "ZUNMQR", " ", n, n, n, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-	nb3 = ilaenv_(&c__1, "ZUNGQR", " ", n, n, n, &c_n1, (ftnlen)6, (
-		ftnlen)1);
+	nb1 = ilaenv_(&c__1, "ZGEQRF", " ", n, n, &c_n1, &c_n1);
+	nb2 = ilaenv_(&c__1, "ZUNMQR", " ", n, n, n, &c_n1);
+	nb3 = ilaenv_(&c__1, "ZUNGQR", " ", n, n, n, &c_n1);
 /* Computing MAX */
 	i__1 = max(nb1,nb2);
 	nb = max(i__1,nb3);
@@ -414,8 +439,8 @@
 	}
     }
 
-/*     Permute the matrix to make it more nearly triangular   
-       Also "balance" the matrix. */
+/*     Permute the matrix to make it more nearly triangular */
+/*     Also "balance" the matrix. */
 
     ileft = 1;
     iright = *n + 1;
@@ -563,7 +588,7 @@
 /*        Undo balancing on VL and VR, rescale */
 
 	if (ilvl) {
-	    zggbak_("P", "L", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n,
+	    zggbak_("P", "L", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n, 
 		     &vl[vl_offset], ldvl, &iinfo);
 	    if (iinfo != 0) {
 		*info = *n + 8;
@@ -598,7 +623,7 @@ L30:
 	    }
 	}
 	if (ilvr) {
-	    zggbak_("P", "R", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n,
+	    zggbak_("P", "R", n, &ilo, &ihi, &rwork[ileft], &rwork[iright], n, 
 		     &vr[vr_offset], ldvr, &iinfo);
 	    if (iinfo != 0) {
 		*info = *n + 9;
@@ -637,13 +662,13 @@ L60:
 
     }
 
-/*     Undo scaling in alpha, beta   
+/*     Undo scaling in alpha, beta */
 
-       Note: this does not give the alpha and beta for the unscaled   
-       problem.   
+/*     Note: this does not give the alpha and beta for the unscaled */
+/*     problem. */
 
-       Un-scaling is limited to avoid underflow in alpha and beta   
-       if they are significant. */
+/*     Un-scaling is limited to avoid underflow in alpha and beta */
+/*     if they are significant. */
 
     i__1 = *n;
     for (jc = 1; jc <= i__1; ++jc) {
@@ -660,9 +685,9 @@ L60:
 	ilimit = FALSE_;
 	scale = 1.;
 
-/*        Check for significant underflow in imaginary part of ALPHA   
+/*        Check for significant underflow in imaginary part of ALPHA */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = safmin, d__2 = eps * absar, d__1 = max(d__1,d__2), d__2 = eps *
 		 absb;
 	if (abs(salfai) < safmin && absai >= max(d__1,d__2)) {
@@ -672,29 +697,29 @@ L60:
 	    scale = safmin / anrm1 / max(d__1,d__2);
 	}
 
-/*        Check for significant underflow in real part of ALPHA   
+/*        Check for significant underflow in real part of ALPHA */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = safmin, d__2 = eps * absai, d__1 = max(d__1,d__2), d__2 = eps *
 		 absb;
 	if (abs(salfar) < safmin && absar >= max(d__1,d__2)) {
 	    ilimit = TRUE_;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    d__3 = safmin, d__4 = anrm2 * absar;
 	    d__1 = scale, d__2 = safmin / anrm1 / max(d__3,d__4);
 	    scale = max(d__1,d__2);
 	}
 
-/*        Check for significant underflow in BETA   
+/*        Check for significant underflow in BETA */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = safmin, d__2 = eps * absar, d__1 = max(d__1,d__2), d__2 = eps *
 		 absai;
 	if (abs(sbeta) < safmin && absb >= max(d__1,d__2)) {
 	    ilimit = TRUE_;
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	    d__3 = safmin, d__4 = bnrm2 * absb;
 	    d__1 = scale, d__2 = safmin / bnrm1 / max(d__3,d__4);
 	    scale = max(d__1,d__2);
