@@ -1,161 +1,185 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static doublereal c_b18 = -1.;
+static doublereal c_b19 = 1.;
+static doublecomplex c_b26 = {1.,0.};
 
 /* Subroutine */ int zgtrfs_(char *trans, integer *n, integer *nrhs, 
 	doublecomplex *dl, doublecomplex *d__, doublecomplex *du, 
 	doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, 
 	doublecomplex *du2, integer *ipiv, doublecomplex *b, integer *ldb, 
 	doublecomplex *x, integer *ldx, doublereal *ferr, doublereal *berr, 
-	doublecomplex *work, doublereal *rwork, integer *info  	)
+	doublecomplex *work, doublereal *rwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-       Modified to call ZLACN2 in place of ZLACON, 10 Feb 03, SJH.   
-
-
-    Purpose   
-    =======   
-
-    ZGTRFS improves the computed solution to a system of linear   
-    equations when the coefficient matrix is tridiagonal, and provides   
-    error bounds and backward error estimates for the solution.   
-
-    Arguments   
-    =========   
-
-    TRANS   (input) CHARACTER*1   
-            Specifies the form of the system of equations:   
-            = 'N':  A * X = B     (No transpose)   
-            = 'T':  A**T * X = B  (Transpose)   
-            = 'C':  A**H * X = B  (Conjugate transpose)   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    NRHS    (input) INTEGER   
-            The number of right hand sides, i.e., the number of columns   
-            of the matrix B.  NRHS >= 0.   
-
-    DL      (input) COMPLEX*16 array, dimension (N-1)   
-            The (n-1) subdiagonal elements of A.   
-
-    D       (input) COMPLEX*16 array, dimension (N)   
-            The diagonal elements of A.   
-
-    DU      (input) COMPLEX*16 array, dimension (N-1)   
-            The (n-1) superdiagonal elements of A.   
-
-    DLF     (input) COMPLEX*16 array, dimension (N-1)   
-            The (n-1) multipliers that define the matrix L from the   
-            LU factorization of A as computed by ZGTTRF.   
-
-    DF      (input) COMPLEX*16 array, dimension (N)   
-            The n diagonal elements of the upper triangular matrix U from   
-            the LU factorization of A.   
-
-    DUF     (input) COMPLEX*16 array, dimension (N-1)   
-            The (n-1) elements of the first superdiagonal of U.   
-
-    DU2     (input) COMPLEX*16 array, dimension (N-2)   
-            The (n-2) elements of the second superdiagonal of U.   
-
-    IPIV    (input) INTEGER array, dimension (N)   
-            The pivot indices; for 1 <= i <= n, row i of the matrix was   
-            interchanged with row IPIV(i).  IPIV(i) will always be either   
-            i or i+1; IPIV(i) = i indicates a row interchange was not   
-            required.   
-
-    B       (input) COMPLEX*16 array, dimension (LDB,NRHS)   
-            The right hand side matrix B.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B.  LDB >= max(1,N).   
-
-    X       (input/output) COMPLEX*16 array, dimension (LDX,NRHS)   
-            On entry, the solution matrix X, as computed by ZGTTRS.   
-            On exit, the improved solution matrix X.   
-
-    LDX     (input) INTEGER   
-            The leading dimension of the array X.  LDX >= max(1,N).   
-
-    FERR    (output) DOUBLE PRECISION array, dimension (NRHS)   
-            The estimated forward error bound for each solution vector   
-            X(j) (the j-th column of the solution matrix X).   
-            If XTRUE is the true solution corresponding to X(j), FERR(j)   
-            is an estimated upper bound for the magnitude of the largest   
-            element in (X(j) - XTRUE) divided by the magnitude of the   
-            largest element in X(j).  The estimate is as reliable as   
-            the estimate for RCOND, and is almost always a slight   
-            overestimate of the true error.   
-
-    BERR    (output) DOUBLE PRECISION array, dimension (NRHS)   
-            The componentwise relative backward error of each solution   
-            vector X(j) (i.e., the smallest relative change in   
-            any element of A or B that makes X(j) an exact solution).   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (2*N)   
-
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value   
-
-    Internal Parameters   
-    ===================   
-
-    ITMAX is the maximum number of steps of iterative refinement.   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static doublereal c_b18 = -1.;
-    static doublereal c_b19 = 1.;
-    static doublecomplex c_b26 = {1.,0.};
-    
     /* System generated locals */
     integer b_dim1, b_offset, x_dim1, x_offset, i__1, i__2, i__3, i__4, i__5, 
 	    i__6, i__7, i__8, i__9;
     doublereal d__1, d__2, d__3, d__4, d__5, d__6, d__7, d__8, d__9, d__10, 
 	    d__11, d__12, d__13, d__14;
     doublecomplex z__1;
+
     /* Builtin functions */
     double d_imag(doublecomplex *);
+
     /* Local variables */
-    static integer i__, j;
-    static doublereal s;
-    static integer nz;
-    static doublereal eps;
-    static integer kase;
-    static doublereal safe1, safe2;
+    integer i__, j;
+    doublereal s;
+    integer nz;
+    doublereal eps;
+    integer kase;
+    doublereal safe1, safe2;
     extern logical lsame_(char *, char *);
-    static integer isave[3], count;
+    integer isave[3], count;
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), zaxpy_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), zlacn2_(
 	    integer *, doublecomplex *, doublecomplex *, doublereal *, 
 	    integer *, integer *);
     extern doublereal dlamch_(char *);
-    static doublereal safmin;
+    doublereal safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *), zlagtm_(
 	    char *, integer *, integer *, doublereal *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, integer *, 
 	    doublereal *, doublecomplex *, integer *);
-    static logical notran;
-    static char transn[1], transt[1];
-    static doublereal lstres;
+    logical notran;
+    char transn[1], transt[1];
+    doublereal lstres;
     extern /* Subroutine */ int zgttrs_(char *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , integer *, doublecomplex *, integer *, integer *);
+, integer *, doublecomplex *, integer *, integer *);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     Modified to call ZLACN2 in place of ZLACON, 10 Feb 03, SJH. */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZGTRFS improves the computed solution to a system of linear */
+/*  equations when the coefficient matrix is tridiagonal, and provides */
+/*  error bounds and backward error estimates for the solution. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies the form of the system of equations: */
+/*          = 'N':  A * X = B     (No transpose) */
+/*          = 'T':  A**T * X = B  (Transpose) */
+/*          = 'C':  A**H * X = B  (Conjugate transpose) */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand sides, i.e., the number of columns */
+/*          of the matrix B.  NRHS >= 0. */
+
+/*  DL      (input) COMPLEX*16 array, dimension (N-1) */
+/*          The (n-1) subdiagonal elements of A. */
+
+/*  D       (input) COMPLEX*16 array, dimension (N) */
+/*          The diagonal elements of A. */
+
+/*  DU      (input) COMPLEX*16 array, dimension (N-1) */
+/*          The (n-1) superdiagonal elements of A. */
+
+/*  DLF     (input) COMPLEX*16 array, dimension (N-1) */
+/*          The (n-1) multipliers that define the matrix L from the */
+/*          LU factorization of A as computed by ZGTTRF. */
+
+/*  DF      (input) COMPLEX*16 array, dimension (N) */
+/*          The n diagonal elements of the upper triangular matrix U from */
+/*          the LU factorization of A. */
+
+/*  DUF     (input) COMPLEX*16 array, dimension (N-1) */
+/*          The (n-1) elements of the first superdiagonal of U. */
+
+/*  DU2     (input) COMPLEX*16 array, dimension (N-2) */
+/*          The (n-2) elements of the second superdiagonal of U. */
+
+/*  IPIV    (input) INTEGER array, dimension (N) */
+/*          The pivot indices; for 1 <= i <= n, row i of the matrix was */
+/*          interchanged with row IPIV(i).  IPIV(i) will always be either */
+/*          i or i+1; IPIV(i) = i indicates a row interchange was not */
+/*          required. */
+
+/*  B       (input) COMPLEX*16 array, dimension (LDB,NRHS) */
+/*          The right hand side matrix B. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B.  LDB >= max(1,N). */
+
+/*  X       (input/output) COMPLEX*16 array, dimension (LDX,NRHS) */
+/*          On entry, the solution matrix X, as computed by ZGTTRS. */
+/*          On exit, the improved solution matrix X. */
+
+/*  LDX     (input) INTEGER */
+/*          The leading dimension of the array X.  LDX >= max(1,N). */
+
+/*  FERR    (output) DOUBLE PRECISION array, dimension (NRHS) */
+/*          The estimated forward error bound for each solution vector */
+/*          X(j) (the j-th column of the solution matrix X). */
+/*          If XTRUE is the true solution corresponding to X(j), FERR(j) */
+/*          is an estimated upper bound for the magnitude of the largest */
+/*          element in (X(j) - XTRUE) divided by the magnitude of the */
+/*          largest element in X(j).  The estimate is as reliable as */
+/*          the estimate for RCOND, and is almost always a slight */
+/*          overestimate of the true error. */
+
+/*  BERR    (output) DOUBLE PRECISION array, dimension (NRHS) */
+/*          The componentwise relative backward error of each solution */
+/*          vector X(j) (i.e., the smallest relative change in */
+/*          any element of A or B that makes X(j) an exact solution). */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (2*N) */
+
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
+
+/*  Internal Parameters */
+/*  =================== */
+
+/*  ITMAX is the maximum number of steps of iterative refinement. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     --dl;
     --d__;
     --du;
@@ -233,17 +257,17 @@
 	lstres = 3.;
 L20:
 
-/*        Loop until stopping criterion is satisfied.   
+/*        Loop until stopping criterion is satisfied. */
 
-          Compute residual R = B - op(A) * X,   
-          where op(A) = A, A**T, or A**H, depending on TRANS. */
+/*        Compute residual R = B - op(A) * X, */
+/*        where op(A) = A, A**T, or A**H, depending on TRANS. */
 
 	zcopy_(n, &b[j * b_dim1 + 1], &c__1, &work[1], &c__1);
 	zlagtm_(trans, n, &c__1, &c_b18, &dl[1], &d__[1], &du[1], &x[j * 
 		x_dim1 + 1], ldx, &c_b19, &work[1], n);
 
-/*        Compute abs(op(A))*abs(x) + abs(b) for use in the backward   
-          error bound. */
+/*        Compute abs(op(A))*abs(x) + abs(b) for use in the backward */
+/*        error bound. */
 
 	if (notran) {
 	    if (*n == 1) {
@@ -278,7 +302,8 @@ L20:
 		    rwork[i__] = (d__1 = b[i__3].r, abs(d__1)) + (d__2 = 
 			    d_imag(&b[i__ + j * b_dim1]), abs(d__2)) + ((d__3 
 			    = dl[i__4].r, abs(d__3)) + (d__4 = d_imag(&dl[i__ 
-			    - 1]), abs(d__4))) * ((d__5 = x[i__5].r, abs(d__5) 			    ) + (d__6 = d_imag(&x[i__ - 1 + j * x_dim1]), abs(
+			    - 1]), abs(d__4))) * ((d__5 = x[i__5].r, abs(d__5)
+			    ) + (d__6 = d_imag(&x[i__ - 1 + j * x_dim1]), abs(
 			    d__6))) + ((d__7 = d__[i__6].r, abs(d__7)) + (
 			    d__8 = d_imag(&d__[i__]), abs(d__8))) * ((d__9 = 
 			    x[i__7].r, abs(d__9)) + (d__10 = d_imag(&x[i__ + 
@@ -336,7 +361,8 @@ L20:
 		    rwork[i__] = (d__1 = b[i__3].r, abs(d__1)) + (d__2 = 
 			    d_imag(&b[i__ + j * b_dim1]), abs(d__2)) + ((d__3 
 			    = du[i__4].r, abs(d__3)) + (d__4 = d_imag(&du[i__ 
-			    - 1]), abs(d__4))) * ((d__5 = x[i__5].r, abs(d__5) 			    ) + (d__6 = d_imag(&x[i__ - 1 + j * x_dim1]), abs(
+			    - 1]), abs(d__4))) * ((d__5 = x[i__5].r, abs(d__5)
+			    ) + (d__6 = d_imag(&x[i__ - 1 + j * x_dim1]), abs(
 			    d__6))) + ((d__7 = d__[i__6].r, abs(d__7)) + (
 			    d__8 = d_imag(&d__[i__]), abs(d__8))) * ((d__9 = 
 			    x[i__7].r, abs(d__9)) + (d__10 = d_imag(&x[i__ + 
@@ -363,14 +389,14 @@ L20:
 	    }
 	}
 
-/*        Compute componentwise relative backward error from formula   
+/*        Compute componentwise relative backward error from formula */
 
-          max(i) ( abs(R(i)) / ( abs(op(A))*abs(X) + abs(B) )(i) )   
+/*        max(i) ( abs(R(i)) / ( abs(op(A))*abs(X) + abs(B) )(i) ) */
 
-          where abs(Z) is the componentwise absolute value of the matrix   
-          or vector Z.  If the i-th component of the denominator is less   
-          than SAFE2, then SAFE1 is added to the i-th components of the   
-          numerator and denominator before dividing. */
+/*        where abs(Z) is the componentwise absolute value of the matrix */
+/*        or vector Z.  If the i-th component of the denominator is less */
+/*        than SAFE2, then SAFE1 is added to the i-th components of the */
+/*        numerator and denominator before dividing. */
 
 	s = 0.;
 	i__2 = *n;
@@ -393,11 +419,11 @@ L20:
 	}
 	berr[j] = s;
 
-/*        Test stopping criterion. Continue iterating if   
-             1) The residual BERR(J) is larger than machine epsilon, and   
-             2) BERR(J) decreased by at least a factor of 2 during the   
-                last iteration, and   
-             3) At most ITMAX iterations tried. */
+/*        Test stopping criterion. Continue iterating if */
+/*           1) The residual BERR(J) is larger than machine epsilon, and */
+/*           2) BERR(J) decreased by at least a factor of 2 during the */
+/*              last iteration, and */
+/*           3) At most ITMAX iterations tried. */
 
 	if (berr[j] > eps && berr[j] * 2. <= lstres && count <= 5) {
 
@@ -411,27 +437,27 @@ L20:
 	    goto L20;
 	}
 
-/*        Bound error from formula   
+/*        Bound error from formula */
 
-          norm(X - XTRUE) / norm(X) .le. FERR =   
-          norm( abs(inv(op(A)))*   
-             ( abs(R) + NZ*EPS*( abs(op(A))*abs(X)+abs(B) ))) / norm(X)   
+/*        norm(X - XTRUE) / norm(X) .le. FERR = */
+/*        norm( abs(inv(op(A)))* */
+/*           ( abs(R) + NZ*EPS*( abs(op(A))*abs(X)+abs(B) ))) / norm(X) */
 
-          where   
-            norm(Z) is the magnitude of the largest component of Z   
-            inv(op(A)) is the inverse of op(A)   
-            abs(Z) is the componentwise absolute value of the matrix or   
-               vector Z   
-            NZ is the maximum number of nonzeros in any row of A, plus 1   
-            EPS is machine epsilon   
+/*        where */
+/*          norm(Z) is the magnitude of the largest component of Z */
+/*          inv(op(A)) is the inverse of op(A) */
+/*          abs(Z) is the componentwise absolute value of the matrix or */
+/*             vector Z */
+/*          NZ is the maximum number of nonzeros in any row of A, plus 1 */
+/*          EPS is machine epsilon */
 
-          The i-th component of abs(R)+NZ*EPS*(abs(op(A))*abs(X)+abs(B))   
-          is incremented by SAFE1 if the i-th component of   
-          abs(op(A))*abs(X) + abs(B) is less than SAFE2.   
+/*        The i-th component of abs(R)+NZ*EPS*(abs(op(A))*abs(X)+abs(B)) */
+/*        is incremented by SAFE1 if the i-th component of */
+/*        abs(op(A))*abs(X) + abs(B) is less than SAFE2. */
 
-          Use ZLACN2 to estimate the infinity-norm of the matrix   
-             inv(op(A)) * diag(W),   
-          where W = abs(R) + NZ*EPS*( abs(op(A))*abs(X)+abs(B) ))) */
+/*        Use ZLACN2 to estimate the infinity-norm of the matrix */
+/*           inv(op(A)) * diag(W), */
+/*        where W = abs(R) + NZ*EPS*( abs(op(A))*abs(X)+abs(B) ))) */
 
 	i__2 = *n;
 	for (i__ = 1; i__ <= i__2; ++i__) {
