@@ -1,142 +1,160 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {0.,0.};
+static doublecomplex c_b2 = {1.,0.};
+static integer c__1 = 1;
 
 /* Subroutine */ int zhbgst_(char *vect, char *uplo, integer *n, integer *ka, 
 	integer *kb, doublecomplex *ab, integer *ldab, doublecomplex *bb, 
 	integer *ldbb, doublecomplex *x, integer *ldx, doublecomplex *work, 
 	doublereal *rwork, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZHBGST reduces a complex Hermitian-definite banded generalized   
-    eigenproblem  A*x = lambda*B*x  to standard form  C*y = lambda*y,   
-    such that C has the same bandwidth as A.   
-
-    B must have been previously factorized as S**H*S by ZPBSTF, using a   
-    split Cholesky factorization. A is overwritten by C = X**H*A*X, where   
-    X = S**(-1)*Q and Q is a unitary matrix chosen to preserve the   
-    bandwidth of A.   
-
-    Arguments   
-    =========   
-
-    VECT    (input) CHARACTER*1   
-            = 'N':  do not form the transformation matrix X;   
-            = 'V':  form X.   
-
-    UPLO    (input) CHARACTER*1   
-            = 'U':  Upper triangle of A is stored;   
-            = 'L':  Lower triangle of A is stored.   
-
-    N       (input) INTEGER   
-            The order of the matrices A and B.  N >= 0.   
-
-    KA      (input) INTEGER   
-            The number of superdiagonals of the matrix A if UPLO = 'U',   
-            or the number of subdiagonals if UPLO = 'L'.  KA >= 0.   
-
-    KB      (input) INTEGER   
-            The number of superdiagonals of the matrix B if UPLO = 'U',   
-            or the number of subdiagonals if UPLO = 'L'.  KA >= KB >= 0.   
-
-    AB      (input/output) COMPLEX*16 array, dimension (LDAB,N)   
-            On entry, the upper or lower triangle of the Hermitian band   
-            matrix A, stored in the first ka+1 rows of the array.  The   
-            j-th column of A is stored in the j-th column of the array AB   
-            as follows:   
-            if UPLO = 'U', AB(ka+1+i-j,j) = A(i,j) for max(1,j-ka)<=i<=j;   
-            if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+ka).   
-
-            On exit, the transformed matrix X**H*A*X, stored in the same   
-            format as A.   
-
-    LDAB    (input) INTEGER   
-            The leading dimension of the array AB.  LDAB >= KA+1.   
-
-    BB      (input) COMPLEX*16 array, dimension (LDBB,N)   
-            The banded factor S from the split Cholesky factorization of   
-            B, as returned by ZPBSTF, stored in the first kb+1 rows of   
-            the array.   
-
-    LDBB    (input) INTEGER   
-            The leading dimension of the array BB.  LDBB >= KB+1.   
-
-    X       (output) COMPLEX*16 array, dimension (LDX,N)   
-            If VECT = 'V', the n-by-n matrix X.   
-            If VECT = 'N', the array X is not referenced.   
-
-    LDX     (input) INTEGER   
-            The leading dimension of the array X.   
-            LDX >= max(1,N) if VECT = 'V'; LDX >= 1 otherwise.   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (N)   
-
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-
-    =====================================================================   
-
-
-       Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {0.,0.};
-    static doublecomplex c_b2 = {1.,0.};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer ab_dim1, ab_offset, bb_dim1, bb_offset, x_dim1, x_offset, i__1, 
 	    i__2, i__3, i__4, i__5, i__6, i__7, i__8;
     doublereal d__1;
     doublecomplex z__1, z__2, z__3, z__4, z__5, z__6, z__7, z__8, z__9, z__10;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, k, l, m;
-    static doublecomplex t;
-    static integer i0, i1, i2, j1, j2;
-    static doublecomplex ra;
-    static integer nr, nx, ka1, kb1;
-    static doublecomplex ra1;
-    static integer j1t, j2t;
-    static doublereal bii;
-    static integer kbt, nrt, inca;
+    integer i__, j, k, l, m;
+    doublecomplex t;
+    integer i0, i1, i2, j1, j2;
+    doublecomplex ra;
+    integer nr, nx, ka1, kb1;
+    doublecomplex ra1;
+    integer j1t, j2t;
+    doublereal bii;
+    integer kbt, nrt, inca;
     extern /* Subroutine */ int zrot_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublecomplex *);
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int zgerc_(integer *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
-    static logical upper;
+    logical upper;
     extern /* Subroutine */ int zgeru_(integer *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
-    static logical wantx;
+    logical wantx;
     extern /* Subroutine */ int zlar2v_(integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, integer *, doublereal *, 
 	    doublecomplex *, integer *), xerbla_(char *, integer *), 
 	    zdscal_(integer *, doublereal *, doublecomplex *, integer *);
-    static logical update;
+    logical update;
     extern /* Subroutine */ int zlacgv_(integer *, doublecomplex *, integer *)
 	    , zlaset_(char *, integer *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, integer *), zlartg_(
 	    doublecomplex *, doublecomplex *, doublereal *, doublecomplex *, 
 	    doublecomplex *), zlargv_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, integer *), zlartv_(
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     doublereal *, doublecomplex *, integer *);
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZHBGST reduces a complex Hermitian-definite banded generalized */
+/*  eigenproblem  A*x = lambda*B*x  to standard form  C*y = lambda*y, */
+/*  such that C has the same bandwidth as A. */
+
+/*  B must have been previously factorized as S**H*S by ZPBSTF, using a */
+/*  split Cholesky factorization. A is overwritten by C = X**H*A*X, where */
+/*  X = S**(-1)*Q and Q is a unitary matrix chosen to preserve the */
+/*  bandwidth of A. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  VECT    (input) CHARACTER*1 */
+/*          = 'N':  do not form the transformation matrix X; */
+/*          = 'V':  form X. */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          = 'U':  Upper triangle of A is stored; */
+/*          = 'L':  Lower triangle of A is stored. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices A and B.  N >= 0. */
+
+/*  KA      (input) INTEGER */
+/*          The number of superdiagonals of the matrix A if UPLO = 'U', */
+/*          or the number of subdiagonals if UPLO = 'L'.  KA >= 0. */
+
+/*  KB      (input) INTEGER */
+/*          The number of superdiagonals of the matrix B if UPLO = 'U', */
+/*          or the number of subdiagonals if UPLO = 'L'.  KA >= KB >= 0. */
+
+/*  AB      (input/output) COMPLEX*16 array, dimension (LDAB,N) */
+/*          On entry, the upper or lower triangle of the Hermitian band */
+/*          matrix A, stored in the first ka+1 rows of the array.  The */
+/*          j-th column of A is stored in the j-th column of the array AB */
+/*          as follows: */
+/*          if UPLO = 'U', AB(ka+1+i-j,j) = A(i,j) for max(1,j-ka)<=i<=j; */
+/*          if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+ka). */
+
+/*          On exit, the transformed matrix X**H*A*X, stored in the same */
+/*          format as A. */
+
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array AB.  LDAB >= KA+1. */
+
+/*  BB      (input) COMPLEX*16 array, dimension (LDBB,N) */
+/*          The banded factor S from the split Cholesky factorization of */
+/*          B, as returned by ZPBSTF, stored in the first kb+1 rows of */
+/*          the array. */
+
+/*  LDBB    (input) INTEGER */
+/*          The leading dimension of the array BB.  LDBB >= KB+1. */
+
+/*  X       (output) COMPLEX*16 array, dimension (LDX,N) */
+/*          If VECT = 'V', the n-by-n matrix X. */
+/*          If VECT = 'N', the array X is not referenced. */
+
+/*  LDX     (input) INTEGER */
+/*          The leading dimension of the array X. */
+/*          LDX >= max(1,N) if VECT = 'V'; LDX >= 1 otherwise. */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (N) */
+
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters */
+
+    /* Parameter adjustments */
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
     ab -= ab_offset;
@@ -192,70 +210,70 @@
 	zlaset_("Full", n, n, &c_b1, &c_b2, &x[x_offset], ldx);
     }
 
-/*     Set M to the splitting point m. It must be the same value as is   
-       used in ZPBSTF. The chosen value allows the arrays WORK and RWORK   
-       to be of dimension (N). */
+/*     Set M to the splitting point m. It must be the same value as is */
+/*     used in ZPBSTF. The chosen value allows the arrays WORK and RWORK */
+/*     to be of dimension (N). */
 
     m = (*n + *kb) / 2;
 
-/*     The routine works in two phases, corresponding to the two halves   
-       of the split Cholesky factorization of B as S**H*S where   
+/*     The routine works in two phases, corresponding to the two halves */
+/*     of the split Cholesky factorization of B as S**H*S where */
 
-       S = ( U    )   
-           ( M  L )   
+/*     S = ( U    ) */
+/*         ( M  L ) */
 
-       with U upper triangular of order m, and L lower triangular of   
-       order n-m. S has the same bandwidth as B.   
+/*     with U upper triangular of order m, and L lower triangular of */
+/*     order n-m. S has the same bandwidth as B. */
 
-       S is treated as a product of elementary matrices:   
+/*     S is treated as a product of elementary matrices: */
 
-       S = S(m)*S(m-1)*...*S(2)*S(1)*S(m+1)*S(m+2)*...*S(n-1)*S(n)   
+/*     S = S(m)*S(m-1)*...*S(2)*S(1)*S(m+1)*S(m+2)*...*S(n-1)*S(n) */
 
-       where S(i) is determined by the i-th row of S.   
+/*     where S(i) is determined by the i-th row of S. */
 
-       In phase 1, the index i takes the values n, n-1, ... , m+1;   
-       in phase 2, it takes the values 1, 2, ... , m.   
+/*     In phase 1, the index i takes the values n, n-1, ... , m+1; */
+/*     in phase 2, it takes the values 1, 2, ... , m. */
 
-       For each value of i, the current matrix A is updated by forming   
-       inv(S(i))**H*A*inv(S(i)). This creates a triangular bulge outside   
-       the band of A. The bulge is then pushed down toward the bottom of   
-       A in phase 1, and up toward the top of A in phase 2, by applying   
-       plane rotations.   
+/*     For each value of i, the current matrix A is updated by forming */
+/*     inv(S(i))**H*A*inv(S(i)). This creates a triangular bulge outside */
+/*     the band of A. The bulge is then pushed down toward the bottom of */
+/*     A in phase 1, and up toward the top of A in phase 2, by applying */
+/*     plane rotations. */
 
-       There are kb*(kb+1)/2 elements in the bulge, but at most 2*kb-1   
-       of them are linearly independent, so annihilating a bulge requires   
-       only 2*kb-1 plane rotations. The rotations are divided into a 1st   
-       set of kb-1 rotations, and a 2nd set of kb rotations.   
+/*     There are kb*(kb+1)/2 elements in the bulge, but at most 2*kb-1 */
+/*     of them are linearly independent, so annihilating a bulge requires */
+/*     only 2*kb-1 plane rotations. The rotations are divided into a 1st */
+/*     set of kb-1 rotations, and a 2nd set of kb rotations. */
 
-       Wherever possible, rotations are generated and applied in vector   
-       operations of length NR between the indices J1 and J2 (sometimes   
-       replaced by modified values NRT, J1T or J2T).   
+/*     Wherever possible, rotations are generated and applied in vector */
+/*     operations of length NR between the indices J1 and J2 (sometimes */
+/*     replaced by modified values NRT, J1T or J2T). */
 
-       The real cosines and complex sines of the rotations are stored in   
-       the arrays RWORK and WORK, those of the 1st set in elements   
-       2:m-kb-1, and those of the 2nd set in elements m-kb+1:n.   
+/*     The real cosines and complex sines of the rotations are stored in */
+/*     the arrays RWORK and WORK, those of the 1st set in elements */
+/*     2:m-kb-1, and those of the 2nd set in elements m-kb+1:n. */
 
-       The bulges are not formed explicitly; nonzero elements outside the   
-       band are created only when they are required for generating new   
-       rotations; they are stored in the array WORK, in positions where   
-       they are later overwritten by the sines of the rotations which   
-       annihilate them.   
+/*     The bulges are not formed explicitly; nonzero elements outside the */
+/*     band are created only when they are required for generating new */
+/*     rotations; they are stored in the array WORK, in positions where */
+/*     they are later overwritten by the sines of the rotations which */
+/*     annihilate them. */
 
-       **************************** Phase 1 *****************************   
+/*     **************************** Phase 1 ***************************** */
 
-       The logical structure of this phase is:   
+/*     The logical structure of this phase is: */
 
-       UPDATE = .TRUE.   
-       DO I = N, M + 1, -1   
-          use S(i) to update A and create a new bulge   
-          apply rotations to push all bulges KA positions downward   
-       END DO   
-       UPDATE = .FALSE.   
-       DO I = M + KA + 1, N - 1   
-          apply rotations to push all bulges KA positions downward   
-       END DO   
+/*     UPDATE = .TRUE. */
+/*     DO I = N, M + 1, -1 */
+/*        use S(i) to update A and create a new bulge */
+/*        apply rotations to push all bulges KA positions downward */
+/*     END DO */
+/*     UPDATE = .FALSE. */
+/*     DO I = M + KA + 1, N - 1 */
+/*        apply rotations to push all bulges KA positions downward */
+/*     END DO */
 
-       To avoid duplicating code, the two loops are merged. */
+/*     To avoid duplicating code, the two loops are merged. */
 
     update = TRUE_;
     i__ = *n + 1;
@@ -409,16 +427,16 @@ L10:
 	    ra1.r = ab[i__3].r, ra1.i = ab[i__3].i;
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions down toward the bottom of the   
-          band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions down toward the bottom of the */
+/*        band */
 
 	i__3 = *kb - 1;
 	for (k = 1; k <= i__3; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ - k + *ka < *n && i__ - k > 1) {
 
@@ -426,10 +444,10 @@ L10:
 
 		    zlartg_(&ab[k + 1 + (i__ - k + *ka) * ab_dim1], &ra1, &
 			    rwork[i__ - k + *ka - m], &work[i__ - k + *ka - m]
-			    , &ra);
+, &ra);
 
-/*                 create nonzero element a(i-k,i-k+ka+1) outside the   
-                   band and store it in WORK(i-k) */
+/*                 create nonzero element a(i-k,i-k+ka+1) outside the */
+/*                 band and store it in WORK(i-k) */
 
 		    i__2 = kb1 - k + i__ * bb_dim1;
 		    z__2.r = -bb[i__2].r, z__2.i = -bb[i__2].i;
@@ -476,8 +494,8 @@ L10:
 	    i__4 = ka1;
 	    for (j = j2t; i__4 < 0 ? j >= i__2 : j <= i__2; j += i__4) {
 
-/*              create nonzero element a(j-ka,j+1) outside the band   
-                and store it in WORK(j-m) */
+/*              create nonzero element a(j-ka,j+1) outside the band */
+/*              and store it in WORK(j-m) */
 
 		i__1 = j - m;
 		i__5 = j - m;
@@ -495,8 +513,8 @@ L10:
 /* L90: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
 		zlargv_(&nrt, &ab[j2t * ab_dim1 + 1], &inca, &work[j2t - m], &
@@ -514,8 +532,8 @@ L10:
 /* L100: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[ka1 + j2 * ab_dim1], &ab[ka1 + (j2 + 1) * 
 			ab_dim1], &ab[*ka + (j2 + 1) * ab_dim1], &inca, &
@@ -557,8 +575,8 @@ L10:
 	if (update) {
 	    if (i2 <= *n && kbt > 0) {
 
-/*              create nonzero element a(i-kbt,i-kbt+ka+1) outside the   
-                band and store it in WORK(i-kbt) */
+/*              create nonzero element a(i-kbt,i-kbt+ka+1) outside the */
+/*              band and store it in WORK(i-kbt) */
 
 		i__3 = i__ - kbt;
 		i__2 = kb1 - kbt + i__ * bb_dim1;
@@ -606,8 +624,8 @@ L10:
 	    i__3 = ka1;
 	    for (j = j2; i__3 < 0 ? j >= i__2 : j <= i__2; j += i__3) {
 
-/*              create nonzero element a(j-ka,j+1) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j-ka,j+1) outside the band */
+/*              and store it in WORK(j) */
 
 		i__4 = j;
 		i__1 = j;
@@ -642,8 +660,8 @@ L10:
 	    j1 = j2 + (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		zlargv_(&nr, &ab[j2 * ab_dim1 + 1], &inca, &work[j2], &ka1, &
 			rwork[j2], &ka1);
@@ -658,8 +676,8 @@ L10:
 /* L180: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[ka1 + j2 * ab_dim1], &ab[ka1 + (j2 + 1) * 
 			ab_dim1], &ab[*ka + (j2 + 1) * ab_dim1], &inca, &
@@ -853,16 +871,16 @@ L10:
 	    ra1.r = ab[i__4].r, ra1.i = ab[i__4].i;
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions down toward the bottom of the   
-          band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions down toward the bottom of the */
+/*        band */
 
 	i__4 = *kb - 1;
 	for (k = 1; k <= i__4; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ - k + *ka < *n && i__ - k > 1) {
 
@@ -871,8 +889,8 @@ L10:
 		    zlartg_(&ab[ka1 - k + i__ * ab_dim1], &ra1, &rwork[i__ - 
 			    k + *ka - m], &work[i__ - k + *ka - m], &ra);
 
-/*                 create nonzero element a(i-k+ka+1,i-k) outside the   
-                   band and store it in WORK(i-k) */
+/*                 create nonzero element a(i-k+ka+1,i-k) outside the */
+/*                 band and store it in WORK(i-k) */
 
 		    i__3 = k + 1 + (i__ - k) * bb_dim1;
 		    z__2.r = -bb[i__3].r, z__2.i = -bb[i__3].i;
@@ -919,8 +937,8 @@ L10:
 	    i__1 = ka1;
 	    for (j = j2t; i__1 < 0 ? j >= i__3 : j <= i__3; j += i__1) {
 
-/*              create nonzero element a(j+1,j-ka) outside the band   
-                and store it in WORK(j-m) */
+/*              create nonzero element a(j+1,j-ka) outside the band */
+/*              and store it in WORK(j-m) */
 
 		i__2 = j - m;
 		i__5 = j - m;
@@ -938,8 +956,8 @@ L10:
 /* L320: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
 		zlargv_(&nrt, &ab[ka1 + (j2t - *ka) * ab_dim1], &inca, &work[
@@ -953,12 +971,12 @@ L10:
 		for (l = 1; l <= i__1; ++l) {
 		    zlartv_(&nr, &ab[l + 1 + (j2 - l) * ab_dim1], &inca, &ab[
 			    l + 2 + (j2 - l) * ab_dim1], &inca, &rwork[j2 - m]
-			    , &work[j2 - m], &ka1);
+, &work[j2 - m], &ka1);
 /* L330: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[j2 * ab_dim1 + 1], &ab[(j2 + 1) * ab_dim1 + 
 			1], &ab[j2 * ab_dim1 + 2], &inca, &rwork[j2 - m], &
@@ -989,7 +1007,8 @@ L10:
 		for (j = j2; i__3 < 0 ? j >= i__1 : j <= i__1; j += i__3) {
 		    i__2 = *n - m;
 		    zrot_(&i__2, &x[m + 1 + j * x_dim1], &c__1, &x[m + 1 + (j 
-			    + 1) * x_dim1], &c__1, &rwork[j - m], &work[j - m] );
+			    + 1) * x_dim1], &c__1, &rwork[j - m], &work[j - m]
+);
 /* L350: */
 		}
 	    }
@@ -999,8 +1018,8 @@ L10:
 	if (update) {
 	    if (i2 <= *n && kbt > 0) {
 
-/*              create nonzero element a(i-kbt+ka+1,i-kbt) outside the   
-                band and store it in WORK(i-kbt) */
+/*              create nonzero element a(i-kbt+ka+1,i-kbt) outside the */
+/*              band and store it in WORK(i-kbt) */
 
 		i__4 = i__ - kbt;
 		i__3 = kbt + 1 + (i__ - kbt) * bb_dim1;
@@ -1048,8 +1067,8 @@ L10:
 	    i__4 = ka1;
 	    for (j = j2; i__4 < 0 ? j >= i__3 : j <= i__3; j += i__4) {
 
-/*              create nonzero element a(j+1,j-ka) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j+1,j-ka) outside the band */
+/*              and store it in WORK(j) */
 
 		i__1 = j;
 		i__2 = j;
@@ -1084,11 +1103,11 @@ L10:
 	    j1 = j2 + (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		zlargv_(&nr, &ab[ka1 + (j2 - *ka) * ab_dim1], &inca, &work[j2]
-			, &ka1, &rwork[j2], &ka1);
+, &ka1, &rwork[j2], &ka1);
 
 /*              apply rotations in 2nd set from the left */
 
@@ -1100,8 +1119,8 @@ L10:
 /* L410: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[j2 * ab_dim1 + 1], &ab[(j2 + 1) * ab_dim1 + 
 			1], &ab[j2 * ab_dim1 + 2], &inca, &rwork[j2], &work[
@@ -1176,21 +1195,21 @@ L10:
 
 L480:
 
-/*     **************************** Phase 2 *****************************   
+/*     **************************** Phase 2 ***************************** */
 
-       The logical structure of this phase is:   
+/*     The logical structure of this phase is: */
 
-       UPDATE = .TRUE.   
-       DO I = 1, M   
-          use S(i) to update A and create a new bulge   
-          apply rotations to push all bulges KA positions upward   
-       END DO   
-       UPDATE = .FALSE.   
-       DO I = M - KA - 1, 2, -1   
-          apply rotations to push all bulges KA positions upward   
-       END DO   
+/*     UPDATE = .TRUE. */
+/*     DO I = 1, M */
+/*        use S(i) to update A and create a new bulge */
+/*        apply rotations to push all bulges KA positions upward */
+/*     END DO */
+/*     UPDATE = .FALSE. */
+/*     DO I = M - KA - 1, 2, -1 */
+/*        apply rotations to push all bulges KA positions upward */
+/*     END DO */
 
-       To avoid duplicating code, the two loops are merged. */
+/*     To avoid duplicating code, the two loops are merged. */
 
     update = TRUE_;
     i__ = 0;
@@ -1349,15 +1368,15 @@ L490:
 	    ra1.r = ab[i__3].r, ra1.i = ab[i__3].i;
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions up toward the top of the band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions up toward the top of the band */
 
 	i__3 = *kb - 1;
 	for (k = 1; k <= i__3; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ + k - ka1 > 0 && i__ + k < m) {
 
@@ -1366,8 +1385,8 @@ L490:
 		    zlartg_(&ab[k + 1 + i__ * ab_dim1], &ra1, &rwork[i__ + k 
 			    - *ka], &work[i__ + k - *ka], &ra);
 
-/*                 create nonzero element a(i+k-ka-1,i+k) outside the   
-                   band and store it in WORK(m-kb+i+k) */
+/*                 create nonzero element a(i+k-ka-1,i+k) outside the */
+/*                 band and store it in WORK(m-kb+i+k) */
 
 		    i__4 = kb1 - k + (i__ + k) * bb_dim1;
 		    z__2.r = -bb[i__4].r, z__2.i = -bb[i__4].i;
@@ -1414,8 +1433,8 @@ L490:
 	    i__1 = ka1;
 	    for (j = j1; i__1 < 0 ? j >= i__4 : j <= i__4; j += i__1) {
 
-/*              create nonzero element a(j-1,j+ka) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j-1,j+ka) outside the band */
+/*              and store it in WORK(j) */
 
 		i__2 = j;
 		i__5 = j;
@@ -1433,11 +1452,11 @@ L490:
 /* L570: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
-		zlargv_(&nrt, &ab[(j1 + *ka) * ab_dim1 + 1], &inca, &work[j1],
+		zlargv_(&nrt, &ab[(j1 + *ka) * ab_dim1 + 1], &inca, &work[j1], 
 			 &ka1, &rwork[j1], &ka1);
 	    }
 	    if (nr > 0) {
@@ -1452,8 +1471,8 @@ L490:
 /* L580: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[ka1 + j1 * ab_dim1], &ab[ka1 + (j1 - 1) * 
 			ab_dim1], &ab[*ka + j1 * ab_dim1], &inca, &rwork[j1], 
@@ -1494,8 +1513,8 @@ L490:
 	if (update) {
 	    if (i2 > 0 && kbt > 0) {
 
-/*              create nonzero element a(i+kbt-ka-1,i+kbt) outside the   
-                band and store it in WORK(m-kb+i+kbt) */
+/*              create nonzero element a(i+kbt-ka-1,i+kbt) outside the */
+/*              band and store it in WORK(m-kb+i+kbt) */
 
 		i__3 = m - *kb + i__ + kbt;
 		i__4 = kb1 - kbt + (i__ + kbt) * bb_dim1;
@@ -1545,8 +1564,8 @@ L490:
 	    i__3 = ka1;
 	    for (j = j1; i__3 < 0 ? j >= i__4 : j <= i__4; j += i__3) {
 
-/*              create nonzero element a(j-1,j+ka) outside the band   
-                and store it in WORK(m-kb+j) */
+/*              create nonzero element a(j-1,j+ka) outside the band */
+/*              and store it in WORK(m-kb+j) */
 
 		i__1 = m - *kb + j;
 		i__2 = m - *kb + j;
@@ -1581,8 +1600,8 @@ L490:
 	    j1 = j2 - (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		zlargv_(&nr, &ab[(j1 + *ka) * ab_dim1 + 1], &inca, &work[m - *
 			kb + j1], &ka1, &rwork[m - *kb + j1], &ka1);
@@ -1597,8 +1616,8 @@ L490:
 /* L660: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[ka1 + j1 * ab_dim1], &ab[ka1 + (j1 - 1) * 
 			ab_dim1], &ab[*ka + j1 * ab_dim1], &inca, &rwork[m - *
@@ -1615,7 +1634,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    zlartv_(&nrt, &ab[l + j1t * ab_dim1], &inca, &ab[l + 1 + (
-			    j1t - 1) * ab_dim1], &inca, &rwork[m - *kb + j1t],
+			    j1t - 1) * ab_dim1], &inca, &rwork[m - *kb + j1t], 
 			     &work[m - *kb + j1t], &ka1);
 		}
 /* L670: */
@@ -1790,15 +1809,15 @@ L490:
 	    ra1.r = ab[i__4].r, ra1.i = ab[i__4].i;
 	}
 
-/*        Generate and apply vectors of rotations to chase all the   
-          existing bulges KA positions up toward the top of the band */
+/*        Generate and apply vectors of rotations to chase all the */
+/*        existing bulges KA positions up toward the top of the band */
 
 	i__4 = *kb - 1;
 	for (k = 1; k <= i__4; ++k) {
 	    if (update) {
 
-/*              Determine the rotations which would annihilate the bulge   
-                which has in theory just been created */
+/*              Determine the rotations which would annihilate the bulge */
+/*              which has in theory just been created */
 
 		if (i__ + k - ka1 > 0 && i__ + k < m) {
 
@@ -1807,8 +1826,8 @@ L490:
 		    zlartg_(&ab[ka1 - k + (i__ + k - *ka) * ab_dim1], &ra1, &
 			    rwork[i__ + k - *ka], &work[i__ + k - *ka], &ra);
 
-/*                 create nonzero element a(i+k,i+k-ka-1) outside the   
-                   band and store it in WORK(m-kb+i+k) */
+/*                 create nonzero element a(i+k,i+k-ka-1) outside the */
+/*                 band and store it in WORK(m-kb+i+k) */
 
 		    i__3 = k + 1 + i__ * bb_dim1;
 		    z__2.r = -bb[i__3].r, z__2.i = -bb[i__3].i;
@@ -1855,8 +1874,8 @@ L490:
 	    i__1 = ka1;
 	    for (j = j1; i__1 < 0 ? j >= i__3 : j <= i__3; j += i__1) {
 
-/*              create nonzero element a(j+ka,j-1) outside the band   
-                and store it in WORK(j) */
+/*              create nonzero element a(j+ka,j-1) outside the band */
+/*              and store it in WORK(j) */
 
 		i__2 = j;
 		i__5 = j;
@@ -1874,11 +1893,11 @@ L490:
 /* L800: */
 	    }
 
-/*           generate rotations in 1st set to annihilate elements which   
-             have been created outside the band */
+/*           generate rotations in 1st set to annihilate elements which */
+/*           have been created outside the band */
 
 	    if (nrt > 0) {
-		zlargv_(&nrt, &ab[ka1 + j1 * ab_dim1], &inca, &work[j1], &ka1,
+		zlargv_(&nrt, &ab[ka1 + j1 * ab_dim1], &inca, &work[j1], &ka1, 
 			 &rwork[j1], &ka1);
 	    }
 	    if (nr > 0) {
@@ -1893,8 +1912,8 @@ L490:
 /* L810: */
 		}
 
-/*              apply rotations in 1st set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 1st set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[j1 * ab_dim1 + 1], &ab[(j1 - 1) * ab_dim1 + 
 			1], &ab[(j1 - 1) * ab_dim1 + 2], &inca, &rwork[j1], &
@@ -1911,7 +1930,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    zlartv_(&nrt, &ab[ka1 - l + 1 + (j1t - ka1 + l) * ab_dim1]
-			    , &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1],
+, &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1], 
 			     &inca, &rwork[j1t], &work[j1t], &ka1);
 		}
 /* L820: */
@@ -1936,8 +1955,8 @@ L490:
 	if (update) {
 	    if (i2 > 0 && kbt > 0) {
 
-/*              create nonzero element a(i+kbt,i+kbt-ka-1) outside the   
-                band and store it in WORK(m-kb+i+kbt) */
+/*              create nonzero element a(i+kbt,i+kbt-ka-1) outside the */
+/*              band and store it in WORK(m-kb+i+kbt) */
 
 		i__4 = m - *kb + i__ + kbt;
 		i__3 = kbt + 1 + i__ * bb_dim1;
@@ -1987,8 +2006,8 @@ L490:
 	    i__4 = ka1;
 	    for (j = j1; i__4 < 0 ? j >= i__3 : j <= i__3; j += i__4) {
 
-/*              create nonzero element a(j+ka,j-1) outside the band   
-                and store it in WORK(m-kb+j) */
+/*              create nonzero element a(j+ka,j-1) outside the band */
+/*              and store it in WORK(m-kb+j) */
 
 		i__1 = m - *kb + j;
 		i__2 = m - *kb + j;
@@ -2023,8 +2042,8 @@ L490:
 	    j1 = j2 - (nr - 1) * ka1;
 	    if (nr > 0) {
 
-/*              generate rotations in 2nd set to annihilate elements   
-                which have been created outside the band */
+/*              generate rotations in 2nd set to annihilate elements */
+/*              which have been created outside the band */
 
 		zlargv_(&nr, &ab[ka1 + j1 * ab_dim1], &inca, &work[m - *kb + 
 			j1], &ka1, &rwork[m - *kb + j1], &ka1);
@@ -2035,12 +2054,12 @@ L490:
 		for (l = 1; l <= i__4; ++l) {
 		    zlartv_(&nr, &ab[l + 1 + j1 * ab_dim1], &inca, &ab[l + 2 
 			    + (j1 - 1) * ab_dim1], &inca, &rwork[m - *kb + j1]
-			    , &work[m - *kb + j1], &ka1);
+, &work[m - *kb + j1], &ka1);
 /* L890: */
 		}
 
-/*              apply rotations in 2nd set from both sides to diagonal   
-                blocks */
+/*              apply rotations in 2nd set from both sides to diagonal */
+/*              blocks */
 
 		zlar2v_(&nr, &ab[j1 * ab_dim1 + 1], &ab[(j1 - 1) * ab_dim1 + 
 			1], &ab[(j1 - 1) * ab_dim1 + 2], &inca, &rwork[m - *
@@ -2057,7 +2076,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    zlartv_(&nrt, &ab[ka1 - l + 1 + (j1t - ka1 + l) * ab_dim1]
-			    , &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1],
+, &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1], 
 			     &inca, &rwork[m - *kb + j1t], &work[m - *kb + 
 			    j1t], &ka1);
 		}
@@ -2093,7 +2112,7 @@ L490:
 		j1t = j2 - (nrt - 1) * ka1;
 		if (nrt > 0) {
 		    zlartv_(&nrt, &ab[ka1 - l + 1 + (j1t - ka1 + l) * ab_dim1]
-			    , &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1],
+, &inca, &ab[ka1 - l + (j1t - ka1 + l) * ab_dim1], 
 			     &inca, &rwork[j1t], &work[j1t], &ka1);
 		}
 /* L930: */
