@@ -1,169 +1,191 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
 
 /* Subroutine */ int zhetf2_(char *uplo, integer *n, doublecomplex *a, 
 	integer *lda, integer *ipiv, integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZHETF2 computes the factorization of a complex Hermitian matrix A   
-    using the Bunch-Kaufman diagonal pivoting method:   
-
-       A = U*D*U'  or  A = L*D*L'   
-
-    where U (or L) is a product of permutation and unit upper (lower)   
-    triangular matrices, U' is the conjugate transpose of U, and D is   
-    Hermitian and block diagonal with 1-by-1 and 2-by-2 diagonal blocks.   
-
-    This is the unblocked version of the algorithm, calling Level 2 BLAS.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the upper or lower triangular part of the   
-            Hermitian matrix A is stored:   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    A       (input/output) COMPLEX*16 array, dimension (LDA,N)   
-            On entry, the Hermitian matrix A.  If UPLO = 'U', the leading   
-            n-by-n upper triangular part of A contains the upper   
-            triangular part of the matrix A, and the strictly lower   
-            triangular part of A is not referenced.  If UPLO = 'L', the   
-            leading n-by-n lower triangular part of A contains the lower   
-            triangular part of the matrix A, and the strictly upper   
-            triangular part of A is not referenced.   
-
-            On exit, the block diagonal matrix D and the multipliers used   
-            to obtain the factor U or L (see below for further details).   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,N).   
-
-    IPIV    (output) INTEGER array, dimension (N)   
-            Details of the interchanges and the block structure of D.   
-            If IPIV(k) > 0, then rows and columns k and IPIV(k) were   
-            interchanged and D(k,k) is a 1-by-1 diagonal block.   
-            If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and   
-            columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)   
-            is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =   
-            IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were   
-            interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.   
-
-    INFO    (output) INTEGER   
-            = 0: successful exit   
-            < 0: if INFO = -k, the k-th argument had an illegal value   
-            > 0: if INFO = k, D(k,k) is exactly zero.  The factorization   
-                 has been completed, but the block diagonal matrix D is   
-                 exactly singular, and division by zero will occur if it   
-                 is used to solve a system of equations.   
-
-    Further Details   
-    ===============   
-
-    09-29-06 - patch from   
-      Bobby Cheng, MathWorks   
-
-      Replace l.210 and l.393   
-           IF( MAX( ABSAKK, COLMAX ).EQ.ZERO ) THEN   
-      by   
-           IF( (MAX( ABSAKK, COLMAX ).EQ.ZERO) .OR. DISNAN(ABSAKK) ) THEN   
-
-    01-01-96 - Based on modifications by   
-      J. Lewis, Boeing Computer Services Company   
-      A. Petitet, Computer Science Dept., Univ. of Tenn., Knoxville, USA   
-
-    If UPLO = 'U', then A = U*D*U', where   
-       U = P(n)*U(n)* ... *P(k)U(k)* ...,   
-    i.e., U is a product of terms P(k)*U(k), where k decreases from n to   
-    1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1   
-    and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as   
-    defined by IPIV(k), and U(k) is a unit upper triangular matrix, such   
-    that if the diagonal block D(k) is of order s (s = 1 or 2), then   
-
-               (   I    v    0   )   k-s   
-       U(k) =  (   0    I    0   )   s   
-               (   0    0    I   )   n-k   
-                  k-s   s   n-k   
-
-    If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).   
-    If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),   
-    and A(k,k), and v overwrites A(1:k-2,k-1:k).   
-
-    If UPLO = 'L', then A = L*D*L', where   
-       L = P(1)*L(1)* ... *P(k)*L(k)* ...,   
-    i.e., L is a product of terms P(k)*L(k), where k increases from 1 to   
-    n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1   
-    and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as   
-    defined by IPIV(k), and L(k) is a unit lower triangular matrix, such   
-    that if the diagonal block D(k) is of order s (s = 1 or 2), then   
-
-               (   I    0     0   )  k-1   
-       L(k) =  (   0    I     0   )  s   
-               (   0    v     I   )  n-k-s+1   
-                  k-1   s  n-k-s+1   
-
-    If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).   
-    If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),   
-    and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).   
-
-    =====================================================================   
-
-
-       Test the input parameters.   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
     doublereal d__1, d__2, d__3, d__4;
     doublecomplex z__1, z__2, z__3, z__4, z__5, z__6;
+
     /* Builtin functions */
     double sqrt(doublereal), d_imag(doublecomplex *);
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static doublereal d__;
-    static integer i__, j, k;
-    static doublecomplex t;
-    static doublereal r1, d11;
-    static doublecomplex d12;
-    static doublereal d22;
-    static doublecomplex d21;
-    static integer kk, kp;
-    static doublecomplex wk;
-    static doublereal tt;
-    static doublecomplex wkm1, wkp1;
-    static integer imax, jmax;
+    doublereal d__;
+    integer i__, j, k;
+    doublecomplex t;
+    doublereal r1, d11;
+    doublecomplex d12;
+    doublereal d22;
+    doublecomplex d21;
+    integer kk, kp;
+    doublecomplex wk;
+    doublereal tt;
+    doublecomplex wkm1, wkp1;
+    integer imax, jmax;
     extern /* Subroutine */ int zher_(char *, integer *, doublereal *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
-    static doublereal alpha;
+    doublereal alpha;
     extern logical lsame_(char *, char *);
-    static integer kstep;
-    static logical upper;
+    integer kstep;
+    logical upper;
     extern /* Subroutine */ int zswap_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
     extern doublereal dlapy2_(doublereal *, doublereal *);
-    static doublereal absakk;
+    doublereal absakk;
     extern logical disnan_(doublereal *);
     extern /* Subroutine */ int xerbla_(char *, integer *), zdscal_(
 	    integer *, doublereal *, doublecomplex *, integer *);
-    static doublereal colmax;
+    doublereal colmax;
     extern integer izamax_(integer *, doublecomplex *, integer *);
-    static doublereal rowmax;
+    doublereal rowmax;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZHETF2 computes the factorization of a complex Hermitian matrix A */
+/*  using the Bunch-Kaufman diagonal pivoting method: */
+
+/*     A = U*D*U'  or  A = L*D*L' */
+
+/*  where U (or L) is a product of permutation and unit upper (lower) */
+/*  triangular matrices, U' is the conjugate transpose of U, and D is */
+/*  Hermitian and block diagonal with 1-by-1 and 2-by-2 diagonal blocks. */
+
+/*  This is the unblocked version of the algorithm, calling Level 2 BLAS. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the upper or lower triangular part of the */
+/*          Hermitian matrix A is stored: */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  A       (input/output) COMPLEX*16 array, dimension (LDA,N) */
+/*          On entry, the Hermitian matrix A.  If UPLO = 'U', the leading */
+/*          n-by-n upper triangular part of A contains the upper */
+/*          triangular part of the matrix A, and the strictly lower */
+/*          triangular part of A is not referenced.  If UPLO = 'L', the */
+/*          leading n-by-n lower triangular part of A contains the lower */
+/*          triangular part of the matrix A, and the strictly upper */
+/*          triangular part of A is not referenced. */
+
+/*          On exit, the block diagonal matrix D and the multipliers used */
+/*          to obtain the factor U or L (see below for further details). */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,N). */
+
+/*  IPIV    (output) INTEGER array, dimension (N) */
+/*          Details of the interchanges and the block structure of D. */
+/*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were */
+/*          interchanged and D(k,k) is a 1-by-1 diagonal block. */
+/*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and */
+/*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k) */
+/*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) = */
+/*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were */
+/*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0: successful exit */
+/*          < 0: if INFO = -k, the k-th argument had an illegal value */
+/*          > 0: if INFO = k, D(k,k) is exactly zero.  The factorization */
+/*               has been completed, but the block diagonal matrix D is */
+/*               exactly singular, and division by zero will occur if it */
+/*               is used to solve a system of equations. */
+
+/*  Further Details */
+/*  =============== */
+
+/*  09-29-06 - patch from */
+/*    Bobby Cheng, MathWorks */
+
+/*    Replace l.210 and l.393 */
+/*         IF( MAX( ABSAKK, COLMAX ).EQ.ZERO ) THEN */
+/*    by */
+/*         IF( (MAX( ABSAKK, COLMAX ).EQ.ZERO) .OR. DISNAN(ABSAKK) ) THEN */
+
+/*  01-01-96 - Based on modifications by */
+/*    J. Lewis, Boeing Computer Services Company */
+/*    A. Petitet, Computer Science Dept., Univ. of Tenn., Knoxville, USA */
+
+/*  If UPLO = 'U', then A = U*D*U', where */
+/*     U = P(n)*U(n)* ... *P(k)U(k)* ..., */
+/*  i.e., U is a product of terms P(k)*U(k), where k decreases from n to */
+/*  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1 */
+/*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as */
+/*  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such */
+/*  that if the diagonal block D(k) is of order s (s = 1 or 2), then */
+
+/*             (   I    v    0   )   k-s */
+/*     U(k) =  (   0    I    0   )   s */
+/*             (   0    0    I   )   n-k */
+/*                k-s   s   n-k */
+
+/*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k). */
+/*  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k), */
+/*  and A(k,k), and v overwrites A(1:k-2,k-1:k). */
+
+/*  If UPLO = 'L', then A = L*D*L', where */
+/*     L = P(1)*L(1)* ... *P(k)*L(k)* ..., */
+/*  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to */
+/*  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1 */
+/*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as */
+/*  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such */
+/*  that if the diagonal block D(k) is of order s (s = 1 or 2), then */
+
+/*             (   I    0     0   )  k-1 */
+/*     L(k) =  (   0    I     0   )  s */
+/*             (   0    v     I   )  n-k-s+1 */
+/*                k-1   s  n-k-s+1 */
+
+/*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k). */
+/*  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k), */
+/*  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Test the input parameters. */
+
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -191,10 +213,10 @@
 
     if (upper) {
 
-/*        Factorize A as U*D*U' using the upper triangle of A   
+/*        Factorize A as U*D*U' using the upper triangle of A */
 
-          K is the main loop index, decreasing from N to 1 in steps of   
-          1 or 2 */
+/*        K is the main loop index, decreasing from N to 1 in steps of */
+/*        1 or 2 */
 
 	k = *n;
 L10:
@@ -206,14 +228,14 @@ L10:
 	}
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	i__1 = k + k * a_dim1;
 	absakk = (d__1 = a[i__1].r, abs(d__1));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k > 1) {
 	    i__1 = k - 1;
@@ -245,8 +267,8 @@ L10:
 		kp = k;
 	    } else {
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		i__1 = k - imax;
 		jmax = imax + izamax_(&i__1, &a[imax + (imax + 1) * a_dim1], 
@@ -260,7 +282,8 @@ L10:
 /* Computing MAX */
 		    i__1 = jmax + imax * a_dim1;
 		    d__3 = rowmax, d__4 = (d__1 = a[i__1].r, abs(d__1)) + (
-			    d__2 = d_imag(&a[jmax + imax * a_dim1]), abs(d__2) );
+			    d__2 = d_imag(&a[jmax + imax * a_dim1]), abs(d__2)
+			    );
 		    rowmax = max(d__3,d__4);
 		}
 
@@ -273,14 +296,14 @@ L10:
 		    i__1 = imax + imax * a_dim1;
 		    if ((d__1 = a[i__1].r, abs(d__1)) >= alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 			kp = imax;
 		    } else {
 
-/*                 interchange rows and columns K-1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K-1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 			kp = imax;
 			kstep = 2;
@@ -291,8 +314,8 @@ L10:
 	    kk = k - kstep + 1;
 	    if (kp != kk) {
 
-/*              Interchange rows and columns KK and KP in the leading   
-                submatrix A(1:k,1:k) */
+/*              Interchange rows and columns KK and KP in the leading */
+/*              submatrix A(1:k,1:k) */
 
 		i__1 = kp - 1;
 		zswap_(&i__1, &a[kk * a_dim1 + 1], &c__1, &a[kp * a_dim1 + 1], 
@@ -349,15 +372,15 @@ L10:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k now holds   
+/*              1-by-1 pivot block D(k): column k now holds */
 
-                W(k) = U(k)*D(k)   
+/*              W(k) = U(k)*D(k) */
 
-                where U(k) is the k-th column of U   
+/*              where U(k) is the k-th column of U */
 
-                Perform a rank-1 update of A(1:k-1,1:k-1) as   
+/*              Perform a rank-1 update of A(1:k-1,1:k-1) as */
 
-                A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)' */
+/*              A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)' */
 
 		i__1 = k + k * a_dim1;
 		r1 = 1. / a[i__1].r;
@@ -372,17 +395,17 @@ L10:
 		zdscal_(&i__1, &r1, &a[k * a_dim1 + 1], &c__1);
 	    } else {
 
-/*              2-by-2 pivot block D(k): columns k and k-1 now hold   
+/*              2-by-2 pivot block D(k): columns k and k-1 now hold */
 
-                ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k)   
+/*              ( W(k-1) W(k) ) = ( U(k-1) U(k) )*D(k) */
 
-                where U(k) and U(k-1) are the k-th and (k-1)-th columns   
-                of U   
+/*              where U(k) and U(k-1) are the k-th and (k-1)-th columns */
+/*              of U */
 
-                Perform a rank-2 update of A(1:k-2,1:k-2) as   
+/*              Perform a rank-2 update of A(1:k-2,1:k-2) as */
 
-                A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )'   
-                   = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )' */
+/*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )' */
+/*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )' */
 
 		if (k > 2) {
 
@@ -473,10 +496,10 @@ L10:
 
     } else {
 
-/*        Factorize A as L*D*L' using the lower triangle of A   
+/*        Factorize A as L*D*L' using the lower triangle of A */
 
-          K is the main loop index, increasing from 1 to N in steps of   
-          1 or 2 */
+/*        K is the main loop index, increasing from 1 to N in steps of */
+/*        1 or 2 */
 
 	k = 1;
 L50:
@@ -488,14 +511,14 @@ L50:
 	}
 	kstep = 1;
 
-/*        Determine rows and columns to be interchanged and whether   
-          a 1-by-1 or 2-by-2 pivot block will be used */
+/*        Determine rows and columns to be interchanged and whether */
+/*        a 1-by-1 or 2-by-2 pivot block will be used */
 
 	i__1 = k + k * a_dim1;
 	absakk = (d__1 = a[i__1].r, abs(d__1));
 
-/*        IMAX is the row-index of the largest off-diagonal element in   
-          column K, and COLMAX is its absolute value */
+/*        IMAX is the row-index of the largest off-diagonal element in */
+/*        column K, and COLMAX is its absolute value */
 
 	if (k < *n) {
 	    i__1 = *n - k;
@@ -527,8 +550,8 @@ L50:
 		kp = k;
 	    } else {
 
-/*              JMAX is the column-index of the largest off-diagonal   
-                element in row IMAX, and ROWMAX is its absolute value */
+/*              JMAX is the column-index of the largest off-diagonal */
+/*              element in row IMAX, and ROWMAX is its absolute value */
 
 		i__1 = imax - k;
 		jmax = k - 1 + izamax_(&i__1, &a[imax + k * a_dim1], lda);
@@ -542,7 +565,8 @@ L50:
 /* Computing MAX */
 		    i__1 = jmax + imax * a_dim1;
 		    d__3 = rowmax, d__4 = (d__1 = a[i__1].r, abs(d__1)) + (
-			    d__2 = d_imag(&a[jmax + imax * a_dim1]), abs(d__2) );
+			    d__2 = d_imag(&a[jmax + imax * a_dim1]), abs(d__2)
+			    );
 		    rowmax = max(d__3,d__4);
 		}
 
@@ -555,14 +579,14 @@ L50:
 		    i__1 = imax + imax * a_dim1;
 		    if ((d__1 = a[i__1].r, abs(d__1)) >= alpha * rowmax) {
 
-/*                 interchange rows and columns K and IMAX, use 1-by-1   
-                   pivot block */
+/*                 interchange rows and columns K and IMAX, use 1-by-1 */
+/*                 pivot block */
 
 			kp = imax;
 		    } else {
 
-/*                 interchange rows and columns K+1 and IMAX, use 2-by-2   
-                   pivot block */
+/*                 interchange rows and columns K+1 and IMAX, use 2-by-2 */
+/*                 pivot block */
 
 			kp = imax;
 			kstep = 2;
@@ -573,8 +597,8 @@ L50:
 	    kk = k + kstep - 1;
 	    if (kp != kk) {
 
-/*              Interchange rows and columns KK and KP in the trailing   
-                submatrix A(k:n,k:n) */
+/*              Interchange rows and columns KK and KP in the trailing */
+/*              submatrix A(k:n,k:n) */
 
 		if (kp < *n) {
 		    i__1 = *n - kp;
@@ -633,17 +657,17 @@ L50:
 
 	    if (kstep == 1) {
 
-/*              1-by-1 pivot block D(k): column k now holds   
+/*              1-by-1 pivot block D(k): column k now holds */
 
-                W(k) = L(k)*D(k)   
+/*              W(k) = L(k)*D(k) */
 
-                where L(k) is the k-th column of L */
+/*              where L(k) is the k-th column of L */
 
 		if (k < *n) {
 
-/*                 Perform a rank-1 update of A(k+1:n,k+1:n) as   
+/*                 Perform a rank-1 update of A(k+1:n,k+1:n) as */
 
-                   A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)' */
+/*                 A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)' */
 
 		    i__1 = k + k * a_dim1;
 		    r1 = 1. / a[i__1].r;
@@ -663,13 +687,13 @@ L50:
 
 		if (k < *n - 1) {
 
-/*                 Perform a rank-2 update of A(k+2:n,k+2:n) as   
+/*                 Perform a rank-2 update of A(k+2:n,k+2:n) as */
 
-                   A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )'   
-                      = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )'   
+/*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )' */
+/*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )' */
 
-                   where L(k) and L(k+1) are the k-th and (k+1)-th   
-                   columns of L */
+/*                 where L(k) and L(k+1) are the k-th and (k+1)-th */
+/*                 columns of L */
 
 		    i__1 = k + 1 + k * a_dim1;
 		    d__1 = a[i__1].r;
