@@ -1,87 +1,103 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Subroutine */ int zlagtm_(char *trans, integer *n, integer *nrhs, 
 	doublereal *alpha, doublecomplex *dl, doublecomplex *d__, 
 	doublecomplex *du, doublecomplex *x, integer *ldx, doublereal *beta, 
 	doublecomplex *b, integer *ldb)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZLAGTM performs a matrix-vector product of the form   
-
-       B := alpha * A * X + beta * B   
-
-    where A is a tridiagonal matrix of order N, B and X are N by NRHS   
-    matrices, and alpha and beta are real scalars, each of which may be   
-    0., 1., or -1.   
-
-    Arguments   
-    =========   
-
-    TRANS   (input) CHARACTER*1   
-            Specifies the operation applied to A.   
-            = 'N':  No transpose, B := alpha * A * X + beta * B   
-            = 'T':  Transpose,    B := alpha * A**T * X + beta * B   
-            = 'C':  Conjugate transpose, B := alpha * A**H * X + beta * B   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    NRHS    (input) INTEGER   
-            The number of right hand sides, i.e., the number of columns   
-            of the matrices X and B.   
-
-    ALPHA   (input) DOUBLE PRECISION   
-            The scalar alpha.  ALPHA must be 0., 1., or -1.; otherwise,   
-            it is assumed to be 0.   
-
-    DL      (input) COMPLEX*16 array, dimension (N-1)   
-            The (n-1) sub-diagonal elements of T.   
-
-    D       (input) COMPLEX*16 array, dimension (N)   
-            The diagonal elements of T.   
-
-    DU      (input) COMPLEX*16 array, dimension (N-1)   
-            The (n-1) super-diagonal elements of T.   
-
-    X       (input) COMPLEX*16 array, dimension (LDX,NRHS)   
-            The N by NRHS matrix X.   
-    LDX     (input) INTEGER   
-            The leading dimension of the array X.  LDX >= max(N,1).   
-
-    BETA    (input) DOUBLE PRECISION   
-            The scalar beta.  BETA must be 0., 1., or -1.; otherwise,   
-            it is assumed to be 1.   
-
-    B       (input/output) COMPLEX*16 array, dimension (LDB,NRHS)   
-            On entry, the N by NRHS matrix B.   
-            On exit, B is overwritten by the matrix expression   
-            B := alpha * A * X + beta * B.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B.  LDB >= max(N,1).   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
     /* System generated locals */
     integer b_dim1, b_offset, x_dim1, x_offset, i__1, i__2, i__3, i__4, i__5, 
 	    i__6, i__7, i__8, i__9, i__10;
     doublecomplex z__1, z__2, z__3, z__4, z__5, z__6, z__7, z__8, z__9;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j;
+    integer i__, j;
     extern logical lsame_(char *, char *);
 
+
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZLAGTM performs a matrix-vector product of the form */
+
+/*     B := alpha * A * X + beta * B */
+
+/*  where A is a tridiagonal matrix of order N, B and X are N by NRHS */
+/*  matrices, and alpha and beta are real scalars, each of which may be */
+/*  0., 1., or -1. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies the operation applied to A. */
+/*          = 'N':  No transpose, B := alpha * A * X + beta * B */
+/*          = 'T':  Transpose,    B := alpha * A**T * X + beta * B */
+/*          = 'C':  Conjugate transpose, B := alpha * A**H * X + beta * B */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand sides, i.e., the number of columns */
+/*          of the matrices X and B. */
+
+/*  ALPHA   (input) DOUBLE PRECISION */
+/*          The scalar alpha.  ALPHA must be 0., 1., or -1.; otherwise, */
+/*          it is assumed to be 0. */
+
+/*  DL      (input) COMPLEX*16 array, dimension (N-1) */
+/*          The (n-1) sub-diagonal elements of T. */
+
+/*  D       (input) COMPLEX*16 array, dimension (N) */
+/*          The diagonal elements of T. */
+
+/*  DU      (input) COMPLEX*16 array, dimension (N-1) */
+/*          The (n-1) super-diagonal elements of T. */
+
+/*  X       (input) COMPLEX*16 array, dimension (LDX,NRHS) */
+/*          The N by NRHS matrix X. */
+/*  LDX     (input) INTEGER */
+/*          The leading dimension of the array X.  LDX >= max(N,1). */
+
+/*  BETA    (input) DOUBLE PRECISION */
+/*          The scalar beta.  BETA must be 0., 1., or -1.; otherwise, */
+/*          it is assumed to be 1. */
+
+/*  B       (input/output) COMPLEX*16 array, dimension (LDB,NRHS) */
+/*          On entry, the N by NRHS matrix B. */
+/*          On exit, B is overwritten by the matrix expression */
+/*          B := alpha * A * X + beta * B. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of the array B.  LDB >= max(N,1). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     --dl;
     --d__;
     --du;
