@@ -1,5 +1,13 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {0.,0.};
+static doublecomplex c_b2 = {1.,0.};
+static integer c__1 = 1;
+static integer c_n1 = -1;
+static logical c_true = TRUE_;
 
 /* Subroutine */ int zlaqr2_(logical *wantt, logical *wantz, integer *n, 
 	integer *ktop, integer *kbot, integer *nw, doublecomplex *h__, 
@@ -9,211 +17,225 @@
 	integer *ldt, integer *nv, doublecomplex *wv, integer *ldwv, 
 	doublecomplex *work, integer *lwork)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-       This subroutine is identical to ZLAQR3 except that it avoids   
-       recursion by calling ZLAHQR instead of ZLAQR4.   
-
-
-       ******************************************************************   
-       Aggressive early deflation:   
-
-       This subroutine accepts as input an upper Hessenberg matrix   
-       H and performs an unitary similarity transformation   
-       designed to detect and deflate fully converged eigenvalues from   
-       a trailing principal submatrix.  On output H has been over-   
-       written by a new Hessenberg matrix that is a perturbation of   
-       an unitary similarity transformation of H.  It is to be   
-       hoped that the final version of H has many zero subdiagonal   
-       entries.   
-
-       ******************************************************************   
-       WANTT   (input) LOGICAL   
-            If .TRUE., then the Hessenberg matrix H is fully updated   
-            so that the triangular Schur factor may be   
-            computed (in cooperation with the calling subroutine).   
-            If .FALSE., then only enough of H is updated to preserve   
-            the eigenvalues.   
-
-       WANTZ   (input) LOGICAL   
-            If .TRUE., then the unitary matrix Z is updated so   
-            so that the unitary Schur factor may be computed   
-            (in cooperation with the calling subroutine).   
-            If .FALSE., then Z is not referenced.   
-
-       N       (input) INTEGER   
-            The order of the matrix H and (if WANTZ is .TRUE.) the   
-            order of the unitary matrix Z.   
-
-       KTOP    (input) INTEGER   
-            It is assumed that either KTOP = 1 or H(KTOP,KTOP-1)=0.   
-            KBOT and KTOP together determine an isolated block   
-            along the diagonal of the Hessenberg matrix.   
-
-       KBOT    (input) INTEGER   
-            It is assumed without a check that either   
-            KBOT = N or H(KBOT+1,KBOT)=0.  KBOT and KTOP together   
-            determine an isolated block along the diagonal of the   
-            Hessenberg matrix.   
-
-       NW      (input) INTEGER   
-            Deflation window size.  1 .LE. NW .LE. (KBOT-KTOP+1).   
-
-       H       (input/output) COMPLEX*16 array, dimension (LDH,N)   
-            On input the initial N-by-N section of H stores the   
-            Hessenberg matrix undergoing aggressive early deflation.   
-            On output H has been transformed by a unitary   
-            similarity transformation, perturbed, and the returned   
-            to Hessenberg form that (it is to be hoped) has some   
-            zero subdiagonal entries.   
-
-       LDH     (input) integer   
-            Leading dimension of H just as declared in the calling   
-            subroutine.  N .LE. LDH   
-
-       ILOZ    (input) INTEGER   
-       IHIZ    (input) INTEGER   
-            Specify the rows of Z to which transformations must be   
-            applied if WANTZ is .TRUE.. 1 .LE. ILOZ .LE. IHIZ .LE. N.   
-
-       Z       (input/output) COMPLEX*16 array, dimension (LDZ,IHI)   
-            IF WANTZ is .TRUE., then on output, the unitary   
-            similarity transformation mentioned above has been   
-            accumulated into Z(ILOZ:IHIZ,ILO:IHI) from the right.   
-            If WANTZ is .FALSE., then Z is unreferenced.   
-
-       LDZ     (input) integer   
-            The leading dimension of Z just as declared in the   
-            calling subroutine.  1 .LE. LDZ.   
-
-       NS      (output) integer   
-            The number of unconverged (ie approximate) eigenvalues   
-            returned in SR and SI that may be used as shifts by the   
-            calling subroutine.   
-
-       ND      (output) integer   
-            The number of converged eigenvalues uncovered by this   
-            subroutine.   
-
-       SH      (output) COMPLEX*16 array, dimension KBOT   
-            On output, approximate eigenvalues that may   
-            be used for shifts are stored in SH(KBOT-ND-NS+1)   
-            through SR(KBOT-ND).  Converged eigenvalues are   
-            stored in SH(KBOT-ND+1) through SH(KBOT).   
-
-       V       (workspace) COMPLEX*16 array, dimension (LDV,NW)   
-            An NW-by-NW work array.   
-
-       LDV     (input) integer scalar   
-            The leading dimension of V just as declared in the   
-            calling subroutine.  NW .LE. LDV   
-
-       NH      (input) integer scalar   
-            The number of columns of T.  NH.GE.NW.   
-
-       T       (workspace) COMPLEX*16 array, dimension (LDT,NW)   
-
-       LDT     (input) integer   
-            The leading dimension of T just as declared in the   
-            calling subroutine.  NW .LE. LDT   
-
-       NV      (input) integer   
-            The number of rows of work array WV available for   
-            workspace.  NV.GE.NW.   
-
-       WV      (workspace) COMPLEX*16 array, dimension (LDWV,NW)   
-
-       LDWV    (input) integer   
-            The leading dimension of W just as declared in the   
-            calling subroutine.  NW .LE. LDV   
-
-       WORK    (workspace) COMPLEX*16 array, dimension LWORK.   
-            On exit, WORK(1) is set to an estimate of the optimal value   
-            of LWORK for the given values of N, NW, KTOP and KBOT.   
-
-       LWORK   (input) integer   
-            The dimension of the work array WORK.  LWORK = 2*NW   
-            suffices, but greater efficiency may result from larger   
-            values of LWORK.   
-
-            If LWORK = -1, then a workspace query is assumed; ZLAQR2   
-            only estimates the optimal workspace size for the given   
-            values of N, NW, KTOP and KBOT.  The estimate is returned   
-            in WORK(1).  No error message related to LWORK is issued   
-            by XERBLA.  Neither H nor Z are accessed.   
-
-       ================================================================   
-       Based on contributions by   
-          Karen Braman and Ralph Byers, Department of Mathematics,   
-          University of Kansas, USA   
-
-       ==================================================================   
-
-       ==== Estimate optimal workspace. ====   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {0.,0.};
-    static doublecomplex c_b2 = {1.,0.};
-    static integer c__1 = 1;
-    static integer c_n1 = -1;
-    static logical c_true = TRUE_;
-    
     /* System generated locals */
     integer h_dim1, h_offset, t_dim1, t_offset, v_dim1, v_offset, wv_dim1, 
 	    wv_offset, z_dim1, z_offset, i__1, i__2, i__3, i__4;
     doublereal d__1, d__2, d__3, d__4, d__5, d__6;
     doublecomplex z__1, z__2;
+
     /* Builtin functions */
     double d_imag(doublecomplex *);
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j;
-    static doublecomplex s;
-    static integer jw;
-    static doublereal foo;
-    static integer kln;
-    static doublecomplex tau;
-    static integer knt;
-    static doublereal ulp;
-    static integer lwk1, lwk2;
-    static doublecomplex beta;
-    static integer kcol, info, ifst, ilst, ltop, krow;
+    integer i__, j;
+    doublecomplex s;
+    integer jw;
+    doublereal foo;
+    integer kln;
+    doublecomplex tau;
+    integer knt;
+    doublereal ulp;
+    integer lwk1, lwk2;
+    doublecomplex beta;
+    integer kcol, info, ifst, ilst, ltop, krow;
     extern /* Subroutine */ int zlarf_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *);
-    static integer infqr;
+    integer infqr;
     extern /* Subroutine */ int zgemm_(char *, char *, integer *, integer *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *);
-    static integer kwtop;
+    integer kwtop;
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
-    static doublereal safmin, safmax;
+    doublereal safmin, safmax;
     extern /* Subroutine */ int zgehrd_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, integer *), zlarfg_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *), zlahqr_(logical *, 
 	    logical *, integer *, integer *, integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, integer *, doublecomplex *,
+	    integer *, doublecomplex *, integer *, integer *, doublecomplex *, 
 	     integer *, integer *), zlacpy_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), 
 	    zlaset_(char *, integer *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, integer *);
-    static doublereal smlnum;
+    doublereal smlnum;
     extern /* Subroutine */ int zunghr_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
-	    integer *, integer *), ztrexc_(char *, integer *, doublecomplex *,
+	    integer *, integer *), ztrexc_(char *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, integer *, integer *, integer *, 
 	    integer *);
-    static integer lwkopt;
+    integer lwkopt;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*     This subroutine is identical to ZLAQR3 except that it avoids */
+/*     recursion by calling ZLAHQR instead of ZLAQR4. */
+
+
+/*     ****************************************************************** */
+/*     Aggressive early deflation: */
+
+/*     This subroutine accepts as input an upper Hessenberg matrix */
+/*     H and performs an unitary similarity transformation */
+/*     designed to detect and deflate fully converged eigenvalues from */
+/*     a trailing principal submatrix.  On output H has been over- */
+/*     written by a new Hessenberg matrix that is a perturbation of */
+/*     an unitary similarity transformation of H.  It is to be */
+/*     hoped that the final version of H has many zero subdiagonal */
+/*     entries. */
+
+/*     ****************************************************************** */
+/*     WANTT   (input) LOGICAL */
+/*          If .TRUE., then the Hessenberg matrix H is fully updated */
+/*          so that the triangular Schur factor may be */
+/*          computed (in cooperation with the calling subroutine). */
+/*          If .FALSE., then only enough of H is updated to preserve */
+/*          the eigenvalues. */
+
+/*     WANTZ   (input) LOGICAL */
+/*          If .TRUE., then the unitary matrix Z is updated so */
+/*          so that the unitary Schur factor may be computed */
+/*          (in cooperation with the calling subroutine). */
+/*          If .FALSE., then Z is not referenced. */
+
+/*     N       (input) INTEGER */
+/*          The order of the matrix H and (if WANTZ is .TRUE.) the */
+/*          order of the unitary matrix Z. */
+
+/*     KTOP    (input) INTEGER */
+/*          It is assumed that either KTOP = 1 or H(KTOP,KTOP-1)=0. */
+/*          KBOT and KTOP together determine an isolated block */
+/*          along the diagonal of the Hessenberg matrix. */
+
+/*     KBOT    (input) INTEGER */
+/*          It is assumed without a check that either */
+/*          KBOT = N or H(KBOT+1,KBOT)=0.  KBOT and KTOP together */
+/*          determine an isolated block along the diagonal of the */
+/*          Hessenberg matrix. */
+
+/*     NW      (input) INTEGER */
+/*          Deflation window size.  1 .LE. NW .LE. (KBOT-KTOP+1). */
+
+/*     H       (input/output) COMPLEX*16 array, dimension (LDH,N) */
+/*          On input the initial N-by-N section of H stores the */
+/*          Hessenberg matrix undergoing aggressive early deflation. */
+/*          On output H has been transformed by a unitary */
+/*          similarity transformation, perturbed, and the returned */
+/*          to Hessenberg form that (it is to be hoped) has some */
+/*          zero subdiagonal entries. */
+
+/*     LDH     (input) integer */
+/*          Leading dimension of H just as declared in the calling */
+/*          subroutine.  N .LE. LDH */
+
+/*     ILOZ    (input) INTEGER */
+/*     IHIZ    (input) INTEGER */
+/*          Specify the rows of Z to which transformations must be */
+/*          applied if WANTZ is .TRUE.. 1 .LE. ILOZ .LE. IHIZ .LE. N. */
+
+/*     Z       (input/output) COMPLEX*16 array, dimension (LDZ,IHI) */
+/*          IF WANTZ is .TRUE., then on output, the unitary */
+/*          similarity transformation mentioned above has been */
+/*          accumulated into Z(ILOZ:IHIZ,ILO:IHI) from the right. */
+/*          If WANTZ is .FALSE., then Z is unreferenced. */
+
+/*     LDZ     (input) integer */
+/*          The leading dimension of Z just as declared in the */
+/*          calling subroutine.  1 .LE. LDZ. */
+
+/*     NS      (output) integer */
+/*          The number of unconverged (ie approximate) eigenvalues */
+/*          returned in SR and SI that may be used as shifts by the */
+/*          calling subroutine. */
+
+/*     ND      (output) integer */
+/*          The number of converged eigenvalues uncovered by this */
+/*          subroutine. */
+
+/*     SH      (output) COMPLEX*16 array, dimension KBOT */
+/*          On output, approximate eigenvalues that may */
+/*          be used for shifts are stored in SH(KBOT-ND-NS+1) */
+/*          through SR(KBOT-ND).  Converged eigenvalues are */
+/*          stored in SH(KBOT-ND+1) through SH(KBOT). */
+
+/*     V       (workspace) COMPLEX*16 array, dimension (LDV,NW) */
+/*          An NW-by-NW work array. */
+
+/*     LDV     (input) integer scalar */
+/*          The leading dimension of V just as declared in the */
+/*          calling subroutine.  NW .LE. LDV */
+
+/*     NH      (input) integer scalar */
+/*          The number of columns of T.  NH.GE.NW. */
+
+/*     T       (workspace) COMPLEX*16 array, dimension (LDT,NW) */
+
+/*     LDT     (input) integer */
+/*          The leading dimension of T just as declared in the */
+/*          calling subroutine.  NW .LE. LDT */
+
+/*     NV      (input) integer */
+/*          The number of rows of work array WV available for */
+/*          workspace.  NV.GE.NW. */
+
+/*     WV      (workspace) COMPLEX*16 array, dimension (LDWV,NW) */
+
+/*     LDWV    (input) integer */
+/*          The leading dimension of W just as declared in the */
+/*          calling subroutine.  NW .LE. LDV */
+
+/*     WORK    (workspace) COMPLEX*16 array, dimension LWORK. */
+/*          On exit, WORK(1) is set to an estimate of the optimal value */
+/*          of LWORK for the given values of N, NW, KTOP and KBOT. */
+
+/*     LWORK   (input) integer */
+/*          The dimension of the work array WORK.  LWORK = 2*NW */
+/*          suffices, but greater efficiency may result from larger */
+/*          values of LWORK. */
+
+/*          If LWORK = -1, then a workspace query is assumed; ZLAQR2 */
+/*          only estimates the optimal workspace size for the given */
+/*          values of N, NW, KTOP and KBOT.  The estimate is returned */
+/*          in WORK(1).  No error message related to LWORK is issued */
+/*          by XERBLA.  Neither H nor Z are accessed. */
+
+/*     ================================================================ */
+/*     Based on contributions by */
+/*        Karen Braman and Ralph Byers, Department of Mathematics, */
+/*        University of Kansas, USA */
+
+/*     ================================================================== */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     ==== Estimate optimal workspace. ==== */
+
+    /* Parameter adjustments */
     h_dim1 = *ldh;
     h_offset = 1 + h_dim1;
     h__ -= h_offset;
@@ -232,8 +254,8 @@
     wv -= wv_offset;
     --work;
 
-    /* Function Body   
-   Computing MIN */
+    /* Function Body */
+/* Computing MIN */
     i__1 = *nw, i__2 = *kbot - *ktop + 1;
     jw = min(i__1,i__2);
     if (jw <= 2) {
@@ -268,8 +290,8 @@
 	return 0;
     }
 
-/*     ==== Nothing to do ...   
-       ... for an empty active block ... ==== */
+/*     ==== Nothing to do ... */
+/*     ... for an empty active block ... ==== */
     *ns = 0;
     *nd = 0;
     if (*ktop > *kbot) {
@@ -288,9 +310,9 @@
     ulp = dlamch_("PRECISION");
     smlnum = safmin * ((doublereal) (*n) / ulp);
 
-/*     ==== Setup deflation window ====   
+/*     ==== Setup deflation window ==== */
 
-   Computing MIN */
+/* Computing MIN */
     i__1 = *nw, i__2 = *kbot - *ktop + 1;
     jw = min(i__1,i__2);
     kwtop = *kbot - jw + 1;
@@ -326,11 +348,11 @@
 	return 0;
     }
 
-/*     ==== Convert to spike-triangular form.  (In case of a   
-       .    rare QR failure, this routine continues to do   
-       .    aggressive early deflation using that part of   
-       .    the deflation window that converged using INFQR   
-       .    here and there to keep track.) ==== */
+/*     ==== Convert to spike-triangular form.  (In case of a */
+/*     .    rare QR failure, this routine continues to do */
+/*     .    aggressive early deflation using that part of */
+/*     .    the deflation window that converged using INFQR */
+/*     .    here and there to keep track.) ==== */
 
     zlacpy_("U", &jw, &jw, &h__[kwtop + kwtop * h_dim1], ldh, &t[t_offset], 
 	    ldt);
@@ -371,8 +393,8 @@
 	    --(*ns);
 	} else {
 
-/*           ==== One undflatable eigenvalue.  Move it up out of the   
-             .    way.   (ZTREXC can not fail in this case.) ==== */
+/*           ==== One undflatable eigenvalue.  Move it up out of the */
+/*           .    way.   (ZTREXC can not fail in this case.) ==== */
 
 	    ifst = *ns;
 	    ztrexc_("V", &jw, &t[t_offset], ldt, &v[v_offset], ldv, &ifst, &
@@ -390,8 +412,8 @@
 
     if (*ns < jw) {
 
-/*        ==== sorting the diagonal of T improves accuracy for   
-          .    graded matrices.  ==== */
+/*        ==== sorting the diagonal of T improves accuracy for */
+/*        .    graded matrices.  ==== */
 
 	i__1 = *ns;
 	for (i__ = infqr + 1; i__ <= i__1; ++i__) {
@@ -402,14 +424,15 @@
 		i__4 = ifst + ifst * t_dim1;
 		if ((d__1 = t[i__3].r, abs(d__1)) + (d__2 = d_imag(&t[j + j * 
 			t_dim1]), abs(d__2)) > (d__3 = t[i__4].r, abs(d__3)) 
-			+ (d__4 = d_imag(&t[ifst + ifst * t_dim1]), abs(d__4)) 			) {
+			+ (d__4 = d_imag(&t[ifst + ifst * t_dim1]), abs(d__4))
+			) {
 		    ifst = j;
 		}
 /* L20: */
 	    }
 	    ilst = i__;
 	    if (ifst != ilst) {
-		ztrexc_("V", &jw, &t[t_offset], ldt, &v[v_offset], ldv, &ifst,
+		ztrexc_("V", &jw, &t[t_offset], ldt, &v[v_offset], ldv, &ifst, 
 			 &ilst, &info);
 	    }
 /* L30: */
@@ -458,7 +481,7 @@
 
 	    i__1 = *lwork - jw;
 	    zgehrd_(&jw, &c__1, ns, &t[t_offset], ldt, &work[1], &work[jw + 1]
-		    , &i__1, &info);
+, &i__1, &info);
 	}
 
 /*        ==== Copy updated reduced window into place ==== */
@@ -471,23 +494,23 @@
 	    h__[i__1].r = z__1.r, h__[i__1].i = z__1.i;
 	}
 	zlacpy_("U", &jw, &jw, &t[t_offset], ldt, &h__[kwtop + kwtop * h_dim1]
-		, ldh);
+, ldh);
 	i__1 = jw - 1;
 	i__2 = *ldt + 1;
 	i__3 = *ldh + 1;
 	zcopy_(&i__1, &t[t_dim1 + 2], &i__2, &h__[kwtop + 1 + kwtop * h_dim1], 
 		 &i__3);
 
-/*        ==== Accumulate orthogonal matrix in order update   
-          .    H and Z, if requested.  (A modified version   
-          .    of  ZUNGHR that accumulates block Householder   
-          .    transformations into V directly might be   
-          .    marginally more efficient than the following.) ==== */
+/*        ==== Accumulate orthogonal matrix in order update */
+/*        .    H and Z, if requested.  (A modified version */
+/*        .    of  ZUNGHR that accumulates block Householder */
+/*        .    transformations into V directly might be */
+/*        .    marginally more efficient than the following.) ==== */
 
 	if (*ns > 1 && (s.r != 0. || s.i != 0.)) {
 	    i__1 = *lwork - jw;
 	    zunghr_(&jw, &c__1, ns, &t[t_offset], ldt, &work[1], &work[jw + 1]
-		    , &i__1, &info);
+, &i__1, &info);
 	    zgemm_("N", "N", &jw, ns, ns, &c_b2, &v[v_offset], ldv, &t[
 		    t_offset], ldt, &c_b1, &wv[wv_offset], ldwv);
 	    zlacpy_("A", &jw, ns, &wv[wv_offset], ldwv, &v[v_offset], ldv);
@@ -558,11 +581,11 @@
 
     *nd = jw - *ns;
 
-/*     ==== ... and the number of shifts. (Subtracting   
-       .    INFQR from the spike length takes care   
-       .    of the case of a rare QR failure while   
-       .    calculating eigenvalues of the deflation   
-       .    window.)  ==== */
+/*     ==== ... and the number of shifts. (Subtracting */
+/*     .    INFQR from the spike length takes care */
+/*     .    of the case of a rare QR failure while */
+/*     .    calculating eigenvalues of the deflation */
+/*     .    window.)  ==== */
 
     *ns -= infqr;
 
