@@ -1,106 +1,26 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {1.,0.};
+static integer c__1 = 1;
 
 /* Subroutine */ int zlarfb_(char *side, char *trans, char *direct, char *
 	storev, integer *m, integer *n, integer *k, doublecomplex *v, integer 
 	*ldv, doublecomplex *t, integer *ldt, doublecomplex *c__, integer *
-	ldc, doublecomplex *work, integer *ldwork  	)
+	ldc, doublecomplex *work, integer *ldwork)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZLARFB applies a complex block reflector H or its transpose H' to a   
-    complex M-by-N matrix C, from either the left or the right.   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'L': apply H or H' from the Left   
-            = 'R': apply H or H' from the Right   
-
-    TRANS   (input) CHARACTER*1   
-            = 'N': apply H (No transpose)   
-            = 'C': apply H' (Conjugate transpose)   
-
-    DIRECT  (input) CHARACTER*1   
-            Indicates how H is formed from a product of elementary   
-            reflectors   
-            = 'F': H = H(1) H(2) . . . H(k) (Forward)   
-            = 'B': H = H(k) . . . H(2) H(1) (Backward)   
-
-    STOREV  (input) CHARACTER*1   
-            Indicates how the vectors which define the elementary   
-            reflectors are stored:   
-            = 'C': Columnwise   
-            = 'R': Rowwise   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix C.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix C.   
-
-    K       (input) INTEGER   
-            The order of the matrix T (= the number of elementary   
-            reflectors whose product defines the block reflector).   
-
-    V       (input) COMPLEX*16 array, dimension   
-                                  (LDV,K) if STOREV = 'C'   
-                                  (LDV,M) if STOREV = 'R' and SIDE = 'L'   
-                                  (LDV,N) if STOREV = 'R' and SIDE = 'R'   
-            The matrix V. See further details.   
-
-    LDV     (input) INTEGER   
-            The leading dimension of the array V.   
-            If STOREV = 'C' and SIDE = 'L', LDV >= max(1,M);   
-            if STOREV = 'C' and SIDE = 'R', LDV >= max(1,N);   
-            if STOREV = 'R', LDV >= K.   
-
-    T       (input) COMPLEX*16 array, dimension (LDT,K)   
-            The triangular K-by-K matrix T in the representation of the   
-            block reflector.   
-
-    LDT     (input) INTEGER   
-            The leading dimension of the array T. LDT >= K.   
-
-    C       (input/output) COMPLEX*16 array, dimension (LDC,N)   
-            On entry, the M-by-N matrix C.   
-            On exit, C is overwritten by H*C or H'*C or C*H or C*H'.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C. LDC >= max(1,M).   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (LDWORK,K)   
-
-    LDWORK  (input) INTEGER   
-            The leading dimension of the array WORK.   
-            If SIDE = 'L', LDWORK >= max(1,N);   
-            if SIDE = 'R', LDWORK >= max(1,M).   
-
-    =====================================================================   
-
-
-       Quick return if possible   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {1.,0.};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer c_dim1, c_offset, t_dim1, t_offset, v_dim1, v_offset, work_dim1, 
 	    work_offset, i__1, i__2, i__3, i__4, i__5;
     doublecomplex z__1, z__2;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j;
+    integer i__, j;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int zgemm_(char *, char *, integer *, integer *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *, 
@@ -110,9 +30,107 @@
 	    char *, char *, integer *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), zlacgv_(integer *, doublecomplex *, 
 	    integer *);
-    static char transt[1];
+    char transt[1];
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZLARFB applies a complex block reflector H or its transpose H' to a */
+/*  complex M-by-N matrix C, from either the left or the right. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'L': apply H or H' from the Left */
+/*          = 'R': apply H or H' from the Right */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          = 'N': apply H (No transpose) */
+/*          = 'C': apply H' (Conjugate transpose) */
+
+/*  DIRECT  (input) CHARACTER*1 */
+/*          Indicates how H is formed from a product of elementary */
+/*          reflectors */
+/*          = 'F': H = H(1) H(2) . . . H(k) (Forward) */
+/*          = 'B': H = H(k) . . . H(2) H(1) (Backward) */
+
+/*  STOREV  (input) CHARACTER*1 */
+/*          Indicates how the vectors which define the elementary */
+/*          reflectors are stored: */
+/*          = 'C': Columnwise */
+/*          = 'R': Rowwise */
+
+/*  M       (input) INTEGER */
+/*          The number of rows of the matrix C. */
+
+/*  N       (input) INTEGER */
+/*          The number of columns of the matrix C. */
+
+/*  K       (input) INTEGER */
+/*          The order of the matrix T (= the number of elementary */
+/*          reflectors whose product defines the block reflector). */
+
+/*  V       (input) COMPLEX*16 array, dimension */
+/*                                (LDV,K) if STOREV = 'C' */
+/*                                (LDV,M) if STOREV = 'R' and SIDE = 'L' */
+/*                                (LDV,N) if STOREV = 'R' and SIDE = 'R' */
+/*          The matrix V. See further details. */
+
+/*  LDV     (input) INTEGER */
+/*          The leading dimension of the array V. */
+/*          If STOREV = 'C' and SIDE = 'L', LDV >= max(1,M); */
+/*          if STOREV = 'C' and SIDE = 'R', LDV >= max(1,N); */
+/*          if STOREV = 'R', LDV >= K. */
+
+/*  T       (input) COMPLEX*16 array, dimension (LDT,K) */
+/*          The triangular K-by-K matrix T in the representation of the */
+/*          block reflector. */
+
+/*  LDT     (input) INTEGER */
+/*          The leading dimension of the array T. LDT >= K. */
+
+/*  C       (input/output) COMPLEX*16 array, dimension (LDC,N) */
+/*          On entry, the M-by-N matrix C. */
+/*          On exit, C is overwritten by H*C or H'*C or C*H or C*H'. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. LDC >= max(1,M). */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (LDWORK,K) */
+
+/*  LDWORK  (input) INTEGER */
+/*          The leading dimension of the array WORK. */
+/*          If SIDE = 'L', LDWORK >= max(1,N); */
+/*          if SIDE = 'R', LDWORK >= max(1,M). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Quick return if possible */
+
+    /* Parameter adjustments */
     v_dim1 = *ldv;
     v_offset = 1 + v_dim1;
     v -= v_offset;
@@ -141,18 +159,18 @@
 
 	if (lsame_(direct, "F")) {
 
-/*           Let  V =  ( V1 )    (first K rows)   
-                       ( V2 )   
-             where  V1  is unit lower triangular. */
+/*           Let  V =  ( V1 )    (first K rows) */
+/*                     ( V2 ) */
+/*           where  V1  is unit lower triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK)   
+/*              W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK) */
 
-                W := C1' */
+/*              W := C1' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -219,11 +237,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK)   
+/*              W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK) */
 
-                W := C1 */
+/*              W := C1 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -290,18 +308,18 @@
 
 	} else {
 
-/*           Let  V =  ( V1 )   
-                       ( V2 )    (last K rows)   
-             where  V2  is unit upper triangular. */
+/*           Let  V =  ( V1 ) */
+/*                     ( V2 )    (last K rows) */
+/*           where  V2  is unit upper triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK)   
+/*              W := C' * V  =  (C1'*V1 + C2'*V2)  (stored in WORK) */
 
-                W := C2' */
+/*              W := C2' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -369,11 +387,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK)   
+/*              W := C * V  =  (C1*V1 + C2*V2)  (stored in WORK) */
 
-                W := C2 */
+/*              W := C2 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -445,17 +463,17 @@
 
 	if (lsame_(direct, "F")) {
 
-/*           Let  V =  ( V1  V2 )    (V1: first K columns)   
-             where  V1  is unit upper triangular. */
+/*           Let  V =  ( V1  V2 )    (V1: first K columns) */
+/*           where  V1  is unit upper triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK)   
+/*              W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK) */
 
-                W := C1' */
+/*              W := C1' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -523,11 +541,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK)   
+/*              W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK) */
 
-                W := C1 */
+/*              W := C1 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -596,17 +614,17 @@
 
 	} else {
 
-/*           Let  V =  ( V1  V2 )    (V2: last K columns)   
-             where  V2  is unit lower triangular. */
+/*           Let  V =  ( V1  V2 )    (V2: last K columns) */
+/*           where  V2  is unit lower triangular. */
 
 	    if (lsame_(side, "L")) {
 
-/*              Form  H * C  or  H' * C  where  C = ( C1 )   
-                                                    ( C2 )   
+/*              Form  H * C  or  H' * C  where  C = ( C1 ) */
+/*                                                  ( C2 ) */
 
-                W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK)   
+/*              W := C' * V'  =  (C1'*V1' + C2'*V2') (stored in WORK) */
 
-                W := C2' */
+/*              W := C2' */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
@@ -674,11 +692,11 @@
 
 	    } else if (lsame_(side, "R")) {
 
-/*              Form  C * H  or  C * H'  where  C = ( C1  C2 )   
+/*              Form  C * H  or  C * H'  where  C = ( C1  C2 ) */
 
-                W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK)   
+/*              W := C * V'  =  (C1*V1' + C2*V2')  (stored in WORK) */
 
-                W := C2 */
+/*              W := C2 */
 
 		i__1 = *k;
 		for (j = 1; j <= i__1; ++j) {
