@@ -1,82 +1,29 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {0.,0.};
+static doublecomplex c_b2 = {1.,0.};
+static integer c__1 = 1;
 
 /* Subroutine */ int zlarfx_(char *side, integer *m, integer *n, 
 	doublecomplex *v, doublecomplex *tau, doublecomplex *c__, integer *
 	ldc, doublecomplex *work)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZLARFX applies a complex elementary reflector H to a complex m by n   
-    matrix C, from either the left or the right. H is represented in the   
-    form   
-
-          H = I - tau * v * v'   
-
-    where tau is a complex scalar and v is a complex vector.   
-
-    If tau = 0, then H is taken to be the unit matrix   
-
-    This version uses inline code if H has order < 11.   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'L': form  H * C   
-            = 'R': form  C * H   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix C.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix C.   
-
-    V       (input) COMPLEX*16 array, dimension (M) if SIDE = 'L'   
-                                          or (N) if SIDE = 'R'   
-            The vector v in the representation of H.   
-
-    TAU     (input) COMPLEX*16   
-            The value tau in the representation of H.   
-
-    C       (input/output) COMPLEX*16 array, dimension (LDC,N)   
-            On entry, the m by n matrix C.   
-            On exit, C is overwritten by the matrix H * C if SIDE = 'L',   
-            or C * H if SIDE = 'R'.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of the array C. LDA >= max(1,M).   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (N) if SIDE = 'L'   
-                                              or (M) if SIDE = 'R'   
-            WORK is not referenced if H has order < 11.   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {0.,0.};
-    static doublecomplex c_b2 = {1.,0.};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer c_dim1, c_offset, i__1, i__2, i__3, i__4, i__5, i__6, i__7, i__8, 
 	    i__9, i__10, i__11;
     doublecomplex z__1, z__2, z__3, z__4, z__5, z__6, z__7, z__8, z__9, z__10,
 	     z__11, z__12, z__13, z__14, z__15, z__16, z__17, z__18, z__19;
+
     /* Builtin functions */
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer j;
-    static doublecomplex t1, t2, t3, t4, t5, t6, t7, t8, t9, v1, v2, v3, v4, 
-	    v5, v6, v7, v8, v9, t10, v10, sum;
+    integer j;
+    doublecomplex t1, t2, t3, t4, t5, t6, t7, t8, t9, v1, v2, v3, v4, v5, v6, 
+	    v7, v8, v9, t10, v10, sum;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int zgerc_(integer *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
@@ -85,6 +32,77 @@
 	    integer *, doublecomplex *, doublecomplex *, integer *);
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZLARFX applies a complex elementary reflector H to a complex m by n */
+/*  matrix C, from either the left or the right. H is represented in the */
+/*  form */
+
+/*        H = I - tau * v * v' */
+
+/*  where tau is a complex scalar and v is a complex vector. */
+
+/*  If tau = 0, then H is taken to be the unit matrix */
+
+/*  This version uses inline code if H has order < 11. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'L': form  H * C */
+/*          = 'R': form  C * H */
+
+/*  M       (input) INTEGER */
+/*          The number of rows of the matrix C. */
+
+/*  N       (input) INTEGER */
+/*          The number of columns of the matrix C. */
+
+/*  V       (input) COMPLEX*16 array, dimension (M) if SIDE = 'L' */
+/*                                        or (N) if SIDE = 'R' */
+/*          The vector v in the representation of H. */
+
+/*  TAU     (input) COMPLEX*16 */
+/*          The value tau in the representation of H. */
+
+/*  C       (input/output) COMPLEX*16 array, dimension (LDC,N) */
+/*          On entry, the m by n matrix C. */
+/*          On exit, C is overwritten by the matrix H * C if SIDE = 'L', */
+/*          or C * H if SIDE = 'R'. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of the array C. LDA >= max(1,M). */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (N) if SIDE = 'L' */
+/*                                            or (M) if SIDE = 'R' */
+/*          WORK is not referenced if H has order < 11. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     --v;
     c_dim1 = *ldc;
     c_offset = 1 + c_dim1;
@@ -112,9 +130,9 @@
 	    case 10:  goto L190;
 	}
 
-/*        Code for general M   
+/*        Code for general M */
 
-          w := C'*v */
+/*        w := C'*v */
 
 	zgemv_("Conjugate transpose", m, n, &c_b2, &c__[c_offset], ldc, &v[1], 
 		 &c__1, &c_b1, &work[1], &c__1);
@@ -1108,9 +1126,9 @@ L190:
 	    case 10:  goto L390;
 	}
 
-/*        Code for general N   
+/*        Code for general N */
 
-          w := C * v */
+/*        w := C * v */
 
 	zgemv_("No transpose", m, n, &c_b2, &c__[c_offset], ldc, &v[1], &c__1, 
 		 &c_b1, &work[1], &c__1);
