@@ -1,196 +1,43 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static integer c__1 = 1;
+static doublereal c_b36 = .5;
 
 /* Subroutine */ int zlatps_(char *uplo, char *trans, char *diag, char *
 	normin, integer *n, doublecomplex *ap, doublecomplex *x, doublereal *
-	scale, doublereal *cnorm, integer *info  	)
+	scale, doublereal *cnorm, integer *info)
 {
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-    Purpose   
-    =======   
-
-    ZLATPS solves one of the triangular systems   
-
-       A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b,   
-
-    with scaling to prevent overflow, where A is an upper or lower   
-    triangular matrix stored in packed form.  Here A**T denotes the   
-    transpose of A, A**H denotes the conjugate transpose of A, x and b   
-    are n-element vectors, and s is a scaling factor, usually less than   
-    or equal to 1, chosen so that the components of x will be less than   
-    the overflow threshold.  If the unscaled problem will not cause   
-    overflow, the Level 2 BLAS routine ZTPSV is called. If the matrix A   
-    is singular (A(j,j) = 0 for some j), then s is set to 0 and a   
-    non-trivial solution to A*x = 0 is returned.   
-
-    Arguments   
-    =========   
-
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A is upper or lower triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
-
-    TRANS   (input) CHARACTER*1   
-            Specifies the operation applied to A.   
-            = 'N':  Solve A * x = s*b     (No transpose)   
-            = 'T':  Solve A**T * x = s*b  (Transpose)   
-            = 'C':  Solve A**H * x = s*b  (Conjugate transpose)   
-
-    DIAG    (input) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
-
-    NORMIN  (input) CHARACTER*1   
-            Specifies whether CNORM has been set or not.   
-            = 'Y':  CNORM contains the column norms on entry   
-            = 'N':  CNORM is not set on entry.  On exit, the norms will   
-                    be computed and stored in CNORM.   
-
-    N       (input) INTEGER   
-            The order of the matrix A.  N >= 0.   
-
-    AP      (input) COMPLEX*16 array, dimension (N*(N+1)/2)   
-            The upper or lower triangular matrix A, packed columnwise in   
-            a linear array.  The j-th column of A is stored in the array   
-            AP as follows:   
-            if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;   
-            if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.   
-
-    X       (input/output) COMPLEX*16 array, dimension (N)   
-            On entry, the right hand side b of the triangular system.   
-            On exit, X is overwritten by the solution vector x.   
-
-    SCALE   (output) DOUBLE PRECISION   
-            The scaling factor s for the triangular system   
-               A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b.   
-            If SCALE = 0, the matrix A is singular or badly scaled, and   
-            the vector x is an exact or approximate solution to A*x = 0.   
-
-    CNORM   (input or output) DOUBLE PRECISION array, dimension (N)   
-
-            If NORMIN = 'Y', CNORM is an input argument and CNORM(j)   
-            contains the norm of the off-diagonal part of the j-th column   
-            of A.  If TRANS = 'N', CNORM(j) must be greater than or equal   
-            to the infinity-norm, and if TRANS = 'T' or 'C', CNORM(j)   
-            must be greater than or equal to the 1-norm.   
-
-            If NORMIN = 'N', CNORM is an output argument and CNORM(j)   
-            returns the 1-norm of the offdiagonal part of the j-th column   
-            of A.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -k, the k-th argument had an illegal value   
-
-    Further Details   
-    ======= =======   
-
-    A rough bound on x is computed; if that is less than overflow, ZTPSV   
-    is called, otherwise, specific code is used which checks for possible   
-    overflow or divide-by-zero at every operation.   
-
-    A columnwise scheme is used for solving A*x = b.  The basic algorithm   
-    if A is lower triangular is   
-
-         x[1:n] := b[1:n]   
-         for j = 1, ..., n   
-              x(j) := x(j) / A(j,j)   
-              x[j+1:n] := x[j+1:n] - x(j) * A[j+1:n,j]   
-         end   
-
-    Define bounds on the components of x after j iterations of the loop:   
-       M(j) = bound on x[1:j]   
-       G(j) = bound on x[j+1:n]   
-    Initially, let M(0) = 0 and G(0) = max{x(i), i=1,...,n}.   
-
-    Then for iteration j+1 we have   
-       M(j+1) <= G(j) / | A(j+1,j+1) |   
-       G(j+1) <= G(j) + M(j+1) * | A[j+2:n,j+1] |   
-              <= G(j) ( 1 + CNORM(j+1) / | A(j+1,j+1) | )   
-
-    where CNORM(j+1) is greater than or equal to the infinity-norm of   
-    column j+1 of A, not counting the diagonal.  Hence   
-
-       G(j) <= G(0) product ( 1 + CNORM(i) / | A(i,i) | )   
-                    1<=i<=j   
-    and   
-
-       |x(j)| <= ( G(0) / |A(j,j)| ) product ( 1 + CNORM(i) / |A(i,i)| )   
-                                     1<=i< j   
-
-    Since |x(j)| <= M(j), we use the Level 2 BLAS routine ZTPSV if the   
-    reciprocal of the largest M(j), j=1,..,n, is larger than   
-    max(underflow, 1/overflow).   
-
-    The bound on x(j) is also used to determine when a step in the   
-    columnwise method can be performed without fear of overflow.  If   
-    the computed bound is greater than a large constant, x is scaled to   
-    prevent overflow, but if the bound overflows, x is set to 0, x(j) to   
-    1, and scale to 0, and a non-trivial solution to A*x = 0 is found.   
-
-    Similarly, a row-wise scheme is used to solve A**T *x = b  or   
-    A**H *x = b.  The basic algorithm for A upper triangular is   
-
-         for j = 1, ..., n   
-              x(j) := ( b(j) - A[1:j-1,j]' * x[1:j-1] ) / A(j,j)   
-         end   
-
-    We simultaneously compute two bounds   
-         G(j) = bound on ( b(i) - A[1:i-1,i]' * x[1:i-1] ), 1<=i<=j   
-         M(j) = bound on x(i), 1<=i<=j   
-
-    The initial values are G(0) = 0, M(0) = max{b(i), i=1,..,n}, and we   
-    add the constraint G(j) >= G(j-1) and M(j) >= M(j-1) for j >= 1.   
-    Then the bound on x(j) is   
-
-         M(j) <= M(j-1) * ( 1 + CNORM(j) ) / | A(j,j) |   
-
-              <= M(0) * product ( ( 1 + CNORM(i) ) / |A(i,i)| )   
-                        1<=i<=j   
-
-    and we can safely call ZTPSV if 1/M(n) and 1/G(n) are both greater   
-    than max(underflow, 1/overflow).   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static integer c__1 = 1;
-    static doublereal c_b36 = .5;
-    
     /* System generated locals */
     integer i__1, i__2, i__3, i__4, i__5;
     doublereal d__1, d__2, d__3, d__4;
     doublecomplex z__1, z__2, z__3, z__4;
+
     /* Builtin functions */
     double d_imag(doublecomplex *);
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static integer i__, j, ip;
-    static doublereal xj, rec, tjj;
-    static integer jinc, jlen;
-    static doublereal xbnd;
-    static integer imax;
-    static doublereal tmax;
-    static doublecomplex tjjs;
-    static doublereal xmax, grow;
+    integer i__, j, ip;
+    doublereal xj, rec, tjj;
+    integer jinc, jlen;
+    doublereal xbnd;
+    integer imax;
+    doublereal tmax;
+    doublecomplex tjjs;
+    doublereal xmax, grow;
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
     extern logical lsame_(char *, char *);
-    static doublereal tscal;
-    static doublecomplex uscal;
-    static integer jlast;
-    static doublecomplex csumj;
+    doublereal tscal;
+    doublecomplex uscal;
+    integer jlast;
+    doublecomplex csumj;
     extern /* Double Complex */ VOID zdotc_(doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
-    static logical upper;
+    logical upper;
     extern /* Double Complex */ VOID zdotu_(doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
     extern /* Subroutine */ int zaxpy_(integer *, doublecomplex *, 
@@ -202,17 +49,192 @@
     extern integer idamax_(integer *, doublereal *, integer *);
     extern /* Subroutine */ int xerbla_(char *, integer *), zdscal_(
 	    integer *, doublereal *, doublecomplex *, integer *);
-    static doublereal bignum;
+    doublereal bignum;
     extern integer izamax_(integer *, doublecomplex *, integer *);
-    extern /* Double Complex */ VOID zladiv_(doublecomplex *, doublecomplex *,
+    extern /* Double Complex */ VOID zladiv_(doublecomplex *, doublecomplex *, 
 	     doublecomplex *);
-    static logical notran;
-    static integer jfirst;
+    logical notran;
+    integer jfirst;
     extern doublereal dzasum_(integer *, doublecomplex *, integer *);
-    static doublereal smlnum;
-    static logical nounit;
+    doublereal smlnum;
+    logical nounit;
 
 
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZLATPS solves one of the triangular systems */
+
+/*     A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b, */
+
+/*  with scaling to prevent overflow, where A is an upper or lower */
+/*  triangular matrix stored in packed form.  Here A**T denotes the */
+/*  transpose of A, A**H denotes the conjugate transpose of A, x and b */
+/*  are n-element vectors, and s is a scaling factor, usually less than */
+/*  or equal to 1, chosen so that the components of x will be less than */
+/*  the overflow threshold.  If the unscaled problem will not cause */
+/*  overflow, the Level 2 BLAS routine ZTPSV is called. If the matrix A */
+/*  is singular (A(j,j) = 0 for some j), then s is set to 0 and a */
+/*  non-trivial solution to A*x = 0 is returned. */
+
+/*  Arguments */
+/*  ========= */
+
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A is upper or lower triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
+
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies the operation applied to A. */
+/*          = 'N':  Solve A * x = s*b     (No transpose) */
+/*          = 'T':  Solve A**T * x = s*b  (Transpose) */
+/*          = 'C':  Solve A**H * x = s*b  (Conjugate transpose) */
+
+/*  DIAG    (input) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
+
+/*  NORMIN  (input) CHARACTER*1 */
+/*          Specifies whether CNORM has been set or not. */
+/*          = 'Y':  CNORM contains the column norms on entry */
+/*          = 'N':  CNORM is not set on entry.  On exit, the norms will */
+/*                  be computed and stored in CNORM. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrix A.  N >= 0. */
+
+/*  AP      (input) COMPLEX*16 array, dimension (N*(N+1)/2) */
+/*          The upper or lower triangular matrix A, packed columnwise in */
+/*          a linear array.  The j-th column of A is stored in the array */
+/*          AP as follows: */
+/*          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j; */
+/*          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n. */
+
+/*  X       (input/output) COMPLEX*16 array, dimension (N) */
+/*          On entry, the right hand side b of the triangular system. */
+/*          On exit, X is overwritten by the solution vector x. */
+
+/*  SCALE   (output) DOUBLE PRECISION */
+/*          The scaling factor s for the triangular system */
+/*             A * x = s*b,  A**T * x = s*b,  or  A**H * x = s*b. */
+/*          If SCALE = 0, the matrix A is singular or badly scaled, and */
+/*          the vector x is an exact or approximate solution to A*x = 0. */
+
+/*  CNORM   (input or output) DOUBLE PRECISION array, dimension (N) */
+
+/*          If NORMIN = 'Y', CNORM is an input argument and CNORM(j) */
+/*          contains the norm of the off-diagonal part of the j-th column */
+/*          of A.  If TRANS = 'N', CNORM(j) must be greater than or equal */
+/*          to the infinity-norm, and if TRANS = 'T' or 'C', CNORM(j) */
+/*          must be greater than or equal to the 1-norm. */
+
+/*          If NORMIN = 'N', CNORM is an output argument and CNORM(j) */
+/*          returns the 1-norm of the offdiagonal part of the j-th column */
+/*          of A. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -k, the k-th argument had an illegal value */
+
+/*  Further Details */
+/*  ======= ======= */
+
+/*  A rough bound on x is computed; if that is less than overflow, ZTPSV */
+/*  is called, otherwise, specific code is used which checks for possible */
+/*  overflow or divide-by-zero at every operation. */
+
+/*  A columnwise scheme is used for solving A*x = b.  The basic algorithm */
+/*  if A is lower triangular is */
+
+/*       x[1:n] := b[1:n] */
+/*       for j = 1, ..., n */
+/*            x(j) := x(j) / A(j,j) */
+/*            x[j+1:n] := x[j+1:n] - x(j) * A[j+1:n,j] */
+/*       end */
+
+/*  Define bounds on the components of x after j iterations of the loop: */
+/*     M(j) = bound on x[1:j] */
+/*     G(j) = bound on x[j+1:n] */
+/*  Initially, let M(0) = 0 and G(0) = max{x(i), i=1,...,n}. */
+
+/*  Then for iteration j+1 we have */
+/*     M(j+1) <= G(j) / | A(j+1,j+1) | */
+/*     G(j+1) <= G(j) + M(j+1) * | A[j+2:n,j+1] | */
+/*            <= G(j) ( 1 + CNORM(j+1) / | A(j+1,j+1) | ) */
+
+/*  where CNORM(j+1) is greater than or equal to the infinity-norm of */
+/*  column j+1 of A, not counting the diagonal.  Hence */
+
+/*     G(j) <= G(0) product ( 1 + CNORM(i) / | A(i,i) | ) */
+/*                  1<=i<=j */
+/*  and */
+
+/*     |x(j)| <= ( G(0) / |A(j,j)| ) product ( 1 + CNORM(i) / |A(i,i)| ) */
+/*                                   1<=i< j */
+
+/*  Since |x(j)| <= M(j), we use the Level 2 BLAS routine ZTPSV if the */
+/*  reciprocal of the largest M(j), j=1,..,n, is larger than */
+/*  max(underflow, 1/overflow). */
+
+/*  The bound on x(j) is also used to determine when a step in the */
+/*  columnwise method can be performed without fear of overflow.  If */
+/*  the computed bound is greater than a large constant, x is scaled to */
+/*  prevent overflow, but if the bound overflows, x is set to 0, x(j) to */
+/*  1, and scale to 0, and a non-trivial solution to A*x = 0 is found. */
+
+/*  Similarly, a row-wise scheme is used to solve A**T *x = b  or */
+/*  A**H *x = b.  The basic algorithm for A upper triangular is */
+
+/*       for j = 1, ..., n */
+/*            x(j) := ( b(j) - A[1:j-1,j]' * x[1:j-1] ) / A(j,j) */
+/*       end */
+
+/*  We simultaneously compute two bounds */
+/*       G(j) = bound on ( b(i) - A[1:i-1,i]' * x[1:i-1] ), 1<=i<=j */
+/*       M(j) = bound on x(i), 1<=i<=j */
+
+/*  The initial values are G(0) = 0, M(0) = max{b(i), i=1,..,n}, and we */
+/*  add the constraint G(j) >= G(j-1) and M(j) >= M(j-1) for j >= 1. */
+/*  Then the bound on x(j) is */
+
+/*       M(j) <= M(j-1) * ( 1 + CNORM(j) ) / | A(j,j) | */
+
+/*            <= M(0) * product ( ( 1 + CNORM(i) ) / |A(i,i)| ) */
+/*                      1<=i<=j */
+
+/*  and we can safely call ZTPSV if 1/M(n) and 1/G(n) are both greater */
+/*  than max(underflow, 1/overflow). */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+    /* Parameter adjustments */
     --cnorm;
     --x;
     --ap;
@@ -291,8 +313,8 @@
 	}
     }
 
-/*     Scale the column norms by TSCAL if the maximum element in CNORM is   
-       greater than BIGNUM/2. */
+/*     Scale the column norms by TSCAL if the maximum element in CNORM is */
+/*     greater than BIGNUM/2. */
 
     imax = idamax_(n, &cnorm[1], &c__1);
     tmax = cnorm[imax];
@@ -303,8 +325,8 @@
 	dscal_(n, &tscal, &cnorm[1], &c__1);
     }
 
-/*     Compute a bound on the computed solution vector to see if the   
-       Level 2 BLAS routine ZTPSV can be used. */
+/*     Compute a bound on the computed solution vector to see if the */
+/*     Level 2 BLAS routine ZTPSV can be used. */
 
     xmax = 0.;
     i__1 = *n;
@@ -338,10 +360,10 @@
 
 	if (nounit) {
 
-/*           A is non-unit triangular.   
+/*           A is non-unit triangular. */
 
-             Compute GROW = 1/G(j) and XBND = 1/M(j).   
-             Initially, G(0) = max{x(i), i=1,...,n}. */
+/*           Compute GROW = 1/G(j) and XBND = 1/M(j). */
+/*           Initially, G(0) = max{x(i), i=1,...,n}. */
 
 	    grow = .5 / max(xbnd,smlnum);
 	    xbnd = grow;
@@ -364,9 +386,9 @@
 
 		if (tjj >= smlnum) {
 
-/*                 M(j) = G(j-1) / abs(A(j,j))   
+/*                 M(j) = G(j-1) / abs(A(j,j)) */
 
-   Computing MIN */
+/* Computing MIN */
 		    d__1 = xbnd, d__2 = min(1.,tjj) * grow;
 		    xbnd = min(d__1,d__2);
 		} else {
@@ -394,11 +416,11 @@
 	    grow = xbnd;
 	} else {
 
-/*           A is unit triangular.   
+/*           A is unit triangular. */
 
-             Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}.   
+/*           Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}. */
 
-   Computing MIN */
+/* Computing MIN */
 	    d__1 = 1., d__2 = .5 / max(xbnd,smlnum);
 	    grow = min(d__1,d__2);
 	    i__2 = jlast;
@@ -441,10 +463,10 @@ L60:
 
 	if (nounit) {
 
-/*           A is non-unit triangular.   
+/*           A is non-unit triangular. */
 
-             Compute GROW = 1/G(j) and XBND = 1/M(j).   
-             Initially, M(0) = max{x(i), i=1,...,n}. */
+/*           Compute GROW = 1/G(j) and XBND = 1/M(j). */
+/*           Initially, M(0) = max{x(i), i=1,...,n}. */
 
 	    grow = .5 / max(xbnd,smlnum);
 	    xbnd = grow;
@@ -492,11 +514,11 @@ L60:
 	    grow = min(grow,xbnd);
 	} else {
 
-/*           A is unit triangular.   
+/*           A is unit triangular. */
 
-             Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}.   
+/*           Compute GROW = 1/G(j), where G(0) = max{x(i), i=1,...,n}. */
 
-   Computing MIN */
+/* Computing MIN */
 	    d__1 = 1., d__2 = .5 / max(xbnd,smlnum);
 	    grow = min(d__1,d__2);
 	    i__2 = jlast;
@@ -522,8 +544,8 @@ L90:
 
     if (grow * tscal > smlnum) {
 
-/*        Use the Level 2 BLAS solve if the reciprocal of the bound on   
-          elements of X is not too small. */
+/*        Use the Level 2 BLAS solve if the reciprocal of the bound on */
+/*        elements of X is not too small. */
 
 	ztpsv_(uplo, trans, diag, n, &ap[1], &x[1], &c__1);
     } else {
@@ -532,8 +554,8 @@ L90:
 
 	if (xmax > bignum * .5) {
 
-/*           Scale X so that its components are less than or equal to   
-             BIGNUM in absolute value. */
+/*           Scale X so that its components are less than or equal to */
+/*           BIGNUM in absolute value. */
 
 	    *scale = bignum * .5 / xmax;
 	    zdscal_(n, scale, &x[1], &c__1);
@@ -595,14 +617,14 @@ L90:
 
 		    if (xj > tjj * bignum) {
 
-/*                       Scale x by (1/abs(x(j)))*abs(A(j,j))*BIGNUM   
-                         to avoid overflow when dividing by A(j,j). */
+/*                       Scale x by (1/abs(x(j)))*abs(A(j,j))*BIGNUM */
+/*                       to avoid overflow when dividing by A(j,j). */
 
 			rec = tjj * bignum / xj;
 			if (cnorm[j] > 1.) {
 
-/*                          Scale by 1/CNORM(j) to avoid overflow when   
-                            multiplying x(j) times column j. */
+/*                          Scale by 1/CNORM(j) to avoid overflow when */
+/*                          multiplying x(j) times column j. */
 
 			    rec /= cnorm[j];
 			}
@@ -618,8 +640,8 @@ L90:
 			    , abs(d__2));
 		} else {
 
-/*                    A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                      scale = 0, and compute a solution to A*x = 0. */
+/*                    A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                    scale = 0, and compute a solution to A*x = 0. */
 
 		    i__3 = *n;
 		    for (i__ = 1; i__ <= i__3; ++i__) {
@@ -635,8 +657,8 @@ L90:
 		}
 L110:
 
-/*              Scale x if necessary to avoid overflow when adding a   
-                multiple of column j of A. */
+/*              Scale x if necessary to avoid overflow when adding a */
+/*              multiple of column j of A. */
 
 		if (xj > 1.) {
 		    rec = 1. / xj;
@@ -659,8 +681,8 @@ L110:
 		if (upper) {
 		    if (j > 1) {
 
-/*                    Compute the update   
-                         x(1:j-1) := x(1:j-1) - x(j) * A(1:j-1,j) */
+/*                    Compute the update */
+/*                       x(1:j-1) := x(1:j-1) - x(j) * A(1:j-1,j) */
 
 			i__3 = j - 1;
 			i__4 = j;
@@ -678,8 +700,8 @@ L110:
 		} else {
 		    if (j < *n) {
 
-/*                    Compute the update   
-                         x(j+1:n) := x(j+1:n) - x(j) * A(j+1:n,j) */
+/*                    Compute the update */
+/*                       x(j+1:n) := x(j+1:n) - x(j) * A(j+1:n,j) */
 
 			i__3 = *n - j;
 			i__4 = j;
@@ -708,8 +730,8 @@ L110:
 	    i__1 = jinc;
 	    for (j = jfirst; i__1 < 0 ? j >= i__2 : j <= i__2; j += i__1) {
 
-/*              Compute x(j) = b(j) - sum A(k,j)*x(k).   
-                                      k<>j */
+/*              Compute x(j) = b(j) - sum A(k,j)*x(k). */
+/*                                    k<>j */
 
 		i__3 = j;
 		xj = (d__1 = x[i__3].r, abs(d__1)) + (d__2 = d_imag(&x[j]), 
@@ -733,9 +755,9 @@ L110:
 			    abs(d__2));
 		    if (tjj > 1.) {
 
-/*                       Divide by A(j,j) when scaling x if A(j,j) > 1.   
+/*                       Divide by A(j,j) when scaling x if A(j,j) > 1. */
 
-   Computing MIN */
+/* Computing MIN */
 			d__1 = 1., d__2 = rec * tjj;
 			rec = min(d__1,d__2);
 			zladiv_(&z__1, &uscal, &tjjs);
@@ -751,8 +773,8 @@ L110:
 		csumj.r = 0., csumj.i = 0.;
 		if (uscal.r == 1. && uscal.i == 0.) {
 
-/*                 If the scaling needed for A in the dot product is 1,   
-                   call ZDOTU to perform the dot product. */
+/*                 If the scaling needed for A in the dot product is 1, */
+/*                 call ZDOTU to perform the dot product. */
 
 		    if (upper) {
 			i__3 = j - 1;
@@ -807,8 +829,8 @@ L110:
 		z__1.r = tscal, z__1.i = 0.;
 		if (uscal.r == z__1.r && uscal.i == z__1.i) {
 
-/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j)   
-                   was not used to scale the dotproduct. */
+/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j) */
+/*                 was not used to scale the dotproduct. */
 
 		    i__3 = j;
 		    i__4 = j;
@@ -870,8 +892,8 @@ L110:
 			x[i__3].r = z__1.r, x[i__3].i = z__1.i;
 		    } else {
 
-/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                         scale = 0 and compute a solution to A**T *x = 0. */
+/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                       scale = 0 and compute a solution to A**T *x = 0. */
 
 			i__3 = *n;
 			for (i__ = 1; i__ <= i__3; ++i__) {
@@ -888,8 +910,8 @@ L160:
 		    ;
 		} else {
 
-/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot   
-                   product has already been divided by 1/A(j,j). */
+/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot */
+/*                 product has already been divided by 1/A(j,j). */
 
 		    i__3 = j;
 		    zladiv_(&z__2, &x[j], &tjjs);
@@ -916,8 +938,8 @@ L160:
 	    i__2 = jinc;
 	    for (j = jfirst; i__2 < 0 ? j >= i__1 : j <= i__1; j += i__2) {
 
-/*              Compute x(j) = b(j) - sum A(k,j)*x(k).   
-                                      k<>j */
+/*              Compute x(j) = b(j) - sum A(k,j)*x(k). */
+/*                                    k<>j */
 
 		i__3 = j;
 		xj = (d__1 = x[i__3].r, abs(d__1)) + (d__2 = d_imag(&x[j]), 
@@ -940,9 +962,9 @@ L160:
 			    abs(d__2));
 		    if (tjj > 1.) {
 
-/*                       Divide by A(j,j) when scaling x if A(j,j) > 1.   
+/*                       Divide by A(j,j) when scaling x if A(j,j) > 1. */
 
-   Computing MIN */
+/* Computing MIN */
 			d__1 = 1., d__2 = rec * tjj;
 			rec = min(d__1,d__2);
 			zladiv_(&z__1, &uscal, &tjjs);
@@ -958,8 +980,8 @@ L160:
 		csumj.r = 0., csumj.i = 0.;
 		if (uscal.r == 1. && uscal.i == 0.) {
 
-/*                 If the scaling needed for A in the dot product is 1,   
-                   call ZDOTC to perform the dot product. */
+/*                 If the scaling needed for A in the dot product is 1, */
+/*                 call ZDOTC to perform the dot product. */
 
 		    if (upper) {
 			i__3 = j - 1;
@@ -1014,8 +1036,8 @@ L160:
 		z__1.r = tscal, z__1.i = 0.;
 		if (uscal.r == z__1.r && uscal.i == z__1.i) {
 
-/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j)   
-                   was not used to scale the dotproduct. */
+/*                 Compute x(j) := ( x(j) - CSUMJ ) / A(j,j) if 1/A(j,j) */
+/*                 was not used to scale the dotproduct. */
 
 		    i__3 = j;
 		    i__4 = j;
@@ -1076,8 +1098,8 @@ L160:
 			x[i__3].r = z__1.r, x[i__3].i = z__1.i;
 		    } else {
 
-/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and   
-                         scale = 0 and compute a solution to A**H *x = 0. */
+/*                       A(j,j) = 0:  Set x(1:n) = 0, x(j) = 1, and */
+/*                       scale = 0 and compute a solution to A**H *x = 0. */
 
 			i__3 = *n;
 			for (i__ = 1; i__ <= i__3; ++i__) {
@@ -1094,8 +1116,8 @@ L210:
 		    ;
 		} else {
 
-/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot   
-                   product has already been divided by 1/A(j,j). */
+/*                 Compute x(j) := x(j) / A(j,j) - CSUMJ if the dot */
+/*                 product has already been divided by 1/A(j,j). */
 
 		    i__3 = j;
 		    zladiv_(&z__2, &x[j], &tjjs);
