@@ -1,195 +1,217 @@
-#include "blaswrap.h"
 #include "f2c.h"
+#include "blaswrap.h"
+
+/* Table of constant values */
+
+static doublecomplex c_b1 = {0.,0.};
+static doublecomplex c_b2 = {1.,0.};
+static integer c__1 = 1;
 
 /* Subroutine */ int ztgevc_(char *side, char *howmny, logical *select, 
 	integer *n, doublecomplex *s, integer *lds, doublecomplex *p, integer 
 	*ldp, doublecomplex *vl, integer *ldvl, doublecomplex *vr, integer *
-	ldvr, integer *mm, integer *m, doublecomplex *work, doublereal *rwork,
+	ldvr, integer *mm, integer *m, doublecomplex *work, doublereal *rwork, 
 	 integer *info)
 {
-/*  -- LAPACK routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
-
-
-
-    Purpose   
-    =======   
-
-    ZTGEVC computes some or all of the right and/or left eigenvectors of   
-    a pair of complex matrices (S,P), where S and P are upper triangular.   
-    Matrix pairs of this type are produced by the generalized Schur   
-    factorization of a complex matrix pair (A,B):   
-
-       A = Q*S*Z**H,  B = Q*P*Z**H   
-
-    as computed by ZGGHRD + ZHGEQZ.   
-
-    The right eigenvector x and the left eigenvector y of (S,P)   
-    corresponding to an eigenvalue w are defined by:   
-
-       S*x = w*P*x,  (y**H)*S = w*(y**H)*P,   
-
-    where y**H denotes the conjugate tranpose of y.   
-    The eigenvalues are not input to this routine, but are computed   
-    directly from the diagonal elements of S and P.   
-
-    This routine returns the matrices X and/or Y of right and left   
-    eigenvectors of (S,P), or the products Z*X and/or Q*Y,   
-    where Z and Q are input matrices.   
-    If Q and Z are the unitary factors from the generalized Schur   
-    factorization of a matrix pair (A,B), then Z*X and Q*Y   
-    are the matrices of right and left eigenvectors of (A,B).   
-
-    Arguments   
-    =========   
-
-    SIDE    (input) CHARACTER*1   
-            = 'R': compute right eigenvectors only;   
-            = 'L': compute left eigenvectors only;   
-            = 'B': compute both right and left eigenvectors.   
-
-    HOWMNY  (input) CHARACTER*1   
-            = 'A': compute all right and/or left eigenvectors;   
-            = 'B': compute all right and/or left eigenvectors,   
-                   backtransformed by the matrices in VR and/or VL;   
-            = 'S': compute selected right and/or left eigenvectors,   
-                   specified by the logical array SELECT.   
-
-    SELECT  (input) LOGICAL array, dimension (N)   
-            If HOWMNY='S', SELECT specifies the eigenvectors to be   
-            computed.  The eigenvector corresponding to the j-th   
-            eigenvalue is computed if SELECT(j) = .TRUE..   
-            Not referenced if HOWMNY = 'A' or 'B'.   
-
-    N       (input) INTEGER   
-            The order of the matrices S and P.  N >= 0.   
-
-    S       (input) COMPLEX*16 array, dimension (LDS,N)   
-            The upper triangular matrix S from a generalized Schur   
-            factorization, as computed by ZHGEQZ.   
-
-    LDS     (input) INTEGER   
-            The leading dimension of array S.  LDS >= max(1,N).   
-
-    P       (input) COMPLEX*16 array, dimension (LDP,N)   
-            The upper triangular matrix P from a generalized Schur   
-            factorization, as computed by ZHGEQZ.  P must have real   
-            diagonal elements.   
-
-    LDP     (input) INTEGER   
-            The leading dimension of array P.  LDP >= max(1,N).   
-
-    VL      (input/output) COMPLEX*16 array, dimension (LDVL,MM)   
-            On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must   
-            contain an N-by-N matrix Q (usually the unitary matrix Q   
-            of left Schur vectors returned by ZHGEQZ).   
-            On exit, if SIDE = 'L' or 'B', VL contains:   
-            if HOWMNY = 'A', the matrix Y of left eigenvectors of (S,P);   
-            if HOWMNY = 'B', the matrix Q*Y;   
-            if HOWMNY = 'S', the left eigenvectors of (S,P) specified by   
-                        SELECT, stored consecutively in the columns of   
-                        VL, in the same order as their eigenvalues.   
-            Not referenced if SIDE = 'R'.   
-
-    LDVL    (input) INTEGER   
-            The leading dimension of array VL.  LDVL >= 1, and if   
-            SIDE = 'L' or 'l' or 'B' or 'b', LDVL >= N.   
-
-    VR      (input/output) COMPLEX*16 array, dimension (LDVR,MM)   
-            On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must   
-            contain an N-by-N matrix Q (usually the unitary matrix Z   
-            of right Schur vectors returned by ZHGEQZ).   
-            On exit, if SIDE = 'R' or 'B', VR contains:   
-            if HOWMNY = 'A', the matrix X of right eigenvectors of (S,P);   
-            if HOWMNY = 'B', the matrix Z*X;   
-            if HOWMNY = 'S', the right eigenvectors of (S,P) specified by   
-                        SELECT, stored consecutively in the columns of   
-                        VR, in the same order as their eigenvalues.   
-            Not referenced if SIDE = 'L'.   
-
-    LDVR    (input) INTEGER   
-            The leading dimension of the array VR.  LDVR >= 1, and if   
-            SIDE = 'R' or 'B', LDVR >= N.   
-
-    MM      (input) INTEGER   
-            The number of columns in the arrays VL and/or VR. MM >= M.   
-
-    M       (output) INTEGER   
-            The number of columns in the arrays VL and/or VR actually   
-            used to store the eigenvectors.  If HOWMNY = 'A' or 'B', M   
-            is set to N.  Each selected eigenvector occupies one column.   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (2*N)   
-
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (2*N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit.   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-
-    =====================================================================   
-
-
-       Decode and Test the input parameters   
-
-       Parameter adjustments */
-    /* Table of constant values */
-    static doublecomplex c_b1 = {0.,0.};
-    static doublecomplex c_b2 = {1.,0.};
-    static integer c__1 = 1;
-    
     /* System generated locals */
     integer p_dim1, p_offset, s_dim1, s_offset, vl_dim1, vl_offset, vr_dim1, 
 	    vr_offset, i__1, i__2, i__3, i__4, i__5;
     doublereal d__1, d__2, d__3, d__4, d__5, d__6;
     doublecomplex z__1, z__2, z__3, z__4;
+
     /* Builtin functions */
     double d_imag(doublecomplex *);
     void d_cnjg(doublecomplex *, doublecomplex *);
+
     /* Local variables */
-    static doublecomplex d__;
-    static integer i__, j;
-    static doublecomplex ca, cb;
-    static integer je, im, jr;
-    static doublereal big;
-    static logical lsa, lsb;
-    static doublereal ulp;
-    static doublecomplex sum;
-    static integer ibeg, ieig, iend;
-    static doublereal dmin__;
-    static integer isrc;
-    static doublereal temp;
-    static doublecomplex suma, sumb;
-    static doublereal xmax, scale;
-    static logical ilall;
-    static integer iside;
-    static doublereal sbeta;
+    doublecomplex d__;
+    integer i__, j;
+    doublecomplex ca, cb;
+    integer je, im, jr;
+    doublereal big;
+    logical lsa, lsb;
+    doublereal ulp;
+    doublecomplex sum;
+    integer ibeg, ieig, iend;
+    doublereal dmin__;
+    integer isrc;
+    doublereal temp;
+    doublecomplex suma, sumb;
+    doublereal xmax, scale;
+    logical ilall;
+    integer iside;
+    doublereal sbeta;
     extern logical lsame_(char *, char *);
-    static doublereal small;
-    static logical compl;
-    static doublereal anorm, bnorm;
-    static logical compr;
+    doublereal small;
+    logical compl;
+    doublereal anorm, bnorm;
+    logical compr;
     extern /* Subroutine */ int zgemv_(char *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *), 
 	    dlabad_(doublereal *, doublereal *);
-    static logical ilbbad;
-    static doublereal acoefa, bcoefa, acoeff;
-    static doublecomplex bcoeff;
-    static logical ilback;
-    static doublereal ascale, bscale;
+    logical ilbbad;
+    doublereal acoefa, bcoefa, acoeff;
+    doublecomplex bcoeff;
+    logical ilback;
+    doublereal ascale, bscale;
     extern doublereal dlamch_(char *);
-    static doublecomplex salpha;
-    static doublereal safmin;
+    doublecomplex salpha;
+    doublereal safmin;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static doublereal bignum;
-    static logical ilcomp;
-    extern /* Double Complex */ VOID zladiv_(doublecomplex *, doublecomplex *,
+    doublereal bignum;
+    logical ilcomp;
+    extern /* Double Complex */ VOID zladiv_(doublecomplex *, doublecomplex *, 
 	     doublecomplex *);
-    static integer ihwmny;
+    integer ihwmny;
 
 
+/*  -- LAPACK routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZTGEVC computes some or all of the right and/or left eigenvectors of */
+/*  a pair of complex matrices (S,P), where S and P are upper triangular. */
+/*  Matrix pairs of this type are produced by the generalized Schur */
+/*  factorization of a complex matrix pair (A,B): */
+
+/*     A = Q*S*Z**H,  B = Q*P*Z**H */
+
+/*  as computed by ZGGHRD + ZHGEQZ. */
+
+/*  The right eigenvector x and the left eigenvector y of (S,P) */
+/*  corresponding to an eigenvalue w are defined by: */
+
+/*     S*x = w*P*x,  (y**H)*S = w*(y**H)*P, */
+
+/*  where y**H denotes the conjugate tranpose of y. */
+/*  The eigenvalues are not input to this routine, but are computed */
+/*  directly from the diagonal elements of S and P. */
+
+/*  This routine returns the matrices X and/or Y of right and left */
+/*  eigenvectors of (S,P), or the products Z*X and/or Q*Y, */
+/*  where Z and Q are input matrices. */
+/*  If Q and Z are the unitary factors from the generalized Schur */
+/*  factorization of a matrix pair (A,B), then Z*X and Q*Y */
+/*  are the matrices of right and left eigenvectors of (A,B). */
+
+/*  Arguments */
+/*  ========= */
+
+/*  SIDE    (input) CHARACTER*1 */
+/*          = 'R': compute right eigenvectors only; */
+/*          = 'L': compute left eigenvectors only; */
+/*          = 'B': compute both right and left eigenvectors. */
+
+/*  HOWMNY  (input) CHARACTER*1 */
+/*          = 'A': compute all right and/or left eigenvectors; */
+/*          = 'B': compute all right and/or left eigenvectors, */
+/*                 backtransformed by the matrices in VR and/or VL; */
+/*          = 'S': compute selected right and/or left eigenvectors, */
+/*                 specified by the logical array SELECT. */
+
+/*  SELECT  (input) LOGICAL array, dimension (N) */
+/*          If HOWMNY='S', SELECT specifies the eigenvectors to be */
+/*          computed.  The eigenvector corresponding to the j-th */
+/*          eigenvalue is computed if SELECT(j) = .TRUE.. */
+/*          Not referenced if HOWMNY = 'A' or 'B'. */
+
+/*  N       (input) INTEGER */
+/*          The order of the matrices S and P.  N >= 0. */
+
+/*  S       (input) COMPLEX*16 array, dimension (LDS,N) */
+/*          The upper triangular matrix S from a generalized Schur */
+/*          factorization, as computed by ZHGEQZ. */
+
+/*  LDS     (input) INTEGER */
+/*          The leading dimension of array S.  LDS >= max(1,N). */
+
+/*  P       (input) COMPLEX*16 array, dimension (LDP,N) */
+/*          The upper triangular matrix P from a generalized Schur */
+/*          factorization, as computed by ZHGEQZ.  P must have real */
+/*          diagonal elements. */
+
+/*  LDP     (input) INTEGER */
+/*          The leading dimension of array P.  LDP >= max(1,N). */
+
+/*  VL      (input/output) COMPLEX*16 array, dimension (LDVL,MM) */
+/*          On entry, if SIDE = 'L' or 'B' and HOWMNY = 'B', VL must */
+/*          contain an N-by-N matrix Q (usually the unitary matrix Q */
+/*          of left Schur vectors returned by ZHGEQZ). */
+/*          On exit, if SIDE = 'L' or 'B', VL contains: */
+/*          if HOWMNY = 'A', the matrix Y of left eigenvectors of (S,P); */
+/*          if HOWMNY = 'B', the matrix Q*Y; */
+/*          if HOWMNY = 'S', the left eigenvectors of (S,P) specified by */
+/*                      SELECT, stored consecutively in the columns of */
+/*                      VL, in the same order as their eigenvalues. */
+/*          Not referenced if SIDE = 'R'. */
+
+/*  LDVL    (input) INTEGER */
+/*          The leading dimension of array VL.  LDVL >= 1, and if */
+/*          SIDE = 'L' or 'l' or 'B' or 'b', LDVL >= N. */
+
+/*  VR      (input/output) COMPLEX*16 array, dimension (LDVR,MM) */
+/*          On entry, if SIDE = 'R' or 'B' and HOWMNY = 'B', VR must */
+/*          contain an N-by-N matrix Q (usually the unitary matrix Z */
+/*          of right Schur vectors returned by ZHGEQZ). */
+/*          On exit, if SIDE = 'R' or 'B', VR contains: */
+/*          if HOWMNY = 'A', the matrix X of right eigenvectors of (S,P); */
+/*          if HOWMNY = 'B', the matrix Z*X; */
+/*          if HOWMNY = 'S', the right eigenvectors of (S,P) specified by */
+/*                      SELECT, stored consecutively in the columns of */
+/*                      VR, in the same order as their eigenvalues. */
+/*          Not referenced if SIDE = 'L'. */
+
+/*  LDVR    (input) INTEGER */
+/*          The leading dimension of the array VR.  LDVR >= 1, and if */
+/*          SIDE = 'R' or 'B', LDVR >= N. */
+
+/*  MM      (input) INTEGER */
+/*          The number of columns in the arrays VL and/or VR. MM >= M. */
+
+/*  M       (output) INTEGER */
+/*          The number of columns in the arrays VL and/or VR actually */
+/*          used to store the eigenvectors.  If HOWMNY = 'A' or 'B', M */
+/*          is set to N.  Each selected eigenvector occupies one column. */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (2*N) */
+
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (2*N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit. */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
+
+/*     Decode and Test the input parameters */
+
+    /* Parameter adjustments */
     --select;
     s_dim1 = *lds;
     s_offset = 1 + s_dim1;
@@ -315,9 +337,9 @@
     big = 1. / small;
     bignum = 1. / (safmin * *n);
 
-/*     Compute the 1-norm of each column of the strictly upper triangular   
-       part of A and B to check for possible overflow in the triangular   
-       solver. */
+/*     Compute the 1-norm of each column of the strictly upper triangular */
+/*     part of A and B to check for possible overflow in the triangular */
+/*     solver. */
 
     i__1 = s_dim1 + 1;
     anorm = (d__1 = s[i__1].r, abs(d__1)) + (d__2 = d_imag(&s[s_dim1 + 1]), 
@@ -393,12 +415,12 @@
 		    goto L140;
 		}
 
-/*              Non-singular eigenvalue:   
-                Compute coefficients  a  and  b  in   
-                     H   
-                   y  ( a A - b B ) = 0   
+/*              Non-singular eigenvalue: */
+/*              Compute coefficients  a  and  b  in */
+/*                   H */
+/*                 y  ( a A - b B ) = 0 */
 
-   Computing MAX */
+/* Computing MAX */
 		i__2 = je + je * s_dim1;
 		i__3 = je + je * p_dim1;
 		d__4 = ((d__2 = s[i__2].r, abs(d__2)) + (d__3 = d_imag(&s[je 
@@ -434,8 +456,8 @@
 		    scale = max(d__3,d__4);
 		}
 		if (lsa || lsb) {
-/* Computing MIN   
-   Computing MAX */
+/* Computing MIN */
+/* Computing MAX */
 		    d__5 = 1., d__6 = abs(acoeff), d__5 = max(d__5,d__6), 
 			    d__6 = (d__1 = bcoeff.r, abs(d__1)) + (d__2 = 
 			    d_imag(&bcoeff), abs(d__2));
@@ -473,20 +495,20 @@
 			d__1 = max(d__1,d__2);
 		dmin__ = max(d__1,safmin);
 
-/*                                              H   
-                Triangular solve of  (a A - b B)  y = 0   
+/*                                              H */
+/*              Triangular solve of  (a A - b B)  y = 0 */
 
-                                        H   
-                (rowwise in  (a A - b B) , or columnwise in a A - b B) */
+/*                                      H */
+/*              (rowwise in  (a A - b B) , or columnwise in a A - b B) */
 
 		i__2 = *n;
 		for (j = je + 1; j <= i__2; ++j) {
 
-/*                 Compute   
-                         j-1   
-                   SUM = sum  conjg( a*S(k,j) - b*P(k,j) )*x(k)   
-                         k=je   
-                   (Scale if necessary) */
+/*                 Compute */
+/*                       j-1 */
+/*                 SUM = sum  conjg( a*S(k,j) - b*P(k,j) )*x(k) */
+/*                       k=je */
+/*                 (Scale if necessary) */
 
 		    temp = 1. / xmax;
 		    if (acoefa * rwork[j] + bcoefa * rwork[*n + j] > bignum * 
@@ -530,9 +552,9 @@
 		    z__1.r = z__2.r - z__3.r, z__1.i = z__2.i - z__3.i;
 		    sum.r = z__1.r, sum.i = z__1.i;
 
-/*                 Form x(j) = - SUM / conjg( a*S(j,j) - b*P(j,j) )   
+/*                 Form x(j) = - SUM / conjg( a*S(j,j) - b*P(j,j) ) */
 
-                   with scaling and perturbation of the denominator */
+/*                 with scaling and perturbation of the denominator */
 
 		    i__3 = j + j * s_dim1;
 		    z__3.r = acoeff * s[i__3].r, z__3.i = acoeff * s[i__3].i;
@@ -672,12 +694,12 @@ L140:
 		    goto L250;
 		}
 
-/*              Non-singular eigenvalue:   
-                Compute coefficients  a  and  b  in   
+/*              Non-singular eigenvalue: */
+/*              Compute coefficients  a  and  b  in */
 
-                ( a A - b B ) x  = 0   
+/*              ( a A - b B ) x  = 0 */
 
-   Computing MAX */
+/* Computing MAX */
 		i__1 = je + je * s_dim1;
 		i__2 = je + je * p_dim1;
 		d__4 = ((d__2 = s[i__1].r, abs(d__2)) + (d__3 = d_imag(&s[je 
@@ -713,8 +735,8 @@ L140:
 		    scale = max(d__3,d__4);
 		}
 		if (lsa || lsb) {
-/* Computing MIN   
-   Computing MAX */
+/* Computing MIN */
+/* Computing MAX */
 		    d__5 = 1., d__6 = abs(acoeff), d__5 = max(d__5,d__6), 
 			    d__6 = (d__1 = bcoeff.r, abs(d__1)) + (d__2 = 
 			    d_imag(&bcoeff), abs(d__2));
@@ -752,10 +774,10 @@ L140:
 			d__1 = max(d__1,d__2);
 		dmin__ = max(d__1,safmin);
 
-/*              Triangular solve of  (a A - b B) x = 0  (columnwise)   
+/*              Triangular solve of  (a A - b B) x = 0  (columnwise) */
 
-                WORK(1:j-1) contains sums w,   
-                WORK(j+1:JE) contains x */
+/*              WORK(1:j-1) contains sums w, */
+/*              WORK(j+1:JE) contains x */
 
 		i__1 = je - 1;
 		for (jr = 1; jr <= i__1; ++jr) {
@@ -775,8 +797,8 @@ L140:
 
 		for (j = je - 1; j >= 1; --j) {
 
-/*                 Form x(j) := - w(j) / d   
-                   with scaling and perturbation of the denominator */
+/*                 Form x(j) := - w(j) / d */
+/*                 with scaling and perturbation of the denominator */
 
 		    i__1 = j + j * s_dim1;
 		    z__2.r = acoeff * s[i__1].r, z__2.i = acoeff * s[i__1].i;
