@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchkbd.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -68,20 +56,20 @@ static integer c__4 = 4;
 	    z_dim1, z_offset, i__1, i__2, i__3, i__4, i__5, i__6, i__7;
     real r__1, r__2, r__3, r__4, r__5, r__6, r__7;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double log(doublereal), sqrt(doublereal), exp(doublereal);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, m, n, mq;
-    static real ulp, cond;
-    static integer jcol;
-    static char path[3];
-    static integer mmax, nmax;
-    static real unfl, ovfl;
-    static char uplo[1];
-    static real temp1, temp2;
+    integer i__, j, m, n, mq;
+    real ulp, cond;
+    integer jcol;
+    char path[3];
+    integer mmax, nmax;
+    real unfl, ovfl;
+    char uplo[1];
+    real temp1, temp2;
     extern /* Subroutine */ int cbdt01_(integer *, integer *, integer *, 
 	    complex *, integer *, complex *, integer *, real *, real *, 
 	    complex *, integer *, complex *, real *, real *), cbdt02_(integer 
@@ -89,21 +77,21 @@ static integer c__4 = 4;
 	    *, integer *, complex *, real *, real *), cbdt03_(char *, integer 
 	    *, integer *, real *, real *, complex *, integer *, real *, 
 	    complex *, integer *, complex *, real *);
-    static logical badmm, badnn;
+    logical badmm, badnn;
     extern /* Subroutine */ int cgemm_(char *, char *, integer *, integer *, 
 	    integer *, complex *, complex *, integer *, complex *, integer *, 
 	    complex *, complex *, integer *);
-    static integer nfail, imode;
-    static real dumma[1];
-    static integer iinfo;
+    integer nfail, imode;
+    real dumma[1];
+    integer iinfo;
     extern /* Subroutine */ int cunt01_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *, real *, real *);
-    static real anorm;
-    static integer mnmin, mnmax, jsize, itype, jtype, iwork[1], ntest;
+    real anorm;
+    integer mnmin, mnmax, jsize, itype, jtype, iwork[1], ntest;
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *), slahd2_(integer *, char *);
-    static integer log2ui;
-    static logical bidiag;
+    integer log2ui;
+    logical bidiag;
     extern /* Subroutine */ int cgebrd_(integer *, integer *, complex *, 
 	    integer *, real *, real *, complex *, complex *, complex *, 
 	    integer *, integer *), slabad_(real *, real *);
@@ -111,7 +99,7 @@ static integer c__4 = 4;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), claset_(char *, 
 	    integer *, integer *, complex *, complex *, complex *, integer *), xerbla_(char *, integer *);
-    static integer ioldsd[4];
+    integer ioldsd[4];
     extern /* Subroutine */ int cbdsqr_(char *, integer *, integer *, integer 
 	    *, integer *, real *, real *, complex *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, integer *), 
@@ -121,18 +109,18 @@ static integer c__4 = 4;
     extern doublereal slarnd_(integer *, integer *);
     extern /* Subroutine */ int clatmr_(integer *, integer *, char *, integer 
 	    *, char *, complex *, integer *, real *, complex *, char *, char *
-	    , complex *, integer *, real *, complex *, integer *, real *, 
+, complex *, integer *, real *, complex *, integer *, real *, 
 	    char *, integer *, integer *, integer *, real *, real *, char *, 
 	    complex *, integer *, integer *, integer *), clatms_(integer *, integer *, 
 	    char *, integer *, char *, real *, integer *, real *, real *, 
 	    integer *, integer *, char *, complex *, integer *, complex *, 
 	    integer *);
-    static real amninv;
+    real amninv;
     extern /* Subroutine */ int ssvdch_(integer *, real *, real *, real *, 
 	    real *, integer *);
-    static integer minwrk;
-    static real rtunfl, rtovfl, ulpinv, result[14];
-    static integer mtypes;
+    integer minwrk;
+    real rtunfl, rtovfl, ulpinv, result[14];
+    integer mtypes;
 
     /* Fortran I/O blocks */
     static cilist io___40 = { 0, 0, 0, fmt_9998, 0 };
@@ -145,293 +133,314 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKBD checks the singular value decomposition (SVD) routines.   
+/*  CCHKBD checks the singular value decomposition (SVD) routines. */
 
-    CGEBRD reduces a complex general m by n matrix A to real upper or   
-    lower bidiagonal form by an orthogonal transformation: Q' * A * P = B   
-    (or A = Q * B * P').  The matrix B is upper bidiagonal if m >= n   
-    and lower bidiagonal if m < n.   
+/*  CGEBRD reduces a complex general m by n matrix A to real upper or */
+/*  lower bidiagonal form by an orthogonal transformation: Q' * A * P = B */
+/*  (or A = Q * B * P').  The matrix B is upper bidiagonal if m >= n */
+/*  and lower bidiagonal if m < n. */
 
-    CUNGBR generates the orthogonal matrices Q and P' from CGEBRD.   
-    Note that Q and P are not necessarily square.   
+/*  CUNGBR generates the orthogonal matrices Q and P' from CGEBRD. */
+/*  Note that Q and P are not necessarily square. */
 
-    CBDSQR computes the singular value decomposition of the bidiagonal   
-    matrix B as B = U S V'.  It is called three times to compute   
-       1)  B = U S1 V', where S1 is the diagonal matrix of singular   
-           values and the columns of the matrices U and V are the left   
-           and right singular vectors, respectively, of B.   
-       2)  Same as 1), but the singular values are stored in S2 and the   
-           singular vectors are not computed.   
-       3)  A = (UQ) S (P'V'), the SVD of the original matrix A.   
-    In addition, CBDSQR has an option to apply the left orthogonal matrix   
-    U to a matrix X, useful in least squares applications.   
+/*  CBDSQR computes the singular value decomposition of the bidiagonal */
+/*  matrix B as B = U S V'.  It is called three times to compute */
+/*     1)  B = U S1 V', where S1 is the diagonal matrix of singular */
+/*         values and the columns of the matrices U and V are the left */
+/*         and right singular vectors, respectively, of B. */
+/*     2)  Same as 1), but the singular values are stored in S2 and the */
+/*         singular vectors are not computed. */
+/*     3)  A = (UQ) S (P'V'), the SVD of the original matrix A. */
+/*  In addition, CBDSQR has an option to apply the left orthogonal matrix */
+/*  U to a matrix X, useful in least squares applications. */
 
-    For each pair of matrix dimensions (M,N) and each selected matrix   
-    type, an M by N matrix A and an M by NRHS matrix X are generated.   
-    The problem dimensions are as follows   
-       A:          M x N   
-       Q:          M x min(M,N) (but M x M if NRHS > 0)   
-       P:          min(M,N) x N   
-       B:          min(M,N) x min(M,N)   
-       U, V:       min(M,N) x min(M,N)   
-       S1, S2      diagonal, order min(M,N)   
-       X:          M x NRHS   
+/*  For each pair of matrix dimensions (M,N) and each selected matrix */
+/*  type, an M by N matrix A and an M by NRHS matrix X are generated. */
+/*  The problem dimensions are as follows */
+/*     A:          M x N */
+/*     Q:          M x min(M,N) (but M x M if NRHS > 0) */
+/*     P:          min(M,N) x N */
+/*     B:          min(M,N) x min(M,N) */
+/*     U, V:       min(M,N) x min(M,N) */
+/*     S1, S2      diagonal, order min(M,N) */
+/*     X:          M x NRHS */
 
-    For each generated matrix, 14 tests are performed:   
+/*  For each generated matrix, 14 tests are performed: */
 
-    Test CGEBRD and CUNGBR   
+/*  Test CGEBRD and CUNGBR */
 
-    (1)   | A - Q B PT | / ( |A| max(M,N) ulp ), PT = P'   
+/*  (1)   | A - Q B PT | / ( |A| max(M,N) ulp ), PT = P' */
 
-    (2)   | I - Q' Q | / ( M ulp )   
+/*  (2)   | I - Q' Q | / ( M ulp ) */
 
-    (3)   | I - PT PT' | / ( N ulp )   
+/*  (3)   | I - PT PT' | / ( N ulp ) */
 
-    Test CBDSQR on bidiagonal matrix B   
+/*  Test CBDSQR on bidiagonal matrix B */
 
-    (4)   | B - U S1 VT | / ( |B| min(M,N) ulp ), VT = V'   
+/*  (4)   | B - U S1 VT | / ( |B| min(M,N) ulp ), VT = V' */
 
-    (5)   | Y - U Z | / ( |Y| max(min(M,N),k) ulp ), where Y = Q' X   
-                                                     and   Z = U' Y.   
-    (6)   | I - U' U | / ( min(M,N) ulp )   
+/*  (5)   | Y - U Z | / ( |Y| max(min(M,N),k) ulp ), where Y = Q' X */
+/*                                                   and   Z = U' Y. */
+/*  (6)   | I - U' U | / ( min(M,N) ulp ) */
 
-    (7)   | I - VT VT' | / ( min(M,N) ulp )   
+/*  (7)   | I - VT VT' | / ( min(M,N) ulp ) */
 
-    (8)   S1 contains min(M,N) nonnegative values in decreasing order.   
-          (Return 0 if true, 1/ULP if false.)   
+/*  (8)   S1 contains min(M,N) nonnegative values in decreasing order. */
+/*        (Return 0 if true, 1/ULP if false.) */
 
-    (9)   0 if the true singular values of B are within THRESH of   
-          those in S1.  2*THRESH if they are not.  (Tested using   
-          SSVDCH)   
+/*  (9)   0 if the true singular values of B are within THRESH of */
+/*        those in S1.  2*THRESH if they are not.  (Tested using */
+/*        SSVDCH) */
 
-    (10)  | S1 - S2 | / ( |S1| ulp ), where S2 is computed without   
-                                      computing U and V.   
+/*  (10)  | S1 - S2 | / ( |S1| ulp ), where S2 is computed without */
+/*                                    computing U and V. */
 
-    Test CBDSQR on matrix A   
+/*  Test CBDSQR on matrix A */
 
-    (11)  | A - (QU) S (VT PT) | / ( |A| max(M,N) ulp )   
+/*  (11)  | A - (QU) S (VT PT) | / ( |A| max(M,N) ulp ) */
 
-    (12)  | X - (QU) Z | / ( |X| max(M,k) ulp )   
+/*  (12)  | X - (QU) Z | / ( |X| max(M,k) ulp ) */
+
+/*  (13)  | I - (QU)'(QU) | / ( M ulp ) */
 
-    (13)  | I - (QU)'(QU) | / ( M ulp )   
+/*  (14)  | I - (VT PT) (PT'VT') | / ( N ulp ) */
+
+/*  The possible matrix types are */
 
-    (14)  | I - (VT PT) (PT'VT') | / ( N ulp )   
+/*  (1)  The zero matrix. */
+/*  (2)  The identity matrix. */
 
-    The possible matrix types are   
+/*  (3)  A diagonal matrix with evenly spaced entries */
+/*       1, ..., ULP  and random signs. */
+/*       (ULP = (first number larger than 1) - 1 ) */
+/*  (4)  A diagonal matrix with geometrically spaced entries */
+/*       1, ..., ULP  and random signs. */
+/*  (5)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP */
+/*       and random signs. */
 
-    (1)  The zero matrix.   
-    (2)  The identity matrix.   
+/*  (6)  Same as (3), but multiplied by SQRT( overflow threshold ) */
+/*  (7)  Same as (3), but multiplied by SQRT( underflow threshold ) */
 
-    (3)  A diagonal matrix with evenly spaced entries   
-         1, ..., ULP  and random signs.   
-         (ULP = (first number larger than 1) - 1 )   
-    (4)  A diagonal matrix with geometrically spaced entries   
-         1, ..., ULP  and random signs.   
-    (5)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP   
-         and random signs.   
+/*  (8)  A matrix of the form  U D V, where U and V are orthogonal and */
+/*       D has evenly spaced entries 1, ..., ULP with random signs */
+/*       on the diagonal. */
 
-    (6)  Same as (3), but multiplied by SQRT( overflow threshold )   
-    (7)  Same as (3), but multiplied by SQRT( underflow threshold )   
+/*  (9)  A matrix of the form  U D V, where U and V are orthogonal and */
+/*       D has geometrically spaced entries 1, ..., ULP with random */
+/*       signs on the diagonal. */
 
-    (8)  A matrix of the form  U D V, where U and V are orthogonal and   
-         D has evenly spaced entries 1, ..., ULP with random signs   
-         on the diagonal.   
+/*  (10) A matrix of the form  U D V, where U and V are orthogonal and */
+/*       D has "clustered" entries 1, ULP,..., ULP with random */
+/*       signs on the diagonal. */
 
-    (9)  A matrix of the form  U D V, where U and V are orthogonal and   
-         D has geometrically spaced entries 1, ..., ULP with random   
-         signs on the diagonal.   
+/*  (11) Same as (8), but multiplied by SQRT( overflow threshold ) */
+/*  (12) Same as (8), but multiplied by SQRT( underflow threshold ) */
 
-    (10) A matrix of the form  U D V, where U and V are orthogonal and   
-         D has "clustered" entries 1, ULP,..., ULP with random   
-         signs on the diagonal.   
+/*  (13) Rectangular matrix with random entries chosen from (-1,1). */
+/*  (14) Same as (13), but multiplied by SQRT( overflow threshold ) */
+/*  (15) Same as (13), but multiplied by SQRT( underflow threshold ) */
 
-    (11) Same as (8), but multiplied by SQRT( overflow threshold )   
-    (12) Same as (8), but multiplied by SQRT( underflow threshold )   
+/*  Special case: */
+/*  (16) A bidiagonal matrix with random entries chosen from a */
+/*       logarithmic distribution on [ulp^2,ulp^(-2)]  (I.e., each */
+/*       entry is  e^x, where x is chosen uniformly on */
+/*       [ 2 log(ulp), -2 log(ulp) ] .)  For *this* type: */
+/*       (a) CGEBRD is not called to reduce it to bidiagonal form. */
+/*       (b) the bidiagonal is  min(M,N) x min(M,N); if M<N, the */
+/*           matrix will be lower bidiagonal, otherwise upper. */
+/*       (c) only tests 5--8 and 14 are performed. */
 
-    (13) Rectangular matrix with random entries chosen from (-1,1).   
-    (14) Same as (13), but multiplied by SQRT( overflow threshold )   
-    (15) Same as (13), but multiplied by SQRT( underflow threshold )   
+/*  A subset of the full set of matrix types may be selected through */
+/*  the logical array DOTYPE. */
 
-    Special case:   
-    (16) A bidiagonal matrix with random entries chosen from a   
-         logarithmic distribution on [ulp^2,ulp^(-2)]  (I.e., each   
-         entry is  e^x, where x is chosen uniformly on   
-         [ 2 log(ulp), -2 log(ulp) ] .)  For *this* type:   
-         (a) CGEBRD is not called to reduce it to bidiagonal form.   
-         (b) the bidiagonal is  min(M,N) x min(M,N); if M<N, the   
-             matrix will be lower bidiagonal, otherwise upper.   
-         (c) only tests 5--8 and 14 are performed.   
+/*  Arguments */
+/*  ========== */
 
-    A subset of the full set of matrix types may be selected through   
-    the logical array DOTYPE.   
+/*  NSIZES  (input) INTEGER */
+/*          The number of values of M and N contained in the vectors */
+/*          MVAL and NVAL.  The matrix sizes are used in pairs (M,N). */
 
-    Arguments   
-    ==========   
+/*  MVAL    (input) INTEGER array, dimension (NM) */
+/*          The values of the matrix row dimension M. */
 
-    NSIZES  (input) INTEGER   
-            The number of values of M and N contained in the vectors   
-            MVAL and NVAL.  The matrix sizes are used in pairs (M,N).   
+/*  NVAL    (input) INTEGER array, dimension (NM) */
+/*          The values of the matrix column dimension N. */
 
-    MVAL    (input) INTEGER array, dimension (NM)   
-            The values of the matrix row dimension M.   
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, CCHKBD */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrices are in A and B. */
+/*          This is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
 
-    NVAL    (input) INTEGER array, dimension (NM)   
-            The values of the matrix column dimension N.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size (m,n), a matrix */
+/*          of type j will be generated.  If NTYPES is smaller than the */
+/*          maximum number of types defined (PARAMETER MAXTYP), then */
+/*          types NTYPES+1 through MAXTYP will not be generated.  If */
+/*          NTYPES is larger than MAXTYP, DOTYPE(MAXTYP+1) through */
+/*          DOTYPE(NTYPES) will be ignored. */
 
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, CCHKBD   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrices are in A and B.   
-            This is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
+/*  NRHS    (input) INTEGER */
+/*          The number of columns in the "right-hand side" matrices X, Y, */
+/*          and Z, used in testing CBDSQR.  If NRHS = 0, then the */
+/*          operations on the right-hand side will not be tested. */
+/*          NRHS must be at least 0. */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size (m,n), a matrix   
-            of type j will be generated.  If NTYPES is smaller than the   
-            maximum number of types defined (PARAMETER MAXTYP), then   
-            types NTYPES+1 through MAXTYP will not be generated.  If   
-            NTYPES is larger than MAXTYP, DOTYPE(MAXTYP+1) through   
-            DOTYPE(NTYPES) will be ignored.   
-
-    NRHS    (input) INTEGER   
-            The number of columns in the "right-hand side" matrices X, Y,   
-            and Z, used in testing CBDSQR.  If NRHS = 0, then the   
-            operations on the right-hand side will not be tested.   
-            NRHS must be at least 0.   
-
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096.  Also, ISEED(4) must   
-            be odd.  The values of ISEED are changed on exit, and can be   
-            used in the next call to CCHKBD to continue the same random   
-            number sequence.   
-
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.  Note that the   
-            expected value of the test ratios is O(1), so THRESH should   
-            be a reasonably small multiple of 1, e.g., 10 or 100.   
-
-    A       (workspace) COMPLEX array, dimension (LDA,NMAX)   
-            where NMAX is the maximum value of N in NVAL.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,MMAX),   
-            where MMAX is the maximum value of M in MVAL.   
-
-    BD      (workspace) REAL array, dimension   
-                        (max(min(MVAL(j),NVAL(j))))   
-
-    BE      (workspace) REAL array, dimension   
-                        (max(min(MVAL(j),NVAL(j))))   
-
-    S1      (workspace) REAL array, dimension   
-                        (max(min(MVAL(j),NVAL(j))))   
-
-    S2      (workspace) REAL array, dimension   
-                        (max(min(MVAL(j),NVAL(j))))   
-
-    X       (workspace) COMPLEX array, dimension (LDX,NRHS)   
-
-    LDX     (input) INTEGER   
-            The leading dimension of the arrays X, Y, and Z.   
-            LDX >= max(1,MMAX).   
-
-    Y       (workspace) COMPLEX array, dimension (LDX,NRHS)   
-
-    Z       (workspace) COMPLEX array, dimension (LDX,NRHS)   
-
-    Q       (workspace) COMPLEX array, dimension (LDQ,MMAX)   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of the array Q.  LDQ >= max(1,MMAX).   
-
-    PT      (workspace) COMPLEX array, dimension (LDPT,NMAX)   
-
-    LDPT    (input) INTEGER   
-            The leading dimension of the arrays PT, U, and V.   
-            LDPT >= max(1, max(min(MVAL(j),NVAL(j)))).   
-
-    U       (workspace) COMPLEX array, dimension   
-                        (LDPT,max(min(MVAL(j),NVAL(j))))   
-
-    V       (workspace) COMPLEX array, dimension   
-                        (LDPT,max(min(MVAL(j),NVAL(j))))   
-
-    WORK    (workspace) COMPLEX array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The number of entries in WORK.  This must be at least   
-            3(M+N) and  M(M + max(M,N,k) + 1) + N*min(M,N)  for all   
-            pairs  (M,N)=(MM(j),NN(j))   
-
-    RWORK   (workspace) REAL array, dimension   
-                        (5*max(min(M,N)))   
-
-    NOUT    (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IINFO not equal to 0.)   
-
-    INFO    (output) INTEGER   
-            If 0, then everything ran OK.   
-             -1: NSIZES < 0   
-             -2: Some MM(j) < 0   
-             -3: Some NN(j) < 0   
-             -4: NTYPES < 0   
-             -6: NRHS  < 0   
-             -8: THRESH < 0   
-            -11: LDA < 1 or LDA < MMAX, where MMAX is max( MM(j) ).   
-            -17: LDB < 1 or LDB < MMAX.   
-            -21: LDQ < 1 or LDQ < MMAX.   
-            -23: LDP < 1 or LDP < MNMAX.   
-            -27: LWORK too small.   
-            If  CLATMR, CLATMS, CGEBRD, CUNGBR, or CBDSQR,   
-                returns an error code, the   
-                absolute value of it is returned.   
-
-   -----------------------------------------------------------------------   
-
-       Some Local Variables and Parameters:   
-       ---- ----- --------- --- ----------   
-
-       ZERO, ONE       Real 0 and 1.   
-       MAXTYP          The number of types defined.   
-       NTEST           The number of tests performed, or which can   
-                       be performed so far, for the current matrix.   
-       MMAX            Largest value in NN.   
-       NMAX            Largest value in NN.   
-       MNMIN           min(MM(j), NN(j)) (the dimension of the bidiagonal   
-                       matrix.)   
-       MNMAX           The maximum value of MNMIN for j=1,...,NSIZES.   
-       NFAIL           The number of tests which have exceeded THRESH   
-       COND, IMODE     Values to be passed to the matrix generators.   
-       ANORM           Norm of A; passed to matrix generators.   
-
-       OVFL, UNFL      Overflow and underflow thresholds.   
-       RTOVFL, RTUNFL  Square roots of the previous 2 values.   
-       ULP, ULPINV     Finest relative precision and its inverse.   
-
-               The following four arrays decode JTYPE:   
-       KTYPE(j)        The general type (1-10) for type "j".   
-       KMODE(j)        The MODE value to be passed to the matrix   
-                       generator for type "j".   
-       KMAGN(j)        The order of magnitude ( O(1),   
-                       O(overflow^(1/2) ), O(underflow^(1/2) )   
-
-   ======================================================================   
-
-       Parameter adjustments */
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096.  Also, ISEED(4) must */
+/*          be odd.  The values of ISEED are changed on exit, and can be */
+/*          used in the next call to CCHKBD to continue the same random */
+/*          number sequence. */
+
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0.  Note that the */
+/*          expected value of the test ratios is O(1), so THRESH should */
+/*          be a reasonably small multiple of 1, e.g., 10 or 100. */
+
+/*  A       (workspace) COMPLEX array, dimension (LDA,NMAX) */
+/*          where NMAX is the maximum value of N in NVAL. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,MMAX), */
+/*          where MMAX is the maximum value of M in MVAL. */
+
+/*  BD      (workspace) REAL array, dimension */
+/*                      (max(min(MVAL(j),NVAL(j)))) */
+
+/*  BE      (workspace) REAL array, dimension */
+/*                      (max(min(MVAL(j),NVAL(j)))) */
+
+/*  S1      (workspace) REAL array, dimension */
+/*                      (max(min(MVAL(j),NVAL(j)))) */
+
+/*  S2      (workspace) REAL array, dimension */
+/*                      (max(min(MVAL(j),NVAL(j)))) */
+
+/*  X       (workspace) COMPLEX array, dimension (LDX,NRHS) */
+
+/*  LDX     (input) INTEGER */
+/*          The leading dimension of the arrays X, Y, and Z. */
+/*          LDX >= max(1,MMAX). */
+
+/*  Y       (workspace) COMPLEX array, dimension (LDX,NRHS) */
+
+/*  Z       (workspace) COMPLEX array, dimension (LDX,NRHS) */
+
+/*  Q       (workspace) COMPLEX array, dimension (LDQ,MMAX) */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of the array Q.  LDQ >= max(1,MMAX). */
+
+/*  PT      (workspace) COMPLEX array, dimension (LDPT,NMAX) */
+
+/*  LDPT    (input) INTEGER */
+/*          The leading dimension of the arrays PT, U, and V. */
+/*          LDPT >= max(1, max(min(MVAL(j),NVAL(j)))). */
+
+/*  U       (workspace) COMPLEX array, dimension */
+/*                      (LDPT,max(min(MVAL(j),NVAL(j)))) */
+
+/*  V       (workspace) COMPLEX array, dimension */
+/*                      (LDPT,max(min(MVAL(j),NVAL(j)))) */
+
+/*  WORK    (workspace) COMPLEX array, dimension (LWORK) */
+
+/*  LWORK   (input) INTEGER */
+/*          The number of entries in WORK.  This must be at least */
+/*          3(M+N) and  M(M + max(M,N,k) + 1) + N*min(M,N)  for all */
+/*          pairs  (M,N)=(MM(j),NN(j)) */
+
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (5*max(min(M,N))) */
+
+/*  NOUT    (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IINFO not equal to 0.) */
+
+/*  INFO    (output) INTEGER */
+/*          If 0, then everything ran OK. */
+/*           -1: NSIZES < 0 */
+/*           -2: Some MM(j) < 0 */
+/*           -3: Some NN(j) < 0 */
+/*           -4: NTYPES < 0 */
+/*           -6: NRHS  < 0 */
+/*           -8: THRESH < 0 */
+/*          -11: LDA < 1 or LDA < MMAX, where MMAX is max( MM(j) ). */
+/*          -17: LDB < 1 or LDB < MMAX. */
+/*          -21: LDQ < 1 or LDQ < MMAX. */
+/*          -23: LDP < 1 or LDP < MNMAX. */
+/*          -27: LWORK too small. */
+/*          If  CLATMR, CLATMS, CGEBRD, CUNGBR, or CBDSQR, */
+/*              returns an error code, the */
+/*              absolute value of it is returned. */
+
+/* ----------------------------------------------------------------------- */
+
+/*     Some Local Variables and Parameters: */
+/*     ---- ----- --------- --- ---------- */
+
+/*     ZERO, ONE       Real 0 and 1. */
+/*     MAXTYP          The number of types defined. */
+/*     NTEST           The number of tests performed, or which can */
+/*                     be performed so far, for the current matrix. */
+/*     MMAX            Largest value in NN. */
+/*     NMAX            Largest value in NN. */
+/*     MNMIN           min(MM(j), NN(j)) (the dimension of the bidiagonal */
+/*                     matrix.) */
+/*     MNMAX           The maximum value of MNMIN for j=1,...,NSIZES. */
+/*     NFAIL           The number of tests which have exceeded THRESH */
+/*     COND, IMODE     Values to be passed to the matrix generators. */
+/*     ANORM           Norm of A; passed to matrix generators. */
+
+/*     OVFL, UNFL      Overflow and underflow thresholds. */
+/*     RTOVFL, RTUNFL  Square roots of the previous 2 values. */
+/*     ULP, ULPINV     Finest relative precision and its inverse. */
+
+/*             The following four arrays decode JTYPE: */
+/*     KTYPE(j)        The general type (1-10) for type "j". */
+/*     KMODE(j)        The MODE value to be passed to the matrix */
+/*                     generator for type "j". */
+/*     KMAGN(j)        The order of magnitude ( O(1), */
+/*                     O(overflow^(1/2) ), O(underflow^(1/2) ) */
+
+/* ====================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --mval;
     --nval;
     --dotype;
@@ -467,9 +476,11 @@ static integer c__4 = 4;
     --work;
     --rwork;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors */
+/*     Check for errors */
 
     *info = 0;
 
@@ -493,13 +504,13 @@ static integer c__4 = 4;
 	if (nval[j] < 0) {
 	    badnn = TRUE_;
 	}
-/* Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
 	i__4 = mval[j], i__5 = nval[j];
 	i__2 = mnmax, i__3 = min(i__4,i__5);
 	mnmax = max(i__2,i__3);
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 	i__4 = mval[j], i__5 = nval[j], i__4 = max(i__4,i__5);
 /* Computing MIN */
 	i__6 = nval[j], i__7 = mval[j];
@@ -591,21 +602,21 @@ static integer c__4 = 4;
 
 	    *(unsigned char *)uplo = ' ';
 
-/*           Compute "A"   
+/*           Compute "A" */
 
-             Control parameters:   
+/*           Control parameters: */
 
-             KMAGN  KMODE        KTYPE   
-         =1  O(1)   clustered 1  zero   
-         =2  large  clustered 2  identity   
-         =3  small  exponential  (none)   
-         =4         arithmetic   diagonal, (w/ eigenvalues)   
-         =5         random       symmetric, w/ eigenvalues   
-         =6                      nonsymmetric, w/ singular values   
-         =7                      random diagonal   
-         =8                      random symmetric   
-         =9                      random nonsymmetric   
-         =10                     random bidiagonal (log. distrib.) */
+/*           KMAGN  KMODE        KTYPE */
+/*       =1  O(1)   clustered 1  zero */
+/*       =2  large  clustered 2  identity */
+/*       =3  small  exponential  (none) */
+/*       =4         arithmetic   diagonal, (w/ eigenvalues) */
+/*       =5         random       symmetric, w/ eigenvalues */
+/*       =6                      nonsymmetric, w/ singular values */
+/*       =7                      random diagonal */
+/*       =8                      random symmetric */
+/*       =9                      random nonsymmetric */
+/*       =10                     random bidiagonal (log. distrib.) */
 
 	    if (mtypes > 16) {
 		goto L100;
@@ -663,7 +674,7 @@ L70:
 /*              Diagonal Matrix, [Eigen]values Specified */
 
 		clatms_(&mnmin, &mnmin, "S", &iseed[1], "N", &rwork[1], &
-			imode, &cond, &anorm, &c__0, &c__0, "N", &a[a_offset],
+			imode, &cond, &anorm, &c__0, &c__0, "N", &a[a_offset], 
 			 lda, &work[1], &iinfo);
 
 	    } else if (itype == 5) {
@@ -678,7 +689,7 @@ L70:
 
 /*              Nonsymmetric, singular values specified */
 
-		clatms_(&m, &n, "S", &iseed[1], "N", &rwork[1], &imode, &cond,
+		clatms_(&m, &n, "S", &iseed[1], "N", &rwork[1], &imode, &cond, 
 			 &anorm, &m, &n, "N", &a[a_offset], lda, &work[1], &
 			iinfo);
 
@@ -778,8 +789,8 @@ L100:
 
 	    if (! bidiag) {
 
-/*              Compute transformations to reduce A to bidiagonal form:   
-                B := Q' * A * P. */
+/*              Compute transformations to reduce A to bidiagonal form: */
+/*              B := Q' * A * P. */
 
 		clacpy_(" ", &m, &n, &a[a_offset], lda, &q[q_offset], ldq);
 		i__3 = *lwork - (mnmin << 1);
@@ -867,9 +878,9 @@ L100:
 			c_b2, &q[q_offset], ldq, &x[x_offset], ldx, &c_b1, &y[
 			y_offset], ldx);
 
-/*              Test 1:  Check the decomposition A := Q * B * PT   
-                     2:  Check the orthogonality of Q   
-                     3:  Check the orthogonality of PT */
+/*              Test 1:  Check the decomposition A := Q * B * PT */
+/*                   2:  Check the orthogonality of Q */
+/*                   3:  Check the orthogonality of PT */
 
 		cbdt01_(&m, &n, &c__1, &a[a_offset], lda, &q[q_offset], ldq, &
 			bd[1], &be[1], &pt[pt_offset], ldpt, &work[1], &rwork[
@@ -880,8 +891,8 @@ L100:
 			lwork, &rwork[1], &result[2]);
 	    }
 
-/*           Use CBDSQR to form the SVD of the bidiagonal matrix B:   
-             B := U * S1 * VT, and compute Z = U' * Y. */
+/*           Use CBDSQR to form the SVD of the bidiagonal matrix B: */
+/*           B := U * S1 * VT, and compute Z = U' * Y. */
 
 	    scopy_(&mnmin, &bd[1], &c__1, &s1[1], &c__1);
 	    if (mnmin > 0) {
@@ -918,8 +929,8 @@ L100:
 		}
 	    }
 
-/*           Use CBDSQR to compute only the singular values of the   
-             bidiagonal matrix B;  U, VT, and Z should not be modified. */
+/*           Use CBDSQR to compute only the singular values of the */
+/*           bidiagonal matrix B;  U, VT, and Z should not be modified. */
 
 	    scopy_(&mnmin, &bd[1], &c__1, &s2[1], &c__1);
 	    if (mnmin > 0) {
@@ -928,7 +939,7 @@ L100:
 	    }
 
 	    cbdsqr_(uplo, &mnmin, &c__0, &c__0, &c__0, &s2[1], &rwork[1], &vt[
-		    vt_offset], ldpt, &u[u_offset], ldpt, &z__[z_offset], ldx,
+		    vt_offset], ldpt, &u[u_offset], ldpt, &z__[z_offset], ldx, 
 		     &rwork[mnmin + 1], &iinfo);
 
 /*           Check error code from CBDSQR. */
@@ -952,10 +963,10 @@ L100:
 		}
 	    }
 
-/*           Test 4:  Check the decomposition B := U * S1 * VT   
-                  5:  Check the computation Z := U' * Y   
-                  6:  Check the orthogonality of U   
-                  7:  Check the orthogonality of VT */
+/*           Test 4:  Check the decomposition B := U * S1 * VT */
+/*                5:  Check the computation Z := U' * Y */
+/*                6:  Check the orthogonality of U */
+/*                7:  Check the orthogonality of VT */
 
 	    cbdt03_(uplo, &mnmin, &c__1, &bd[1], &be[1], &u[u_offset], ldpt, &
 		    s1[1], &vt[vt_offset], ldpt, &work[1], &result[3]);
@@ -966,8 +977,8 @@ L100:
 	    cunt01_("Rows", &mnmin, &mnmin, &vt[vt_offset], ldpt, &work[1], 
 		    lwork, &rwork[1], &result[6]);
 
-/*           Test 8:  Check that the singular values are sorted in   
-                      non-increasing order and are non-negative */
+/*           Test 8:  Check that the singular values are sorted in */
+/*                    non-increasing order and are non-negative */
 
 	    result[7] = 0.f;
 	    i__3 = mnmin - 1;
@@ -992,8 +1003,8 @@ L100:
 
 	    i__3 = mnmin;
 	    for (j = 1; j <= i__3; ++j) {
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 		r__6 = (r__1 = s1[j], dabs(r__1)), r__7 = (r__2 = s2[j], dabs(
 			r__2));
 		r__4 = sqrt(unfl) * dmax(s1[1],1.f), r__5 = ulp * dmax(r__6,
@@ -1005,8 +1016,8 @@ L100:
 
 	    result[8] = temp2;
 
-/*           Test 10:  Sturm sequence test of singular values   
-                       Go up by factors of two until it succeeds */
+/*           Test 10:  Sturm sequence test of singular values */
+/*                     Go up by factors of two until it succeeds */
 
 	    temp1 = *thresh * (.5f - ulp);
 
@@ -1023,8 +1034,8 @@ L100:
 L140:
 	    result[9] = temp1;
 
-/*           Use CBDSQR to form the decomposition A := (QU) S (VT PT)   
-             from the bidiagonal form A := Q B PT. */
+/*           Use CBDSQR to form the decomposition A := (QU) S (VT PT) */
+/*           from the bidiagonal form A := Q B PT. */
 
 	    if (! bidiag) {
 		scopy_(&mnmin, &bd[1], &c__1, &s2[1], &c__1);
@@ -1037,10 +1048,10 @@ L140:
 			pt_offset], ldpt, &q[q_offset], ldq, &y[y_offset], 
 			ldx, &rwork[mnmin + 1], &iinfo);
 
-/*              Test 11:  Check the decomposition A := Q*U * S2 * VT*PT   
-                     12:  Check the computation Z := U' * Q' * X   
-                     13:  Check the orthogonality of Q*U   
-                     14:  Check the orthogonality of VT*PT */
+/*              Test 11:  Check the decomposition A := Q*U * S2 * VT*PT */
+/*                   12:  Check the computation Z := U' * Q' * X */
+/*                   13:  Check the orthogonality of Q*U */
+/*                   14:  Check the orthogonality of VT*PT */
 
 		cbdt01_(&m, &n, &c__0, &a[a_offset], lda, &q[q_offset], ldq, &
 			s2[1], dumma, &pt[pt_offset], ldpt, &work[1], &rwork[
@@ -1069,7 +1080,8 @@ L150:
 		    do_fio(&c__4, (char *)&ioldsd[0], (ftnlen)sizeof(integer))
 			    ;
 		    do_fio(&c__1, (char *)&j, (ftnlen)sizeof(integer));
-		    do_fio(&c__1, (char *)&result[j - 1], (ftnlen)sizeof(real) );
+		    do_fio(&c__1, (char *)&result[j - 1], (ftnlen)sizeof(real)
+			    );
 		    e_wsfe();
 		    ++nfail;
 		}
