@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrgev.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -117,22 +105,22 @@ static integer c__0 = 0;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, n, n1, jc, nb, in, jr;
-    static real ulp;
-    static integer iadd, ierr, nmax;
-    static logical badnn;
+    integer i__, j, n, n1, jc, nb, in, jr;
+    real ulp;
+    integer iadd, ierr, nmax;
+    logical badnn;
     extern /* Subroutine */ int cget52_(logical *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    complex *, complex *, real *, real *), cggev_(char *, char *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    complex *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, real *, integer *);
-    static real rmagn[4];
-    static complex ctemp;
-    static integer nmats, jsize, nerrs, jtype;
+    real rmagn[4];
+    complex ctemp;
+    integer nmats, jsize, nerrs, jtype;
     extern /* Subroutine */ int clatm4_(integer *, integer *, integer *, 
 	    integer *, logical *, real *, real *, real *, integer *, integer *
-	    , complex *, integer *), cunm2r_(char *, char *, integer *, 
+, complex *, integer *), cunm2r_(char *, char *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, complex *, 
 	    integer *, complex *, integer *), slabad_(real *, 
 	    real *), clarfg_(integer *, complex *, complex *, integer *, 
@@ -142,15 +130,15 @@ static integer c__0 = 0;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), claset_(char *, 
 	    integer *, integer *, complex *, complex *, complex *, integer *);
-    static real safmin, safmax;
-    static integer ioldsd[4];
+    real safmin, safmax;
+    integer ioldsd[4];
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *), xerbla_(char *, integer *);
-    static integer minwrk, maxwrk;
-    static real ulpinv;
-    static integer mtypes, ntestt;
+    integer minwrk, maxwrk;
+    real ulpinv;
+    integer mtypes, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___40 = { 0, 0, 0, fmt_9999, 0 };
@@ -170,281 +158,298 @@ static integer c__0 = 0;
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       February 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     February 2007 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRGEV checks the nonsymmetric generalized eigenvalue problem driver   
-    routine CGGEV.   
+/*  CDRGEV checks the nonsymmetric generalized eigenvalue problem driver */
+/*  routine CGGEV. */
 
-    CGGEV computes for a pair of n-by-n nonsymmetric matrices (A,B) the   
-    generalized eigenvalues and, optionally, the left and right   
-    eigenvectors.   
+/*  CGGEV computes for a pair of n-by-n nonsymmetric matrices (A,B) the */
+/*  generalized eigenvalues and, optionally, the left and right */
+/*  eigenvectors. */
 
-    A generalized eigenvalue for a pair of matrices (A,B) is a scalar w   
-    or a ratio  alpha/beta = w, such that A - w*B is singular.  It is   
-    usually represented as the pair (alpha,beta), as there is reasonalbe   
-    interpretation for beta=0, and even for both being zero.   
+/*  A generalized eigenvalue for a pair of matrices (A,B) is a scalar w */
+/*  or a ratio  alpha/beta = w, such that A - w*B is singular.  It is */
+/*  usually represented as the pair (alpha,beta), as there is reasonalbe */
+/*  interpretation for beta=0, and even for both being zero. */
 
-    A right generalized eigenvector corresponding to a generalized   
-    eigenvalue  w  for a pair of matrices (A,B) is a vector r  such that   
-    (A - wB) * r = 0.  A left generalized eigenvector is a vector l such   
-    that l**H * (A - wB) = 0, where l**H is the conjugate-transpose of l.   
+/*  A right generalized eigenvector corresponding to a generalized */
+/*  eigenvalue  w  for a pair of matrices (A,B) is a vector r  such that */
+/*  (A - wB) * r = 0.  A left generalized eigenvector is a vector l such */
+/*  that l**H * (A - wB) = 0, where l**H is the conjugate-transpose of l. */
 
-    When CDRGEV is called, a number of matrix "sizes" ("n's") and a   
-    number of matrix "types" are specified.  For each size ("n")   
-    and each type of matrix, a pair of matrices (A, B) will be generated   
-    and used for testing.  For each matrix pair, the following tests   
-    will be performed and compared with the threshhold THRESH.   
+/*  When CDRGEV is called, a number of matrix "sizes" ("n's") and a */
+/*  number of matrix "types" are specified.  For each size ("n") */
+/*  and each type of matrix, a pair of matrices (A, B) will be generated */
+/*  and used for testing.  For each matrix pair, the following tests */
+/*  will be performed and compared with the threshhold THRESH. */
 
-    Results from CGGEV:   
+/*  Results from CGGEV: */
 
-    (1)  max over all left eigenvalue/-vector pairs (alpha/beta,l) of   
+/*  (1)  max over all left eigenvalue/-vector pairs (alpha/beta,l) of */
 
-         | VL**H * (beta A - alpha B) |/( ulp max(|beta A|, |alpha B|) )   
+/*       | VL**H * (beta A - alpha B) |/( ulp max(|beta A|, |alpha B|) ) */
 
-         where VL**H is the conjugate-transpose of VL.   
+/*       where VL**H is the conjugate-transpose of VL. */
 
-    (2)  | |VL(i)| - 1 | / ulp and whether largest component real   
+/*  (2)  | |VL(i)| - 1 | / ulp and whether largest component real */
 
-         VL(i) denotes the i-th column of VL.   
+/*       VL(i) denotes the i-th column of VL. */
 
-    (3)  max over all left eigenvalue/-vector pairs (alpha/beta,r) of   
+/*  (3)  max over all left eigenvalue/-vector pairs (alpha/beta,r) of */
 
-         | (beta A - alpha B) * VR | / ( ulp max(|beta A|, |alpha B|) )   
+/*       | (beta A - alpha B) * VR | / ( ulp max(|beta A|, |alpha B|) ) */
 
-    (4)  | |VR(i)| - 1 | / ulp and whether largest component real   
+/*  (4)  | |VR(i)| - 1 | / ulp and whether largest component real */
 
-         VR(i) denotes the i-th column of VR.   
+/*       VR(i) denotes the i-th column of VR. */
 
-    (5)  W(full) = W(partial)   
-         W(full) denotes the eigenvalues computed when both l and r   
-         are also computed, and W(partial) denotes the eigenvalues   
-         computed when only W, only W and r, or only W and l are   
-         computed.   
+/*  (5)  W(full) = W(partial) */
+/*       W(full) denotes the eigenvalues computed when both l and r */
+/*       are also computed, and W(partial) denotes the eigenvalues */
+/*       computed when only W, only W and r, or only W and l are */
+/*       computed. */
 
-    (6)  VL(full) = VL(partial)   
-         VL(full) denotes the left eigenvectors computed when both l   
-         and r are computed, and VL(partial) denotes the result   
-         when only l is computed.   
+/*  (6)  VL(full) = VL(partial) */
+/*       VL(full) denotes the left eigenvectors computed when both l */
+/*       and r are computed, and VL(partial) denotes the result */
+/*       when only l is computed. */
 
-    (7)  VR(full) = VR(partial)   
-         VR(full) denotes the right eigenvectors computed when both l   
-         and r are also computed, and VR(partial) denotes the result   
-         when only l is computed.   
+/*  (7)  VR(full) = VR(partial) */
+/*       VR(full) denotes the right eigenvectors computed when both l */
+/*       and r are also computed, and VR(partial) denotes the result */
+/*       when only l is computed. */
 
 
-    Test Matrices   
-    ---- --------   
+/*  Test Matrices */
+/*  ---- -------- */
 
-    The sizes of the test matrices are specified by an array   
-    NN(1:NSIZES); the value of each element NN(j) specifies one size.   
-    The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if   
-    DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-    Currently, the list of possible types is:   
+/*  The sizes of the test matrices are specified by an array */
+/*  NN(1:NSIZES); the value of each element NN(j) specifies one size. */
+/*  The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if */
+/*  DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*  Currently, the list of possible types is: */
 
-    (1)  ( 0, 0 )         (a pair of zero matrices)   
+/*  (1)  ( 0, 0 )         (a pair of zero matrices) */
 
-    (2)  ( I, 0 )         (an identity and a zero matrix)   
+/*  (2)  ( I, 0 )         (an identity and a zero matrix) */
 
-    (3)  ( 0, I )         (an identity and a zero matrix)   
+/*  (3)  ( 0, I )         (an identity and a zero matrix) */
 
-    (4)  ( I, I )         (a pair of identity matrices)   
+/*  (4)  ( I, I )         (a pair of identity matrices) */
 
-            t   t   
-    (5)  ( J , J  )       (a pair of transposed Jordan blocks)   
+/*          t   t */
+/*  (5)  ( J , J  )       (a pair of transposed Jordan blocks) */
 
-                                        t                ( I   0  )   
-    (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t )   
-                                     ( 0   I  )          ( 0   J  )   
-                          and I is a k x k identity and J a (k+1)x(k+1)   
-                          Jordan block; k=(N-1)/2   
+/*                                      t                ( I   0  ) */
+/*  (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t ) */
+/*                                   ( 0   I  )          ( 0   J  ) */
+/*                        and I is a k x k identity and J a (k+1)x(k+1) */
+/*                        Jordan block; k=(N-1)/2 */
 
-    (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal   
-                          matrix with those diagonal entries.)   
-    (8)  ( I, D )   
+/*  (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal */
+/*                        matrix with those diagonal entries.) */
+/*  (8)  ( I, D ) */
 
-    (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big   
+/*  (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big */
 
-    (10) ( small*D, big*I )   
+/*  (10) ( small*D, big*I ) */
 
-    (11) ( big*I, small*D )   
+/*  (11) ( big*I, small*D ) */
 
-    (12) ( small*I, big*D )   
+/*  (12) ( small*I, big*D ) */
 
-    (13) ( big*D, big*I )   
+/*  (13) ( big*D, big*I ) */
 
-    (14) ( small*D, small*I )   
+/*  (14) ( small*D, small*I ) */
 
-    (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and   
-                           D2 is diag( 0, N-3, N-4,..., 1, 0, 0 )   
-              t   t   
-    (16) Q ( J , J ) Z     where Q and Z are random orthogonal matrices.   
+/*  (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and */
+/*                         D2 is diag( 0, N-3, N-4,..., 1, 0, 0 ) */
+/*            t   t */
+/*  (16) Q ( J , J ) Z     where Q and Z are random orthogonal matrices. */
 
-    (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices   
-                           with random O(1) entries above the diagonal   
-                           and diagonal entries diag(T1) =   
-                           ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) =   
-                           ( 0, N-3, N-4,..., 1, 0, 0 )   
+/*  (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices */
+/*                         with random O(1) entries above the diagonal */
+/*                         and diagonal entries diag(T1) = */
+/*                         ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) = */
+/*                         ( 0, N-3, N-4,..., 1, 0, 0 ) */
 
-    (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1,..., 1, 0 )   
-                           s = machine precision.   
+/*  (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1,..., 1, 0 ) */
+/*                         s = machine precision. */
 
-    (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 )   
+/*  (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 ) */
 
-                                                           N-5   
-    (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
+/*                                                         N-5 */
+/*  (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
 
-    (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
-                           where r1,..., r(N-4) are random.   
+/*  (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
+/*                         where r1,..., r(N-4) are random. */
 
-    (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular   
-                            matrices.   
+/*  (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular */
+/*                          matrices. */
 
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  If it is zero,   
-            CDRGES does nothing.  NSIZES >= 0.   
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  If it is zero, */
+/*          CDRGES does nothing.  NSIZES >= 0. */
 
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  NN >= 0.   
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  NN >= 0. */
 
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, CDRGEV   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrix is in A.  This   
-            is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, CDRGEV */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrix is in A.  This */
+/*          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated. If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated. If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
 
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096. Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to CDRGES to continue the same random number   
-            sequence.   
-
-    THRESH  (input) REAL   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error is   
-            scaled to be O(1), so THRESH should be a reasonably small   
-            multiple of 1, e.g., 10 or 100.  In particular, it should   
-            not depend on the precision (single vs. double) or the size   
-            of the matrix.  It must be at least zero.   
-
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IERR not equal to 0.)   
-
-    A       (input/workspace) COMPLEX array, dimension(LDA, max(NN))   
-            Used to hold the original A matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, S, and T.   
-            It must be at least 1 and at least max( NN ).   
-
-    B       (input/workspace) COMPLEX array, dimension(LDA, max(NN))   
-            Used to hold the original B matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    S       (workspace) COMPLEX array, dimension (LDA, max(NN))   
-            The Schur form matrix computed from A by CGGEV.  On exit, S   
-            contains the Schur form matrix corresponding to the matrix   
-            in A.   
-
-    T       (workspace) COMPLEX array, dimension (LDA, max(NN))   
-            The upper triangular matrix computed from B by CGGEV.   
-
-    Q      (workspace) COMPLEX array, dimension (LDQ, max(NN))   
-            The (left) eigenvectors matrix computed by CGGEV.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of Q and Z. It must   
-            be at least 1 and at least max( NN ).   
-
-    Z       (workspace) COMPLEX array, dimension( LDQ, max(NN) )   
-            The (right) orthogonal matrix computed by CGGEV.   
-
-    QE      (workspace) COMPLEX array, dimension( LDQ, max(NN) )   
-            QE holds the computed right or left eigenvectors.   
-
-    LDQE    (input) INTEGER   
-            The leading dimension of QE. LDQE >= max(1,max(NN)).   
-
-    ALPHA   (workspace) COMPLEX array, dimension (max(NN))   
-    BETA    (workspace) COMPLEX array, dimension (max(NN))   
-            The generalized eigenvalues of (A,B) computed by CGGEV.   
-            ( ALPHAR(k)+ALPHAI(k)*i ) / BETA(k) is the k-th   
-            generalized eigenvalue of A and B.   
-
-    ALPHA1  (workspace) COMPLEX array, dimension (max(NN))   
-    BETA1   (workspace) COMPLEX array, dimension (max(NN))   
-            Like ALPHAR, ALPHAI, BETA, these arrays contain the   
-            eigenvalues of A and B, but those computed when CGGEV only   
-            computes a partial eigendecomposition, i.e. not the   
-            eigenvalues and left and right eigenvectors.   
-
-    WORK    (workspace) COMPLEX array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The number of entries in WORK.  LWORK >= N*(N+1)   
-
-    RWORK   (workspace) REAL array, dimension (8*N)   
-            Real workspace.   
-
-    RESULT  (output) REAL array, dimension (2)   
-            The values computed by the tests described above.   
-            The values are currently limited to 1/ulp, to avoid overflow.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.  INFO is the   
-                  absolute value of the INFO value returned.   
-
-    =====================================================================   
-
-       Parameter adjustments */
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096. Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to CDRGES to continue the same random number */
+/*          sequence. */
+
+/*  THRESH  (input) REAL */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error is */
+/*          scaled to be O(1), so THRESH should be a reasonably small */
+/*          multiple of 1, e.g., 10 or 100.  In particular, it should */
+/*          not depend on the precision (single vs. double) or the size */
+/*          of the matrix.  It must be at least zero. */
+
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IERR not equal to 0.) */
+
+/*  A       (input/workspace) COMPLEX array, dimension(LDA, max(NN)) */
+/*          Used to hold the original A matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, S, and T. */
+/*          It must be at least 1 and at least max( NN ). */
+
+/*  B       (input/workspace) COMPLEX array, dimension(LDA, max(NN)) */
+/*          Used to hold the original B matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  S       (workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          The Schur form matrix computed from A by CGGEV.  On exit, S */
+/*          contains the Schur form matrix corresponding to the matrix */
+/*          in A. */
+
+/*  T       (workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          The upper triangular matrix computed from B by CGGEV. */
+
+/*  Q      (workspace) COMPLEX array, dimension (LDQ, max(NN)) */
+/*          The (left) eigenvectors matrix computed by CGGEV. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of Q and Z. It must */
+/*          be at least 1 and at least max( NN ). */
+
+/*  Z       (workspace) COMPLEX array, dimension( LDQ, max(NN) ) */
+/*          The (right) orthogonal matrix computed by CGGEV. */
+
+/*  QE      (workspace) COMPLEX array, dimension( LDQ, max(NN) ) */
+/*          QE holds the computed right or left eigenvectors. */
+
+/*  LDQE    (input) INTEGER */
+/*          The leading dimension of QE. LDQE >= max(1,max(NN)). */
+
+/*  ALPHA   (workspace) COMPLEX array, dimension (max(NN)) */
+/*  BETA    (workspace) COMPLEX array, dimension (max(NN)) */
+/*          The generalized eigenvalues of (A,B) computed by CGGEV. */
+/*          ( ALPHAR(k)+ALPHAI(k)*i ) / BETA(k) is the k-th */
+/*          generalized eigenvalue of A and B. */
+
+/*  ALPHA1  (workspace) COMPLEX array, dimension (max(NN)) */
+/*  BETA1   (workspace) COMPLEX array, dimension (max(NN)) */
+/*          Like ALPHAR, ALPHAI, BETA, these arrays contain the */
+/*          eigenvalues of A and B, but those computed when CGGEV only */
+/*          computes a partial eigendecomposition, i.e. not the */
+/*          eigenvalues and left and right eigenvectors. */
+
+/*  WORK    (workspace) COMPLEX array, dimension (LWORK) */
+
+/*  LWORK   (input) INTEGER */
+/*          The number of entries in WORK.  LWORK >= N*(N+1) */
+
+/*  RWORK   (workspace) REAL array, dimension (8*N) */
+/*          Real workspace. */
+
+/*  RESULT  (output) REAL array, dimension (2) */
+/*          The values computed by the tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid overflow. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code.  INFO is the */
+/*                absolute value of the INFO value returned. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -477,9 +482,11 @@ static integer c__0 = 0;
     --rwork;
     --result;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors */
+/*     Check for errors */
 
     *info = 0;
 
@@ -512,24 +519,22 @@ static integer c__0 = 0;
 	*info = -17;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV. */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
 	minwrk = nmax * (nmax + 1);
 /* Computing MAX */
 	i__1 = 1, i__2 = ilaenv_(&c__1, "CGEQRF", " ", &nmax, &nmax, &c_n1, &
-                c_n1, (ftnlen)6, (ftnlen)1), i__1 = max(i__1,i__2), i__2 =
-                ilaenv_(&c__1, "CUNMQR", "LC", &nmax, &nmax, &nmax, &c_n1, (
-                ftnlen)6, (ftnlen)2), i__1 = max(i__1,i__2), i__2 = ilaenv_(&
-                c__1, "CUNGQR", " ", &nmax, &nmax, &nmax, &c_n1, (ftnlen)6, (
-                ftnlen)1);
-        nb = max(i__1,i__2);
+		c_n1), i__1 = max(i__1,i__2), i__2 = 
+		ilaenv_(&c__1, "CUNMQR", "LC", &nmax, &nmax, &nmax, &c_n1), i__1 = max(i__1,i__2), i__2 = ilaenv_(&
+		c__1, "CUNGQR", " ", &nmax, &nmax, &nmax, &c_n1);
+	nb = max(i__1,i__2);
 /* Computing MAX */
 	i__1 = nmax << 1, i__2 = nmax * (nb + 1), i__1 = max(i__1,i__2), i__2 
 		= nmax * (nmax + 1);
@@ -598,26 +603,26 @@ static integer c__0 = 0;
 /* L20: */
 	    }
 
-/*           Generate test matrices A and B   
+/*           Generate test matrices A and B */
 
-             Description of control parameters:   
+/*           Description of control parameters: */
 
-             KCLASS: =1 means w/o rotation, =2 means w/ rotation,   
-                     =3 means random.   
-             KATYPE: the "type" to be passed to CLATM4 for computing A.   
-             KAZERO: the pattern of zeros on the diagonal for A:   
-                     =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ),   
-                     =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ),   
-                     =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of   
-                     non-zero entries.)   
-             KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1),   
-                     =2: large, =3: small.   
-             LASIGN: .TRUE. if the diagonal elements of A are to be   
-                     multiplied by a random magnitude 1 number.   
-             KBTYPE, KBZERO, KBMAGN, LBSIGN: the same, but for B.   
-             KTRIAN: =0: don't fill in the upper triangle, =1: do.   
-             KZ1, KZ2, KADD: used to implement KAZERO and KBZERO.   
-             RMAGN: used to implement KAMAGN and KBMAGN. */
+/*           KCLASS: =1 means w/o rotation, =2 means w/ rotation, */
+/*                   =3 means random. */
+/*           KATYPE: the "type" to be passed to CLATM4 for computing A. */
+/*           KAZERO: the pattern of zeros on the diagonal for A: */
+/*                   =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ), */
+/*                   =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ), */
+/*                   =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of */
+/*                   non-zero entries.) */
+/*           KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1), */
+/*                   =2: large, =3: small. */
+/*           LASIGN: .TRUE. if the diagonal elements of A are to be */
+/*                   multiplied by a random magnitude 1 number. */
+/*           KBTYPE, KBZERO, KBMAGN, LBSIGN: the same, but for B. */
+/*           KTRIAN: =0: don't fill in the upper triangle, =1: do. */
+/*           KZ1, KZ2, KADD: used to implement KAZERO and KBZERO. */
+/*           RMAGN: used to implement KAMAGN and KBMAGN. */
 
 	    if (mtypes > 26) {
 		goto L100;
@@ -673,10 +678,10 @@ static integer c__0 = 0;
 
 		if (kclass[jtype - 1] == 2 && n > 0) {
 
-/*                 Include rotations   
+/*                 Include rotations */
 
-                   Generate Q, Z as Householder transformations times   
-                   a diagonal matrix. */
+/*                 Generate Q, Z as Householder transformations times */
+/*                 a diagonal matrix. */
 
 		    i__3 = n - 1;
 		    for (jc = 1; jc <= i__3; ++jc) {
@@ -930,14 +935,14 @@ L100:
 /* L120: */
 	    }
 
-/*           Do test (6): Compute eigenvalues and left eigenvectors,   
-             and test them */
+/*           Do test (6): Compute eigenvalues and left eigenvectors, */
+/*           and test them */
 
 	    clacpy_(" ", &n, &n, &a[a_offset], lda, &s[s_offset], lda);
 	    clacpy_(" ", &n, &n, &b[b_offset], lda, &t[t_offset], lda);
 	    cggev_("V", "N", &n, &s[s_offset], lda, &t[t_offset], lda, &
 		    alpha1[1], &beta1[1], &qe[qe_offset], ldqe, &z__[z_offset]
-		    , ldq, &work[1], lwork, &rwork[1], &ierr);
+, ldq, &work[1], lwork, &rwork[1], &ierr);
 	    if (ierr != 0 && ierr != n + 1) {
 		result[1] = ulpinv;
 		io___46.ciunit = *nounit;
@@ -980,8 +985,8 @@ L100:
 /* L150: */
 	    }
 
-/*           Do test (7): Compute eigenvalues and right eigenvectors,   
-             and test them */
+/*           Do test (7): Compute eigenvalues and right eigenvectors, */
+/*           and test them */
 
 	    clacpy_(" ", &n, &n, &a[a_offset], lda, &s[s_offset], lda);
 	    clacpy_(" ", &n, &n, &b[b_offset], lda, &t[t_offset], lda);
@@ -1042,8 +1047,8 @@ L190:
 	    for (jr = 1; jr <= 7; ++jr) {
 		if (result[jr] >= *thresh) {
 
-/*                 If this is the first test to fail,   
-                   print a header to the data file. */
+/*                 If this is the first test to fail, */
+/*                 print a header to the data file. */
 
 		    if (nerrs == 0) {
 			io___48.ciunit = *nounit;
