@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrgvx.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -92,37 +80,37 @@ static integer c__4 = 4;
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, n, iwa, iwb;
-    static real ulp;
-    static integer iwx, iwy, nmax;
+    integer i__, j, n, iwa, iwb;
+    real ulp;
+    integer iwx, iwy, nmax;
     extern /* Subroutine */ int cget52_(logical *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    complex *, complex *, real *, real *);
-    static integer linfo;
-    static real anorm, bnorm;
-    static integer nerrs;
+    integer linfo;
+    real anorm, bnorm;
+    integer nerrs;
     extern /* Subroutine */ int clatm6_(integer *, integer *, complex *, 
 	    integer *, complex *, complex *, integer *, complex *, integer *, 
 	    complex *, complex *, complex *, complex *, real *, real *);
-    static real ratio1, ratio2, thrsh2;
+    real ratio1, ratio2, thrsh2;
     extern doublereal clange_(char *, integer *, integer *, complex *, 
 	    integer *, real *), slamch_(char *);
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), xerbla_(char *, 
 	    integer *);
-    static real abnorm;
+    real abnorm;
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *), cggevx_(char *, char *, char *, char *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    complex *, complex *, integer *, complex *, integer *, integer *, 
 	    integer *, real *, real *, real *, real *, real *, real *, 
 	    complex *, integer *, real *, integer *, logical *, integer *);
-    static complex weight[5];
-    static integer minwrk, maxwrk, iptype;
-    static real ulpinv;
-    static integer nptknt, ntestt;
+    complex weight[5];
+    integer minwrk, maxwrk, iptype;
+    real ulpinv;
+    integer nptknt, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___20 = { 0, 0, 0, fmt_9999, 0 };
@@ -151,175 +139,192 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRGVX checks the nonsymmetric generalized eigenvalue problem   
-    expert driver CGGEVX.   
+/*  CDRGVX checks the nonsymmetric generalized eigenvalue problem */
+/*  expert driver CGGEVX. */
 
-    CGGEVX computes the generalized eigenvalues, (optionally) the left   
-    and/or right eigenvectors, (optionally) computes a balancing   
-    transformation to improve the conditioning, and (optionally)   
-    reciprocal condition numbers for the eigenvalues and eigenvectors.   
+/*  CGGEVX computes the generalized eigenvalues, (optionally) the left */
+/*  and/or right eigenvectors, (optionally) computes a balancing */
+/*  transformation to improve the conditioning, and (optionally) */
+/*  reciprocal condition numbers for the eigenvalues and eigenvectors. */
 
-    When CDRGVX is called with NSIZE > 0, two types of test matrix pairs   
-    are generated by the subroutine SLATM6 and test the driver CGGEVX.   
-    The test matrices have the known exact condition numbers for   
-    eigenvalues. For the condition numbers of the eigenvectors   
-    corresponding the first and last eigenvalues are also know   
-    ``exactly'' (see CLATM6).   
-    For each matrix pair, the following tests will be performed and   
-    compared with the threshhold THRESH.   
+/*  When CDRGVX is called with NSIZE > 0, two types of test matrix pairs */
+/*  are generated by the subroutine SLATM6 and test the driver CGGEVX. */
+/*  The test matrices have the known exact condition numbers for */
+/*  eigenvalues. For the condition numbers of the eigenvectors */
+/*  corresponding the first and last eigenvalues are also know */
+/*  ``exactly'' (see CLATM6). */
+/*  For each matrix pair, the following tests will be performed and */
+/*  compared with the threshhold THRESH. */
 
-    (1) max over all left eigenvalue/-vector pairs (beta/alpha,l) of   
+/*  (1) max over all left eigenvalue/-vector pairs (beta/alpha,l) of */
 
-       | l**H * (beta A - alpha B) | / ( ulp max( |beta A|, |alpha B| ) )   
+/*     | l**H * (beta A - alpha B) | / ( ulp max( |beta A|, |alpha B| ) ) */
 
-        where l**H is the conjugate tranpose of l.   
+/*      where l**H is the conjugate tranpose of l. */
 
-    (2) max over all right eigenvalue/-vector pairs (beta/alpha,r) of   
+/*  (2) max over all right eigenvalue/-vector pairs (beta/alpha,r) of */
 
-          | (beta A - alpha B) r | / ( ulp max( |beta A|, |alpha B| ) )   
+/*        | (beta A - alpha B) r | / ( ulp max( |beta A|, |alpha B| ) ) */
 
-    (3) The condition number S(i) of eigenvalues computed by CGGEVX   
-        differs less than a factor THRESH from the exact S(i) (see   
-        CLATM6).   
+/*  (3) The condition number S(i) of eigenvalues computed by CGGEVX */
+/*      differs less than a factor THRESH from the exact S(i) (see */
+/*      CLATM6). */
 
-    (4) DIF(i) computed by CTGSNA differs less than a factor 10*THRESH   
-        from the exact value (for the 1st and 5th vectors only).   
+/*  (4) DIF(i) computed by CTGSNA differs less than a factor 10*THRESH */
+/*      from the exact value (for the 1st and 5th vectors only). */
 
-    Test Matrices   
-    =============   
+/*  Test Matrices */
+/*  ============= */
 
-    Two kinds of test matrix pairs   
-             (A, B) = inverse(YH) * (Da, Db) * inverse(X)   
-    are used in the tests:   
+/*  Two kinds of test matrix pairs */
+/*           (A, B) = inverse(YH) * (Da, Db) * inverse(X) */
+/*  are used in the tests: */
 
-    1: Da = 1+a   0    0    0    0    Db = 1   0   0   0   0   
-             0   2+a   0    0    0         0   1   0   0   0   
-             0    0   3+a   0    0         0   0   1   0   0   
-             0    0    0   4+a   0         0   0   0   1   0   
-             0    0    0    0   5+a ,      0   0   0   0   1 , and   
+/*  1: Da = 1+a   0    0    0    0    Db = 1   0   0   0   0 */
+/*           0   2+a   0    0    0         0   1   0   0   0 */
+/*           0    0   3+a   0    0         0   0   1   0   0 */
+/*           0    0    0   4+a   0         0   0   0   1   0 */
+/*           0    0    0    0   5+a ,      0   0   0   0   1 , and */
 
-    2: Da =  1   -1    0    0    0    Db = 1   0   0   0   0   
-             1    1    0    0    0         0   1   0   0   0   
-             0    0    1    0    0         0   0   1   0   0   
-             0    0    0   1+a  1+b        0   0   0   1   0   
-             0    0    0  -1-b  1+a ,      0   0   0   0   1 .   
+/*  2: Da =  1   -1    0    0    0    Db = 1   0   0   0   0 */
+/*           1    1    0    0    0         0   1   0   0   0 */
+/*           0    0    1    0    0         0   0   1   0   0 */
+/*           0    0    0   1+a  1+b        0   0   0   1   0 */
+/*           0    0    0  -1-b  1+a ,      0   0   0   0   1 . */
 
-    In both cases the same inverse(YH) and inverse(X) are used to compute   
-    (A, B), giving the exact eigenvectors to (A,B) as (YH, X):   
+/*  In both cases the same inverse(YH) and inverse(X) are used to compute */
+/*  (A, B), giving the exact eigenvectors to (A,B) as (YH, X): */
 
-    YH:  =  1    0   -y    y   -y    X =  1   0  -x  -x   x   
-            0    1   -y    y   -y         0   1   x  -x  -x   
-            0    0    1    0    0         0   0   1   0   0   
-            0    0    0    1    0         0   0   0   1   0   
-            0    0    0    0    1,        0   0   0   0   1 , where   
+/*  YH:  =  1    0   -y    y   -y    X =  1   0  -x  -x   x */
+/*          0    1   -y    y   -y         0   1   x  -x  -x */
+/*          0    0    1    0    0         0   0   1   0   0 */
+/*          0    0    0    1    0         0   0   0   1   0 */
+/*          0    0    0    0    1,        0   0   0   0   1 , where */
 
-    a, b, x and y will have all values independently of each other from   
-    { sqrt(sqrt(ULP)),  0.1,  1,  10,  1/sqrt(sqrt(ULP)) }.   
+/*  a, b, x and y will have all values independently of each other from */
+/*  { sqrt(sqrt(ULP)),  0.1,  1,  10,  1/sqrt(sqrt(ULP)) }. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    NSIZE   (input) INTEGER   
-            The number of sizes of matrices to use.  NSIZE must be at   
-            least zero. If it is zero, no randomly generated matrices   
-            are tested, but any test matrices read from NIN will be   
-            tested.  If it is not zero, then N = 5.   
+/*  NSIZE   (input) INTEGER */
+/*          The number of sizes of matrices to use.  NSIZE must be at */
+/*          least zero. If it is zero, no randomly generated matrices */
+/*          are tested, but any test matrices read from NIN will be */
+/*          tested.  If it is not zero, then N = 5. */
 
-    THRESH  (input) REAL   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
+/*  THRESH  (input) REAL */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
 
-    NIN     (input) INTEGER   
-            The FORTRAN unit number for reading in the data file of   
-            problems to solve.   
+/*  NIN     (input) INTEGER */
+/*          The FORTRAN unit number for reading in the data file of */
+/*          problems to solve. */
 
-    NOUT    (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IINFO not equal to 0.)   
+/*  NOUT    (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IINFO not equal to 0.) */
 
-    A       (workspace) COMPLEX array, dimension (LDA, NSIZE)   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
+/*  A       (workspace) COMPLEX array, dimension (LDA, NSIZE) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
 
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, AI, BI, Ao, and Bo.   
-            It must be at least 1 and at least NSIZE.   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, AI, BI, Ao, and Bo. */
+/*          It must be at least 1 and at least NSIZE. */
 
-    B       (workspace) COMPLEX array, dimension (LDA, NSIZE)   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, B contains the last matrix actually used.   
+/*  B       (workspace) COMPLEX array, dimension (LDA, NSIZE) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, B contains the last matrix actually used. */
 
-    AI      (workspace) COMPLEX array, dimension (LDA, NSIZE)   
-            Copy of A, modified by CGGEVX.   
+/*  AI      (workspace) COMPLEX array, dimension (LDA, NSIZE) */
+/*          Copy of A, modified by CGGEVX. */
 
-    BI      (workspace) COMPLEX array, dimension (LDA, NSIZE)   
-            Copy of B, modified by CGGEVX.   
+/*  BI      (workspace) COMPLEX array, dimension (LDA, NSIZE) */
+/*          Copy of B, modified by CGGEVX. */
 
-    ALPHA   (workspace) COMPLEX array, dimension (NSIZE)   
-    BETA    (workspace) COMPLEX array, dimension (NSIZE)   
-            On exit, ALPHA/BETA are the eigenvalues.   
+/*  ALPHA   (workspace) COMPLEX array, dimension (NSIZE) */
+/*  BETA    (workspace) COMPLEX array, dimension (NSIZE) */
+/*          On exit, ALPHA/BETA are the eigenvalues. */
 
-    VL      (workspace) COMPLEX array, dimension (LDA, NSIZE)   
-            VL holds the left eigenvectors computed by CGGEVX.   
+/*  VL      (workspace) COMPLEX array, dimension (LDA, NSIZE) */
+/*          VL holds the left eigenvectors computed by CGGEVX. */
 
-    VR      (workspace) COMPLEX array, dimension (LDA, NSIZE)   
-            VR holds the right eigenvectors computed by CGGEVX.   
+/*  VR      (workspace) COMPLEX array, dimension (LDA, NSIZE) */
+/*          VR holds the right eigenvectors computed by CGGEVX. */
 
-    ILO     (output/workspace) INTEGER   
+/*  ILO     (output/workspace) INTEGER */
 
-    IHI     (output/workspace) INTEGER   
+/*  IHI     (output/workspace) INTEGER */
 
-    LSCALE  (output/workspace) REAL array, dimension (N)   
+/*  LSCALE  (output/workspace) REAL array, dimension (N) */
 
-    RSCALE  (output/workspace) REAL array, dimension (N)   
+/*  RSCALE  (output/workspace) REAL array, dimension (N) */
 
-    S       (output/workspace) REAL array, dimension (N)   
+/*  S       (output/workspace) REAL array, dimension (N) */
 
-    STRU    (output/workspace) REAL array, dimension (N)   
+/*  STRU    (output/workspace) REAL array, dimension (N) */
 
-    DIF     (output/workspace) REAL array, dimension (N)   
+/*  DIF     (output/workspace) REAL array, dimension (N) */
 
-    DIFTRU  (output/workspace) REAL array, dimension (N)   
+/*  DIFTRU  (output/workspace) REAL array, dimension (N) */
 
-    WORK    (workspace) COMPLEX array, dimension (LWORK)   
+/*  WORK    (workspace) COMPLEX array, dimension (LWORK) */
 
-    LWORK   (input) INTEGER   
-            Leading dimension of WORK.  LWORK >= 2*N*N + 2*N   
+/*  LWORK   (input) INTEGER */
+/*          Leading dimension of WORK.  LWORK >= 2*N*N + 2*N */
 
-    RWORK   (workspace) REAL array, dimension (6*N)   
+/*  RWORK   (workspace) REAL array, dimension (6*N) */
 
-    IWORK   (workspace) INTEGER array, dimension (LIWORK)   
+/*  IWORK   (workspace) INTEGER array, dimension (LIWORK) */
 
-    LIWORK  (input) INTEGER   
-            Leading dimension of IWORK.  LIWORK >= N+2.   
+/*  LIWORK  (input) INTEGER */
+/*          Leading dimension of IWORK.  LIWORK >= N+2. */
 
-    RESULT  (output/workspace) REAL array, dimension (4)   
+/*  RESULT  (output/workspace) REAL array, dimension (4) */
 
-    BWORK   (workspace) LOGICAL array, dimension (N)   
+/*  BWORK   (workspace) LOGICAL array, dimension (N) */
 
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors   
+/*     Check for errors */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     vr_dim1 = *lda;
     vr_offset = 1 + vr_dim1;
     vr -= vr_offset;
@@ -371,18 +376,18 @@ static integer c__4 = 4;
 	*info = -26;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV.) */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
 	minwrk = (nmax << 1) * (nmax + 1);
 	maxwrk = nmax * (ilaenv_(&c__1, "CGEQRF", " ", &nmax, &c__1, &nmax, &
-		c__0, (ftnlen)6, (ftnlen)1) + 1);
+		c__0) + 1);
 /* Computing MAX */
 	i__1 = maxwrk, i__2 = (nmax << 1) * (nmax + 1);
 	maxwrk = max(i__1,i__2);
@@ -433,18 +438,18 @@ static integer c__4 = 4;
 
 			clatm6_(&iptype, &c__5, &a[a_offset], lda, &b[
 				b_offset], &vr[vr_offset], lda, &vl[vl_offset]
-				, lda, &weight[iwa - 1], &weight[iwb - 1], &
+, lda, &weight[iwa - 1], &weight[iwb - 1], &
 				weight[iwx - 1], &weight[iwy - 1], &stru[1], &
 				diftru[1]);
 
-/*                    Compute eigenvalues/eigenvectors of (A, B).   
-                      Compute eigenvalue/eigenvector condition numbers   
-                      using computed eigenvectors. */
+/*                    Compute eigenvalues/eigenvectors of (A, B). */
+/*                    Compute eigenvalue/eigenvector condition numbers */
+/*                    using computed eigenvectors. */
 
 			clacpy_("F", &n, &n, &a[a_offset], lda, &ai[ai_offset]
-				, lda);
+, lda);
 			clacpy_("F", &n, &n, &b[b_offset], lda, &bi[bi_offset]
-				, lda);
+, lda);
 
 			cggevx_("N", "V", "V", "B", &n, &ai[ai_offset], lda, &
 				bi[bi_offset], lda, &alpha[1], &beta[1], &vl[
@@ -476,7 +481,7 @@ static integer c__4 = 4;
 
 /*                    Compute the norm(A, B) */
 
-			clacpy_("Full", &n, &n, &ai[ai_offset], lda, &work[1],
+			clacpy_("Full", &n, &n, &ai[ai_offset], lda, &work[1], 
 				 &n);
 			clacpy_("Full", &n, &n, &bi[bi_offset], lda, &work[n *
 				 n + 1], &n);
@@ -488,7 +493,7 @@ static integer c__4 = 4;
 
 			result[1] = 0.f;
 			cget52_(&c_true, &n, &a[a_offset], lda, &b[b_offset], 
-				lda, &vl[vl_offset], lda, &alpha[1], &beta[1],
+				lda, &vl[vl_offset], lda, &alpha[1], &beta[1], 
 				 &work[1], &rwork[1], &result[1]);
 			if (result[2] > *thresh) {
 			    io___22.ciunit = *nout;
@@ -513,9 +518,9 @@ static integer c__4 = 4;
 			}
 
 			result[2] = 0.f;
-			cget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset],
+			cget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset], 
 				 lda, &vr[vr_offset], lda, &alpha[1], &beta[1]
-				, &work[1], &rwork[1], &result[2]);
+, &work[1], &rwork[1], &result[2]);
 			if (result[3] > *thresh) {
 			    io___23.ciunit = *nout;
 			    s_wsfe(&io___23);
@@ -605,8 +610,8 @@ static integer c__4 = 4;
 			    if (result[j] >= thrsh2 && j >= 4 || result[j] >= 
 				    *thresh && j <= 3) {
 
-/*                       If this is the first test to fail,   
-                         print a header to the data file. */
+/*                       If this is the first test to fail, */
+/*                       print a header to the data file. */
 
 				if (nerrs == 0) {
 				    io___28.ciunit = *nout;
@@ -614,9 +619,9 @@ static integer c__4 = 4;
 				    do_fio(&c__1, "CXV", (ftnlen)3);
 				    e_wsfe();
 
-/*                          Print out messages for built-in examples   
+/*                          Print out messages for built-in examples */
 
-                            Matrix types */
+/*                          Matrix types */
 
 				    io___29.ciunit = *nout;
 				    s_wsfe(&io___29);
@@ -698,8 +703,8 @@ L30:
 
 L90:
 
-/*     Read in data from file to check accuracy of condition estimation   
-       Read input data until N=0 */
+/*     Read in data from file to check accuracy of condition estimation */
+/*     Read input data until N=0 */
 
     io___35.ciunit = *nin;
     i__1 = s_rsle(&io___35);
@@ -758,9 +763,9 @@ L90:
 
     ++nptknt;
 
-/*     Compute eigenvalues/eigenvectors of (A, B).   
-       Compute eigenvalue/eigenvector condition numbers   
-       using computed eigenvectors. */
+/*     Compute eigenvalues/eigenvectors of (A, B). */
+/*     Compute eigenvalue/eigenvector condition numbers */
+/*     using computed eigenvectors. */
 
     clacpy_("F", &n, &n, &a[a_offset], lda, &ai[ai_offset], lda);
     clacpy_("F", &n, &n, &b[b_offset], lda, &bi[bi_offset], lda);
@@ -791,7 +796,7 @@ L90:
 /*     Tests (1) and (2) */
 
     result[1] = 0.f;
-    cget52_(&c_true, &n, &a[a_offset], lda, &b[b_offset], lda, &vl[vl_offset],
+    cget52_(&c_true, &n, &a[a_offset], lda, &b[b_offset], lda, &vl[vl_offset], 
 	     lda, &alpha[1], &beta[1], &work[1], &rwork[1], &result[1]);
     if (result[2] > *thresh) {
 	io___41.ciunit = *nout;
@@ -806,7 +811,7 @@ L90:
 
     result[2] = 0.f;
     cget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset], lda, &vr[vr_offset]
-	    , lda, &alpha[1], &beta[1], &work[1], &rwork[1], &result[2]);
+, lda, &alpha[1], &beta[1], &work[1], &rwork[1], &result[2]);
     if (result[3] > *thresh) {
 	io___42.ciunit = *nout;
 	s_wsfe(&io___42);
@@ -881,8 +886,8 @@ L90:
     for (j = 1; j <= 4; ++j) {
 	if (result[j] >= thrsh2) {
 
-/*           If this is the first test to fail,   
-             print a header to the data file. */
+/*           If this is the first test to fail, */
+/*           print a header to the data file. */
 
 	    if (nerrs == 0) {
 		io___43.ciunit = *nout;
@@ -890,9 +895,9 @@ L90:
 		do_fio(&c__1, "CXV", (ftnlen)3);
 		e_wsfe();
 
-/*              Print out messages for built-in examples   
+/*              Print out messages for built-in examples */
 
-                Matrix types */
+/*              Matrix types */
 
 		io___44.ciunit = *nout;
 		s_wsfe(&io___44);
