@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvgg.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -127,11 +115,11 @@ static logical c_false = FALSE_;
     double r_imag(complex *);
 
     /* Local variables */
-    static integer j, n, i1, n1, jc, nb, in, jr, ns, nbz;
-    static real ulp;
-    static integer iadd, nmax;
-    static real temp1, temp2;
-    static logical badnn;
+    integer j, n, i1, n1, jc, nb, in, jr, ns, nbz;
+    real ulp;
+    integer iadd, nmax;
+    real temp1, temp2;
+    logical badnn;
     extern /* Subroutine */ int cgegs_(char *, char *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, complex *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
@@ -143,14 +131,14 @@ static logical c_false = FALSE_;
 	    integer *, real *, integer *), cget52_(logical *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, complex *, complex *, complex *, real *, real *);
-    static real dumma[4];
-    static integer iinfo;
-    static real rmagn[4];
-    static complex ctemp;
-    static integer nmats, jsize, nerrs, jtype, ntest;
+    real dumma[4];
+    integer iinfo;
+    real rmagn[4];
+    complex ctemp;
+    integer nmats, jsize, nerrs, jtype, ntest;
     extern /* Subroutine */ int clatm4_(integer *, integer *, integer *, 
 	    integer *, logical *, real *, real *, real *, integer *, integer *
-	    , complex *, integer *), cunm2r_(char *, char *, integer *, 
+, complex *, integer *), cunm2r_(char *, char *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, complex *, 
 	    integer *, complex *, integer *), slabad_(real *, 
 	    real *), clarfg_(integer *, complex *, complex *, integer *, 
@@ -159,16 +147,16 @@ static logical c_false = FALSE_;
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *);
-    static real safmin, safmax;
-    static integer ioldsd[4];
+    real safmin, safmax;
+    integer ioldsd[4];
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *), claset_(char *, integer *, integer *, 
 	    complex *, complex *, complex *, integer *), xerbla_(char 
 	    *, integer *);
-    static real ulpinv;
-    static integer lwkopt, mtypes, ntestt;
+    real ulpinv;
+    integer lwkopt, mtypes, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___43 = { 0, 0, 0, fmt_9999, 0 };
@@ -186,304 +174,325 @@ static logical c_false = FALSE_;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRVGG  checks the nonsymmetric generalized eigenvalue driver   
-    routines.   
-                                  T          T        T   
-    CGEGS factors A and B as Q S Z  and Q T Z , where   means   
-    transpose, T is upper triangular, S is in generalized Schur form   
-    (upper triangular), and Q and Z are unitary.  It also   
-    computes the generalized eigenvalues (alpha(1),beta(1)), ...,   
-    (alpha(n),beta(n)), where alpha(j)=S(j,j) and beta(j)=T(j,j) --   
-    thus, w(j) = alpha(j)/beta(j) is a root of the generalized   
-    eigenvalue problem   
+/*  CDRVGG  checks the nonsymmetric generalized eigenvalue driver */
+/*  routines. */
+/*                                T          T        T */
+/*  CGEGS factors A and B as Q S Z  and Q T Z , where   means */
+/*  transpose, T is upper triangular, S is in generalized Schur form */
+/*  (upper triangular), and Q and Z are unitary.  It also */
+/*  computes the generalized eigenvalues (alpha(1),beta(1)), ..., */
+/*  (alpha(n),beta(n)), where alpha(j)=S(j,j) and beta(j)=T(j,j) -- */
+/*  thus, w(j) = alpha(j)/beta(j) is a root of the generalized */
+/*  eigenvalue problem */
 
-        det( A - w(j) B ) = 0   
+/*      det( A - w(j) B ) = 0 */
 
-    and m(j) = beta(j)/alpha(j) is a root of the essentially equivalent   
-    problem   
+/*  and m(j) = beta(j)/alpha(j) is a root of the essentially equivalent */
+/*  problem */
 
-        det( m(j) A - B ) = 0   
+/*      det( m(j) A - B ) = 0 */
 
-    CGEGV computes the generalized eigenvalues (alpha(1),beta(1)), ...,   
-    (alpha(n),beta(n)), the matrix L whose columns contain the   
-    generalized left eigenvectors l, and the matrix R whose columns   
-    contain the generalized right eigenvectors r for the pair (A,B).   
+/*  CGEGV computes the generalized eigenvalues (alpha(1),beta(1)), ..., */
+/*  (alpha(n),beta(n)), the matrix L whose columns contain the */
+/*  generalized left eigenvectors l, and the matrix R whose columns */
+/*  contain the generalized right eigenvectors r for the pair (A,B). */
 
-    When CDRVGG is called, a number of matrix "sizes" ("n's") and a   
-    number of matrix "types" are specified.  For each size ("n")   
-    and each type of matrix, one matrix will be generated and used   
-    to test the nonsymmetric eigenroutines.  For each matrix, 7   
-    tests will be performed and compared with the threshhold THRESH:   
+/*  When CDRVGG is called, a number of matrix "sizes" ("n's") and a */
+/*  number of matrix "types" are specified.  For each size ("n") */
+/*  and each type of matrix, one matrix will be generated and used */
+/*  to test the nonsymmetric eigenroutines.  For each matrix, 7 */
+/*  tests will be performed and compared with the threshhold THRESH: */
 
-    Results from CGEGS:   
+/*  Results from CGEGS: */
 
-                     H   
-    (1)   | A - Q S Z  | / ( |A| n ulp )   
+/*                   H */
+/*  (1)   | A - Q S Z  | / ( |A| n ulp ) */
 
-                     H   
-    (2)   | B - Q T Z  | / ( |B| n ulp )   
+/*                   H */
+/*  (2)   | B - Q T Z  | / ( |B| n ulp ) */
 
-                  H   
-    (3)   | I - QQ  | / ( n ulp )   
+/*                H */
+/*  (3)   | I - QQ  | / ( n ulp ) */
 
-                  H   
-    (4)   | I - ZZ  | / ( n ulp )   
+/*                H */
+/*  (4)   | I - ZZ  | / ( n ulp ) */
 
-    (5)   maximum over j of D(j)  where:   
+/*  (5)   maximum over j of D(j)  where: */
 
-                        |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|   
-              D(j) = ------------------------ + -----------------------   
-                     max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)   
+/*                      |alpha(j) - S(j,j)|        |beta(j) - T(j,j)| */
+/*            D(j) = ------------------------ + ----------------------- */
+/*                   max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|) */
 
-    Results from CGEGV:   
+/*  Results from CGEGV: */
 
-    (6)   max over all left eigenvalue/-vector pairs (beta/alpha,l) of   
+/*  (6)   max over all left eigenvalue/-vector pairs (beta/alpha,l) of */
 
-       | l**H * (beta A - alpha B) | / ( ulp max( |beta A|, |alpha B| ) )   
+/*     | l**H * (beta A - alpha B) | / ( ulp max( |beta A|, |alpha B| ) ) */
 
-          where l**H is the conjugate tranpose of l.   
+/*        where l**H is the conjugate tranpose of l. */
 
-    (7)   max over all right eigenvalue/-vector pairs (beta/alpha,r) of   
+/*  (7)   max over all right eigenvalue/-vector pairs (beta/alpha,r) of */
 
-          | (beta A - alpha B) r | / ( ulp max( |beta A|, |alpha B| ) )   
+/*        | (beta A - alpha B) r | / ( ulp max( |beta A|, |alpha B| ) ) */
 
-    Test Matrices   
-    ---- --------   
+/*  Test Matrices */
+/*  ---- -------- */
 
-    The sizes of the test matrices are specified by an array   
-    NN(1:NSIZES); the value of each element NN(j) specifies one size.   
-    The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if   
-    DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-    Currently, the list of possible types is:   
+/*  The sizes of the test matrices are specified by an array */
+/*  NN(1:NSIZES); the value of each element NN(j) specifies one size. */
+/*  The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if */
+/*  DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*  Currently, the list of possible types is: */
 
-    (1)  ( 0, 0 )         (a pair of zero matrices)   
+/*  (1)  ( 0, 0 )         (a pair of zero matrices) */
 
-    (2)  ( I, 0 )         (an identity and a zero matrix)   
+/*  (2)  ( I, 0 )         (an identity and a zero matrix) */
 
-    (3)  ( 0, I )         (an identity and a zero matrix)   
+/*  (3)  ( 0, I )         (an identity and a zero matrix) */
 
-    (4)  ( I, I )         (a pair of identity matrices)   
+/*  (4)  ( I, I )         (a pair of identity matrices) */
 
-            t   t   
-    (5)  ( J , J  )       (a pair of transposed Jordan blocks)   
+/*          t   t */
+/*  (5)  ( J , J  )       (a pair of transposed Jordan blocks) */
 
-                                        t                ( I   0  )   
-    (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t )   
-                                     ( 0   I  )          ( 0   J  )   
-                          and I is a k x k identity and J a (k+1)x(k+1)   
-                          Jordan block; k=(N-1)/2   
+/*                                      t                ( I   0  ) */
+/*  (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t ) */
+/*                                   ( 0   I  )          ( 0   J  ) */
+/*                        and I is a k x k identity and J a (k+1)x(k+1) */
+/*                        Jordan block; k=(N-1)/2 */
 
-    (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal   
-                          matrix with those diagonal entries.)   
-    (8)  ( I, D )   
+/*  (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal */
+/*                        matrix with those diagonal entries.) */
+/*  (8)  ( I, D ) */
 
-    (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big   
+/*  (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big */
 
-    (10) ( small*D, big*I )   
+/*  (10) ( small*D, big*I ) */
 
-    (11) ( big*I, small*D )   
+/*  (11) ( big*I, small*D ) */
 
-    (12) ( small*I, big*D )   
+/*  (12) ( small*I, big*D ) */
 
-    (13) ( big*D, big*I )   
+/*  (13) ( big*D, big*I ) */
 
-    (14) ( small*D, small*I )   
+/*  (14) ( small*D, small*I ) */
 
-    (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and   
-                           D2 is diag( 0, N-3, N-4,..., 1, 0, 0 )   
-              t   t   
-    (16) Q ( J , J ) Z     where Q and Z are random unitary matrices.   
+/*  (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and */
+/*                         D2 is diag( 0, N-3, N-4,..., 1, 0, 0 ) */
+/*            t   t */
+/*  (16) Q ( J , J ) Z     where Q and Z are random unitary matrices. */
 
-    (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices   
-                           with random O(1) entries above the diagonal   
-                           and diagonal entries diag(T1) =   
-                           ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) =   
-                           ( 0, N-3, N-4,..., 1, 0, 0 )   
+/*  (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices */
+/*                         with random O(1) entries above the diagonal */
+/*                         and diagonal entries diag(T1) = */
+/*                         ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) = */
+/*                         ( 0, N-3, N-4,..., 1, 0, 0 ) */
 
-    (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1,..., 1, 0 )   
-                           s = machine precision.   
+/*  (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1,..., 1, 0 ) */
+/*                         s = machine precision. */
 
-    (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 )   
+/*  (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 ) */
 
-                                                           N-5   
-    (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
+/*                                                         N-5 */
+/*  (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
 
-    (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
-                           where r1,..., r(N-4) are random.   
+/*  (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
+/*                         where r1,..., r(N-4) are random. */
 
-    (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular   
-                            matrices.   
+/*  (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular */
+/*                          matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  If it is zero,   
-            CDRVGG does nothing.  It must be at least zero.   
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  If it is zero, */
+/*          CDRVGG does nothing.  It must be at least zero. */
 
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  The values must be at least   
-            zero.   
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  The values must be at least */
+/*          zero. */
 
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, CDRVGG   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrix is in A.  This   
-            is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
-
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated.  If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
-
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096.  Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to CDRVGG to continue the same random number   
-            sequence.   
-
-    THRESH  (input) REAL   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error is   
-            scaled to be O(1), so THRESH should be a reasonably small   
-            multiple of 1, e.g., 10 or 100.  In particular, it should   
-            not depend on the precision (single vs. double) or the size   
-            of the matrix.  It must be at least zero.   
-
-    THRSHN  (input) REAL   
-            Threshhold for reporting eigenvector normalization error.   
-            If the normalization of any eigenvector differs from 1 by   
-            more than THRSHN*ulp, then a special error message will be   
-            printed.  (This is handled separately from the other tests,   
-            since only a compiler or programming error should cause an   
-            error message, at least if THRSHN is at least 5--10.)   
-
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IINFO not equal to 0.)   
-
-    A       (input/workspace) COMPLEX array, dimension (LDA, max(NN))   
-            Used to hold the original A matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, S, T, S2, and T2.   
-            It must be at least 1 and at least max( NN ).   
-
-    B       (input/workspace) COMPLEX array, dimension (LDA, max(NN))   
-            Used to hold the original B matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    S       (workspace) COMPLEX array, dimension (LDA, max(NN))   
-            The upper triangular matrix computed from A by CGEGS.   
-
-    T       (workspace) COMPLEX array, dimension (LDA, max(NN))   
-            The upper triangular matrix computed from B by CGEGS.   
-
-    S2      (workspace) COMPLEX array, dimension (LDA, max(NN))   
-            The matrix computed from A by CGEGV.  This will be the   
-            Schur (upper triangular) form of some matrix related to A,   
-            but will not, in general, be the same as S.   
-
-    T2      (workspace) COMPLEX array, dimension (LDA, max(NN))   
-            The matrix computed from B by CGEGV.  This will be the   
-            Schur form of some matrix related to B, but will not, in   
-            general, be the same as T.   
-
-    Q       (workspace) COMPLEX array, dimension (LDQ, max(NN))   
-            The (left) unitary matrix computed by CGEGS.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of Q, Z, VL, and VR.  It must   
-            be at least 1 and at least max( NN ).   
-
-    Z       (workspace) COMPLEX array, dimension (LDQ, max(NN))   
-            The (right) unitary matrix computed by CGEGS.   
-
-    ALPHA1  (workspace) COMPLEX array, dimension (max(NN))   
-    BETA1   (workspace) COMPLEX array, dimension (max(NN))   
-            The generalized eigenvalues of (A,B) computed by CGEGS.   
-            ALPHA1(k) / BETA1(k)  is the k-th generalized eigenvalue of   
-            the matrices in A and B.   
-
-    ALPHA2  (workspace) COMPLEX array, dimension (max(NN))   
-    BETA2   (workspace) COMPLEX array, dimension (max(NN))   
-            The generalized eigenvalues of (A,B) computed by CGEGV.   
-            ALPHA2(k) / BETA2(k)  is the k-th generalized eigenvalue of   
-            the matrices in A and B.   
-
-    VL      (workspace) COMPLEX array, dimension (LDQ, max(NN))   
-            The (lower triangular) left eigenvector matrix for the   
-            matrices in A and B.   
-
-    VR      (workspace) COMPLEX array, dimension (LDQ, max(NN))   
-            The (upper triangular) right eigenvector matrix for the   
-            matrices in A and B.   
-
-    WORK    (workspace) COMPLEX array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The number of entries in WORK.  This must be at least   
-            MAX( 2*N, N*(NB+1), (k+1)*(2*k+N+1) ), where "k" is the   
-            sum of the blocksize and number-of-shifts for CHGEQZ, and   
-            NB is the greatest of the blocksizes for CGEQRF, CUNMQR,   
-            and CUNGQR.  (The blocksizes and the number-of-shifts are   
-            retrieved through calls to ILAENV.)   
-
-    RWORK   (workspace) REAL array, dimension (8*N)   
-
-    RESULT  (output) REAL array, dimension (7)   
-            The values computed by the tests described above.   
-            The values are currently limited to 1/ulp, to avoid   
-            overflow.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.  INFO is the   
-                  absolute value of the INFO value returned.   
-
-    =====================================================================   
-
-       Parameter adjustments */
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, CDRVGG */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrix is in A.  This */
+/*          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
+
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated.  If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
+
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096.  Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to CDRVGG to continue the same random number */
+/*          sequence. */
+
+/*  THRESH  (input) REAL */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error is */
+/*          scaled to be O(1), so THRESH should be a reasonably small */
+/*          multiple of 1, e.g., 10 or 100.  In particular, it should */
+/*          not depend on the precision (single vs. double) or the size */
+/*          of the matrix.  It must be at least zero. */
+
+/*  THRSHN  (input) REAL */
+/*          Threshhold for reporting eigenvector normalization error. */
+/*          If the normalization of any eigenvector differs from 1 by */
+/*          more than THRSHN*ulp, then a special error message will be */
+/*          printed.  (This is handled separately from the other tests, */
+/*          since only a compiler or programming error should cause an */
+/*          error message, at least if THRSHN is at least 5--10.) */
+
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IINFO not equal to 0.) */
+
+/*  A       (input/workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          Used to hold the original A matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, S, T, S2, and T2. */
+/*          It must be at least 1 and at least max( NN ). */
+
+/*  B       (input/workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          Used to hold the original B matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  S       (workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          The upper triangular matrix computed from A by CGEGS. */
+
+/*  T       (workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          The upper triangular matrix computed from B by CGEGS. */
+
+/*  S2      (workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          The matrix computed from A by CGEGV.  This will be the */
+/*          Schur (upper triangular) form of some matrix related to A, */
+/*          but will not, in general, be the same as S. */
+
+/*  T2      (workspace) COMPLEX array, dimension (LDA, max(NN)) */
+/*          The matrix computed from B by CGEGV.  This will be the */
+/*          Schur form of some matrix related to B, but will not, in */
+/*          general, be the same as T. */
+
+/*  Q       (workspace) COMPLEX array, dimension (LDQ, max(NN)) */
+/*          The (left) unitary matrix computed by CGEGS. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of Q, Z, VL, and VR.  It must */
+/*          be at least 1 and at least max( NN ). */
+
+/*  Z       (workspace) COMPLEX array, dimension (LDQ, max(NN)) */
+/*          The (right) unitary matrix computed by CGEGS. */
+
+/*  ALPHA1  (workspace) COMPLEX array, dimension (max(NN)) */
+/*  BETA1   (workspace) COMPLEX array, dimension (max(NN)) */
+/*          The generalized eigenvalues of (A,B) computed by CGEGS. */
+/*          ALPHA1(k) / BETA1(k)  is the k-th generalized eigenvalue of */
+/*          the matrices in A and B. */
+
+/*  ALPHA2  (workspace) COMPLEX array, dimension (max(NN)) */
+/*  BETA2   (workspace) COMPLEX array, dimension (max(NN)) */
+/*          The generalized eigenvalues of (A,B) computed by CGEGV. */
+/*          ALPHA2(k) / BETA2(k)  is the k-th generalized eigenvalue of */
+/*          the matrices in A and B. */
+
+/*  VL      (workspace) COMPLEX array, dimension (LDQ, max(NN)) */
+/*          The (lower triangular) left eigenvector matrix for the */
+/*          matrices in A and B. */
+
+/*  VR      (workspace) COMPLEX array, dimension (LDQ, max(NN)) */
+/*          The (upper triangular) right eigenvector matrix for the */
+/*          matrices in A and B. */
+
+/*  WORK    (workspace) COMPLEX array, dimension (LWORK) */
+
+/*  LWORK   (input) INTEGER */
+/*          The number of entries in WORK.  This must be at least */
+/*          MAX( 2*N, N*(NB+1), (k+1)*(2*k+N+1) ), where "k" is the */
+/*          sum of the blocksize and number-of-shifts for CHGEQZ, and */
+/*          NB is the greatest of the blocksizes for CGEQRF, CUNMQR, */
+/*          and CUNGQR.  (The blocksizes and the number-of-shifts are */
+/*          retrieved through calls to ILAENV.) */
+
+/*  RWORK   (workspace) REAL array, dimension (8*N) */
+
+/*  RESULT  (output) REAL array, dimension (7) */
+/*          The values computed by the tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid */
+/*          overflow. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code.  INFO is the */
+/*                absolute value of the INFO value returned. */
+
+/*  ===================================================================== */
+
+/*     .. */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -525,9 +534,11 @@ static logical c_false = FALSE_;
     --rwork;
     --result;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors */
+/*     Check for errors */
 
     *info = 0;
 
@@ -544,20 +555,16 @@ static logical c_false = FALSE_;
 /* L10: */
     }
 
-/*     Maximum blocksize and shift -- we assume that blocksize and number   
-       of shifts are monotone increasing functions of N.   
+/*     Maximum blocksize and shift -- we assume that blocksize and number */
+/*     of shifts are monotone increasing functions of N. */
 
-   Computing MAX */
-    i__1 = 1, i__2 = ilaenv_(&c__1, "CGEQRF", " ", &nmax, &nmax, &c_n1, &c_n1,
-	     (ftnlen)6, (ftnlen)1), i__1 = max(i__1,i__2), i__2 = ilaenv_(&
-	    c__1, "CUNMQR", "LC", &nmax, &nmax, &nmax, &c_n1, (ftnlen)6, (
-	    ftnlen)2), i__1 = max(i__1,i__2), i__2 = ilaenv_(&c__1, "CUNGQR", 
-	    " ", &nmax, &nmax, &nmax, &c_n1, (ftnlen)6, (ftnlen)1);
+/* Computing MAX */
+    i__1 = 1, i__2 = ilaenv_(&c__1, "CGEQRF", " ", &nmax, &nmax, &c_n1, &c_n1), i__1 = max(i__1,i__2), i__2 = ilaenv_(&
+	    c__1, "CUNMQR", "LC", &nmax, &nmax, &nmax, &c_n1), i__1 = max(i__1,i__2), i__2 = ilaenv_(&c__1, "CUNGQR", 
+	    " ", &nmax, &nmax, &nmax, &c_n1);
     nb = max(i__1,i__2);
-    nbz = ilaenv_(&c__1, "CHGEQZ", "SII", &nmax, &c__1, &nmax, &c__0, (ftnlen)
-	    6, (ftnlen)3);
-    ns = ilaenv_(&c__4, "CHGEQZ", "SII", &nmax, &c__1, &nmax, &c__0, (ftnlen)
-	    6, (ftnlen)3);
+    nbz = ilaenv_(&c__1, "CHGEQZ", "SII", &nmax, &c__1, &nmax, &c__0);
+    ns = ilaenv_(&c__4, "CHGEQZ", "SII", &nmax, &c__1, &nmax, &c__0);
     i1 = nbz + ns;
 /* Computing MAX */
     i__1 = nmax << 1, i__2 = nmax * (nb + 1), i__1 = max(i__1,i__2), i__2 = ((
@@ -647,26 +654,26 @@ static logical c_false = FALSE_;
 /* L30: */
 	    }
 
-/*           Compute A and B   
+/*           Compute A and B */
 
-             Description of control parameters:   
+/*           Description of control parameters: */
 
-             KCLASS: =1 means w/o rotation, =2 means w/ rotation,   
-                     =3 means random.   
-             KATYPE: the "type" to be passed to CLATM4 for computing A.   
-             KAZERO: the pattern of zeros on the diagonal for A:   
-                     =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ),   
-                     =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ),   
-                     =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of   
-                     non-zero entries.)   
-             KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1),   
-                     =2: large, =3: small.   
-             LASIGN: .TRUE. if the diagonal elements of A are to be   
-                     multiplied by a random magnitude 1 number.   
-             KBTYPE, KBZERO, KBMAGN, IBSIGN: the same, but for B.   
-             KTRIAN: =0: don't fill in the upper triangle, =1: do.   
-             KZ1, KZ2, KADD: used to implement KAZERO and KBZERO.   
-             RMAGN:  used to implement KAMAGN and KBMAGN. */
+/*           KCLASS: =1 means w/o rotation, =2 means w/ rotation, */
+/*                   =3 means random. */
+/*           KATYPE: the "type" to be passed to CLATM4 for computing A. */
+/*           KAZERO: the pattern of zeros on the diagonal for A: */
+/*                   =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ), */
+/*                   =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ), */
+/*                   =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of */
+/*                   non-zero entries.) */
+/*           KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1), */
+/*                   =2: large, =3: small. */
+/*           LASIGN: .TRUE. if the diagonal elements of A are to be */
+/*                   multiplied by a random magnitude 1 number. */
+/*           KBTYPE, KBZERO, KBMAGN, IBSIGN: the same, but for B. */
+/*           KTRIAN: =0: don't fill in the upper triangle, =1: do. */
+/*           KZ1, KZ2, KADD: used to implement KAZERO and KBZERO. */
+/*           RMAGN:  used to implement KAMAGN and KBMAGN. */
 
 	    if (mtypes > 26) {
 		goto L110;
@@ -722,10 +729,10 @@ static logical c_false = FALSE_;
 
 		if (kclass[jtype - 1] == 2 && n > 0) {
 
-/*                 Include rotations   
+/*                 Include rotations */
 
-                   Generate Q, Z as Householder transformations times   
-                   a diagonal matrix. */
+/*                 Generate Q, Z as Householder transformations times */
+/*                 a diagonal matrix. */
 
 		    i__3 = n - 1;
 		    for (jc = 1; jc <= i__3; ++jc) {
@@ -965,9 +972,9 @@ L110:
 	    }
 	    result[5] = temp1;
 
-/*           Call CGEGV to compute S2, T2, VL, and VR, do tests.   
+/*           Call CGEGV to compute S2, T2, VL, and VR, do tests. */
 
-             Eigenvalues and Eigenvectors */
+/*           Eigenvalues and Eigenvectors */
 
 	    clacpy_(" ", &n, &n, &a[a_offset], lda, &s2[s2_offset], lda);
 	    clacpy_(" ", &n, &n, &b[b_offset], lda, &t2[t2_offset], lda);
@@ -975,7 +982,7 @@ L110:
 	    result[6] = ulpinv;
 
 	    cgegv_("V", "V", &n, &s2[s2_offset], lda, &t2[t2_offset], lda, &
-		    alpha2[1], &beta2[1], &vl[vl_offset], ldq, &vr[vr_offset],
+		    alpha2[1], &beta2[1], &vl[vl_offset], ldq, &vr[vr_offset], 
 		     ldq, &work[1], lwork, &rwork[1], &iinfo);
 	    if (iinfo != 0) {
 		io___47.ciunit = *nounit;
@@ -1038,8 +1045,8 @@ L130:
 	    for (jr = 1; jr <= i__3; ++jr) {
 		if (result[jr] >= *thresh) {
 
-/*                 If this is the first test to fail,   
-                   print a header to the data file. */
+/*                 If this is the first test to fail, */
+/*                 print a header to the data file. */
 
 		    if (nerrs == 0) {
 			io___51.ciunit = *nounit;
