@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvvx.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -99,62 +87,62 @@ static integer c__22 = 22;
 	     vl_offset, vr_dim1, vr_offset, i__1, i__2, i__3, i__4;
     complex q__1;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void),
 	     s_rsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, n;
-    static real wi, wr;
-    static integer iwk;
-    static real ulp;
-    static integer ibal;
-    static real cond;
-    static integer jcol;
-    static char path[3];
-    static integer nmax;
-    static real unfl, ovfl;
-    static integer isrt;
-    static logical badnn;
+    integer i__, j, n;
+    real wi, wr;
+    integer iwk;
+    real ulp;
+    integer ibal;
+    real cond;
+    integer jcol;
+    char path[3];
+    integer nmax;
+    real unfl, ovfl;
+    integer isrt;
+    logical badnn;
     extern /* Subroutine */ int cget23_(logical *, integer *, char *, integer 
 	    *, real *, integer *, integer *, integer *, complex *, integer *, 
 	    complex *, complex *, complex *, complex *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *, real *, real *, 
 	    real *, real *, real *, real *, real *, complex *, integer *, 
 	    real *, integer *);
-    static integer nfail, imode, iinfo;
-    static real conds, anorm;
-    static integer jsize, nerrs, itype, jtype, ntest;
-    static real rtulp;
-    static char balanc[1];
+    integer nfail, imode, iinfo;
+    real conds, anorm;
+    integer jsize, nerrs, itype, jtype, ntest;
+    real rtulp;
+    char balanc[1];
     extern /* Subroutine */ int slabad_(real *, real *), clatme_(integer *, 
 	    char *, integer *, complex *, integer *, real *, complex *, char *
-	    , char *, char *, char *, real *, integer *, real *, integer *, 
+, char *, char *, char *, real *, integer *, real *, integer *, 
 	    integer *, real *, complex *, integer *, complex *, integer *);
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int claset_(char *, integer *, integer *, complex 
 	    *, complex *, complex *, integer *);
-    static integer idumma[1];
+    integer idumma[1];
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static integer ioldsd[4];
+    integer ioldsd[4];
     extern /* Subroutine */ int clatmr_(integer *, integer *, char *, integer 
 	    *, char *, complex *, integer *, real *, complex *, char *, char *
-	    , complex *, integer *, real *, complex *, integer *, real *, 
+, complex *, integer *, real *, complex *, integer *, real *, 
 	    char *, integer *, integer *, integer *, real *, real *, char *, 
 	    complex *, integer *, integer *, integer *), clatms_(integer *, integer *, 
 	    char *, integer *, char *, real *, integer *, real *, real *, 
 	    integer *, integer *, char *, complex *, integer *, complex *, 
 	    integer *);
-    static integer ntestf;
+    integer ntestf;
     extern /* Subroutine */ int slasum_(char *, integer *, integer *, integer 
 	    *);
-    static integer nnwork;
-    static real rtulpi;
-    static integer mtypes, ntestt;
-    static real ulpinv;
+    integer nnwork;
+    real rtulpi;
+    integer mtypes, ntestt;
+    real ulpinv;
 
     /* Fortran I/O blocks */
     static cilist io___32 = { 0, 0, 0, fmt_9992, 0 };
@@ -176,328 +164,345 @@ static integer c__22 = 22;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       CDRVVX  checks the nonsymmetric eigenvalue problem expert driver   
-       CGEEVX.   
+/*     CDRVVX  checks the nonsymmetric eigenvalue problem expert driver */
+/*     CGEEVX. */
 
-       CDRVVX uses both test matrices generated randomly depending on   
-       data supplied in the calling sequence, as well as on data   
-       read from an input file and including precomputed condition   
-       numbers to which it compares the ones it computes.   
+/*     CDRVVX uses both test matrices generated randomly depending on */
+/*     data supplied in the calling sequence, as well as on data */
+/*     read from an input file and including precomputed condition */
+/*     numbers to which it compares the ones it computes. */
 
-       When CDRVVX is called, a number of matrix "sizes" ("n's") and a   
-       number of matrix "types" are specified in the calling sequence.   
-       For each size ("n") and each type of matrix, one matrix will be   
-       generated and used to test the nonsymmetric eigenroutines.  For   
-       each matrix, 9 tests will be performed:   
+/*     When CDRVVX is called, a number of matrix "sizes" ("n's") and a */
+/*     number of matrix "types" are specified in the calling sequence. */
+/*     For each size ("n") and each type of matrix, one matrix will be */
+/*     generated and used to test the nonsymmetric eigenroutines.  For */
+/*     each matrix, 9 tests will be performed: */
 
-       (1)     | A * VR - VR * W | / ( n |A| ulp )   
+/*     (1)     | A * VR - VR * W | / ( n |A| ulp ) */
 
-         Here VR is the matrix of unit right eigenvectors.   
-         W is a diagonal matrix with diagonal entries W(j).   
+/*       Here VR is the matrix of unit right eigenvectors. */
+/*       W is a diagonal matrix with diagonal entries W(j). */
 
-       (2)     | A**H  * VL - VL * W**H | / ( n |A| ulp )   
+/*     (2)     | A**H  * VL - VL * W**H | / ( n |A| ulp ) */
 
-         Here VL is the matrix of unit left eigenvectors, A**H is the   
-         conjugate transpose of A, and W is as above.   
+/*       Here VL is the matrix of unit left eigenvectors, A**H is the */
+/*       conjugate transpose of A, and W is as above. */
 
-       (3)     | |VR(i)| - 1 | / ulp and largest component real   
+/*     (3)     | |VR(i)| - 1 | / ulp and largest component real */
 
-         VR(i) denotes the i-th column of VR.   
+/*       VR(i) denotes the i-th column of VR. */
 
-       (4)     | |VL(i)| - 1 | / ulp and largest component real   
+/*     (4)     | |VL(i)| - 1 | / ulp and largest component real */
 
-         VL(i) denotes the i-th column of VL.   
+/*       VL(i) denotes the i-th column of VL. */
 
-       (5)     W(full) = W(partial)   
+/*     (5)     W(full) = W(partial) */
 
-         W(full) denotes the eigenvalues computed when VR, VL, RCONDV   
-         and RCONDE are also computed, and W(partial) denotes the   
-         eigenvalues computed when only some of VR, VL, RCONDV, and   
-         RCONDE are computed.   
+/*       W(full) denotes the eigenvalues computed when VR, VL, RCONDV */
+/*       and RCONDE are also computed, and W(partial) denotes the */
+/*       eigenvalues computed when only some of VR, VL, RCONDV, and */
+/*       RCONDE are computed. */
 
-       (6)     VR(full) = VR(partial)   
+/*     (6)     VR(full) = VR(partial) */
+
+/*       VR(full) denotes the right eigenvectors computed when VL, RCONDV */
+/*       and RCONDE are computed, and VR(partial) denotes the result */
+/*       when only some of VL and RCONDV are computed. */
+
+/*     (7)     VL(full) = VL(partial) */
+
+/*       VL(full) denotes the left eigenvectors computed when VR, RCONDV */
+/*       and RCONDE are computed, and VL(partial) denotes the result */
+/*       when only some of VR and RCONDV are computed. */
 
-         VR(full) denotes the right eigenvectors computed when VL, RCONDV   
-         and RCONDE are computed, and VR(partial) denotes the result   
-         when only some of VL and RCONDV are computed.   
+/*     (8)     0 if SCALE, ILO, IHI, ABNRM (full) = */
+/*                  SCALE, ILO, IHI, ABNRM (partial) */
+/*             1/ulp otherwise */
+
+/*       SCALE, ILO, IHI and ABNRM describe how the matrix is balanced. */
+/*       (full) is when VR, VL, RCONDE and RCONDV are also computed, and */
+/*       (partial) is when some are not computed. */
 
-       (7)     VL(full) = VL(partial)   
-
-         VL(full) denotes the left eigenvectors computed when VR, RCONDV   
-         and RCONDE are computed, and VL(partial) denotes the result   
-         when only some of VR and RCONDV are computed.   
-
-       (8)     0 if SCALE, ILO, IHI, ABNRM (full) =   
-                    SCALE, ILO, IHI, ABNRM (partial)   
-               1/ulp otherwise   
-
-         SCALE, ILO, IHI and ABNRM describe how the matrix is balanced.   
-         (full) is when VR, VL, RCONDE and RCONDV are also computed, and   
-         (partial) is when some are not computed.   
-
-       (9)     RCONDV(full) = RCONDV(partial)   
-
-         RCONDV(full) denotes the reciprocal condition numbers of the   
-         right eigenvectors computed when VR, VL and RCONDE are also   
-         computed. RCONDV(partial) denotes the reciprocal condition   
-         numbers when only some of VR, VL and RCONDE are computed.   
-
-       The "sizes" are specified by an array NN(1:NSIZES); the value of   
-       each element NN(j) specifies one size.   
-       The "types" are specified by a logical array DOTYPE( 1:NTYPES );   
-       if DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-       Currently, the list of possible types is:   
-
-       (1)  The zero matrix.   
-       (2)  The identity matrix.   
-       (3)  A (transposed) Jordan block, with 1's on the diagonal.   
-
-       (4)  A diagonal matrix with evenly spaced entries   
-            1, ..., ULP  and random complex angles.   
-            (ULP = (first number larger than 1) - 1 )   
-       (5)  A diagonal matrix with geometrically spaced entries   
-            1, ..., ULP  and random complex angles.   
-       (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP   
-            and random complex angles.   
-
-       (7)  Same as (4), but multiplied by a constant near   
-            the overflow threshold   
-       (8)  Same as (4), but multiplied by a constant near   
-            the underflow threshold   
-
-       (9)  A matrix of the form  U' T U, where U is unitary and   
-            T has evenly spaced entries 1, ..., ULP with random complex   
-            angles on the diagonal and random O(1) entries in the upper   
-            triangle.   
-
-       (10) A matrix of the form  U' T U, where U is unitary and   
-            T has geometrically spaced entries 1, ..., ULP with random   
-            complex angles on the diagonal and random O(1) entries in   
-            the upper triangle.   
-
-       (11) A matrix of the form  U' T U, where U is unitary and   
-            T has "clustered" entries 1, ULP,..., ULP with random   
-            complex angles on the diagonal and random O(1) entries in   
-            the upper triangle.   
-
-       (12) A matrix of the form  U' T U, where U is unitary and   
-            T has complex eigenvalues randomly chosen from   
-            ULP < |z| < 1   and random O(1) entries in the upper   
-            triangle.   
-
-       (13) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP   
-            with random complex angles on the diagonal and random O(1)   
-            entries in the upper triangle.   
-
-       (14) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has geometrically spaced entries   
-            1, ..., ULP with random complex angles on the diagonal   
-            and random O(1) entries in the upper triangle.   
-
-       (15) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP   
-            with random complex angles on the diagonal and random O(1)   
-            entries in the upper triangle.   
-
-       (16) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has complex eigenvalues randomly chosen   
-            from ULP < |z| < 1 and random O(1) entries in the upper   
-            triangle.   
-
-       (17) Same as (16), but multiplied by a constant   
-            near the overflow threshold   
-       (18) Same as (16), but multiplied by a constant   
-            near the underflow threshold   
-
-       (19) Nonsymmetric matrix with random entries chosen from |z| < 1   
-            If N is at least 4, all entries in first two rows and last   
-            row, and first column and last two columns are zero.   
-       (20) Same as (19), but multiplied by a constant   
-            near the overflow threshold   
-       (21) Same as (19), but multiplied by a constant   
-            near the underflow threshold   
-
-       In addition, an input file will be read from logical unit number   
-       NIUNIT. The file contains matrices along with precomputed   
-       eigenvalues and reciprocal condition numbers for the eigenvalues   
-       and right eigenvectors. For these matrices, in addition to tests   
-       (1) to (9) we will compute the following two tests:   
-
-      (10)  |RCONDV - RCDVIN| / cond(RCONDV)   
-
-         RCONDV is the reciprocal right eigenvector condition number   
-         computed by CGEEVX and RCDVIN (the precomputed true value)   
-         is supplied as input. cond(RCONDV) is the condition number of   
-         RCONDV, and takes errors in computing RCONDV into account, so   
-         that the resulting quantity should be O(ULP). cond(RCONDV) is   
-         essentially given by norm(A)/RCONDE.   
-
-      (11)  |RCONDE - RCDEIN| / cond(RCONDE)   
-
-         RCONDE is the reciprocal eigenvalue condition number   
-         computed by CGEEVX and RCDEIN (the precomputed true value)   
-         is supplied as input.  cond(RCONDE) is the condition number   
-         of RCONDE, and takes errors in computing RCONDE into account,   
-         so that the resulting quantity should be O(ULP). cond(RCONDE)   
-         is essentially given by norm(A)/RCONDV.   
-
-    Arguments   
-    ==========   
-
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  NSIZES must be at   
-            least zero. If it is zero, no randomly generated matrices   
-            are tested, but any test matrices read from NIUNIT will be   
-            tested.   
-
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  The values must be at least   
-            zero.   
-
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE. NTYPES must be at least   
-            zero. If it is zero, no randomly generated test matrices   
-            are tested, but and test matrices read from NIUNIT will be   
-            tested. If it is MAXTYP+1 and NSIZES is 1, then an   
-            additional type, MAXTYP+1 is defined, which is to use   
-            whatever matrix is in A.  This is only useful if   
-            DOTYPE(1:MAXTYP) is .FALSE. and DOTYPE(MAXTYP+1) is .TRUE. .   
-
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated.  If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
-
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096.  Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to CDRVVX to continue the same random number   
-            sequence.   
-
-    THRESH  (input) REAL   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
-
-    NIUNIT  (input) INTEGER   
-            The FORTRAN unit number for reading in the data file of   
-            problems to solve.   
-
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns INFO not equal to 0.)   
-
-    A       (workspace) COMPLEX array, dimension (LDA, max(NN,12))   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, and H. LDA must be at   
-            least 1 and at least max( NN, 12 ). (12 is the   
-            dimension of the largest matrix on the precomputed   
-            input file.)   
-
-    H       (workspace) COMPLEX array, dimension (LDA, max(NN,12))   
-            Another copy of the test matrix A, modified by CGEEVX.   
-
-    W       (workspace) COMPLEX array, dimension (max(NN,12))   
-            Contains the eigenvalues of A.   
-
-    W1      (workspace) COMPLEX array, dimension (max(NN,12))   
-            Like W, this array contains the eigenvalues of A,   
-            but those computed when CGEEVX only computes a partial   
-            eigendecomposition, i.e. not the eigenvalues and left   
-            and right eigenvectors.   
-
-    VL      (workspace) COMPLEX array, dimension (LDVL, max(NN,12))   
-            VL holds the computed left eigenvectors.   
-
-    LDVL    (input) INTEGER   
-            Leading dimension of VL. Must be at least max(1,max(NN,12)).   
-
-    VR      (workspace) COMPLEX array, dimension (LDVR, max(NN,12))   
-            VR holds the computed right eigenvectors.   
-
-    LDVR    (input) INTEGER   
-            Leading dimension of VR. Must be at least max(1,max(NN,12)).   
-
-    LRE     (workspace) COMPLEX array, dimension (LDLRE, max(NN,12))   
-            LRE holds the computed right or left eigenvectors.   
-
-    LDLRE   (input) INTEGER   
-            Leading dimension of LRE. Must be at least max(1,max(NN,12))   
-
-    RESULT  (output) REAL array, dimension (11)   
-            The values computed by the seven tests described above.   
-            The values are currently limited to 1/ulp, to avoid   
-            overflow.   
-
-    WORK    (workspace) COMPLEX array, dimension (NWORK)   
-
-    NWORK   (input) INTEGER   
-            The number of entries in WORK.  This must be at least   
-            max(6*12+2*12**2,6*NN(j)+2*NN(j)**2) =   
-            max(    360     ,6*NN(j)+2*NN(j)**2)    for all j.   
-
-    RWORK   (workspace) REAL array, dimension (2*max(NN,12))   
-
-    INFO    (output) INTEGER   
-            If 0,  then successful exit.   
-            If <0, then input paramter -INFO is incorrect.   
-            If >0, CLATMR, CLATMS, CLATME or CGET23 returned an error   
-                   code, and INFO is its absolute value.   
-
-   -----------------------------------------------------------------------   
-
-       Some Local Variables and Parameters:   
-       ---- ----- --------- --- ----------   
-
-       ZERO, ONE       Real 0 and 1.   
-       MAXTYP          The number of types defined.   
-       NMAX            Largest value in NN or 12.   
-       NERRS           The number of tests which have exceeded THRESH   
-       COND, CONDS,   
-       IMODE           Values to be passed to the matrix generators.   
-       ANORM           Norm of A; passed to matrix generators.   
-
-       OVFL, UNFL      Overflow and underflow thresholds.   
-       ULP, ULPINV     Finest relative precision and its inverse.   
-       RTULP, RTULPI   Square roots of the previous 4 values.   
-
-               The following four arrays decode JTYPE:   
-       KTYPE(j)        The general type (1-10) for type "j".   
-       KMODE(j)        The MODE value to be passed to the matrix   
-                       generator for type "j".   
-       KMAGN(j)        The order of magnitude ( O(1),   
-                       O(overflow^(1/2) ), O(underflow^(1/2) )   
-       KCONDS(j)       Selectw whether CONDS is to be 1 or   
-                       1/sqrt(ulp).  (0 means irrelevant.)   
-
-    =====================================================================   
-
-       Parameter adjustments */
+/*     (9)     RCONDV(full) = RCONDV(partial) */
+
+/*       RCONDV(full) denotes the reciprocal condition numbers of the */
+/*       right eigenvectors computed when VR, VL and RCONDE are also */
+/*       computed. RCONDV(partial) denotes the reciprocal condition */
+/*       numbers when only some of VR, VL and RCONDE are computed. */
+
+/*     The "sizes" are specified by an array NN(1:NSIZES); the value of */
+/*     each element NN(j) specifies one size. */
+/*     The "types" are specified by a logical array DOTYPE( 1:NTYPES ); */
+/*     if DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*     Currently, the list of possible types is: */
+
+/*     (1)  The zero matrix. */
+/*     (2)  The identity matrix. */
+/*     (3)  A (transposed) Jordan block, with 1's on the diagonal. */
+
+/*     (4)  A diagonal matrix with evenly spaced entries */
+/*          1, ..., ULP  and random complex angles. */
+/*          (ULP = (first number larger than 1) - 1 ) */
+/*     (5)  A diagonal matrix with geometrically spaced entries */
+/*          1, ..., ULP  and random complex angles. */
+/*     (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP */
+/*          and random complex angles. */
+
+/*     (7)  Same as (4), but multiplied by a constant near */
+/*          the overflow threshold */
+/*     (8)  Same as (4), but multiplied by a constant near */
+/*          the underflow threshold */
+
+/*     (9)  A matrix of the form  U' T U, where U is unitary and */
+/*          T has evenly spaced entries 1, ..., ULP with random complex */
+/*          angles on the diagonal and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (10) A matrix of the form  U' T U, where U is unitary and */
+/*          T has geometrically spaced entries 1, ..., ULP with random */
+/*          complex angles on the diagonal and random O(1) entries in */
+/*          the upper triangle. */
+
+/*     (11) A matrix of the form  U' T U, where U is unitary and */
+/*          T has "clustered" entries 1, ULP,..., ULP with random */
+/*          complex angles on the diagonal and random O(1) entries in */
+/*          the upper triangle. */
+
+/*     (12) A matrix of the form  U' T U, where U is unitary and */
+/*          T has complex eigenvalues randomly chosen from */
+/*          ULP < |z| < 1   and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (13) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP */
+/*          with random complex angles on the diagonal and random O(1) */
+/*          entries in the upper triangle. */
+
+/*     (14) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has geometrically spaced entries */
+/*          1, ..., ULP with random complex angles on the diagonal */
+/*          and random O(1) entries in the upper triangle. */
+
+/*     (15) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP */
+/*          with random complex angles on the diagonal and random O(1) */
+/*          entries in the upper triangle. */
+
+/*     (16) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has complex eigenvalues randomly chosen */
+/*          from ULP < |z| < 1 and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (17) Same as (16), but multiplied by a constant */
+/*          near the overflow threshold */
+/*     (18) Same as (16), but multiplied by a constant */
+/*          near the underflow threshold */
+
+/*     (19) Nonsymmetric matrix with random entries chosen from |z| < 1 */
+/*          If N is at least 4, all entries in first two rows and last */
+/*          row, and first column and last two columns are zero. */
+/*     (20) Same as (19), but multiplied by a constant */
+/*          near the overflow threshold */
+/*     (21) Same as (19), but multiplied by a constant */
+/*          near the underflow threshold */
+
+/*     In addition, an input file will be read from logical unit number */
+/*     NIUNIT. The file contains matrices along with precomputed */
+/*     eigenvalues and reciprocal condition numbers for the eigenvalues */
+/*     and right eigenvectors. For these matrices, in addition to tests */
+/*     (1) to (9) we will compute the following two tests: */
+
+/*    (10)  |RCONDV - RCDVIN| / cond(RCONDV) */
+
+/*       RCONDV is the reciprocal right eigenvector condition number */
+/*       computed by CGEEVX and RCDVIN (the precomputed true value) */
+/*       is supplied as input. cond(RCONDV) is the condition number of */
+/*       RCONDV, and takes errors in computing RCONDV into account, so */
+/*       that the resulting quantity should be O(ULP). cond(RCONDV) is */
+/*       essentially given by norm(A)/RCONDE. */
+
+/*    (11)  |RCONDE - RCDEIN| / cond(RCONDE) */
+
+/*       RCONDE is the reciprocal eigenvalue condition number */
+/*       computed by CGEEVX and RCDEIN (the precomputed true value) */
+/*       is supplied as input.  cond(RCONDE) is the condition number */
+/*       of RCONDE, and takes errors in computing RCONDE into account, */
+/*       so that the resulting quantity should be O(ULP). cond(RCONDE) */
+/*       is essentially given by norm(A)/RCONDV. */
+
+/*  Arguments */
+/*  ========== */
+
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  NSIZES must be at */
+/*          least zero. If it is zero, no randomly generated matrices */
+/*          are tested, but any test matrices read from NIUNIT will be */
+/*          tested. */
+
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  The values must be at least */
+/*          zero. */
+
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE. NTYPES must be at least */
+/*          zero. If it is zero, no randomly generated test matrices */
+/*          are tested, but and test matrices read from NIUNIT will be */
+/*          tested. If it is MAXTYP+1 and NSIZES is 1, then an */
+/*          additional type, MAXTYP+1 is defined, which is to use */
+/*          whatever matrix is in A.  This is only useful if */
+/*          DOTYPE(1:MAXTYP) is .FALSE. and DOTYPE(MAXTYP+1) is .TRUE. . */
+
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated.  If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
+
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096.  Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to CDRVVX to continue the same random number */
+/*          sequence. */
+
+/*  THRESH  (input) REAL */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
+
+/*  NIUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for reading in the data file of */
+/*          problems to solve. */
+
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns INFO not equal to 0.) */
+
+/*  A       (workspace) COMPLEX array, dimension (LDA, max(NN,12)) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, and H. LDA must be at */
+/*          least 1 and at least max( NN, 12 ). (12 is the */
+/*          dimension of the largest matrix on the precomputed */
+/*          input file.) */
+
+/*  H       (workspace) COMPLEX array, dimension (LDA, max(NN,12)) */
+/*          Another copy of the test matrix A, modified by CGEEVX. */
+
+/*  W       (workspace) COMPLEX array, dimension (max(NN,12)) */
+/*          Contains the eigenvalues of A. */
+
+/*  W1      (workspace) COMPLEX array, dimension (max(NN,12)) */
+/*          Like W, this array contains the eigenvalues of A, */
+/*          but those computed when CGEEVX only computes a partial */
+/*          eigendecomposition, i.e. not the eigenvalues and left */
+/*          and right eigenvectors. */
+
+/*  VL      (workspace) COMPLEX array, dimension (LDVL, max(NN,12)) */
+/*          VL holds the computed left eigenvectors. */
+
+/*  LDVL    (input) INTEGER */
+/*          Leading dimension of VL. Must be at least max(1,max(NN,12)). */
+
+/*  VR      (workspace) COMPLEX array, dimension (LDVR, max(NN,12)) */
+/*          VR holds the computed right eigenvectors. */
+
+/*  LDVR    (input) INTEGER */
+/*          Leading dimension of VR. Must be at least max(1,max(NN,12)). */
+
+/*  LRE     (workspace) COMPLEX array, dimension (LDLRE, max(NN,12)) */
+/*          LRE holds the computed right or left eigenvectors. */
+
+/*  LDLRE   (input) INTEGER */
+/*          Leading dimension of LRE. Must be at least max(1,max(NN,12)) */
+
+/*  RESULT  (output) REAL array, dimension (11) */
+/*          The values computed by the seven tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid */
+/*          overflow. */
+
+/*  WORK    (workspace) COMPLEX array, dimension (NWORK) */
+
+/*  NWORK   (input) INTEGER */
+/*          The number of entries in WORK.  This must be at least */
+/*          max(6*12+2*12**2,6*NN(j)+2*NN(j)**2) = */
+/*          max(    360     ,6*NN(j)+2*NN(j)**2)    for all j. */
+
+/*  RWORK   (workspace) REAL array, dimension (2*max(NN,12)) */
+
+/*  INFO    (output) INTEGER */
+/*          If 0,  then successful exit. */
+/*          If <0, then input paramter -INFO is incorrect. */
+/*          If >0, CLATMR, CLATMS, CLATME or CGET23 returned an error */
+/*                 code, and INFO is its absolute value. */
+
+/* ----------------------------------------------------------------------- */
+
+/*     Some Local Variables and Parameters: */
+/*     ---- ----- --------- --- ---------- */
+
+/*     ZERO, ONE       Real 0 and 1. */
+/*     MAXTYP          The number of types defined. */
+/*     NMAX            Largest value in NN or 12. */
+/*     NERRS           The number of tests which have exceeded THRESH */
+/*     COND, CONDS, */
+/*     IMODE           Values to be passed to the matrix generators. */
+/*     ANORM           Norm of A; passed to matrix generators. */
+
+/*     OVFL, UNFL      Overflow and underflow thresholds. */
+/*     ULP, ULPINV     Finest relative precision and its inverse. */
+/*     RTULP, RTULPI   Square roots of the previous 4 values. */
+
+/*             The following four arrays decode JTYPE: */
+/*     KTYPE(j)        The general type (1-10) for type "j". */
+/*     KMODE(j)        The MODE value to be passed to the matrix */
+/*                     generator for type "j". */
+/*     KMAGN(j)        The order of magnitude ( O(1), */
+/*                     O(overflow^(1/2) ), O(underflow^(1/2) ) */
+/*     KCONDS(j)       Selectw whether CONDS is to be 1 or */
+/*                     1/sqrt(ulp).  (0 means irrelevant.) */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -531,6 +536,8 @@ static integer c__22 = 22;
     --rwork;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "VX", (ftnlen)2, (ftnlen)2);
@@ -545,8 +552,8 @@ static integer c__22 = 22;
 
     badnn = FALSE_;
 
-/*     7 is the largest dimension in the input file of precomputed   
-       problems */
+/*     7 is the largest dimension in the input file of precomputed */
+/*     problems */
 
     nmax = 7;
     i__1 = *nsizes;
@@ -634,21 +641,21 @@ static integer c__22 = 22;
 /* L20: */
 	    }
 
-/*           Compute "A"   
+/*           Compute "A" */
 
-             Control parameters:   
+/*           Control parameters: */
 
-             KMAGN  KCONDS  KMODE        KTYPE   
-         =1  O(1)   1       clustered 1  zero   
-         =2  large  large   clustered 2  identity   
-         =3  small          exponential  Jordan   
-         =4                 arithmetic   diagonal, (w/ eigenvalues)   
-         =5                 random log   symmetric, w/ eigenvalues   
-         =6                 random       general, w/ eigenvalues   
-         =7                              random diagonal   
-         =8                              random symmetric   
-         =9                              random general   
-         =10                             random triangular */
+/*           KMAGN  KCONDS  KMODE        KTYPE */
+/*       =1  O(1)   1       clustered 1  zero */
+/*       =2  large  large   clustered 2  identity */
+/*       =3  small          exponential  Jordan */
+/*       =4                 arithmetic   diagonal, (w/ eigenvalues) */
+/*       =5                 random log   symmetric, w/ eigenvalues */
+/*       =6                 random       general, w/ eigenvalues */
+/*       =7                              random diagonal */
+/*       =8                              random symmetric */
+/*       =9                              random general */
+/*       =10                             random triangular */
 
 	    if (mtypes > 21) {
 		goto L90;
@@ -683,9 +690,9 @@ L60:
 	    iinfo = 0;
 	    cond = ulpinv;
 
-/*           Special Matrices -- Identity & Jordan block   
+/*           Special Matrices -- Identity & Jordan block */
 
-                Zero */
+/*              Zero */
 
 	    if (itype == 1) {
 		iinfo = 0;
@@ -720,7 +727,7 @@ L60:
 
 /*              Diagonal Matrix, [Eigen]values Specified */
 
-		clatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond,
+		clatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond, 
 			 &anorm, &c__0, &c__0, "N", &a[a_offset], lda, &work[
 			n + 1], &iinfo);
 
@@ -728,8 +735,8 @@ L60:
 
 /*              Symmetric, eigenvalues specified */
 
-		clatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond,
-			 &anorm, &n, &n, "N", &a[a_offset], lda, &work[n + 1],
+		clatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond, 
+			 &anorm, &n, &n, "N", &a[a_offset], lda, &work[n + 1], 
 			 &iinfo);
 
 	    } else if (itype == 6) {
@@ -756,7 +763,7 @@ L60:
 		clatmr_(&n, &n, "D", &iseed[1], "S", &work[1], &c__6, &c_b39, 
 			&c_b2, "T", "N", &work[n + 1], &c__1, &c_b39, &work[(
 			n << 1) + 1], &c__1, &c_b39, "N", idumma, &c__0, &
-			c__0, &c_b49, &anorm, "NO", &a[a_offset], lda, idumma,
+			c__0, &c_b49, &anorm, "NO", &a[a_offset], lda, idumma, 
 			 &iinfo);
 
 	    } else if (itype == 8) {
@@ -783,7 +790,7 @@ L60:
 			    lda);
 		    i__3 = n - 3;
 		    claset_("Full", &i__3, &c__1, &c_b1, &c_b1, &a[a_dim1 + 3]
-			    , lda);
+, lda);
 		    i__3 = n - 3;
 		    claset_("Full", &i__3, &c__2, &c_b1, &c_b1, &a[(n - 1) * 
 			    a_dim1 + 3], lda);
@@ -886,7 +893,8 @@ L90:
 			e_wsfe();
 			io___43.ciunit = *nounit;
 			s_wsfe(&io___43);
-			do_fio(&c__1, (char *)&(*thresh), (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&(*thresh), (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			ntestf = 2;
 		    }
@@ -928,9 +936,9 @@ L140:
 
 L160:
 
-/*     Read in data from file to check accuracy of condition estimation.   
-       Assume input eigenvalues are sorted lexicographically (increasing   
-       by real part, then decreasing by imaginary part) */
+/*     Read in data from file to check accuracy of condition estimation. */
+/*     Assume input eigenvalues are sorted lexicographically (increasing */
+/*     by real part, then decreasing by imaginary part) */
 
     jtype = 0;
 L170:
