@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cerrhs.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -55,24 +43,24 @@ static integer c__4 = 4;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static complex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
-    static integer i__, j, m;
-    static real s[3];
-    static complex w[9], x[3];
-    static char c2[2];
-    static integer nt;
-    static complex vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */;
-    static real rw[3];
-    static integer ihi, ilo;
-    static logical sel[3];
-    static complex tau[3];
-    static integer info;
+    complex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
+    integer i__, j, m;
+    real s[3];
+    complex w[9], x[3];
+    char c2[2];
+    integer nt;
+    complex vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */;
+    real rw[3];
+    integer ihi, ilo;
+    logical sel[3];
+    complex tau[3];
+    integer info;
     extern /* Subroutine */ int cgebak_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, complex *, integer *, integer *), cgebal_(char *, integer *, complex *, integer *, 
 	    integer *, integer *, real *, integer *), cgehrd_(integer 
 	    *, integer *, integer *, complex *, integer *, complex *, complex 
 	    *, integer *, integer *);
-    static integer ifaill[3], ifailr[3];
+    integer ifaill[3], ifailr[3];
     extern /* Subroutine */ int chsein_(char *, char *, char *, logical *, 
 	    integer *, complex *, integer *, complex *, complex *, integer *, 
 	    complex *, integer *, integer *, integer *, complex *, real *, 
@@ -96,28 +84,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CERRHS tests the error exits for CGEBAK, CGEBAL, CGEHRD, CUNGHR,   
-    CUNMHR, CHSEQR, CHSEIN, and CTREVC.   
+/*  CERRHS tests the error exits for CGEBAK, CGEBAL, CGEHRD, CUNGHR, */
+/*  CUNMHR, CHSEQR, CHSEIN, and CTREVC. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
