@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cerrst.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -64,19 +52,19 @@ static real c_b472 = 1.f;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static complex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
-    static real d__[3], e[3];
-    static integer i__, j, m, n;
-    static complex q[9]	/* was [3][3] */;
-    static real r__[60];
-    static complex w[60];
-    static real x[3];
-    static complex z__[9]	/* was [3][3] */;
-    static char c2[2];
-    static integer i1[3], i2[3], i3[3], iw[36], nt;
-    static real rw[60];
-    static complex tau[3];
-    static integer info;
+    complex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
+    real d__[3], e[3];
+    integer i__, j, m, n;
+    complex q[9]	/* was [3][3] */;
+    real r__[60];
+    complex w[60];
+    real x[3];
+    complex z__[9]	/* was [3][3] */;
+    char c2[2];
+    integer i1[3], i2[3], i3[3], iw[36], nt;
+    real rw[60];
+    complex tau[3];
+    integer info;
     extern /* Subroutine */ int chbev_(char *, char *, integer *, integer *, 
 	    complex *, integer *, real *, complex *, integer *, complex *, 
 	    real *, integer *), cheev_(char *, char *, 
@@ -98,30 +86,33 @@ static real c_b472 = 1.f;
 	    integer *, complex *, real *, complex *, integer *, complex *, 
 	    integer *, real *, integer *, integer *, integer *, integer *), cheevr_(char *, char *, char *, integer *, 
 	    complex *, integer *, real *, real *, integer *, integer *, real *
-	    , integer *, real *, complex *, integer *, integer *, complex *, 
+, integer *, real *, complex *, integer *, integer *, complex *, 
 	    integer *, real *, integer *, integer *, integer *, integer *);
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int chbevx_(char *, char *, char *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, integer *, integer *, real *, integer *, real *, complex *
-	    , integer *, complex *, real *, integer *, integer *, integer *), cheevx_(char *, char *, char *, integer *
-	    , complex *, integer *, real *, real *, integer *, integer *, 
+, integer *, complex *, real *, integer *, integer *, integer *), cheevx_(char *, char *, char *, integer *
+, complex *, integer *, real *, real *, integer *, integer *, 
 	    real *, integer *, real *, complex *, integer *, complex *, 
-	    integer *, real *, integer *, integer *, integer *), chkxer_(char *, integer *, integer *, logical *,	    logical *), chptrd_(char *, integer *, complex *, real *, 
+	    integer *, real *, integer *, integer *, integer *), chkxer_(char *, integer *, integer *, logical *, 
+	    logical *), chptrd_(char *, integer *, complex *, real *, 
 	    real *, complex *, integer *), cstein_(integer *, real *, 
 	    real *, integer *, real *, integer *, integer *, complex *, 
 	    integer *, real *, integer *, integer *, integer *), chpevx_(char 
 	    *, char *, char *, integer *, complex *, real *, real *, integer *
-	    , integer *, real *, integer *, real *, complex *, integer *, 
+, integer *, real *, integer *, real *, complex *, integer *, 
 	    complex *, real *, integer *, integer *, integer *), cpteqr_(char *, integer *, real *, real *, 
-	    complex *, integer *, real *, integer *), csteqr_(char *,  	    integer *, real *, real *, complex *, integer *, real *, integer * 	    ), cungtr_(char *, integer *, complex *, integer *, 
+	    complex *, integer *, real *, integer *), csteqr_(char *, 
+	    integer *, real *, real *, complex *, integer *, real *, integer *
+), cungtr_(char *, integer *, complex *, integer *, 
 	    complex *, complex *, integer *, integer *), cupgtr_(char 
 	    *, integer *, complex *, complex *, complex *, integer *, complex 
 	    *, integer *), cunmtr_(char *, char *, char *, integer *, 
 	    integer *, complex *, integer *, complex *, complex *, integer *, 
 	    complex *, integer *, integer *), cupmtr_(
 	    char *, char *, char *, integer *, integer *, complex *, complex *
-	    , complex *, integer *, complex *, integer *);
+, complex *, integer *, complex *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 0, 0, 0, 0 };
@@ -130,30 +121,49 @@ static real c_b472 = 1.f;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CERRST tests the error exits for CHETRD, CUNGTR, CUNMTR, CHPTRD,   
-    CUNGTR, CUPMTR, CSTEQR, CSTEIN, CPTEQR, CHBTRD,   
-    CHEEV, CHEEVX, CHEEVD, CHBEV, CHBEVX, CHBEVD,   
-    CHPEV, CHPEVX, CHPEVD, and CSTEDC.   
+/*  CERRST tests the error exits for CHETRD, CUNGTR, CUNMTR, CHPTRD, */
+/*  CUNGTR, CUPMTR, CSTEQR, CSTEIN, CPTEQR, CHBTRD, */
+/*  CHEEV, CHEEVX, CHEEVD, CHBEV, CHBEVX, CHBEVD, */
+/*  CHPEV, CHPEVX, CHPEVD, and CSTEDC. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -904,77 +914,77 @@ static real c_b472 = 1.f;
 
 	s_copy(srnamc_1.srnamt, "CHBEVD", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	chbevd_("/", "U", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	chbevd_("/", "U", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	chbevd_("N", "/", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	chbevd_("N", "/", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	chbevd_("N", "U", &c_n1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	chbevd_("N", "U", &c_n1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	chbevd_("N", "U", &c__0, &c_n1, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	chbevd_("N", "U", &c__0, &c_n1, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	chbevd_("N", "U", &c__2, &c__1, a, &c__1, x, z__, &c__1, w, &c__2, rw,
+	chbevd_("N", "U", &c__2, &c__1, a, &c__1, x, z__, &c__1, w, &c__2, rw, 
 		 &c__2, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
-	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__1, w, &c__8, rw,
+	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__1, w, &c__8, rw, 
 		 &c__25, iw, &c__12, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	chbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__0, rw,
+	chbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__0, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	chbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__1, rw,
+	chbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__1, rw, 
 		 &c__2, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw,
+	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw, 
 		 &c__25, iw, &c__12, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	chbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	chbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__0, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	chbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw,
+	chbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw,
+	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw, 
 		 &c__2, iw, &c__12, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	chbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	chbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__0, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	chbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw,
+	chbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw, 
 		 &c__2, iw, &c__0, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw,
+	chbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw, 
 		 &c__25, iw, &c__2, &info);
 	chkxer_("CHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
