@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cget23.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -49,34 +37,35 @@ static integer c__4 = 4;
     double c_abs(complex *), r_imag(complex *);
 
     /* Local variables */
-    static integer i__, j;
-    static real v;
-    static integer jj, ihi, ilo;
-    static real eps, res[2], tol, ulp, vmx;
-    static integer ihi1, ilo1;
-    static complex cdum[1];
-    static integer kmin;
-    static complex ctmp;
-    static real vmax, tnrm, vrmx, vtst;
+    integer i__, j;
+    real v;
+    integer jj, ihi, ilo;
+    real eps, res[2], tol, ulp, vmx;
+    integer ihi1, ilo1;
+    complex cdum[1];
+    integer kmin;
+    complex ctmp;
+    real vmax, tnrm, vrmx, vtst;
     extern /* Subroutine */ int cget22_(char *, char *, char *, integer *, 
 	    complex *, integer *, complex *, integer *, complex *, complex *, 
 	    real *, real *);
-    static logical balok, nobal;
-    static real abnrm;
+    logical balok, nobal;
+    real abnrm;
     extern logical lsame_(char *, char *);
-    static integer iinfo;
-    static char sense[1];
-    static integer isens;
-    static real tolin, abnrm1;
-    extern doublereal scnrm2_(integer *, complex *, integer *), slamch_(char * );
+    integer iinfo;
+    char sense[1];
+    integer isens;
+    real tolin, abnrm1;
+    extern doublereal scnrm2_(integer *, complex *, integer *), slamch_(char *
+);
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), xerbla_(char *, 
 	    integer *), cgeevx_(char *, char *, char *, char *, 
 	    integer *, complex *, integer *, complex *, complex *, integer *, 
 	    complex *, integer *, integer *, integer *, real *, real *, real *
-	    , real *, complex *, integer *, real *, integer *);
-    static integer isensm;
-    static real vricmp, vrimin, smlnum, ulpinv;
+, real *, complex *, integer *, real *, integer *);
+    integer isensm;
+    real vricmp, vrimin, smlnum, ulpinv;
 
     /* Fortran I/O blocks */
     static cilist io___14 = { 0, 0, 0, fmt_9998, 0 };
@@ -91,231 +80,248 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       CGET23  checks the nonsymmetric eigenvalue problem driver CGEEVX.   
-       If COMP = .FALSE., the first 8 of the following tests will be   
-       performed on the input matrix A, and also test 9 if LWORK is   
-       sufficiently large.   
-       if COMP is .TRUE. all 11 tests will be performed.   
+/*     CGET23  checks the nonsymmetric eigenvalue problem driver CGEEVX. */
+/*     If COMP = .FALSE., the first 8 of the following tests will be */
+/*     performed on the input matrix A, and also test 9 if LWORK is */
+/*     sufficiently large. */
+/*     if COMP is .TRUE. all 11 tests will be performed. */
 
-       (1)     | A * VR - VR * W | / ( n |A| ulp )   
+/*     (1)     | A * VR - VR * W | / ( n |A| ulp ) */
 
-         Here VR is the matrix of unit right eigenvectors.   
-         W is a diagonal matrix with diagonal entries W(j).   
+/*       Here VR is the matrix of unit right eigenvectors. */
+/*       W is a diagonal matrix with diagonal entries W(j). */
 
-       (2)     | A**H * VL - VL * W**H | / ( n |A| ulp )   
+/*     (2)     | A**H * VL - VL * W**H | / ( n |A| ulp ) */
 
-         Here VL is the matrix of unit left eigenvectors, A**H is the   
-         conjugate transpose of A, and W is as above.   
+/*       Here VL is the matrix of unit left eigenvectors, A**H is the */
+/*       conjugate transpose of A, and W is as above. */
 
-       (3)     | |VR(i)| - 1 | / ulp and largest component real   
+/*     (3)     | |VR(i)| - 1 | / ulp and largest component real */
 
-         VR(i) denotes the i-th column of VR.   
+/*       VR(i) denotes the i-th column of VR. */
 
-       (4)     | |VL(i)| - 1 | / ulp and largest component real   
+/*     (4)     | |VL(i)| - 1 | / ulp and largest component real */
 
-         VL(i) denotes the i-th column of VL.   
+/*       VL(i) denotes the i-th column of VL. */
 
-       (5)     0 if W(full) = W(partial), 1/ulp otherwise   
+/*     (5)     0 if W(full) = W(partial), 1/ulp otherwise */
 
-         W(full) denotes the eigenvalues computed when VR, VL, RCONDV   
-         and RCONDE are also computed, and W(partial) denotes the   
-         eigenvalues computed when only some of VR, VL, RCONDV, and   
-         RCONDE are computed.   
+/*       W(full) denotes the eigenvalues computed when VR, VL, RCONDV */
+/*       and RCONDE are also computed, and W(partial) denotes the */
+/*       eigenvalues computed when only some of VR, VL, RCONDV, and */
+/*       RCONDE are computed. */
 
-       (6)     0 if VR(full) = VR(partial), 1/ulp otherwise   
+/*     (6)     0 if VR(full) = VR(partial), 1/ulp otherwise */
 
-         VR(full) denotes the right eigenvectors computed when VL, RCONDV   
-         and RCONDE are computed, and VR(partial) denotes the result   
-         when only some of VL and RCONDV are computed.   
+/*       VR(full) denotes the right eigenvectors computed when VL, RCONDV */
+/*       and RCONDE are computed, and VR(partial) denotes the result */
+/*       when only some of VL and RCONDV are computed. */
 
-       (7)     0 if VL(full) = VL(partial), 1/ulp otherwise   
+/*     (7)     0 if VL(full) = VL(partial), 1/ulp otherwise */
 
-         VL(full) denotes the left eigenvectors computed when VR, RCONDV   
-         and RCONDE are computed, and VL(partial) denotes the result   
-         when only some of VR and RCONDV are computed.   
+/*       VL(full) denotes the left eigenvectors computed when VR, RCONDV */
+/*       and RCONDE are computed, and VL(partial) denotes the result */
+/*       when only some of VR and RCONDV are computed. */
 
-       (8)     0 if SCALE, ILO, IHI, ABNRM (full) =   
-                    SCALE, ILO, IHI, ABNRM (partial)   
-               1/ulp otherwise   
+/*     (8)     0 if SCALE, ILO, IHI, ABNRM (full) = */
+/*                  SCALE, ILO, IHI, ABNRM (partial) */
+/*             1/ulp otherwise */
 
-         SCALE, ILO, IHI and ABNRM describe how the matrix is balanced.   
-         (full) is when VR, VL, RCONDE and RCONDV are also computed, and   
-         (partial) is when some are not computed.   
+/*       SCALE, ILO, IHI and ABNRM describe how the matrix is balanced. */
+/*       (full) is when VR, VL, RCONDE and RCONDV are also computed, and */
+/*       (partial) is when some are not computed. */
 
-       (9)     0 if RCONDV(full) = RCONDV(partial), 1/ulp otherwise   
+/*     (9)     0 if RCONDV(full) = RCONDV(partial), 1/ulp otherwise */
 
-         RCONDV(full) denotes the reciprocal condition numbers of the   
-         right eigenvectors computed when VR, VL and RCONDE are also   
-         computed. RCONDV(partial) denotes the reciprocal condition   
-         numbers when only some of VR, VL and RCONDE are computed.   
+/*       RCONDV(full) denotes the reciprocal condition numbers of the */
+/*       right eigenvectors computed when VR, VL and RCONDE are also */
+/*       computed. RCONDV(partial) denotes the reciprocal condition */
+/*       numbers when only some of VR, VL and RCONDE are computed. */
 
-      (10)     |RCONDV - RCDVIN| / cond(RCONDV)   
+/*    (10)     |RCONDV - RCDVIN| / cond(RCONDV) */
 
-         RCONDV is the reciprocal right eigenvector condition number   
-         computed by CGEEVX and RCDVIN (the precomputed true value)   
-         is supplied as input. cond(RCONDV) is the condition number of   
-         RCONDV, and takes errors in computing RCONDV into account, so   
-         that the resulting quantity should be O(ULP). cond(RCONDV) is   
-         essentially given by norm(A)/RCONDE.   
+/*       RCONDV is the reciprocal right eigenvector condition number */
+/*       computed by CGEEVX and RCDVIN (the precomputed true value) */
+/*       is supplied as input. cond(RCONDV) is the condition number of */
+/*       RCONDV, and takes errors in computing RCONDV into account, so */
+/*       that the resulting quantity should be O(ULP). cond(RCONDV) is */
+/*       essentially given by norm(A)/RCONDE. */
 
-      (11)     |RCONDE - RCDEIN| / cond(RCONDE)   
+/*    (11)     |RCONDE - RCDEIN| / cond(RCONDE) */
 
-         RCONDE is the reciprocal eigenvalue condition number   
-         computed by CGEEVX and RCDEIN (the precomputed true value)   
-         is supplied as input.  cond(RCONDE) is the condition number   
-         of RCONDE, and takes errors in computing RCONDE into account,   
-         so that the resulting quantity should be O(ULP). cond(RCONDE)   
-         is essentially given by norm(A)/RCONDV.   
+/*       RCONDE is the reciprocal eigenvalue condition number */
+/*       computed by CGEEVX and RCDEIN (the precomputed true value) */
+/*       is supplied as input.  cond(RCONDE) is the condition number */
+/*       of RCONDE, and takes errors in computing RCONDE into account, */
+/*       so that the resulting quantity should be O(ULP). cond(RCONDE) */
+/*       is essentially given by norm(A)/RCONDV. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    COMP    (input) LOGICAL   
-            COMP describes which input tests to perform:   
-              = .FALSE. if the computed condition numbers are not to   
-                        be tested against RCDVIN and RCDEIN   
-              = .TRUE.  if they are to be compared   
+/*  COMP    (input) LOGICAL */
+/*          COMP describes which input tests to perform: */
+/*            = .FALSE. if the computed condition numbers are not to */
+/*                      be tested against RCDVIN and RCDEIN */
+/*            = .TRUE.  if they are to be compared */
 
-    ISRT    (input) INTEGER   
-            If COMP = .TRUE., ISRT indicates in how the eigenvalues   
-            corresponding to values in RCDVIN and RCDEIN are ordered:   
-              = 0 means the eigenvalues are sorted by   
-                  increasing real part   
-              = 1 means the eigenvalues are sorted by   
-                  increasing imaginary part   
-            If COMP = .FALSE., ISRT is not referenced.   
+/*  ISRT    (input) INTEGER */
+/*          If COMP = .TRUE., ISRT indicates in how the eigenvalues */
+/*          corresponding to values in RCDVIN and RCDEIN are ordered: */
+/*            = 0 means the eigenvalues are sorted by */
+/*                increasing real part */
+/*            = 1 means the eigenvalues are sorted by */
+/*                increasing imaginary part */
+/*          If COMP = .FALSE., ISRT is not referenced. */
 
-    BALANC  (input) CHARACTER   
-            Describes the balancing option to be tested.   
-              = 'N' for no permuting or diagonal scaling   
-              = 'P' for permuting but no diagonal scaling   
-              = 'S' for no permuting but diagonal scaling   
-              = 'B' for permuting and diagonal scaling   
+/*  BALANC  (input) CHARACTER */
+/*          Describes the balancing option to be tested. */
+/*            = 'N' for no permuting or diagonal scaling */
+/*            = 'P' for permuting but no diagonal scaling */
+/*            = 'S' for no permuting but diagonal scaling */
+/*            = 'B' for permuting and diagonal scaling */
 
-    JTYPE   (input) INTEGER   
-            Type of input matrix. Used to label output if error occurs.   
+/*  JTYPE   (input) INTEGER */
+/*          Type of input matrix. Used to label output if error occurs. */
 
-    THRESH  (input) REAL   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
+/*  THRESH  (input) REAL */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
 
-    ISEED   (input) INTEGER array, dimension (4)   
-            If COMP = .FALSE., the random number generator seed   
-            used to produce matrix.   
-            If COMP = .TRUE., ISEED(1) = the number of the example.   
-            Used to label output if error occurs.   
+/*  ISEED   (input) INTEGER array, dimension (4) */
+/*          If COMP = .FALSE., the random number generator seed */
+/*          used to produce matrix. */
+/*          If COMP = .TRUE., ISEED(1) = the number of the example. */
+/*          Used to label output if error occurs. */
 
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns INFO not equal to 0.)   
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns INFO not equal to 0.) */
 
-    N       (input) INTEGER   
-            The dimension of A. N must be at least 0.   
+/*  N       (input) INTEGER */
+/*          The dimension of A. N must be at least 0. */
 
-    A       (input/output) COMPLEX array, dimension (LDA,N)   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.   
+/*  A       (input/output) COMPLEX array, dimension (LDA,N) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed. */
 
-    LDA     (input) INTEGER   
-            The leading dimension of A, and H. LDA must be at   
-            least 1 and at least N.   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, and H. LDA must be at */
+/*          least 1 and at least N. */
 
-    H       (workspace) COMPLEX array, dimension (LDA,N)   
-            Another copy of the test matrix A, modified by CGEEVX.   
+/*  H       (workspace) COMPLEX array, dimension (LDA,N) */
+/*          Another copy of the test matrix A, modified by CGEEVX. */
 
-    W       (workspace) COMPLEX array, dimension (N)   
-            Contains the eigenvalues of A.   
+/*  W       (workspace) COMPLEX array, dimension (N) */
+/*          Contains the eigenvalues of A. */
 
-    W1      (workspace) COMPLEX array, dimension (N)   
-            Like W, this array contains the eigenvalues of A,   
-            but those computed when CGEEVX only computes a partial   
-            eigendecomposition, i.e. not the eigenvalues and left   
-            and right eigenvectors.   
+/*  W1      (workspace) COMPLEX array, dimension (N) */
+/*          Like W, this array contains the eigenvalues of A, */
+/*          but those computed when CGEEVX only computes a partial */
+/*          eigendecomposition, i.e. not the eigenvalues and left */
+/*          and right eigenvectors. */
 
-    VL      (workspace) COMPLEX array, dimension (LDVL,N)   
-            VL holds the computed left eigenvectors.   
+/*  VL      (workspace) COMPLEX array, dimension (LDVL,N) */
+/*          VL holds the computed left eigenvectors. */
 
-    LDVL    (input) INTEGER   
-            Leading dimension of VL. Must be at least max(1,N).   
+/*  LDVL    (input) INTEGER */
+/*          Leading dimension of VL. Must be at least max(1,N). */
 
-    VR      (workspace) COMPLEX array, dimension (LDVR,N)   
-            VR holds the computed right eigenvectors.   
+/*  VR      (workspace) COMPLEX array, dimension (LDVR,N) */
+/*          VR holds the computed right eigenvectors. */
 
-    LDVR    (input) INTEGER   
-            Leading dimension of VR. Must be at least max(1,N).   
+/*  LDVR    (input) INTEGER */
+/*          Leading dimension of VR. Must be at least max(1,N). */
 
-    LRE     (workspace) COMPLEX array, dimension (LDLRE,N)   
-            LRE holds the computed right or left eigenvectors.   
+/*  LRE     (workspace) COMPLEX array, dimension (LDLRE,N) */
+/*          LRE holds the computed right or left eigenvectors. */
 
-    LDLRE   (input) INTEGER   
-            Leading dimension of LRE. Must be at least max(1,N).   
+/*  LDLRE   (input) INTEGER */
+/*          Leading dimension of LRE. Must be at least max(1,N). */
 
-    RCONDV  (workspace) REAL array, dimension (N)   
-            RCONDV holds the computed reciprocal condition numbers   
-            for eigenvectors.   
+/*  RCONDV  (workspace) REAL array, dimension (N) */
+/*          RCONDV holds the computed reciprocal condition numbers */
+/*          for eigenvectors. */
 
-    RCNDV1  (workspace) REAL array, dimension (N)   
-            RCNDV1 holds more computed reciprocal condition numbers   
-            for eigenvectors.   
+/*  RCNDV1  (workspace) REAL array, dimension (N) */
+/*          RCNDV1 holds more computed reciprocal condition numbers */
+/*          for eigenvectors. */
 
-    RCDVIN  (input) REAL array, dimension (N)   
-            When COMP = .TRUE. RCDVIN holds the precomputed reciprocal   
-            condition numbers for eigenvectors to be compared with   
-            RCONDV.   
+/*  RCDVIN  (input) REAL array, dimension (N) */
+/*          When COMP = .TRUE. RCDVIN holds the precomputed reciprocal */
+/*          condition numbers for eigenvectors to be compared with */
+/*          RCONDV. */
 
-    RCONDE  (workspace) REAL array, dimension (N)   
-            RCONDE holds the computed reciprocal condition numbers   
-            for eigenvalues.   
+/*  RCONDE  (workspace) REAL array, dimension (N) */
+/*          RCONDE holds the computed reciprocal condition numbers */
+/*          for eigenvalues. */
 
-    RCNDE1  (workspace) REAL array, dimension (N)   
-            RCNDE1 holds more computed reciprocal condition numbers   
-            for eigenvalues.   
+/*  RCNDE1  (workspace) REAL array, dimension (N) */
+/*          RCNDE1 holds more computed reciprocal condition numbers */
+/*          for eigenvalues. */
 
-    RCDEIN  (input) REAL array, dimension (N)   
-            When COMP = .TRUE. RCDEIN holds the precomputed reciprocal   
-            condition numbers for eigenvalues to be compared with   
-            RCONDE.   
+/*  RCDEIN  (input) REAL array, dimension (N) */
+/*          When COMP = .TRUE. RCDEIN holds the precomputed reciprocal */
+/*          condition numbers for eigenvalues to be compared with */
+/*          RCONDE. */
 
-    SCALE   (workspace) REAL array, dimension (N)   
-            Holds information describing balancing of matrix.   
+/*  SCALE   (workspace) REAL array, dimension (N) */
+/*          Holds information describing balancing of matrix. */
 
-    SCALE1  (workspace) REAL array, dimension (N)   
-            Holds information describing balancing of matrix.   
+/*  SCALE1  (workspace) REAL array, dimension (N) */
+/*          Holds information describing balancing of matrix. */
 
-    RESULT  (output) REAL array, dimension (11)   
-            The values computed by the 11 tests described above.   
-            The values are currently limited to 1/ulp, to avoid   
-            overflow.   
+/*  RESULT  (output) REAL array, dimension (11) */
+/*          The values computed by the 11 tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid */
+/*          overflow. */
 
-    WORK    (workspace) COMPLEX array, dimension (LWORK)   
+/*  WORK    (workspace) COMPLEX array, dimension (LWORK) */
 
-    LWORK   (input) INTEGER   
-            The number of entries in WORK.  This must be at least   
-            2*N, and 2*N+N**2 if tests 9, 10 or 11 are to be performed.   
+/*  LWORK   (input) INTEGER */
+/*          The number of entries in WORK.  This must be at least */
+/*          2*N, and 2*N+N**2 if tests 9, 10 or 11 are to be performed. */
 
-    RWORK   (workspace) REAL array, dimension (2*N)   
+/*  RWORK   (workspace) REAL array, dimension (2*N) */
 
-    INFO    (output) INTEGER   
-            If 0,  successful exit.   
-            If <0, input parameter -INFO had an incorrect value.   
-            If >0, CGEEVX returned an error code, the absolute   
-                   value of which is returned.   
+/*  INFO    (output) INTEGER */
+/*          If 0,  successful exit. */
+/*          If <0, input parameter -INFO had an incorrect value. */
+/*          If >0, CGEEVX returned an error code, the absolute */
+/*                 value of which is returned. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iseed;
     h_dim1 = *lda;
     h_offset = 1 + h_dim1;
@@ -346,9 +352,11 @@ static integer c__4 = 4;
     --work;
     --rwork;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors */
+/*     Check for errors */
 
     nobal = lsame_(balanc, "N");
     balok = nobal || lsame_(balanc, "P") || lsame_(
@@ -454,8 +462,8 @@ static integer c__4 = 4;
     i__1 = *n;
     for (j = 1; j <= i__1; ++j) {
 	tnrm = scnrm2_(n, &vr[j * vr_dim1 + 1], &c__1);
-/* Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
 	r__4 = ulpinv, r__5 = (r__1 = tnrm - 1.f, dabs(r__1)) / ulp;
 	r__2 = result[3], r__3 = dmin(r__4,r__5);
 	result[3] = dmax(r__2,r__3);
@@ -486,8 +494,8 @@ static integer c__4 = 4;
     i__1 = *n;
     for (j = 1; j <= i__1; ++j) {
 	tnrm = scnrm2_(n, &vl[j * vl_dim1 + 1], &c__1);
-/* Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
 	r__4 = ulpinv, r__5 = (r__1 = tnrm - 1.f, dabs(r__1)) / ulp;
 	r__2 = result[4], r__3 = dmin(r__4,r__5);
 	result[4] = dmax(r__2,r__3);
@@ -523,7 +531,7 @@ static integer c__4 = 4;
 /*        Compute eigenvalues only, and test them */
 
 	clacpy_("F", n, n, &a[a_offset], lda, &h__[h_offset], lda);
-	cgeevx_(balanc, "N", "N", sense, n, &h__[h_offset], lda, &w1[1], cdum,
+	cgeevx_(balanc, "N", "N", sense, n, &h__[h_offset], lda, &w1[1], cdum, 
 		 &c__1, cdum, &c__1, &ilo1, &ihi1, &scale1[1], &abnrm1, &
 		rcnde1[1], &rcndv1[1], &work[1], lwork, &rwork[1], &iinfo);
 	if (iinfo != 0) {
@@ -599,7 +607,7 @@ static integer c__4 = 4;
 /*        Compute eigenvalues and right eigenvectors, and test them */
 
 	clacpy_("F", n, n, &a[a_offset], lda, &h__[h_offset], lda);
-	cgeevx_(balanc, "N", "V", sense, n, &h__[h_offset], lda, &w1[1], cdum,
+	cgeevx_(balanc, "N", "V", sense, n, &h__[h_offset], lda, &w1[1], cdum, 
 		 &c__1, &lre[lre_offset], ldlre, &ilo1, &ihi1, &scale1[1], &
 		abnrm1, &rcnde1[1], &rcndv1[1], &work[1], lwork, &rwork[1], &
 		iinfo);
@@ -793,7 +801,7 @@ L190:
     if (*comp) {
 	clacpy_("F", n, n, &a[a_offset], lda, &h__[h_offset], lda);
 	cgeevx_("N", "V", "V", "B", n, &h__[h_offset], lda, &w[1], &vl[
-		vl_offset], ldvl, &vr[vr_offset], ldvr, &ilo, &ihi, &scale[1],
+		vl_offset], ldvl, &vr[vr_offset], ldvr, &ilo, &ihi, &scale[1], 
 		 &abnrm, &rconde[1], &rcondv[1], &work[1], lwork, &rwork[1], &
 		iinfo);
 	if (iinfo != 0) {
@@ -809,8 +817,8 @@ L190:
 	    goto L250;
 	}
 
-/*        Sort eigenvalues and condition numbers lexicographically   
-          to compare with inputs */
+/*        Sort eigenvalues and condition numbers lexicographically */
+/*        to compare with inputs */
 
 	i__1 = *n - 1;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -851,8 +859,8 @@ L190:
 /* L220: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        taking their condition numbers into account */
 
 	result[10] = 0.f;
 	eps = dmax(5.9605e-8f,ulp);
@@ -895,8 +903,8 @@ L190:
 /* L230: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          taking their condition numbers into account */
+/*        Compare condition numbers for eigenvalues */
+/*        taking their condition numbers into account */
 
 	result[11] = 0.f;
 	i__1 = *n;
