@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cget37.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -37,30 +25,30 @@ static integer c__0 = 0;
     double r_imag(complex *);
 
     /* Local variables */
-    static integer i__, j, m, n;
-    static real s[20];
-    static complex t[400]	/* was [20][20] */;
-    static real v;
-    static complex w[20], le[400]	/* was [20][20] */, re[400]	/* 
-	    was [20][20] */;
-    static real val[3], dum[1], eps, sep[20], sin__[20], tol;
-    static complex tmp[400]	/* was [20][20] */;
-    static integer icmp;
-    static complex cdum[1];
-    static integer iscl, info, lcmp[3], kmin;
-    static real wiin[20], vmin, vmax, tnrm;
-    static integer isrt;
-    static real wrin[20], vmul, stmp[20];
-    static complex work[1200], wtmp[20];
-    static real wsrt[20];
+    integer i__, j, m, n;
+    real s[20];
+    complex t[400]	/* was [20][20] */;
+    real v;
+    complex w[20], le[400]	/* was [20][20] */, re[400]	/* was [20][
+	    20] */;
+    real val[3], dum[1], eps, sep[20], sin__[20], tol;
+    complex tmp[400]	/* was [20][20] */;
+    integer icmp;
+    complex cdum[1];
+    integer iscl, info, lcmp[3], kmin;
+    real wiin[20], vmin, vmax, tnrm;
+    integer isrt;
+    real wrin[20], vmul, stmp[20];
+    complex work[1200], wtmp[20];
+    real wsrt[20];
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static real vcmin;
+    real vcmin;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *);
-    static real sepin[20], tolin;
+    real sepin[20], tolin;
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *);
-    static real rwork[40];
+    real rwork[40];
     extern /* Subroutine */ int slabad_(real *, real *);
     extern doublereal clange_(char *, integer *, integer *, complex *, 
 	    integer *, real *);
@@ -70,8 +58,8 @@ static integer c__0 = 0;
     extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
 	    *), clacpy_(char *, integer *, integer *, complex *, integer *, 
 	    complex *, integer *);
-    static logical select[20];
-    static real bignum;
+    logical select[20];
+    real bignum;
     extern /* Subroutine */ int chseqr_(char *, char *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, complex *, integer *, 
 	    complex *, integer *, integer *), ctrevc_(char *, 
@@ -81,7 +69,7 @@ static integer c__0 = 0;
 	    logical *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, real *, real *, integer *, integer *, 
 	    complex *, integer *, real *, integer *);
-    static real septmp[20], smlnum;
+    real septmp[20], smlnum;
 
     /* Fortran I/O blocks */
     static cilist io___5 = { 0, 0, 0, 0, 0 };
@@ -90,53 +78,70 @@ static integer c__0 = 0;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CGET37 tests CTRSNA, a routine for estimating condition numbers of   
-    eigenvalues and/or right eigenvectors of a matrix.   
+/*  CGET37 tests CTRSNA, a routine for estimating condition numbers of */
+/*  eigenvalues and/or right eigenvectors of a matrix. */
 
-    The test matrices are read from a file with logical unit number NIN.   
+/*  The test matrices are read from a file with logical unit number NIN. */
 
-    Arguments   
-    ==========   
+/*  Arguments */
+/*  ========== */
 
-    RMAX    (output) REAL array, dimension (3)   
-            Value of the largest test ratio.   
-            RMAX(1) = largest ratio comparing different calls to CTRSNA   
-            RMAX(2) = largest error in reciprocal condition   
-                      numbers taking their conditioning into account   
-            RMAX(3) = largest error in reciprocal condition   
-                      numbers not taking their conditioning into   
-                      account (may be larger than RMAX(2))   
+/*  RMAX    (output) REAL array, dimension (3) */
+/*          Value of the largest test ratio. */
+/*          RMAX(1) = largest ratio comparing different calls to CTRSNA */
+/*          RMAX(2) = largest error in reciprocal condition */
+/*                    numbers taking their conditioning into account */
+/*          RMAX(3) = largest error in reciprocal condition */
+/*                    numbers not taking their conditioning into */
+/*                    account (may be larger than RMAX(2)) */
 
-    LMAX    (output) INTEGER array, dimension (3)   
-            LMAX(i) is example number where largest test ratio   
-            RMAX(i) is achieved. Also:   
-            If CGEHRD returns INFO nonzero on example i, LMAX(1)=i   
-            If CHSEQR returns INFO nonzero on example i, LMAX(2)=i   
-            If CTRSNA returns INFO nonzero on example i, LMAX(3)=i   
+/*  LMAX    (output) INTEGER array, dimension (3) */
+/*          LMAX(i) is example number where largest test ratio */
+/*          RMAX(i) is achieved. Also: */
+/*          If CGEHRD returns INFO nonzero on example i, LMAX(1)=i */
+/*          If CHSEQR returns INFO nonzero on example i, LMAX(2)=i */
+/*          If CTRSNA returns INFO nonzero on example i, LMAX(3)=i */
 
-    NINFO   (output) INTEGER array, dimension (3)   
-            NINFO(1) = No. of times CGEHRD returned INFO nonzero   
-            NINFO(2) = No. of times CHSEQR returned INFO nonzero   
-            NINFO(3) = No. of times CTRSNA returned INFO nonzero   
+/*  NINFO   (output) INTEGER array, dimension (3) */
+/*          NINFO(1) = No. of times CGEHRD returned INFO nonzero */
+/*          NINFO(2) = No. of times CHSEQR returned INFO nonzero */
+/*          NINFO(3) = No. of times CTRSNA returned INFO nonzero */
 
-    KNT     (output) INTEGER   
-            Total number of examples tested.   
+/*  KNT     (output) INTEGER */
+/*          Total number of examples tested. */
 
-    NIN     (input) INTEGER   
-            Input logical unit number   
+/*  NIN     (input) INTEGER */
+/*          Input logical unit number */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ninfo;
     --lmax;
     --rmax;
@@ -164,9 +169,9 @@ static integer c__0 = 0;
     val[1] = 1.f;
     val[2] = sqrt(bignum);
 
-/*     Read input data until N=0.  Assume input eigenvalues are sorted   
-       lexicographically (increasing by real part if ISRT = 0,   
-       increasing by imaginary part if ISRT = 1) */
+/*     Read input data until N=0.  Assume input eigenvalues are sorted */
+/*     lexicographically (increasing by real part if ISRT = 0, */
+/*     increasing by imaginary part if ISRT = 1) */
 
 L10:
     io___5.ciunit = *nin;
@@ -267,8 +272,8 @@ L10:
 	    goto L260;
 	}
 
-/*        Sort eigenvalues and condition numbers lexicographically   
-          to compare with inputs */
+/*        Sort eigenvalues and condition numbers lexicographically */
+/*        to compare with inputs */
 
 	ccopy_(&n, w, &c__1, wtmp, &c__1);
 	if (isrt == 0) {
@@ -325,10 +330,10 @@ L10:
 /* L110: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          taking their condition numbers into account   
+/*        Compare condition numbers for eigenvalues */
+/*        taking their condition numbers into account */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = (real) n * 2.f * eps * tnrm;
 	v = dmax(r__1,smlnum);
 	if (tnrm == 0.f) {
@@ -372,8 +377,8 @@ L10:
 /* L120: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -414,8 +419,8 @@ L10:
 /* L130: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvalues */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -442,8 +447,8 @@ L10:
 /* L140: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -475,7 +480,7 @@ L10:
 	dum[0] = -1.f;
 	scopy_(&n, dum, &c__0, stmp, &c__1);
 	scopy_(&n, dum, &c__0, septmp, &c__1);
-	ctrsna_("E", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("E", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -498,7 +503,7 @@ L10:
 
 	scopy_(&n, dum, &c__0, stmp, &c__1);
 	scopy_(&n, dum, &c__0, septmp, &c__1);
-	ctrsna_("V", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("V", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -526,7 +531,7 @@ L10:
 	}
 	scopy_(&n, dum, &c__0, stmp, &c__1);
 	scopy_(&n, dum, &c__0, septmp, &c__1);
-	ctrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -549,7 +554,7 @@ L10:
 
 	scopy_(&n, dum, &c__0, stmp, &c__1);
 	scopy_(&n, dum, &c__0, septmp, &c__1);
-	ctrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -572,7 +577,7 @@ L10:
 
 	scopy_(&n, dum, &c__0, stmp, &c__1);
 	scopy_(&n, dum, &c__0, septmp, &c__1);
-	ctrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -624,7 +629,7 @@ L10:
 
 	scopy_(&icmp, dum, &c__0, stmp, &c__1);
 	scopy_(&icmp, dum, &c__0, septmp, &c__1);
-	ctrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -648,7 +653,7 @@ L10:
 
 	scopy_(&icmp, dum, &c__0, stmp, &c__1);
 	scopy_(&icmp, dum, &c__0, septmp, &c__1);
-	ctrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -672,7 +677,7 @@ L10:
 
 	scopy_(&icmp, dum, &c__0, stmp, &c__1);
 	scopy_(&icmp, dum, &c__0, septmp, &c__1);
-	ctrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ctrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
