@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* ddrgev.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -112,10 +100,10 @@ static logical c_false = FALSE_;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, n, n1, jc, in, jr;
-    static doublereal ulp;
-    static integer iadd, ierr, nmax;
-    static logical badnn;
+    integer i__, j, n, n1, jc, in, jr;
+    doublereal ulp;
+    integer iadd, ierr, nmax;
+    logical badnn;
     extern /* Subroutine */ int dget52_(logical *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
@@ -123,30 +111,30 @@ static logical c_false = FALSE_;
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, integer *);
-    static doublereal rmagn[4];
-    static integer nmats, jsize, nerrs, jtype;
+    doublereal rmagn[4];
+    integer nmats, jsize, nerrs, jtype;
     extern /* Subroutine */ int dlatm4_(integer *, integer *, integer *, 
 	    integer *, integer *, doublereal *, doublereal *, doublereal *, 
 	    integer *, integer *, doublereal *, integer *), dorm2r_(char *, 
 	    char *, integer *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *), dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
-    extern /* Subroutine */ int dlarfg_(integer *, doublereal *, doublereal *,
+    extern /* Subroutine */ int dlarfg_(integer *, doublereal *, doublereal *, 
 	     integer *, doublereal *);
     extern doublereal dlarnd_(integer *, integer *);
-    static doublereal safmin;
-    static integer ioldsd[4];
-    static doublereal safmax;
+    doublereal safmin;
+    integer ioldsd[4];
+    doublereal safmax;
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *), 
 	    alasvm_(char *, integer *, integer *, integer *, integer *), dlaset_(char *, integer *, integer *, doublereal *, 
 	    doublereal *, doublereal *, integer *), xerbla_(char *, 
 	    integer *);
-    static integer minwrk, maxwrk;
-    static doublereal ulpinv;
-    static integer mtypes, ntestt;
+    integer minwrk, maxwrk;
+    doublereal ulpinv;
+    integer mtypes, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___38 = { 0, 0, 0, fmt_9999, 0 };
@@ -166,285 +154,302 @@ static logical c_false = FALSE_;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DDRGEV checks the nonsymmetric generalized eigenvalue problem driver   
-    routine DGGEV.   
+/*  DDRGEV checks the nonsymmetric generalized eigenvalue problem driver */
+/*  routine DGGEV. */
 
-    DGGEV computes for a pair of n-by-n nonsymmetric matrices (A,B) the   
-    generalized eigenvalues and, optionally, the left and right   
-    eigenvectors.   
+/*  DGGEV computes for a pair of n-by-n nonsymmetric matrices (A,B) the */
+/*  generalized eigenvalues and, optionally, the left and right */
+/*  eigenvectors. */
 
-    A generalized eigenvalue for a pair of matrices (A,B) is a scalar w   
-    or a ratio  alpha/beta = w, such that A - w*B is singular.  It is   
-    usually represented as the pair (alpha,beta), as there is reasonalbe   
-    interpretation for beta=0, and even for both being zero.   
+/*  A generalized eigenvalue for a pair of matrices (A,B) is a scalar w */
+/*  or a ratio  alpha/beta = w, such that A - w*B is singular.  It is */
+/*  usually represented as the pair (alpha,beta), as there is reasonalbe */
+/*  interpretation for beta=0, and even for both being zero. */
 
-    A right generalized eigenvector corresponding to a generalized   
-    eigenvalue  w  for a pair of matrices (A,B) is a vector r  such that   
-    (A - wB) * r = 0.  A left generalized eigenvector is a vector l such   
-    that l**H * (A - wB) = 0, where l**H is the conjugate-transpose of l.   
+/*  A right generalized eigenvector corresponding to a generalized */
+/*  eigenvalue  w  for a pair of matrices (A,B) is a vector r  such that */
+/*  (A - wB) * r = 0.  A left generalized eigenvector is a vector l such */
+/*  that l**H * (A - wB) = 0, where l**H is the conjugate-transpose of l. */
 
-    When DDRGEV is called, a number of matrix "sizes" ("n's") and a   
-    number of matrix "types" are specified.  For each size ("n")   
-    and each type of matrix, a pair of matrices (A, B) will be generated   
-    and used for testing.  For each matrix pair, the following tests   
-    will be performed and compared with the threshhold THRESH.   
+/*  When DDRGEV is called, a number of matrix "sizes" ("n's") and a */
+/*  number of matrix "types" are specified.  For each size ("n") */
+/*  and each type of matrix, a pair of matrices (A, B) will be generated */
+/*  and used for testing.  For each matrix pair, the following tests */
+/*  will be performed and compared with the threshhold THRESH. */
 
-    Results from DGGEV:   
+/*  Results from DGGEV: */
 
-    (1)  max over all left eigenvalue/-vector pairs (alpha/beta,l) of   
+/*  (1)  max over all left eigenvalue/-vector pairs (alpha/beta,l) of */
 
-         | VL**H * (beta A - alpha B) |/( ulp max(|beta A|, |alpha B|) )   
+/*       | VL**H * (beta A - alpha B) |/( ulp max(|beta A|, |alpha B|) ) */
 
-         where VL**H is the conjugate-transpose of VL.   
+/*       where VL**H is the conjugate-transpose of VL. */
 
-    (2)  | |VL(i)| - 1 | / ulp and whether largest component real   
+/*  (2)  | |VL(i)| - 1 | / ulp and whether largest component real */
 
-         VL(i) denotes the i-th column of VL.   
+/*       VL(i) denotes the i-th column of VL. */
 
-    (3)  max over all left eigenvalue/-vector pairs (alpha/beta,r) of   
+/*  (3)  max over all left eigenvalue/-vector pairs (alpha/beta,r) of */
 
-         | (beta A - alpha B) * VR | / ( ulp max(|beta A|, |alpha B|) )   
+/*       | (beta A - alpha B) * VR | / ( ulp max(|beta A|, |alpha B|) ) */
 
-    (4)  | |VR(i)| - 1 | / ulp and whether largest component real   
+/*  (4)  | |VR(i)| - 1 | / ulp and whether largest component real */
 
-         VR(i) denotes the i-th column of VR.   
+/*       VR(i) denotes the i-th column of VR. */
 
-    (5)  W(full) = W(partial)   
-         W(full) denotes the eigenvalues computed when both l and r   
-         are also computed, and W(partial) denotes the eigenvalues   
-         computed when only W, only W and r, or only W and l are   
-         computed.   
+/*  (5)  W(full) = W(partial) */
+/*       W(full) denotes the eigenvalues computed when both l and r */
+/*       are also computed, and W(partial) denotes the eigenvalues */
+/*       computed when only W, only W and r, or only W and l are */
+/*       computed. */
 
-    (6)  VL(full) = VL(partial)   
-         VL(full) denotes the left eigenvectors computed when both l   
-         and r are computed, and VL(partial) denotes the result   
-         when only l is computed.   
+/*  (6)  VL(full) = VL(partial) */
+/*       VL(full) denotes the left eigenvectors computed when both l */
+/*       and r are computed, and VL(partial) denotes the result */
+/*       when only l is computed. */
 
-    (7)  VR(full) = VR(partial)   
-         VR(full) denotes the right eigenvectors computed when both l   
-         and r are also computed, and VR(partial) denotes the result   
-         when only l is computed.   
+/*  (7)  VR(full) = VR(partial) */
+/*       VR(full) denotes the right eigenvectors computed when both l */
+/*       and r are also computed, and VR(partial) denotes the result */
+/*       when only l is computed. */
 
 
-    Test Matrices   
-    ---- --------   
+/*  Test Matrices */
+/*  ---- -------- */
 
-    The sizes of the test matrices are specified by an array   
-    NN(1:NSIZES); the value of each element NN(j) specifies one size.   
-    The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if   
-    DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-    Currently, the list of possible types is:   
+/*  The sizes of the test matrices are specified by an array */
+/*  NN(1:NSIZES); the value of each element NN(j) specifies one size. */
+/*  The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if */
+/*  DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*  Currently, the list of possible types is: */
 
-    (1)  ( 0, 0 )         (a pair of zero matrices)   
+/*  (1)  ( 0, 0 )         (a pair of zero matrices) */
 
-    (2)  ( I, 0 )         (an identity and a zero matrix)   
+/*  (2)  ( I, 0 )         (an identity and a zero matrix) */
 
-    (3)  ( 0, I )         (an identity and a zero matrix)   
+/*  (3)  ( 0, I )         (an identity and a zero matrix) */
 
-    (4)  ( I, I )         (a pair of identity matrices)   
+/*  (4)  ( I, I )         (a pair of identity matrices) */
 
-            t   t   
-    (5)  ( J , J  )       (a pair of transposed Jordan blocks)   
+/*          t   t */
+/*  (5)  ( J , J  )       (a pair of transposed Jordan blocks) */
 
-                                        t                ( I   0  )   
-    (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t )   
-                                     ( 0   I  )          ( 0   J  )   
-                          and I is a k x k identity and J a (k+1)x(k+1)   
-                          Jordan block; k=(N-1)/2   
+/*                                      t                ( I   0  ) */
+/*  (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t ) */
+/*                                   ( 0   I  )          ( 0   J  ) */
+/*                        and I is a k x k identity and J a (k+1)x(k+1) */
+/*                        Jordan block; k=(N-1)/2 */
 
-    (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal   
-                          matrix with those diagonal entries.)   
-    (8)  ( I, D )   
+/*  (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal */
+/*                        matrix with those diagonal entries.) */
+/*  (8)  ( I, D ) */
 
-    (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big   
+/*  (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big */
 
-    (10) ( small*D, big*I )   
+/*  (10) ( small*D, big*I ) */
 
-    (11) ( big*I, small*D )   
+/*  (11) ( big*I, small*D ) */
 
-    (12) ( small*I, big*D )   
+/*  (12) ( small*I, big*D ) */
 
-    (13) ( big*D, big*I )   
+/*  (13) ( big*D, big*I ) */
 
-    (14) ( small*D, small*I )   
+/*  (14) ( small*D, small*I ) */
 
-    (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and   
-                           D2 is diag( 0, N-3, N-4,..., 1, 0, 0 )   
-              t   t   
-    (16) Q ( J , J ) Z     where Q and Z are random orthogonal matrices.   
+/*  (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and */
+/*                         D2 is diag( 0, N-3, N-4,..., 1, 0, 0 ) */
+/*            t   t */
+/*  (16) Q ( J , J ) Z     where Q and Z are random orthogonal matrices. */
 
-    (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices   
-                           with random O(1) entries above the diagonal   
-                           and diagonal entries diag(T1) =   
-                           ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) =   
-                           ( 0, N-3, N-4,..., 1, 0, 0 )   
+/*  (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices */
+/*                         with random O(1) entries above the diagonal */
+/*                         and diagonal entries diag(T1) = */
+/*                         ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) = */
+/*                         ( 0, N-3, N-4,..., 1, 0, 0 ) */
 
-    (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1,..., 1, 0 )   
-                           s = machine precision.   
+/*  (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1,..., 1, 0 ) */
+/*                         s = machine precision. */
 
-    (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 )   
+/*  (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 ) */
 
-                                                           N-5   
-    (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
+/*                                                         N-5 */
+/*  (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
 
-    (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
-                           where r1,..., r(N-4) are random.   
+/*  (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
+/*                         where r1,..., r(N-4) are random. */
 
-    (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular   
-                            matrices.   
+/*  (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular */
+/*                          matrices. */
 
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
+
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  If it is zero, */
+/*          DDRGES does nothing.  NSIZES >= 0. */
 
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  If it is zero,   
-            DDRGES does nothing.  NSIZES >= 0.   
-
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  NN >= 0.   
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  NN >= 0. */
 
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, DDRGES   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrix is in A.  This   
-            is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, DDRGES */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrix is in A.  This */
+/*          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated. If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
-
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096. Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to DDRGES to continue the same random number   
-            sequence.   
-
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error is   
-            scaled to be O(1), so THRESH should be a reasonably small   
-            multiple of 1, e.g., 10 or 100.  In particular, it should   
-            not depend on the precision (single vs. double) or the size   
-            of the matrix.  It must be at least zero.   
-
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IERR not equal to 0.)   
-
-    A       (input/workspace) DOUBLE PRECISION array,   
-                                         dimension(LDA, max(NN))   
-            Used to hold the original A matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, S, and T.   
-            It must be at least 1 and at least max( NN ).   
-
-    B       (input/workspace) DOUBLE PRECISION array,   
-                                         dimension(LDA, max(NN))   
-            Used to hold the original B matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    S       (workspace) DOUBLE PRECISION array,   
-                                   dimension (LDA, max(NN))   
-            The Schur form matrix computed from A by DGGES.  On exit, S   
-            contains the Schur form matrix corresponding to the matrix   
-            in A.   
-
-    T       (workspace) DOUBLE PRECISION array,   
-                                   dimension (LDA, max(NN))   
-            The upper triangular matrix computed from B by DGGES.   
-
-    Q       (workspace) DOUBLE PRECISION array,   
-                                   dimension (LDQ, max(NN))   
-            The (left) eigenvectors matrix computed by DGGEV.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of Q and Z. It must   
-            be at least 1 and at least max( NN ).   
-
-    Z       (workspace) DOUBLE PRECISION array, dimension( LDQ, max(NN) )   
-            The (right) orthogonal matrix computed by DGGES.   
-
-    QE      (workspace) DOUBLE PRECISION array, dimension( LDQ, max(NN) )   
-            QE holds the computed right or left eigenvectors.   
-
-    LDQE    (input) INTEGER   
-            The leading dimension of QE. LDQE >= max(1,max(NN)).   
-
-    ALPHAR  (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-    ALPHAI  (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-    BETA    (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-            The generalized eigenvalues of (A,B) computed by DGGEV.   
-            ( ALPHAR(k)+ALPHAI(k)*i ) / BETA(k) is the k-th   
-            generalized eigenvalue of A and B.   
-
-    ALPHR1  (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-    ALPHI1  (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-    BETA1   (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-            Like ALPHAR, ALPHAI, BETA, these arrays contain the   
-            eigenvalues of A and B, but those computed when DGGEV only   
-            computes a partial eigendecomposition, i.e. not the   
-            eigenvalues and left and right eigenvectors.   
-
-    WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The number of entries in WORK.  LWORK >= MAX( 8*N, N*(N+1) ).   
-
-    RESULT  (output) DOUBLE PRECISION array, dimension (2)   
-            The values computed by the tests described above.   
-            The values are currently limited to 1/ulp, to avoid overflow.   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.  INFO is the   
-                  absolute value of the INFO value returned.   
-
-    =====================================================================   
-
-       Parameter adjustments */
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated. If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
+
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096. Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to DDRGES to continue the same random number */
+/*          sequence. */
+
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error is */
+/*          scaled to be O(1), so THRESH should be a reasonably small */
+/*          multiple of 1, e.g., 10 or 100.  In particular, it should */
+/*          not depend on the precision (single vs. double) or the size */
+/*          of the matrix.  It must be at least zero. */
+
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IERR not equal to 0.) */
+
+/*  A       (input/workspace) DOUBLE PRECISION array, */
+/*                                       dimension(LDA, max(NN)) */
+/*          Used to hold the original A matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, S, and T. */
+/*          It must be at least 1 and at least max( NN ). */
+
+/*  B       (input/workspace) DOUBLE PRECISION array, */
+/*                                       dimension(LDA, max(NN)) */
+/*          Used to hold the original B matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  S       (workspace) DOUBLE PRECISION array, */
+/*                                 dimension (LDA, max(NN)) */
+/*          The Schur form matrix computed from A by DGGES.  On exit, S */
+/*          contains the Schur form matrix corresponding to the matrix */
+/*          in A. */
+
+/*  T       (workspace) DOUBLE PRECISION array, */
+/*                                 dimension (LDA, max(NN)) */
+/*          The upper triangular matrix computed from B by DGGES. */
+
+/*  Q       (workspace) DOUBLE PRECISION array, */
+/*                                 dimension (LDQ, max(NN)) */
+/*          The (left) eigenvectors matrix computed by DGGEV. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of Q and Z. It must */
+/*          be at least 1 and at least max( NN ). */
+
+/*  Z       (workspace) DOUBLE PRECISION array, dimension( LDQ, max(NN) ) */
+/*          The (right) orthogonal matrix computed by DGGES. */
+
+/*  QE      (workspace) DOUBLE PRECISION array, dimension( LDQ, max(NN) ) */
+/*          QE holds the computed right or left eigenvectors. */
+
+/*  LDQE    (input) INTEGER */
+/*          The leading dimension of QE. LDQE >= max(1,max(NN)). */
+
+/*  ALPHAR  (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*  ALPHAI  (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*  BETA    (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*          The generalized eigenvalues of (A,B) computed by DGGEV. */
+/*          ( ALPHAR(k)+ALPHAI(k)*i ) / BETA(k) is the k-th */
+/*          generalized eigenvalue of A and B. */
+
+/*  ALPHR1  (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*  ALPHI1  (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*  BETA1   (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*          Like ALPHAR, ALPHAI, BETA, these arrays contain the */
+/*          eigenvalues of A and B, but those computed when DGGEV only */
+/*          computes a partial eigendecomposition, i.e. not the */
+/*          eigenvalues and left and right eigenvectors. */
+
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK) */
+
+/*  LWORK   (input) INTEGER */
+/*          The number of entries in WORK.  LWORK >= MAX( 8*N, N*(N+1) ). */
+
+/*  RESULT  (output) DOUBLE PRECISION array, dimension (2) */
+/*          The values computed by the tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid overflow. */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code.  INFO is the */
+/*                absolute value of the INFO value returned. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -478,9 +483,11 @@ static logical c_false = FALSE_;
     --work;
     --result;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors */
+/*     Check for errors */
 
     *info = 0;
 
@@ -513,12 +520,12 @@ static logical c_false = FALSE_;
 	*info = -17;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV. */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
@@ -526,8 +533,8 @@ static logical c_false = FALSE_;
 	i__1 = 1, i__2 = nmax << 3, i__1 = max(i__1,i__2), i__2 = nmax * (
 		nmax + 1);
 	minwrk = max(i__1,i__2);
-	maxwrk = nmax * 7 + nmax * ilaenv_(&c__1, "DGEQRF", " ", &nmax, &c__1,
-		 &nmax, &c__0, (ftnlen)6, (ftnlen)1);
+	maxwrk = nmax * 7 + nmax * ilaenv_(&c__1, "DGEQRF", " ", &nmax, &c__1, 
+		 &nmax, &c__0);
 /* Computing MAX */
 	i__1 = maxwrk, i__2 = nmax * (nmax + 1);
 	maxwrk = max(i__1,i__2);
@@ -595,28 +602,28 @@ static logical c_false = FALSE_;
 /* L20: */
 	    }
 
-/*           Generate test matrices A and B   
+/*           Generate test matrices A and B */
 
-             Description of control parameters:   
+/*           Description of control parameters: */
 
-             KZLASS: =1 means w/o rotation, =2 means w/ rotation,   
-                     =3 means random.   
-             KATYPE: the "type" to be passed to DLATM4 for computing A.   
-             KAZERO: the pattern of zeros on the diagonal for A:   
-                     =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ),   
-                     =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ),   
-                     =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of   
-                     non-zero entries.)   
-             KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1),   
-                     =2: large, =3: small.   
-             IASIGN: 1 if the diagonal elements of A are to be   
-                     multiplied by a random magnitude 1 number, =2 if   
-                     randomly chosen diagonal blocks are to be rotated   
-                     to form 2x2 blocks.   
-             KBTYPE, KBZERO, KBMAGN, IBSIGN: the same, but for B.   
-             KTRIAN: =0: don't fill in the upper triangle, =1: do.   
-             KZ1, KZ2, KADD: used to implement KAZERO and KBZERO.   
-             RMAGN: used to implement KAMAGN and KBMAGN. */
+/*           KZLASS: =1 means w/o rotation, =2 means w/ rotation, */
+/*                   =3 means random. */
+/*           KATYPE: the "type" to be passed to DLATM4 for computing A. */
+/*           KAZERO: the pattern of zeros on the diagonal for A: */
+/*                   =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ), */
+/*                   =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ), */
+/*                   =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of */
+/*                   non-zero entries.) */
+/*           KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1), */
+/*                   =2: large, =3: small. */
+/*           IASIGN: 1 if the diagonal elements of A are to be */
+/*                   multiplied by a random magnitude 1 number, =2 if */
+/*                   randomly chosen diagonal blocks are to be rotated */
+/*                   to form 2x2 blocks. */
+/*           KBTYPE, KBZERO, KBMAGN, IBSIGN: the same, but for B. */
+/*           KTRIAN: =0: don't fill in the upper triangle, =1: do. */
+/*           KZ1, KZ2, KADD: used to implement KAZERO and KBZERO. */
+/*           RMAGN: used to implement KAMAGN and KBMAGN. */
 
 	    if (mtypes > 26) {
 		goto L100;
@@ -668,10 +675,10 @@ static logical c_false = FALSE_;
 
 		if (kclass[jtype - 1] == 2 && n > 0) {
 
-/*                 Include rotations   
+/*                 Include rotations */
 
-                   Generate Q, Z as Householder transformations times   
-                   a diagonal matrix. */
+/*                 Generate Q, Z as Householder transformations times */
+/*                 a diagonal matrix. */
 
 		    i__3 = n - 1;
 		    for (jc = 1; jc <= i__3; ++jc) {
@@ -810,7 +817,7 @@ L100:
 
 	    dget52_(&c_true, &n, &a[a_offset], lda, &b[b_offset], lda, &q[
 		    q_offset], ldq, &alphar[1], &alphai[1], &beta[1], &work[1]
-		    , &result[1]);
+, &result[1]);
 	    if (result[2] > *thresh) {
 		io___41.ciunit = *nounit;
 		s_wsfe(&io___41);
@@ -827,7 +834,7 @@ L100:
 
 	    dget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset], lda, &z__[
 		    z_offset], ldq, &alphar[1], &alphai[1], &beta[1], &work[1]
-		    , &result[3]);
+, &result[3]);
 	    if (result[4] > *thresh) {
 		io___42.ciunit = *nounit;
 		s_wsfe(&io___42);
@@ -870,8 +877,8 @@ L100:
 /* L120: */
 	    }
 
-/*           Do the test (6): Compute eigenvalues and left eigenvectors,   
-             and test them */
+/*           Do the test (6): Compute eigenvalues and left eigenvectors, */
+/*           and test them */
 
 	    dlacpy_(" ", &n, &n, &a[a_offset], lda, &s[s_offset], lda);
 	    dlacpy_(" ", &n, &n, &b[b_offset], lda, &t[t_offset], lda);
@@ -913,8 +920,8 @@ L100:
 /* L150: */
 	    }
 
-/*           DO the test (7): Compute eigenvalues and right eigenvectors,   
-             and test them */
+/*           DO the test (7): Compute eigenvalues and right eigenvectors, */
+/*           and test them */
 
 	    dlacpy_(" ", &n, &n, &a[a_offset], lda, &s[s_offset], lda);
 	    dlacpy_(" ", &n, &n, &b[b_offset], lda, &t[t_offset], lda);
@@ -967,8 +974,8 @@ L190:
 	    for (jr = 1; jr <= 7; ++jr) {
 		if (result[jr] >= *thresh) {
 
-/*                 If this is the first test to fail,   
-                   print a header to the data file. */
+/*                 If this is the first test to fail, */
+/*                 print a header to the data file. */
 
 		    if (nerrs == 0) {
 			io___46.ciunit = *nounit;
