@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* ddrgsx.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -101,59 +89,59 @@ static integer c__5 = 5;
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, i1, mm;
-    static doublereal pl[2];
-    static integer mn2, qba, qbb;
-    static doublereal ulp, temp1, temp2;
+    integer i__, j, i1, mm;
+    doublereal pl[2];
+    integer mn2, qba, qbb;
+    doublereal ulp, temp1, temp2;
     extern /* Subroutine */ int dget51_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *), dget53_(
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *);
-    static doublereal abnrm;
-    static integer ifunc, iinfo, linfo;
-    static char sense[1];
-    static integer nerrs, ntest;
+    doublereal abnrm;
+    integer ifunc, iinfo, linfo;
+    char sense[1];
+    integer nerrs, ntest;
     extern /* Subroutine */ int dlakf2_(integer *, integer *, doublereal *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     integer *);
-    static doublereal pltru;
+    doublereal pltru;
     extern /* Subroutine */ int dlatm5_(integer *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *), dlabad_(
 	    doublereal *, doublereal *);
-    static doublereal thrsh2;
-    static logical ilabad;
+    doublereal thrsh2;
+    logical ilabad;
     extern doublereal dlamch_(char *), dlange_(char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *);
-    static integer bdspac;
+    integer bdspac;
     extern /* Subroutine */ int dgesvd_(char *, char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *), dlacpy_(char *, integer *, integer *, doublereal 
 	    *, integer *, doublereal *, integer *);
-    static doublereal difest[2];
+    doublereal difest[2];
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *);
-    static doublereal bignum;
+    doublereal bignum;
     extern /* Subroutine */ int dggesx_(char *, char *, char *, L_fp, char *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *, integer *, integer *, logical *, integer 
 	    *), alasvm_(char *, integer *, 
 	    integer *, integer *, integer *), xerbla_(char *, integer 
 	    *);
-    static doublereal weight, diftru;
+    doublereal weight, diftru;
     extern logical dlctsx_();
-    static integer minwrk, maxwrk;
-    static doublereal smlnum, ulpinv;
-    static integer nptknt;
-    static doublereal result[10];
-    static integer ntestt, prtype;
+    integer minwrk, maxwrk;
+    doublereal smlnum, ulpinv;
+    integer nptknt;
+    doublereal result[10];
+    integer ntestt, prtype;
 
     /* Fortran I/O blocks */
     static cilist io___22 = { 0, 0, 0, fmt_9999, 0 };
@@ -180,254 +168,275 @@ static integer c__5 = 5;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  DDRGSX checks the nonsymmetric generalized eigenvalue (Schur form) */
+/*  problem expert driver DGGESX. */
+
+/*  DGGESX factors A and B as Q S Z' and Q T Z', where ' means */
+/*  transpose, T is upper triangular, S is in generalized Schur form */
+/*  (block upper triangular, with 1x1 and 2x2 blocks on the diagonal, */
+/*  the 2x2 blocks corresponding to complex conjugate pairs of */
+/*  generalized eigenvalues), and Q and Z are orthogonal.  It also */
+/*  computes the generalized eigenvalues (alpha(1),beta(1)), ..., */
+/*  (alpha(n),beta(n)). Thus, w(j) = alpha(j)/beta(j) is a root of the */
+/*  characteristic equation */
+
+/*      det( A - w(j) B ) = 0 */
+
+/*  Optionally it also reorders the eigenvalues so that a selected */
+/*  cluster of eigenvalues appears in the leading diagonal block of the */
+/*  Schur forms; computes a reciprocal condition number for the average */
+/*  of the selected eigenvalues; and computes a reciprocal condition */
+/*  number for the right and left deflating subspaces corresponding to */
+/*  the selected eigenvalues. */
+
+/*  When DDRGSX is called with NSIZE > 0, five (5) types of built-in */
+/*  matrix pairs are used to test the routine DGGESX. */
+
+/*  When DDRGSX is called with NSIZE = 0, it reads in test matrix data */
+/*  to test DGGESX. */
+
+/*  For each matrix pair, the following tests will be performed and */
+/*  compared with the threshhold THRESH except for the tests (7) and (9): */
+
+/*  (1)   | A - Q S Z' | / ( |A| n ulp ) */
+
+/*  (2)   | B - Q T Z' | / ( |B| n ulp ) */
+
+/*  (3)   | I - QQ' | / ( n ulp ) */
+
+/*  (4)   | I - ZZ' | / ( n ulp ) */
+
+/*  (5)   if A is in Schur form (i.e. quasi-triangular form) */
+
+/*  (6)   maximum over j of D(j)  where: */
+
+/*        if alpha(j) is real: */
+/*                      |alpha(j) - S(j,j)|        |beta(j) - T(j,j)| */
+/*            D(j) = ------------------------ + ----------------------- */
+/*                   max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|) */
+
+/*        if alpha(j) is complex: */
+/*                                  | det( s S - w T ) | */
+/*            D(j) = --------------------------------------------------- */
+/*                   ulp max( s norm(S), |w| norm(T) )*norm( s S - w T ) */
+
+/*            and S and T are here the 2 x 2 diagonal blocks of S and T */
+/*            corresponding to the j-th and j+1-th eigenvalues. */
+
+/*  (7)   if sorting worked and SDIM is the number of eigenvalues */
+/*        which were selected. */
+
+/*  (8)   the estimated value DIF does not differ from the true values of */
+/*        Difu and Difl more than a factor 10*THRESH. If the estimate DIF */
+/*        equals zero the corresponding true values of Difu and Difl */
+/*        should be less than EPS*norm(A, B). If the true value of Difu */
+/*        and Difl equal zero, the estimate DIF should be less than */
+/*        EPS*norm(A, B). */
+
+/*  (9)   If INFO = N+3 is returned by DGGESX, the reordering "failed" */
+/*        and we check that DIF = PL = PR = 0 and that the true value of */
+/*        Difu and Difl is < EPS*norm(A, B). We count the events when */
+/*        INFO=N+3. */
+
+/*  For read-in test matrices, the above tests are run except that the */
+/*  exact value for DIF (and PL) is input data.  Additionally, there is */
+/*  one more test run for read-in test matrices: */
+
+/*  (10)  the estimated value PL does not differ from the true value of */
+/*        PLTRU more than a factor THRESH. If the estimate PL equals */
+/*        zero the corresponding true value of PLTRU should be less than */
+/*        EPS*norm(A, B). If the true value of PLTRU equal zero, the */
+/*        estimate PL should be less than EPS*norm(A, B). */
+
+/*  Note that for the built-in tests, a total of 10*NSIZE*(NSIZE-1) */
+/*  matrix pairs are generated and tested. NSIZE should be kept small. */
+
+/*  SVD (routine DGESVD) is used for computing the true value of DIF_u */
+/*  and DIF_l when testing the built-in test problems. */
+
+/*  Built-in Test Matrices */
+/*  ====================== */
+
+/*  All built-in test matrices are the 2 by 2 block of triangular */
+/*  matrices */
+
+/*           A = [ A11 A12 ]    and      B = [ B11 B12 ] */
+/*               [     A22 ]                 [     B22 ] */
+
+/*  where for different type of A11 and A22 are given as the following. */
+/*  A12 and B12 are chosen so that the generalized Sylvester equation */
+
+/*           A11*R - L*A22 = -A12 */
+/*           B11*R - L*B22 = -B12 */
+
+/*  have prescribed solution R and L. */
+
+/*  Type 1:  A11 = J_m(1,-1) and A_22 = J_k(1-a,1). */
+/*           B11 = I_m, B22 = I_k */
+/*           where J_k(a,b) is the k-by-k Jordan block with ``a'' on */
+/*           diagonal and ``b'' on superdiagonal. */
+
+/*  Type 2:  A11 = (a_ij) = ( 2(.5-sin(i)) ) and */
+/*           B11 = (b_ij) = ( 2(.5-sin(ij)) ) for i=1,...,m, j=i,...,m */
+/*           A22 = (a_ij) = ( 2(.5-sin(i+j)) ) and */
+/*           B22 = (b_ij) = ( 2(.5-sin(ij)) ) for i=m+1,...,k, j=i,...,k */
+
+/*  Type 3:  A11, A22 and B11, B22 are chosen as for Type 2, but each */
+/*           second diagonal block in A_11 and each third diagonal block */
+/*           in A_22 are made as 2 by 2 blocks. */
+
+/*  Type 4:  A11 = ( 20(.5 - sin(ij)) ) and B22 = ( 2(.5 - sin(i+j)) ) */
+/*              for i=1,...,m,  j=1,...,m and */
+/*           A22 = ( 20(.5 - sin(i+j)) ) and B22 = ( 2(.5 - sin(ij)) ) */
+/*              for i=m+1,...,k,  j=m+1,...,k */
+
+/*  Type 5:  (A,B) and have potentially close or common eigenvalues and */
+/*           very large departure from block diagonality A_11 is chosen */
+/*           as the m x m leading submatrix of A_1: */
+/*                   |  1  b                            | */
+/*                   | -b  1                            | */
+/*                   |        1+d  b                    | */
+/*                   |         -b 1+d                   | */
+/*            A_1 =  |                  d  1            | */
+/*                   |                 -1  d            | */
+/*                   |                        -d  1     | */
+/*                   |                        -1 -d     | */
+/*                   |                               1  | */
+/*           and A_22 is chosen as the k x k leading submatrix of A_2: */
+/*                   | -1  b                            | */
+/*                   | -b -1                            | */
+/*                   |       1-d  b                     | */
+/*                   |       -b  1-d                    | */
+/*            A_2 =  |                 d 1+b            | */
+/*                   |               -1-b d             | */
+/*                   |                       -d  1+b    | */
+/*                   |                      -1+b  -d    | */
+/*                   |                              1-d | */
+/*           and matrix B are chosen as identity matrices (see DLATM5). */
 
 
-    Purpose   
-    =======   
+/*  Arguments */
+/*  ========= */
 
-    DDRGSX checks the nonsymmetric generalized eigenvalue (Schur form)   
-    problem expert driver DGGESX.   
+/*  NSIZE   (input) INTEGER */
+/*          The maximum size of the matrices to use. NSIZE >= 0. */
+/*          If NSIZE = 0, no built-in tests matrices are used, but */
+/*          read-in test matrices are used to test DGGESX. */
 
-    DGGESX factors A and B as Q S Z' and Q T Z', where ' means   
-    transpose, T is upper triangular, S is in generalized Schur form   
-    (block upper triangular, with 1x1 and 2x2 blocks on the diagonal,   
-    the 2x2 blocks corresponding to complex conjugate pairs of   
-    generalized eigenvalues), and Q and Z are orthogonal.  It also   
-    computes the generalized eigenvalues (alpha(1),beta(1)), ...,   
-    (alpha(n),beta(n)). Thus, w(j) = alpha(j)/beta(j) is a root of the   
-    characteristic equation   
+/*  NCMAX   (input) INTEGER */
+/*          Maximum allowable NMAX for generating Kroneker matrix */
+/*          in call to DLAKF2 */
 
-        det( A - w(j) B ) = 0   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  THRESH >= 0. */
 
-    Optionally it also reorders the eigenvalues so that a selected   
-    cluster of eigenvalues appears in the leading diagonal block of the   
-    Schur forms; computes a reciprocal condition number for the average   
-    of the selected eigenvalues; and computes a reciprocal condition   
-    number for the right and left deflating subspaces corresponding to   
-    the selected eigenvalues.   
+/*  NIN     (input) INTEGER */
+/*          The FORTRAN unit number for reading in the data file of */
+/*          problems to solve. */
 
-    When DDRGSX is called with NSIZE > 0, five (5) types of built-in   
-    matrix pairs are used to test the routine DGGESX.   
+/*  NOUT    (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IINFO not equal to 0.) */
 
-    When DDRGSX is called with NSIZE = 0, it reads in test matrix data   
-    to test DGGESX.   
+/*  A       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Used to store the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
 
-    For each matrix pair, the following tests will be performed and   
-    compared with the threshhold THRESH except for the tests (7) and (9):   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, AI, BI, Z and Q, */
+/*          LDA >= max( 1, NSIZE ). For the read-in test, */
+/*          LDA >= max( 1, N ), N is the size of the test matrices. */
 
-    (1)   | A - Q S Z' | / ( |A| n ulp )   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Used to store the matrix whose eigenvalues are to be */
+/*          computed.  On exit, B contains the last matrix actually used. */
 
-    (2)   | B - Q T Z' | / ( |B| n ulp )   
+/*  AI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Copy of A, modified by DGGESX. */
 
-    (3)   | I - QQ' | / ( n ulp )   
+/*  BI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Copy of B, modified by DGGESX. */
 
-    (4)   | I - ZZ' | / ( n ulp )   
+/*  Z       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Z holds the left Schur vectors computed by DGGESX. */
 
-    (5)   if A is in Schur form (i.e. quasi-triangular form)   
+/*  Q       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Q holds the right Schur vectors computed by DGGESX. */
 
-    (6)   maximum over j of D(j)  where:   
+/*  ALPHAR  (workspace) DOUBLE PRECISION array, dimension (NSIZE) */
+/*  ALPHAI  (workspace) DOUBLE PRECISION array, dimension (NSIZE) */
+/*  BETA    (workspace) DOUBLE PRECISION array, dimension (NSIZE) */
+/*          On exit, (ALPHAR + ALPHAI*i)/BETA are the eigenvalues. */
 
-          if alpha(j) is real:   
-                        |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|   
-              D(j) = ------------------------ + -----------------------   
-                     max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)   
+/*  C       (workspace) DOUBLE PRECISION array, dimension (LDC, LDC) */
+/*          Store the matrix generated by subroutine DLAKF2, this is the */
+/*          matrix formed by Kronecker products used for estimating */
+/*          DIF. */
 
-          if alpha(j) is complex:   
-                                    | det( s S - w T ) |   
-              D(j) = ---------------------------------------------------   
-                     ulp max( s norm(S), |w| norm(T) )*norm( s S - w T )   
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of C. LDC >= max(1, LDA*LDA/2 ). */
 
-              and S and T are here the 2 x 2 diagonal blocks of S and T   
-              corresponding to the j-th and j+1-th eigenvalues.   
+/*  S       (workspace) DOUBLE PRECISION array, dimension (LDC) */
+/*          Singular values of C */
 
-    (7)   if sorting worked and SDIM is the number of eigenvalues   
-          which were selected.   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK) */
 
-    (8)   the estimated value DIF does not differ from the true values of   
-          Difu and Difl more than a factor 10*THRESH. If the estimate DIF   
-          equals zero the corresponding true values of Difu and Difl   
-          should be less than EPS*norm(A, B). If the true value of Difu   
-          and Difl equal zero, the estimate DIF should be less than   
-          EPS*norm(A, B).   
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK. */
+/*          LWORK >= MAX( 5*NSIZE*NSIZE/2 - 2, 10*(NSIZE+1) ) */
 
-    (9)   If INFO = N+3 is returned by DGGESX, the reordering "failed"   
-          and we check that DIF = PL = PR = 0 and that the true value of   
-          Difu and Difl is < EPS*norm(A, B). We count the events when   
-          INFO=N+3.   
+/*  IWORK   (workspace) INTEGER array, dimension (LIWORK) */
 
-    For read-in test matrices, the above tests are run except that the   
-    exact value for DIF (and PL) is input data.  Additionally, there is   
-    one more test run for read-in test matrices:   
+/*  LIWORK  (input) INTEGER */
+/*          The dimension of the array IWORK. LIWORK >= NSIZE + 6. */
 
-    (10)  the estimated value PL does not differ from the true value of   
-          PLTRU more than a factor THRESH. If the estimate PL equals   
-          zero the corresponding true value of PLTRU should be less than   
-          EPS*norm(A, B). If the true value of PLTRU equal zero, the   
-          estimate PL should be less than EPS*norm(A, B).   
+/*  BWORK   (workspace) LOGICAL array, dimension (LDA) */
 
-    Note that for the built-in tests, a total of 10*NSIZE*(NSIZE-1)   
-    matrix pairs are generated and tested. NSIZE should be kept small.   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code. */
 
-    SVD (routine DGESVD) is used for computing the true value of DIF_u   
-    and DIF_l when testing the built-in test problems.   
+/*  ===================================================================== */
 
-    Built-in Test Matrices   
-    ======================   
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-    All built-in test matrices are the 2 by 2 block of triangular   
-    matrices   
+/*     Check for errors */
 
-             A = [ A11 A12 ]    and      B = [ B11 B12 ]   
-                 [     A22 ]                 [     B22 ]   
-
-    where for different type of A11 and A22 are given as the following.   
-    A12 and B12 are chosen so that the generalized Sylvester equation   
-
-             A11*R - L*A22 = -A12   
-             B11*R - L*B22 = -B12   
-
-    have prescribed solution R and L.   
-
-    Type 1:  A11 = J_m(1,-1) and A_22 = J_k(1-a,1).   
-             B11 = I_m, B22 = I_k   
-             where J_k(a,b) is the k-by-k Jordan block with ``a'' on   
-             diagonal and ``b'' on superdiagonal.   
-
-    Type 2:  A11 = (a_ij) = ( 2(.5-sin(i)) ) and   
-             B11 = (b_ij) = ( 2(.5-sin(ij)) ) for i=1,...,m, j=i,...,m   
-             A22 = (a_ij) = ( 2(.5-sin(i+j)) ) and   
-             B22 = (b_ij) = ( 2(.5-sin(ij)) ) for i=m+1,...,k, j=i,...,k   
-
-    Type 3:  A11, A22 and B11, B22 are chosen as for Type 2, but each   
-             second diagonal block in A_11 and each third diagonal block   
-             in A_22 are made as 2 by 2 blocks.   
-
-    Type 4:  A11 = ( 20(.5 - sin(ij)) ) and B22 = ( 2(.5 - sin(i+j)) )   
-                for i=1,...,m,  j=1,...,m and   
-             A22 = ( 20(.5 - sin(i+j)) ) and B22 = ( 2(.5 - sin(ij)) )   
-                for i=m+1,...,k,  j=m+1,...,k   
-
-    Type 5:  (A,B) and have potentially close or common eigenvalues and   
-             very large departure from block diagonality A_11 is chosen   
-             as the m x m leading submatrix of A_1:   
-                     |  1  b                            |   
-                     | -b  1                            |   
-                     |        1+d  b                    |   
-                     |         -b 1+d                   |   
-              A_1 =  |                  d  1            |   
-                     |                 -1  d            |   
-                     |                        -d  1     |   
-                     |                        -1 -d     |   
-                     |                               1  |   
-             and A_22 is chosen as the k x k leading submatrix of A_2:   
-                     | -1  b                            |   
-                     | -b -1                            |   
-                     |       1-d  b                     |   
-                     |       -b  1-d                    |   
-              A_2 =  |                 d 1+b            |   
-                     |               -1-b d             |   
-                     |                       -d  1+b    |   
-                     |                      -1+b  -d    |   
-                     |                              1-d |   
-             and matrix B are chosen as identity matrices (see DLATM5).   
-
-
-    Arguments   
-    =========   
-
-    NSIZE   (input) INTEGER   
-            The maximum size of the matrices to use. NSIZE >= 0.   
-            If NSIZE = 0, no built-in tests matrices are used, but   
-            read-in test matrices are used to test DGGESX.   
-
-    NCMAX   (input) INTEGER   
-            Maximum allowable NMAX for generating Kroneker matrix   
-            in call to DLAKF2   
-
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  THRESH >= 0.   
-
-    NIN     (input) INTEGER   
-            The FORTRAN unit number for reading in the data file of   
-            problems to solve.   
-
-    NOUT    (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IINFO not equal to 0.)   
-
-    A       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Used to store the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, AI, BI, Z and Q,   
-            LDA >= max( 1, NSIZE ). For the read-in test,   
-            LDA >= max( 1, N ), N is the size of the test matrices.   
-
-    B       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Used to store the matrix whose eigenvalues are to be   
-            computed.  On exit, B contains the last matrix actually used.   
-
-    AI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Copy of A, modified by DGGESX.   
-
-    BI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Copy of B, modified by DGGESX.   
-
-    Z       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Z holds the left Schur vectors computed by DGGESX.   
-
-    Q       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Q holds the right Schur vectors computed by DGGESX.   
-
-    ALPHAR  (workspace) DOUBLE PRECISION array, dimension (NSIZE)   
-    ALPHAI  (workspace) DOUBLE PRECISION array, dimension (NSIZE)   
-    BETA    (workspace) DOUBLE PRECISION array, dimension (NSIZE)   
-            On exit, (ALPHAR + ALPHAI*i)/BETA are the eigenvalues.   
-
-    C       (workspace) DOUBLE PRECISION array, dimension (LDC, LDC)   
-            Store the matrix generated by subroutine DLAKF2, this is the   
-            matrix formed by Kronecker products used for estimating   
-            DIF.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of C. LDC >= max(1, LDA*LDA/2 ).   
-
-    S       (workspace) DOUBLE PRECISION array, dimension (LDC)   
-            Singular values of C   
-
-    WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.   
-            LWORK >= MAX( 5*NSIZE*NSIZE/2 - 2, 10*(NSIZE+1) )   
-
-    IWORK   (workspace) INTEGER array, dimension (LIWORK)   
-
-    LIWORK  (input) INTEGER   
-            The dimension of the array IWORK. LIWORK >= NSIZE + 6.   
-
-    BWORK   (workspace) LOGICAL array, dimension (LDA)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.   
-
-    =====================================================================   
-
-
-       Check for errors   
-
-       Parameter adjustments */
+    /* Parameter adjustments */
     q_dim1 = *lda;
     q_offset = 1 + q_dim1;
     q -= q_offset;
@@ -474,12 +483,12 @@ static integer c__5 = 5;
 	*info = -21;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV.) */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
@@ -490,10 +499,10 @@ static integer c__5 = 5;
 /*        workspace for sggesx */
 
 	maxwrk = (*nsize + 1) * 9 + *nsize * ilaenv_(&c__1, "DGEQRF", " ", 
-		nsize, &c__1, nsize, &c__0, (ftnlen)6, (ftnlen)1);
+		nsize, &c__1, nsize, &c__0);
 /* Computing MAX */
 	i__1 = maxwrk, i__2 = (*nsize + 1) * 9 + *nsize * ilaenv_(&c__1, 
-		"DORGQR", " ", nsize, &c__1, nsize, &c_n1, (ftnlen)6, (ftnlen)1);
+		"DORGQR", " ", nsize, &c__1, nsize, &c_n1);
 	maxwrk = max(i__1,i__2);
 
 /*        workspace for dgesvd */
@@ -503,7 +512,7 @@ static integer c__5 = 5;
 	i__3 = *nsize * *nsize / 2;
 	i__4 = *nsize * *nsize / 2;
 	i__1 = maxwrk, i__2 = *nsize * 3 * *nsize / 2 + *nsize * *nsize * 
-		ilaenv_(&c__1, "DGEBRD", " ", &i__3, &i__4, &c_n1, &c_n1, (ftnlen)6, (ftnlen)1);
+		ilaenv_(&c__1, "DGEBRD", " ", &i__3, &i__4, &c_n1, &c_n1);
 	maxwrk = max(i__1,i__2);
 	maxwrk = max(maxwrk,bdspac);
 
@@ -540,9 +549,9 @@ static integer c__5 = 5;
 	goto L70;
     }
 
-/*     Test the built-in matrix pairs.   
-       Loop over different functions (IFUNC) of DGGESX, types (PRTYPE)   
-       of test matrices, different size (M+N) */
+/*     Test the built-in matrix pairs. */
+/*     Loop over different functions (IFUNC) of DGGESX, types (PRTYPE) */
+/*     of test matrices, different size (M+N) */
 
     prtype = 0;
     qba = 3;
@@ -577,10 +586,10 @@ static integer c__5 = 5;
 			    q_offset], lda, &z__[z_offset], lda, &weight, &
 			    qba, &qbb);
 
-/*                 Compute the Schur factorization and swapping the   
-                   m-by-m (1,1)-blocks with n-by-n (2,2)-blocks.   
-                   Swapping is accomplished via the function DLCTSX   
-                   which is supplied below. */
+/*                 Compute the Schur factorization and swapping the */
+/*                 m-by-m (1,1)-blocks with n-by-n (2,2)-blocks. */
+/*                 Swapping is accomplished via the function DLCTSX */
+/*                 which is supplied below. */
 
 		    if (ifunc == 0) {
 			*(unsigned char *)sense = 'N';
@@ -593,11 +602,11 @@ static integer c__5 = 5;
 		    }
 
 		    dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset]
-			    , lda, &a[a_offset], lda);
+, lda, &a[a_offset], lda);
 		    dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset]
-			    , lda, &b[b_offset], lda);
+, lda, &b[b_offset], lda);
 
-		    dggesx_("V", "V", "S", (L_fp)dlctsx_, sense, &mn_1.mplusn,
+		    dggesx_("V", "V", "S", (L_fp)dlctsx_, sense, &mn_1.mplusn, 
 			     &ai[ai_offset], lda, &bi[bi_offset], lda, &mm, &
 			    alphar[1], &alphai[1], &beta[1], &q[q_offset], 
 			    lda, &z__[z_offset], lda, pl, difest, &work[1], 
@@ -612,7 +621,8 @@ static integer c__5 = 5;
 				;
 			do_fio(&c__1, (char *)&mn_1.mplusn, (ftnlen)sizeof(
 				integer));
-			do_fio(&c__1, (char *)&prtype, (ftnlen)sizeof(integer) );
+			do_fio(&c__1, (char *)&prtype, (ftnlen)sizeof(integer)
+				);
 			e_wsfe();
 			*info = linfo;
 			goto L30;
@@ -621,9 +631,9 @@ static integer c__5 = 5;
 /*                 Compute the norm(A, B) */
 
 		    dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset]
-			    , lda, &work[1], &mn_1.mplusn);
+, lda, &work[1], &mn_1.mplusn);
 		    dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset]
-			    , lda, &work[mn_1.mplusn * mn_1.mplusn + 1], &
+, lda, &work[mn_1.mplusn * mn_1.mplusn + 1], &
 			    mn_1.mplusn);
 		    i__3 = mn_1.mplusn << 1;
 		    abnrm = dlange_("Fro", &mn_1.mplusn, &i__3, &work[1], &
@@ -633,10 +643,10 @@ static integer c__5 = 5;
 
 		    dget51_(&c__1, &mn_1.mplusn, &a[a_offset], lda, &ai[
 			    ai_offset], lda, &q[q_offset], lda, &z__[z_offset]
-			    , lda, &work[1], result);
+, lda, &work[1], result);
 		    dget51_(&c__1, &mn_1.mplusn, &b[b_offset], lda, &bi[
 			    bi_offset], lda, &q[q_offset], lda, &z__[z_offset]
-			    , lda, &work[1], &result[1]);
+, lda, &work[1], &result[1]);
 		    dget51_(&c__3, &mn_1.mplusn, &b[b_offset], lda, &bi[
 			    bi_offset], lda, &q[q_offset], lda, &q[q_offset], 
 			    lda, &work[1], &result[2]);
@@ -645,8 +655,8 @@ static integer c__5 = 5;
 			    z_offset], lda, &work[1], &result[3]);
 		    ntest = 4;
 
-/*                 Do tests (5) and (6): check Schur form of A and   
-                   compare eigenvalues with diagonals. */
+/*                 Do tests (5) and (6): check Schur form of A and */
+/*                 compare eigenvalues with diagonals. */
 
 		    temp1 = 0.;
 		    result[4] = 0.;
@@ -656,7 +666,9 @@ static integer c__5 = 5;
 		    for (j = 1; j <= i__3; ++j) {
 			ilabad = FALSE_;
 			if (alphai[j] == 0.) {
-/* Computing MAX */ 			    d__7 = smlnum, d__8 = (d__2 = alphar[j], abs(d__2) 				    ), d__7 = max(d__7,d__8), d__8 = (d__3 = 
+/* Computing MAX */
+			    d__7 = smlnum, d__8 = (d__2 = alphar[j], abs(d__2)
+				    ), d__7 = max(d__7,d__8), d__8 = (d__3 = 
 				    ai[j + j * ai_dim1], abs(d__3));
 /* Computing MAX */
 			    d__9 = smlnum, d__10 = (d__5 = beta[j], abs(d__5))
@@ -746,15 +758,15 @@ static integer c__5 = 5;
 		    }
 		    ++ntest;
 
-/*                 Test (8): compare the estimated value DIF and its   
-                   value. first, compute the exact DIF. */
+/*                 Test (8): compare the estimated value DIF and its */
+/*                 value. first, compute the exact DIF. */
 
 		    result[7] = 0.;
 		    mn2 = mm * (mn_1.mplusn - mm) << 1;
 		    if (ifunc >= 2 && mn2 <= *ncmax * *ncmax) {
 
-/*                    Note: for either following two causes, there are   
-                      almost same number of test cases fail the test. */
+/*                    Note: for either following two causes, there are */
+/*                    almost same number of test cases fail the test. */
 
 			i__3 = mn_1.mplusn - mm;
 			dlakf2_(&mm, &i__3, &ai[ai_offset], lda, &ai[mm + 1 + 
@@ -764,7 +776,7 @@ static integer c__5 = 5;
 			i__3 = *lwork - 2;
 			dgesvd_("N", "N", &mn2, &mn2, &c__[c_offset], ldc, &s[
 				1], &work[1], &c__1, &work[2], &c__1, &work[3]
-				, &i__3, info);
+, &i__3, info);
 			diftru = s[mn2];
 
 			if (difest[1] == 0.) {
@@ -808,8 +820,8 @@ static integer c__5 = 5;
 		    for (j = 1; j <= 9; ++j) {
 			if (result[j - 1] >= *thresh) {
 
-/*                       If this is the first test to fail,   
-                         print a header to the data file. */
+/*                       If this is the first test to fail, */
+/*                       print a header to the data file. */
 
 			    if (nerrs == 0) {
 				io___35.ciunit = *nout;
@@ -888,8 +900,8 @@ L30:
 
 L70:
 
-/*     Read in data from file to check accuracy of condition estimation   
-       Read input data until N=0 */
+/*     Read in data from file to check accuracy of condition estimation */
+/*     Read input data until N=0 */
 
     nptknt = 0;
 
@@ -964,8 +976,8 @@ L80:
     dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset], lda, &b[
 	    b_offset], lda);
 
-/*     Compute the Schur factorization while swaping the   
-       m-by-m (1,1)-blocks with n-by-n (2,2)-blocks. */
+/*     Compute the Schur factorization while swaping the */
+/*     m-by-m (1,1)-blocks with n-by-n (2,2)-blocks. */
 
     dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &mn_1.mplusn, &ai[ai_offset], 
 	    lda, &bi[bi_offset], lda, &mm, &alphar[1], &alphai[1], &beta[1], &
@@ -984,10 +996,10 @@ L80:
 	goto L130;
     }
 
-/*     Compute the norm(A, B)   
-          (should this be norm of (A,B) or (AI,BI)?) */
+/*     Compute the norm(A, B) */
+/*        (should this be norm of (A,B) or (AI,BI)?) */
 
-    dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset], lda, &work[1],
+    dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset], lda, &work[1], 
 	     &mn_1.mplusn);
     dlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset], lda, &work[
 	    mn_1.mplusn * mn_1.mplusn + 1], &mn_1.mplusn);
@@ -1006,8 +1018,8 @@ L80:
     dget51_(&c__3, &mn_1.mplusn, &b[b_offset], lda, &bi[bi_offset], lda, &z__[
 	    z_offset], lda, &z__[z_offset], lda, &work[1], &result[3]);
 
-/*     Do tests (5) and (6): check Schur form of A and compare   
-       eigenvalues with diagonals. */
+/*     Do tests (5) and (6): check Schur form of A and compare */
+/*     eigenvalues with diagonals. */
 
     ntest = 6;
     temp1 = 0.;
@@ -1158,8 +1170,8 @@ L80:
     for (j = 1; j <= i__1; ++j) {
 	if (result[j - 1] >= *thresh) {
 
-/*           If this is the first test to fail,   
-             print a header to the data file. */
+/*           If this is the first test to fail, */
+/*           print a header to the data file. */
 
 	    if (nerrs == 0) {
 		io___51.ciunit = *nout;
