@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* ddrgvx.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -22,7 +10,7 @@ static logical c_true = TRUE_;
 static logical c_false = FALSE_;
 static integer c__3 = 3;
 
-/* Subroutine */ int ddrgvx_(integer *nsize, doublereal *thresh, integer *nin,
+/* Subroutine */ int ddrgvx_(integer *nsize, doublereal *thresh, integer *nin, 
 	 integer *nout, doublereal *a, integer *lda, doublereal *b, 
 	doublereal *ai, doublereal *bi, doublereal *alphar, doublereal *
 	alphai, doublereal *beta, doublereal *vl, doublereal *vr, integer *
@@ -88,41 +76,41 @@ static integer c__3 = 3;
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, n, iwa, iwb;
-    static doublereal ulp;
-    static integer iwx, iwy, nmax;
+    integer i__, j, n, iwa, iwb;
+    doublereal ulp;
+    integer iwx, iwy, nmax;
     extern /* Subroutine */ int dget52_(logical *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *);
-    static integer linfo;
-    static doublereal anorm, bnorm;
-    static integer nerrs;
+    integer linfo;
+    doublereal anorm, bnorm;
+    integer nerrs;
     extern /* Subroutine */ int dlatm6_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *, doublereal *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *);
-    static doublereal ratio1, ratio2, thrsh2;
+    doublereal ratio1, ratio2, thrsh2;
     extern doublereal dlamch_(char *), dlange_(char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *);
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *), 
 	    xerbla_(char *, integer *);
-    static doublereal abnorm;
+    doublereal abnorm;
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *), dggevx_(char *, char *, char *, char *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, integer *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, integer *, integer *, logical *, 
 	    integer *);
-    static doublereal weight[5];
-    static integer minwrk, maxwrk, iptype;
-    static doublereal ulpinv;
-    static integer nptknt, ntestt;
+    doublereal weight[5];
+    integer minwrk, maxwrk, iptype;
+    doublereal ulpinv;
+    integer nptknt, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___20 = { 0, 0, 0, fmt_9999, 0 };
@@ -151,177 +139,194 @@ static integer c__3 = 3;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DDRGVX checks the nonsymmetric generalized eigenvalue problem   
-    expert driver DGGEVX.   
+/*  DDRGVX checks the nonsymmetric generalized eigenvalue problem */
+/*  expert driver DGGEVX. */
 
-    DGGEVX computes the generalized eigenvalues, (optionally) the left   
-    and/or right eigenvectors, (optionally) computes a balancing   
-    transformation to improve the conditioning, and (optionally)   
-    reciprocal condition numbers for the eigenvalues and eigenvectors.   
+/*  DGGEVX computes the generalized eigenvalues, (optionally) the left */
+/*  and/or right eigenvectors, (optionally) computes a balancing */
+/*  transformation to improve the conditioning, and (optionally) */
+/*  reciprocal condition numbers for the eigenvalues and eigenvectors. */
 
-    When DDRGVX is called with NSIZE > 0, two types of test matrix pairs   
-    are generated by the subroutine DLATM6 and test the driver DGGEVX.   
-    The test matrices have the known exact condition numbers for   
-    eigenvalues. For the condition numbers of the eigenvectors   
-    corresponding the first and last eigenvalues are also know   
-    ``exactly'' (see DLATM6).   
+/*  When DDRGVX is called with NSIZE > 0, two types of test matrix pairs */
+/*  are generated by the subroutine DLATM6 and test the driver DGGEVX. */
+/*  The test matrices have the known exact condition numbers for */
+/*  eigenvalues. For the condition numbers of the eigenvectors */
+/*  corresponding the first and last eigenvalues are also know */
+/*  ``exactly'' (see DLATM6). */
 
-    For each matrix pair, the following tests will be performed and   
-    compared with the threshhold THRESH.   
+/*  For each matrix pair, the following tests will be performed and */
+/*  compared with the threshhold THRESH. */
 
-    (1) max over all left eigenvalue/-vector pairs (beta/alpha,l) of   
+/*  (1) max over all left eigenvalue/-vector pairs (beta/alpha,l) of */
 
-       | l**H * (beta A - alpha B) | / ( ulp max( |beta A|, |alpha B| ) )   
+/*     | l**H * (beta A - alpha B) | / ( ulp max( |beta A|, |alpha B| ) ) */
 
-        where l**H is the conjugate tranpose of l.   
+/*      where l**H is the conjugate tranpose of l. */
 
-    (2) max over all right eigenvalue/-vector pairs (beta/alpha,r) of   
+/*  (2) max over all right eigenvalue/-vector pairs (beta/alpha,r) of */
 
-          | (beta A - alpha B) r | / ( ulp max( |beta A|, |alpha B| ) )   
+/*        | (beta A - alpha B) r | / ( ulp max( |beta A|, |alpha B| ) ) */
 
-    (3) The condition number S(i) of eigenvalues computed by DGGEVX   
-        differs less than a factor THRESH from the exact S(i) (see   
-        DLATM6).   
+/*  (3) The condition number S(i) of eigenvalues computed by DGGEVX */
+/*      differs less than a factor THRESH from the exact S(i) (see */
+/*      DLATM6). */
 
-    (4) DIF(i) computed by DTGSNA differs less than a factor 10*THRESH   
-        from the exact value (for the 1st and 5th vectors only).   
+/*  (4) DIF(i) computed by DTGSNA differs less than a factor 10*THRESH */
+/*      from the exact value (for the 1st and 5th vectors only). */
 
-    Test Matrices   
-    =============   
+/*  Test Matrices */
+/*  ============= */
 
-    Two kinds of test matrix pairs   
+/*  Two kinds of test matrix pairs */
 
-             (A, B) = inverse(YH) * (Da, Db) * inverse(X)   
+/*           (A, B) = inverse(YH) * (Da, Db) * inverse(X) */
 
-    are used in the tests:   
+/*  are used in the tests: */
 
-    1: Da = 1+a   0    0    0    0    Db = 1   0   0   0   0   
-             0   2+a   0    0    0         0   1   0   0   0   
-             0    0   3+a   0    0         0   0   1   0   0   
-             0    0    0   4+a   0         0   0   0   1   0   
-             0    0    0    0   5+a ,      0   0   0   0   1 , and   
+/*  1: Da = 1+a   0    0    0    0    Db = 1   0   0   0   0 */
+/*           0   2+a   0    0    0         0   1   0   0   0 */
+/*           0    0   3+a   0    0         0   0   1   0   0 */
+/*           0    0    0   4+a   0         0   0   0   1   0 */
+/*           0    0    0    0   5+a ,      0   0   0   0   1 , and */
 
-    2: Da =  1   -1    0    0    0    Db = 1   0   0   0   0   
-             1    1    0    0    0         0   1   0   0   0   
-             0    0    1    0    0         0   0   1   0   0   
-             0    0    0   1+a  1+b        0   0   0   1   0   
-             0    0    0  -1-b  1+a ,      0   0   0   0   1 .   
+/*  2: Da =  1   -1    0    0    0    Db = 1   0   0   0   0 */
+/*           1    1    0    0    0         0   1   0   0   0 */
+/*           0    0    1    0    0         0   0   1   0   0 */
+/*           0    0    0   1+a  1+b        0   0   0   1   0 */
+/*           0    0    0  -1-b  1+a ,      0   0   0   0   1 . */
 
-    In both cases the same inverse(YH) and inverse(X) are used to compute   
-    (A, B), giving the exact eigenvectors to (A,B) as (YH, X):   
+/*  In both cases the same inverse(YH) and inverse(X) are used to compute */
+/*  (A, B), giving the exact eigenvectors to (A,B) as (YH, X): */
 
-    YH:  =  1    0   -y    y   -y    X =  1   0  -x  -x   x   
-            0    1   -y    y   -y         0   1   x  -x  -x   
-            0    0    1    0    0         0   0   1   0   0   
-            0    0    0    1    0         0   0   0   1   0   
-            0    0    0    0    1,        0   0   0   0   1 , where   
+/*  YH:  =  1    0   -y    y   -y    X =  1   0  -x  -x   x */
+/*          0    1   -y    y   -y         0   1   x  -x  -x */
+/*          0    0    1    0    0         0   0   1   0   0 */
+/*          0    0    0    1    0         0   0   0   1   0 */
+/*          0    0    0    0    1,        0   0   0   0   1 , where */
 
-    a, b, x and y will have all values independently of each other from   
-    { sqrt(sqrt(ULP)),  0.1,  1,  10,  1/sqrt(sqrt(ULP)) }.   
+/*  a, b, x and y will have all values independently of each other from */
+/*  { sqrt(sqrt(ULP)),  0.1,  1,  10,  1/sqrt(sqrt(ULP)) }. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    NSIZE   (input) INTEGER   
-            The number of sizes of matrices to use.  NSIZE must be at   
-            least zero. If it is zero, no randomly generated matrices   
-            are tested, but any test matrices read from NIN will be   
-            tested.   
+/*  NSIZE   (input) INTEGER */
+/*          The number of sizes of matrices to use.  NSIZE must be at */
+/*          least zero. If it is zero, no randomly generated matrices */
+/*          are tested, but any test matrices read from NIN will be */
+/*          tested. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
 
-    NIN     (input) INTEGER   
-            The FORTRAN unit number for reading in the data file of   
-            problems to solve.   
+/*  NIN     (input) INTEGER */
+/*          The FORTRAN unit number for reading in the data file of */
+/*          problems to solve. */
 
-    NOUT    (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IINFO not equal to 0.)   
+/*  NOUT    (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IINFO not equal to 0.) */
 
-    A       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
+/*  A       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
 
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, AI, BI, Ao, and Bo.   
-            It must be at least 1 and at least NSIZE.   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, AI, BI, Ao, and Bo. */
+/*          It must be at least 1 and at least NSIZE. */
 
-    B       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, B contains the last matrix actually used.   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, B contains the last matrix actually used. */
 
-    AI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Copy of A, modified by DGGEVX.   
+/*  AI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Copy of A, modified by DGGEVX. */
 
-    BI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            Copy of B, modified by DGGEVX.   
+/*  BI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          Copy of B, modified by DGGEVX. */
 
-    ALPHAR  (workspace) DOUBLE PRECISION array, dimension (NSIZE)   
-    ALPHAI  (workspace) DOUBLE PRECISION array, dimension (NSIZE)   
-    BETA    (workspace) DOUBLE PRECISION array, dimension (NSIZE)   
-            On exit, (ALPHAR + ALPHAI*i)/BETA are the eigenvalues.   
+/*  ALPHAR  (workspace) DOUBLE PRECISION array, dimension (NSIZE) */
+/*  ALPHAI  (workspace) DOUBLE PRECISION array, dimension (NSIZE) */
+/*  BETA    (workspace) DOUBLE PRECISION array, dimension (NSIZE) */
+/*          On exit, (ALPHAR + ALPHAI*i)/BETA are the eigenvalues. */
 
-    VL      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            VL holds the left eigenvectors computed by DGGEVX.   
+/*  VL      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          VL holds the left eigenvectors computed by DGGEVX. */
 
-    VR      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)   
-            VR holds the right eigenvectors computed by DGGEVX.   
+/*  VR      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE) */
+/*          VR holds the right eigenvectors computed by DGGEVX. */
 
-    ILO     (output/workspace) INTEGER   
+/*  ILO     (output/workspace) INTEGER */
 
-    IHI     (output/workspace) INTEGER   
+/*  IHI     (output/workspace) INTEGER */
 
-    LSCALE  (output/workspace) DOUBLE PRECISION array, dimension (N)   
+/*  LSCALE  (output/workspace) DOUBLE PRECISION array, dimension (N) */
 
-    RSCALE  (output/workspace) DOUBLE PRECISION array, dimension (N)   
+/*  RSCALE  (output/workspace) DOUBLE PRECISION array, dimension (N) */
 
-    S       (output/workspace) DOUBLE PRECISION array, dimension (N)   
+/*  S       (output/workspace) DOUBLE PRECISION array, dimension (N) */
 
-    DTRU    (output/workspace) DOUBLE PRECISION array, dimension (N)   
+/*  DTRU    (output/workspace) DOUBLE PRECISION array, dimension (N) */
 
-    DIF     (output/workspace) DOUBLE PRECISION array, dimension (N)   
+/*  DIF     (output/workspace) DOUBLE PRECISION array, dimension (N) */
 
-    DIFTRU  (output/workspace) DOUBLE PRECISION array, dimension (N)   
+/*  DIFTRU  (output/workspace) DOUBLE PRECISION array, dimension (N) */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK)   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK) */
 
-    LWORK   (input) INTEGER   
-            Leading dimension of WORK.  LWORK >= 2*N*N+12*N+16.   
+/*  LWORK   (input) INTEGER */
+/*          Leading dimension of WORK.  LWORK >= 2*N*N+12*N+16. */
 
-    IWORK   (workspace) INTEGER array, dimension (LIWORK)   
+/*  IWORK   (workspace) INTEGER array, dimension (LIWORK) */
 
-    LIWORK  (input) INTEGER   
-            Leading dimension of IWORK.  Must be at least N+6.   
+/*  LIWORK  (input) INTEGER */
+/*          Leading dimension of IWORK.  Must be at least N+6. */
 
-    RESULT  (output/workspace) DOUBLE PRECISION array, dimension (4)   
+/*  RESULT  (output/workspace) DOUBLE PRECISION array, dimension (4) */
 
-    BWORK   (workspace) LOGICAL array, dimension (N)   
+/*  BWORK   (workspace) LOGICAL array, dimension (N) */
 
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors   
+/*     Check for errors */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     vr_dim1 = *lda;
     vr_offset = 1 + vr_dim1;
     vr -= vr_offset;
@@ -373,18 +378,18 @@ static integer c__3 = 3;
 	*info = -26;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV.) */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
 	minwrk = (nmax << 1) * nmax + nmax * 12 + 16;
-	maxwrk = nmax * 6 + nmax * ilaenv_(&c__1, "DGEQRF", " ", &nmax, &c__1,
-		 &nmax, &c__0, (ftnlen)6, (ftnlen)1);
+	maxwrk = nmax * 6 + nmax * ilaenv_(&c__1, "DGEQRF", " ", &nmax, &c__1, 
+		 &nmax, &c__0);
 /* Computing MAX */
 	i__1 = maxwrk, i__2 = (nmax << 1) * nmax + nmax * 12 + 16;
 	maxwrk = max(i__1,i__2);
@@ -431,23 +436,23 @@ static integer c__3 = 3;
 
 			dlatm6_(&iptype, &c__5, &a[a_offset], lda, &b[
 				b_offset], &vr[vr_offset], lda, &vl[vl_offset]
-				, lda, &weight[iwa - 1], &weight[iwb - 1], &
+, lda, &weight[iwa - 1], &weight[iwb - 1], &
 				weight[iwx - 1], &weight[iwy - 1], &dtru[1], &
 				diftru[1]);
 
-/*                    Compute eigenvalues/eigenvectors of (A, B).   
-                      Compute eigenvalue/eigenvector condition numbers   
-                      using computed eigenvectors. */
+/*                    Compute eigenvalues/eigenvectors of (A, B). */
+/*                    Compute eigenvalue/eigenvector condition numbers */
+/*                    using computed eigenvectors. */
 
 			dlacpy_("F", &n, &n, &a[a_offset], lda, &ai[ai_offset]
-				, lda);
+, lda);
 			dlacpy_("F", &n, &n, &b[b_offset], lda, &bi[bi_offset]
-				, lda);
+, lda);
 
 			dggevx_("N", "V", "V", "B", &n, &ai[ai_offset], lda, &
 				bi[bi_offset], lda, &alphar[1], &alphai[1], &
 				beta[1], &vl[vl_offset], lda, &vr[vr_offset], 
-				lda, ilo, ihi, &lscale[1], &rscale[1], &anorm,
+				lda, ilo, ihi, &lscale[1], &rscale[1], &anorm, 
 				 &bnorm, &s[1], &dif[1], &work[1], lwork, &
 				iwork[1], &bwork[1], &linfo);
 			if (linfo != 0) {
@@ -467,7 +472,7 @@ static integer c__3 = 3;
 
 /*                    Compute the norm(A, B) */
 
-			dlacpy_("Full", &n, &n, &ai[ai_offset], lda, &work[1],
+			dlacpy_("Full", &n, &n, &ai[ai_offset], lda, &work[1], 
 				 &n);
 			dlacpy_("Full", &n, &n, &bi[bi_offset], lda, &work[n *
 				 n + 1], &n);
@@ -504,7 +509,7 @@ static integer c__3 = 3;
 			}
 
 			result[2] = 0.;
-			dget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset],
+			dget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset], 
 				 lda, &vr[vr_offset], lda, &alphar[1], &
 				alphai[1], &beta[1], &work[1], &result[2]);
 			if (result[3] > *thresh) {
@@ -596,8 +601,8 @@ static integer c__3 = 3;
 			    if (result[j] >= thrsh2 && j >= 4 || result[j] >= 
 				    *thresh && j <= 3) {
 
-/*                       If this is the first test to fail,   
-                         print a header to the data file. */
+/*                       If this is the first test to fail, */
+/*                       print a header to the data file. */
 
 				if (nerrs == 0) {
 				    io___28.ciunit = *nout;
@@ -605,9 +610,9 @@ static integer c__3 = 3;
 				    do_fio(&c__1, "DXV", (ftnlen)3);
 				    e_wsfe();
 
-/*                          Print out messages for built-in examples   
+/*                          Print out messages for built-in examples */
 
-                            Matrix types */
+/*                          Matrix types */
 
 				    io___29.ciunit = *nout;
 				    s_wsfe(&io___29);
@@ -689,8 +694,8 @@ L30:
 
 L90:
 
-/*     Read in data from file to check accuracy of condition estimation   
-       Read input data until N=0 */
+/*     Read in data from file to check accuracy of condition estimation */
+/*     Read input data until N=0 */
 
     io___35.ciunit = *nin;
     i__1 = s_rsle(&io___35);
@@ -750,16 +755,16 @@ L90:
 
     ++nptknt;
 
-/*     Compute eigenvalues/eigenvectors of (A, B).   
-       Compute eigenvalue/eigenvector condition numbers   
-       using computed eigenvectors. */
+/*     Compute eigenvalues/eigenvectors of (A, B). */
+/*     Compute eigenvalue/eigenvector condition numbers */
+/*     using computed eigenvectors. */
 
     dlacpy_("F", &n, &n, &a[a_offset], lda, &ai[ai_offset], lda);
     dlacpy_("F", &n, &n, &b[b_offset], lda, &bi[bi_offset], lda);
 
     dggevx_("N", "V", "V", "B", &n, &ai[ai_offset], lda, &bi[bi_offset], lda, 
 	    &alphar[1], &alphai[1], &beta[1], &vl[vl_offset], lda, &vr[
-	    vr_offset], lda, ilo, ihi, &lscale[1], &rscale[1], &anorm, &bnorm,
+	    vr_offset], lda, ilo, ihi, &lscale[1], &rscale[1], &anorm, &bnorm, 
 	     &s[1], &dif[1], &work[1], lwork, &iwork[1], &bwork[1], &linfo);
 
     if (linfo != 0) {
@@ -784,7 +789,7 @@ L90:
 /*     Tests (1) and (2) */
 
     result[1] = 0.;
-    dget52_(&c_true, &n, &a[a_offset], lda, &b[b_offset], lda, &vl[vl_offset],
+    dget52_(&c_true, &n, &a[a_offset], lda, &b[b_offset], lda, &vl[vl_offset], 
 	     lda, &alphar[1], &alphai[1], &beta[1], &work[1], &result[1]);
     if (result[2] > *thresh) {
 	io___41.ciunit = *nout;
@@ -799,7 +804,7 @@ L90:
 
     result[2] = 0.;
     dget52_(&c_false, &n, &a[a_offset], lda, &b[b_offset], lda, &vr[vr_offset]
-	    , lda, &alphar[1], &alphai[1], &beta[1], &work[1], &result[2]);
+, lda, &alphar[1], &alphai[1], &beta[1], &work[1], &result[2]);
     if (result[3] > *thresh) {
 	io___42.ciunit = *nout;
 	s_wsfe(&io___42);
@@ -874,8 +879,8 @@ L90:
     for (j = 1; j <= 4; ++j) {
 	if (result[j] >= thrsh2) {
 
-/*           If this is the first test to fail,   
-             print a header to the data file. */
+/*           If this is the first test to fail, */
+/*           print a header to the data file. */
 
 	    if (nerrs == 0) {
 		io___43.ciunit = *nout;
@@ -883,9 +888,9 @@ L90:
 		do_fio(&c__1, "DXV", (ftnlen)3);
 		e_wsfe();
 
-/*              Print out messages for built-in examples   
+/*              Print out messages for built-in examples */
 
-                Matrix types */
+/*              Matrix types */
 
 		io___44.ciunit = *nout;
 		s_wsfe(&io___44);
