@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* ddrvev.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -83,46 +71,46 @@ static integer c__2 = 2;
 	     vl_offset, vr_dim1, vr_offset, i__1, i__2, i__3, i__4;
     doublereal d__1, d__2, d__3, d__4, d__5;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer j, n, jj;
-    static doublereal dum[1], res[2];
-    static integer iwk;
-    static doublereal ulp, vmx, cond;
-    static integer jcol;
-    static char path[3];
-    static integer nmax;
-    static doublereal unfl, ovfl, tnrm, vrmx, vtst;
+    integer j, n, jj;
+    doublereal dum[1], res[2];
+    integer iwk;
+    doublereal ulp, vmx, cond;
+    integer jcol;
+    char path[3];
+    integer nmax;
+    doublereal unfl, ovfl, tnrm, vrmx, vtst;
     extern doublereal dnrm2_(integer *, doublereal *, integer *);
-    static logical badnn;
+    logical badnn;
     extern /* Subroutine */ int dget22_(char *, char *, char *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *);
-    static integer nfail;
+    integer nfail;
     extern /* Subroutine */ int dgeev_(char *, char *, integer *, doublereal *
-	    , integer *, doublereal *, doublereal *, doublereal *, integer *, 
+, integer *, doublereal *, doublereal *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *);
-    static integer imode, iinfo;
-    static doublereal conds, anorm;
-    static integer jsize, nerrs, itype, jtype, ntest;
-    static doublereal rtulp;
+    integer imode, iinfo;
+    doublereal conds, anorm;
+    integer jsize, nerrs, itype, jtype, ntest;
+    doublereal rtulp;
     extern doublereal dlapy2_(doublereal *, doublereal *);
     extern /* Subroutine */ int dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
-    static char adumma[1*1];
+    char adumma[1*1];
     extern /* Subroutine */ int dlatme_(integer *, char *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, char *, char 
 	    *, char *, char *, doublereal *, integer *, doublereal *, integer 
-	    *, integer *, doublereal *, doublereal *, integer *, doublereal *,
+	    *, integer *, doublereal *, doublereal *, integer *, doublereal *, 
 	     integer *);
-    static integer idumma[1];
+    integer idumma[1];
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *);
-    static integer ioldsd[4];
+    integer ioldsd[4];
     extern /* Subroutine */ int dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *), 
 	    xerbla_(char *, integer *), dlatmr_(integer *, integer *, 
@@ -135,11 +123,11 @@ static integer c__2 = 2;
 	    doublereal *, integer *, integer *, char *, doublereal *, integer 
 	    *, doublereal *, integer *), dlasum_(char 
 	    *, integer *, integer *, integer *);
-    static integer ntestf;
-    static doublereal ulpinv;
-    static integer nnwork;
-    static doublereal rtulpi;
-    static integer mtypes, ntestt;
+    integer ntestf;
+    doublereal ulpinv;
+    integer nnwork;
+    doublereal rtulpi;
+    integer mtypes, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___32 = { 0, 0, 0, fmt_9993, 0 };
@@ -156,293 +144,310 @@ static integer c__2 = 2;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       DDRVEV  checks the nonsymmetric eigenvalue problem driver DGEEV.   
+/*     DDRVEV  checks the nonsymmetric eigenvalue problem driver DGEEV. */
 
-       When DDRVEV is called, a number of matrix "sizes" ("n's") and a   
-       number of matrix "types" are specified.  For each size ("n")   
-       and each type of matrix, one matrix will be generated and used   
-       to test the nonsymmetric eigenroutines.  For each matrix, 7   
-       tests will be performed:   
+/*     When DDRVEV is called, a number of matrix "sizes" ("n's") and a */
+/*     number of matrix "types" are specified.  For each size ("n") */
+/*     and each type of matrix, one matrix will be generated and used */
+/*     to test the nonsymmetric eigenroutines.  For each matrix, 7 */
+/*     tests will be performed: */
 
-       (1)     | A * VR - VR * W | / ( n |A| ulp )   
+/*     (1)     | A * VR - VR * W | / ( n |A| ulp ) */
 
-         Here VR is the matrix of unit right eigenvectors.   
-         W is a block diagonal matrix, with a 1x1 block for each   
-         real eigenvalue and a 2x2 block for each complex conjugate   
-         pair.  If eigenvalues j and j+1 are a complex conjugate pair,   
-         so WR(j) = WR(j+1) = wr and WI(j) = - WI(j+1) = wi, then the   
-         2 x 2 block corresponding to the pair will be:   
+/*       Here VR is the matrix of unit right eigenvectors. */
+/*       W is a block diagonal matrix, with a 1x1 block for each */
+/*       real eigenvalue and a 2x2 block for each complex conjugate */
+/*       pair.  If eigenvalues j and j+1 are a complex conjugate pair, */
+/*       so WR(j) = WR(j+1) = wr and WI(j) = - WI(j+1) = wi, then the */
+/*       2 x 2 block corresponding to the pair will be: */
 
-                 (  wr  wi  )   
-                 ( -wi  wr  )   
+/*               (  wr  wi  ) */
+/*               ( -wi  wr  ) */
 
-         Such a block multiplying an n x 2 matrix  ( ur ui ) on the   
-         right will be the same as multiplying  ur + i*ui  by  wr + i*wi.   
+/*       Such a block multiplying an n x 2 matrix  ( ur ui ) on the */
+/*       right will be the same as multiplying  ur + i*ui  by  wr + i*wi. */
 
-       (2)     | A**H * VL - VL * W**H | / ( n |A| ulp )   
+/*     (2)     | A**H * VL - VL * W**H | / ( n |A| ulp ) */
 
-         Here VL is the matrix of unit left eigenvectors, A**H is the   
-         conjugate transpose of A, and W is as above.   
+/*       Here VL is the matrix of unit left eigenvectors, A**H is the */
+/*       conjugate transpose of A, and W is as above. */
+
+/*     (3)     | |VR(i)| - 1 | / ulp and whether largest component real */
+
+/*       VR(i) denotes the i-th column of VR. */
+
+/*     (4)     | |VL(i)| - 1 | / ulp and whether largest component real */
 
-       (3)     | |VR(i)| - 1 | / ulp and whether largest component real   
+/*       VL(i) denotes the i-th column of VL. */
+
+/*     (5)     W(full) = W(partial) */
 
-         VR(i) denotes the i-th column of VR.   
+/*       W(full) denotes the eigenvalues computed when both VR and VL */
+/*       are also computed, and W(partial) denotes the eigenvalues */
+/*       computed when only W, only W and VR, or only W and VL are */
+/*       computed. */
 
-       (4)     | |VL(i)| - 1 | / ulp and whether largest component real   
-
-         VL(i) denotes the i-th column of VL.   
-
-       (5)     W(full) = W(partial)   
-
-         W(full) denotes the eigenvalues computed when both VR and VL   
-         are also computed, and W(partial) denotes the eigenvalues   
-         computed when only W, only W and VR, or only W and VL are   
-         computed.   
-
-       (6)     VR(full) = VR(partial)   
-
-         VR(full) denotes the right eigenvectors computed when both VR   
-         and VL are computed, and VR(partial) denotes the result   
-         when only VR is computed.   
-
-        (7)     VL(full) = VL(partial)   
-
-         VL(full) denotes the left eigenvectors computed when both VR   
-         and VL are also computed, and VL(partial) denotes the result   
-         when only VL is computed.   
-
-       The "sizes" are specified by an array NN(1:NSIZES); the value of   
-       each element NN(j) specifies one size.   
-       The "types" are specified by a logical array DOTYPE( 1:NTYPES );   
-       if DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-       Currently, the list of possible types is:   
-
-       (1)  The zero matrix.   
-       (2)  The identity matrix.   
-       (3)  A (transposed) Jordan block, with 1's on the diagonal.   
-
-       (4)  A diagonal matrix with evenly spaced entries   
-            1, ..., ULP  and random signs.   
-            (ULP = (first number larger than 1) - 1 )   
-       (5)  A diagonal matrix with geometrically spaced entries   
-            1, ..., ULP  and random signs.   
-       (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP   
-            and random signs.   
-
-       (7)  Same as (4), but multiplied by a constant near   
-            the overflow threshold   
-       (8)  Same as (4), but multiplied by a constant near   
-            the underflow threshold   
-
-       (9)  A matrix of the form  U' T U, where U is orthogonal and   
-            T has evenly spaced entries 1, ..., ULP with random signs   
-            on the diagonal and random O(1) entries in the upper   
-            triangle.   
-
-       (10) A matrix of the form  U' T U, where U is orthogonal and   
-            T has geometrically spaced entries 1, ..., ULP with random   
-            signs on the diagonal and random O(1) entries in the upper   
-            triangle.   
-
-       (11) A matrix of the form  U' T U, where U is orthogonal and   
-            T has "clustered" entries 1, ULP,..., ULP with random   
-            signs on the diagonal and random O(1) entries in the upper   
-            triangle.   
-
-       (12) A matrix of the form  U' T U, where U is orthogonal and   
-            T has real or complex conjugate paired eigenvalues randomly   
-            chosen from ( ULP, 1 ) and random O(1) entries in the upper   
-            triangle.   
-
-       (13) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP   
-            with random signs on the diagonal and random O(1) entries   
-            in the upper triangle.   
-
-       (14) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has geometrically spaced entries   
-            1, ..., ULP with random signs on the diagonal and random   
-            O(1) entries in the upper triangle.   
-
-       (15) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP   
-            with random signs on the diagonal and random O(1) entries   
-            in the upper triangle.   
-
-       (16) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has real or complex conjugate paired   
-            eigenvalues randomly chosen from ( ULP, 1 ) and random   
-            O(1) entries in the upper triangle.   
-
-       (17) Same as (16), but multiplied by a constant   
-            near the overflow threshold   
-       (18) Same as (16), but multiplied by a constant   
-            near the underflow threshold   
-
-       (19) Nonsymmetric matrix with random entries chosen from (-1,1).   
-            If N is at least 4, all entries in first two rows and last   
-            row, and first column and last two columns are zero.   
-       (20) Same as (19), but multiplied by a constant   
-            near the overflow threshold   
-       (21) Same as (19), but multiplied by a constant   
-            near the underflow threshold   
-
-    Arguments   
-    ==========   
-
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  If it is zero,   
-            DDRVEV does nothing.  It must be at least zero.   
-
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  The values must be at least   
-            zero.   
-
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, DDRVEV   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrix is in A.  This   
-            is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
-
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated.  If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
-
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096.  Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to DDRVEV to continue the same random number   
-            sequence.   
-
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
-
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns INFO not equal to 0.)   
-
-    A       (workspace) DOUBLE PRECISION array, dimension (LDA, max(NN))   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, and H. LDA must be at   
-            least 1 and at least max(NN).   
-
-    H       (workspace) DOUBLE PRECISION array, dimension (LDA, max(NN))   
-            Another copy of the test matrix A, modified by DGEEV.   
-
-    WR      (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-    WI      (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-            The real and imaginary parts of the eigenvalues of A.   
-            On exit, WR + WI*i are the eigenvalues of the matrix in A.   
-
-    WR1     (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-    WI1     (workspace) DOUBLE PRECISION array, dimension (max(NN))   
-            Like WR, WI, these arrays contain the eigenvalues of A,   
-            but those computed when DGEEV only computes a partial   
-            eigendecomposition, i.e. not the eigenvalues and left   
-            and right eigenvectors.   
-
-    VL      (workspace) DOUBLE PRECISION array, dimension (LDVL, max(NN))   
-            VL holds the computed left eigenvectors.   
-
-    LDVL    (input) INTEGER   
-            Leading dimension of VL. Must be at least max(1,max(NN)).   
-
-    VR      (workspace) DOUBLE PRECISION array, dimension (LDVR, max(NN))   
-            VR holds the computed right eigenvectors.   
-
-    LDVR    (input) INTEGER   
-            Leading dimension of VR. Must be at least max(1,max(NN)).   
-
-    LRE     (workspace) DOUBLE PRECISION array, dimension (LDLRE,max(NN))   
-            LRE holds the computed right or left eigenvectors.   
-
-    LDLRE   (input) INTEGER   
-            Leading dimension of LRE. Must be at least max(1,max(NN)).   
-
-    RESULT  (output) DOUBLE PRECISION array, dimension (7)   
-            The values computed by the seven tests described above.   
-            The values are currently limited to 1/ulp, to avoid overflow.   
-
-    WORK    (workspace) DOUBLE PRECISION array, dimension (NWORK)   
-
-    NWORK   (input) INTEGER   
-            The number of entries in WORK.  This must be at least   
-            5*NN(j)+2*NN(j)**2 for all j.   
-
-    IWORK   (workspace) INTEGER array, dimension (max(NN))   
-
-    INFO    (output) INTEGER   
-            If 0, then everything ran OK.   
-             -1: NSIZES < 0   
-             -2: Some NN(j) < 0   
-             -3: NTYPES < 0   
-             -6: THRESH < 0   
-             -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ).   
-            -16: LDVL < 1 or LDVL < NMAX, where NMAX is max( NN(j) ).   
-            -18: LDVR < 1 or LDVR < NMAX, where NMAX is max( NN(j) ).   
-            -20: LDLRE < 1 or LDLRE < NMAX, where NMAX is max( NN(j) ).   
-            -23: NWORK too small.   
-            If  DLATMR, SLATMS, SLATME or DGEEV returns an error code,   
-                the absolute value of it is returned.   
-
-   -----------------------------------------------------------------------   
-
-       Some Local Variables and Parameters:   
-       ---- ----- --------- --- ----------   
-
-       ZERO, ONE       Real 0 and 1.   
-       MAXTYP          The number of types defined.   
-       NMAX            Largest value in NN.   
-       NERRS           The number of tests which have exceeded THRESH   
-       COND, CONDS,   
-       IMODE           Values to be passed to the matrix generators.   
-       ANORM           Norm of A; passed to matrix generators.   
-
-       OVFL, UNFL      Overflow and underflow thresholds.   
-       ULP, ULPINV     Finest relative precision and its inverse.   
-       RTULP, RTULPI   Square roots of the previous 4 values.   
-
-               The following four arrays decode JTYPE:   
-       KTYPE(j)        The general type (1-10) for type "j".   
-       KMODE(j)        The MODE value to be passed to the matrix   
-                       generator for type "j".   
-       KMAGN(j)        The order of magnitude ( O(1),   
-                       O(overflow^(1/2) ), O(underflow^(1/2) )   
-       KCONDS(j)       Selectw whether CONDS is to be 1 or   
-                       1/sqrt(ulp).  (0 means irrelevant.)   
-
-    =====================================================================   
-
-       Parameter adjustments */
+/*     (6)     VR(full) = VR(partial) */
+
+/*       VR(full) denotes the right eigenvectors computed when both VR */
+/*       and VL are computed, and VR(partial) denotes the result */
+/*       when only VR is computed. */
+
+/*      (7)     VL(full) = VL(partial) */
+
+/*       VL(full) denotes the left eigenvectors computed when both VR */
+/*       and VL are also computed, and VL(partial) denotes the result */
+/*       when only VL is computed. */
+
+/*     The "sizes" are specified by an array NN(1:NSIZES); the value of */
+/*     each element NN(j) specifies one size. */
+/*     The "types" are specified by a logical array DOTYPE( 1:NTYPES ); */
+/*     if DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*     Currently, the list of possible types is: */
+
+/*     (1)  The zero matrix. */
+/*     (2)  The identity matrix. */
+/*     (3)  A (transposed) Jordan block, with 1's on the diagonal. */
+
+/*     (4)  A diagonal matrix with evenly spaced entries */
+/*          1, ..., ULP  and random signs. */
+/*          (ULP = (first number larger than 1) - 1 ) */
+/*     (5)  A diagonal matrix with geometrically spaced entries */
+/*          1, ..., ULP  and random signs. */
+/*     (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP */
+/*          and random signs. */
+
+/*     (7)  Same as (4), but multiplied by a constant near */
+/*          the overflow threshold */
+/*     (8)  Same as (4), but multiplied by a constant near */
+/*          the underflow threshold */
+
+/*     (9)  A matrix of the form  U' T U, where U is orthogonal and */
+/*          T has evenly spaced entries 1, ..., ULP with random signs */
+/*          on the diagonal and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (10) A matrix of the form  U' T U, where U is orthogonal and */
+/*          T has geometrically spaced entries 1, ..., ULP with random */
+/*          signs on the diagonal and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (11) A matrix of the form  U' T U, where U is orthogonal and */
+/*          T has "clustered" entries 1, ULP,..., ULP with random */
+/*          signs on the diagonal and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (12) A matrix of the form  U' T U, where U is orthogonal and */
+/*          T has real or complex conjugate paired eigenvalues randomly */
+/*          chosen from ( ULP, 1 ) and random O(1) entries in the upper */
+/*          triangle. */
+
+/*     (13) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP */
+/*          with random signs on the diagonal and random O(1) entries */
+/*          in the upper triangle. */
+
+/*     (14) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has geometrically spaced entries */
+/*          1, ..., ULP with random signs on the diagonal and random */
+/*          O(1) entries in the upper triangle. */
+
+/*     (15) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP */
+/*          with random signs on the diagonal and random O(1) entries */
+/*          in the upper triangle. */
+
+/*     (16) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has real or complex conjugate paired */
+/*          eigenvalues randomly chosen from ( ULP, 1 ) and random */
+/*          O(1) entries in the upper triangle. */
+
+/*     (17) Same as (16), but multiplied by a constant */
+/*          near the overflow threshold */
+/*     (18) Same as (16), but multiplied by a constant */
+/*          near the underflow threshold */
+
+/*     (19) Nonsymmetric matrix with random entries chosen from (-1,1). */
+/*          If N is at least 4, all entries in first two rows and last */
+/*          row, and first column and last two columns are zero. */
+/*     (20) Same as (19), but multiplied by a constant */
+/*          near the overflow threshold */
+/*     (21) Same as (19), but multiplied by a constant */
+/*          near the underflow threshold */
+
+/*  Arguments */
+/*  ========== */
+
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  If it is zero, */
+/*          DDRVEV does nothing.  It must be at least zero. */
+
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  The values must be at least */
+/*          zero. */
+
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, DDRVEV */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrix is in A.  This */
+/*          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
+
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated.  If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
+
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096.  Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to DDRVEV to continue the same random number */
+/*          sequence. */
+
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
+
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns INFO not equal to 0.) */
+
+/*  A       (workspace) DOUBLE PRECISION array, dimension (LDA, max(NN)) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, and H. LDA must be at */
+/*          least 1 and at least max(NN). */
+
+/*  H       (workspace) DOUBLE PRECISION array, dimension (LDA, max(NN)) */
+/*          Another copy of the test matrix A, modified by DGEEV. */
+
+/*  WR      (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*  WI      (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*          The real and imaginary parts of the eigenvalues of A. */
+/*          On exit, WR + WI*i are the eigenvalues of the matrix in A. */
+
+/*  WR1     (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*  WI1     (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
+/*          Like WR, WI, these arrays contain the eigenvalues of A, */
+/*          but those computed when DGEEV only computes a partial */
+/*          eigendecomposition, i.e. not the eigenvalues and left */
+/*          and right eigenvectors. */
+
+/*  VL      (workspace) DOUBLE PRECISION array, dimension (LDVL, max(NN)) */
+/*          VL holds the computed left eigenvectors. */
+
+/*  LDVL    (input) INTEGER */
+/*          Leading dimension of VL. Must be at least max(1,max(NN)). */
+
+/*  VR      (workspace) DOUBLE PRECISION array, dimension (LDVR, max(NN)) */
+/*          VR holds the computed right eigenvectors. */
+
+/*  LDVR    (input) INTEGER */
+/*          Leading dimension of VR. Must be at least max(1,max(NN)). */
+
+/*  LRE     (workspace) DOUBLE PRECISION array, dimension (LDLRE,max(NN)) */
+/*          LRE holds the computed right or left eigenvectors. */
+
+/*  LDLRE   (input) INTEGER */
+/*          Leading dimension of LRE. Must be at least max(1,max(NN)). */
+
+/*  RESULT  (output) DOUBLE PRECISION array, dimension (7) */
+/*          The values computed by the seven tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid overflow. */
+
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension (NWORK) */
+
+/*  NWORK   (input) INTEGER */
+/*          The number of entries in WORK.  This must be at least */
+/*          5*NN(j)+2*NN(j)**2 for all j. */
+
+/*  IWORK   (workspace) INTEGER array, dimension (max(NN)) */
+
+/*  INFO    (output) INTEGER */
+/*          If 0, then everything ran OK. */
+/*           -1: NSIZES < 0 */
+/*           -2: Some NN(j) < 0 */
+/*           -3: NTYPES < 0 */
+/*           -6: THRESH < 0 */
+/*           -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ). */
+/*          -16: LDVL < 1 or LDVL < NMAX, where NMAX is max( NN(j) ). */
+/*          -18: LDVR < 1 or LDVR < NMAX, where NMAX is max( NN(j) ). */
+/*          -20: LDLRE < 1 or LDLRE < NMAX, where NMAX is max( NN(j) ). */
+/*          -23: NWORK too small. */
+/*          If  DLATMR, SLATMS, SLATME or DGEEV returns an error code, */
+/*              the absolute value of it is returned. */
+
+/* ----------------------------------------------------------------------- */
+
+/*     Some Local Variables and Parameters: */
+/*     ---- ----- --------- --- ---------- */
+
+/*     ZERO, ONE       Real 0 and 1. */
+/*     MAXTYP          The number of types defined. */
+/*     NMAX            Largest value in NN. */
+/*     NERRS           The number of tests which have exceeded THRESH */
+/*     COND, CONDS, */
+/*     IMODE           Values to be passed to the matrix generators. */
+/*     ANORM           Norm of A; passed to matrix generators. */
+
+/*     OVFL, UNFL      Overflow and underflow thresholds. */
+/*     ULP, ULPINV     Finest relative precision and its inverse. */
+/*     RTULP, RTULPI   Square roots of the previous 4 values. */
+
+/*             The following four arrays decode JTYPE: */
+/*     KTYPE(j)        The general type (1-10) for type "j". */
+/*     KMODE(j)        The MODE value to be passed to the matrix */
+/*                     generator for type "j". */
+/*     KMAGN(j)        The order of magnitude ( O(1), */
+/*                     O(overflow^(1/2) ), O(underflow^(1/2) ) */
+/*     KCONDS(j)       Selectw whether CONDS is to be 1 or */
+/*                     1/sqrt(ulp).  (0 means irrelevant.) */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -470,6 +475,8 @@ static integer c__2 = 2;
     --iwork;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Double precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "EV", (ftnlen)2, (ftnlen)2);
@@ -571,21 +578,21 @@ static integer c__2 = 2;
 /* L20: */
 	    }
 
-/*           Compute "A"   
+/*           Compute "A" */
 
-             Control parameters:   
+/*           Control parameters: */
 
-             KMAGN  KCONDS  KMODE        KTYPE   
-         =1  O(1)   1       clustered 1  zero   
-         =2  large  large   clustered 2  identity   
-         =3  small          exponential  Jordan   
-         =4                 arithmetic   diagonal, (w/ eigenvalues)   
-         =5                 random log   symmetric, w/ eigenvalues   
-         =6                 random       general, w/ eigenvalues   
-         =7                              random diagonal   
-         =8                              random symmetric   
-         =9                              random general   
-         =10                             random triangular */
+/*           KMAGN  KCONDS  KMODE        KTYPE */
+/*       =1  O(1)   1       clustered 1  zero */
+/*       =2  large  large   clustered 2  identity */
+/*       =3  small          exponential  Jordan */
+/*       =4                 arithmetic   diagonal, (w/ eigenvalues) */
+/*       =5                 random log   symmetric, w/ eigenvalues */
+/*       =6                 random       general, w/ eigenvalues */
+/*       =7                              random diagonal */
+/*       =8                              random symmetric */
+/*       =9                              random general */
+/*       =10                             random triangular */
 
 	    if (mtypes > 21) {
 		goto L90;
@@ -620,9 +627,9 @@ L60:
 	    iinfo = 0;
 	    cond = ulpinv;
 
-/*           Special Matrices -- Identity & Jordan block   
+/*           Special Matrices -- Identity & Jordan block */
 
-                Zero */
+/*              Zero */
 
 	    if (itype == 1) {
 		iinfo = 0;
@@ -681,7 +688,7 @@ L60:
 		*(unsigned char *)&adumma[0] = ' ';
 		dlatme_(&n, "S", &iseed[1], &work[1], &imode, &cond, &c_b31, 
 			adumma, "T", "T", "T", &work[n + 1], &c__4, &conds, &
-			n, &n, &anorm, &a[a_offset], lda, &work[(n << 1) + 1],
+			n, &n, &anorm, &a[a_offset], lda, &work[(n << 1) + 1], 
 			 &iinfo);
 
 	    } else if (itype == 7) {
@@ -722,7 +729,7 @@ L60:
 		    i__3 = n - 3;
 		    dlaset_("Full", &i__3, &c__2, &c_b17, &c_b17, &a[(n - 1) *
 			     a_dim1 + 3], lda);
-		    dlaset_("Full", &c__1, &n, &c_b17, &c_b17, &a[n + a_dim1],
+		    dlaset_("Full", &c__1, &n, &c_b17, &c_b17, &a[n + a_dim1], 
 			     lda);
 		}
 
@@ -820,8 +827,8 @@ L90:
 			d__2 = dnrm2_(&n, &vr[(j + 1) * vr_dim1 + 1], &c__1);
 			tnrm = dlapy2_(&d__1, &d__2);
 		    }
-/* Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
 		    d__4 = ulpinv, d__5 = (d__1 = tnrm - 1., abs(d__1)) / ulp;
 		    d__2 = result[3], d__3 = min(d__4,d__5);
 		    result[3] = max(d__2,d__3);
@@ -837,7 +844,8 @@ L90:
 			    }
 			    if (vr[jj + (j + 1) * vr_dim1] == 0. && (d__1 = 
 				    vr[jj + j * vr_dim1], abs(d__1)) > vrmx) {
-				vrmx = (d__2 = vr[jj + j * vr_dim1], abs(d__2) );
+				vrmx = (d__2 = vr[jj + j * vr_dim1], abs(d__2)
+					);
 			    }
 /* L110: */
 			}
@@ -860,8 +868,8 @@ L90:
 			d__2 = dnrm2_(&n, &vl[(j + 1) * vl_dim1 + 1], &c__1);
 			tnrm = dlapy2_(&d__1, &d__2);
 		    }
-/* Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
 		    d__4 = ulpinv, d__5 = (d__1 = tnrm - 1., abs(d__1)) / ulp;
 		    d__2 = result[4], d__3 = min(d__4,d__5);
 		    result[4] = max(d__2,d__3);
@@ -877,7 +885,8 @@ L90:
 			    }
 			    if (vl[jj + (j + 1) * vl_dim1] == 0. && (d__1 = 
 				    vl[jj + j * vl_dim1], abs(d__1)) > vrmx) {
-				vrmx = (d__2 = vl[jj + j * vl_dim1], abs(d__2) );
+				vrmx = (d__2 = vl[jj + j * vl_dim1], abs(d__2)
+					);
 			    }
 /* L130: */
 			}
@@ -967,7 +976,7 @@ L90:
 
 		dlacpy_("F", &n, &n, &a[a_offset], lda, &h__[h_offset], lda);
 		dgeev_("V", "N", &n, &h__[h_offset], lda, &wr1[1], &wi1[1], &
-			lre[lre_offset], ldlre, dum, &c__1, &work[1], &nnwork,
+			lre[lre_offset], ldlre, dum, &c__1, &work[1], &nnwork, 
 			 &iinfo);
 		if (iinfo != 0) {
 		    result[1] = ulpinv;
