@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* derrgg.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -55,43 +43,43 @@ static integer c__20 = 20;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublereal a[9]	/* was [3][3] */, b[9]	/* was [3][3] */;
-    static integer i__, j, m;
-    static doublereal q[9]	/* was [3][3] */, u[9]	/* was [3][3] */, v[9]
-	    	/* was [3][3] */, w[18], z__[9]	/* was [3][3] */;
-    static char c2[2];
-    static doublereal r1[3], r2[3], r3[3];
-    static logical bw[3];
-    static doublereal ls[3];
-    static integer iw[3], nt;
-    static doublereal rs[3], dif, rce[2];
-    static logical sel[3];
-    static doublereal tau[3], rcv[2];
-    static integer info, sdim;
-    static doublereal anrm, bnrm, tola, tolb;
-    static integer ifst, ilst;
-    static doublereal scale;
+    doublereal a[9]	/* was [3][3] */, b[9]	/* was [3][3] */;
+    integer i__, j, m;
+    doublereal q[9]	/* was [3][3] */, u[9]	/* was [3][3] */, v[9]	/* 
+	    was [3][3] */, w[18], z__[9]	/* was [3][3] */;
+    char c2[2];
+    doublereal r1[3], r2[3], r3[3];
+    logical bw[3];
+    doublereal ls[3];
+    integer iw[3], nt;
+    doublereal rs[3], dif, rce[2];
+    logical sel[3];
+    doublereal tau[3], rcv[2];
+    integer info, sdim;
+    doublereal anrm, bnrm, tola, tolb;
+    integer ifst, ilst;
+    doublereal scale;
     extern /* Subroutine */ int dgges_(char *, char *, char *, L_fp, integer *
-	    , doublereal *, integer *, doublereal *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+, doublereal *, integer *, doublereal *, integer *, integer *, 
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, doublereal *, integer *, logical *, 
 	    integer *), dggev_(char *, char *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, doublereal *, integer *, integer *), dgghrd_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *), dggglm_(integer *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *), 
 	    dgglse_(integer *, integer *, integer *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *, integer *), dggqrf_(integer *, integer *
-	    , integer *, doublereal *, integer *, doublereal *, doublereal *, 
+, integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *, integer *), 
 	    dggrqf_(integer *, integer *, integer *, doublereal *, integer *, 
-	    doublereal *, doublereal *, integer *, doublereal *, doublereal *,
+	    doublereal *, doublereal *, integer *, doublereal *, doublereal *, 
 	     integer *, integer *);
-    static integer ncycle;
+    integer ncycle;
     extern logical dlctes_(), lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int dggsvd_(char *, char *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, doublereal *, integer 
@@ -99,32 +87,33 @@ static integer c__20 = 20;
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *), dggesx_(char *, char *, char *, L_fp, char *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, doublereal *, doublereal *, doublereal *
-	    , integer *, integer *, integer *, logical *, integer *), dhgeqz_(char *, char *, char *, integer *
-	    , integer *, integer *, doublereal *, integer *, doublereal *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+, integer *, integer *, integer *, logical *, integer *), dhgeqz_(char *, char *, char *, integer *
+, integer *, integer *, doublereal *, integer *, doublereal *, 
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *), dtgevc_(char *, char *, 
 	    logical *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *, integer *, doublereal *, integer *), 
-	    chkxer_(char *, integer *, integer *, logical *, logical *), dggevx_(char *, char *, char *, char *, integer *,	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, integer *, doublereal *,
+	    chkxer_(char *, integer *, integer *, logical *, logical *), dggevx_(char *, char *, char *, char *, integer *, 
+	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
+	    doublereal *, doublereal *, doublereal *, integer *, doublereal *, 
 	     integer *, integer *, integer *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, integer *, integer *, logical *, integer *), dtgexc_(logical *, logical *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *, integer *, 
-	    doublereal *, integer *, integer *), dtgsen_(integer *, logical *,
+	    doublereal *, integer *, integer *), dtgsen_(integer *, logical *, 
 	     logical *, logical *, integer *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *, doublereal *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
-	     integer *, integer *, integer *), dtgsja_(char *, char *, char *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
+	     integer *, integer *, integer *), dtgsja_(char *, char *, char *, 
 	     integer *, integer *, integer *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, integer *), dtgsna_(char *, 
 	    char *, logical *, integer *, doublereal *, integer *, doublereal 
@@ -137,11 +126,11 @@ static integer c__20 = 20;
 	    integer *, doublereal *, integer *, integer *, doublereal *, 
 	    doublereal *, integer *);
     extern logical dlctsx_();
-    static integer dummyk, dummyl;
+    integer dummyk, dummyl;
     extern /* Subroutine */ int dtgsyl_(char *, integer *, integer *, integer 
-	    *, doublereal *, integer *, doublereal *, integer *, doublereal *,
+	    *, doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     integer *, integer *, integer *);
 
     /* Fortran I/O blocks */
@@ -151,29 +140,46 @@ static integer c__20 = 20;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DERRGG tests the error exits for DGGES, DGGESX, DGGEV, DGGEVX,   
-    DGGGLM, DGGHRD, DGGLSE, DGGQRF, DGGRQF, DGGSVD, DGGSVP, DHGEQZ,   
-    DTGEVC, DTGEXC, DTGSEN, DTGSJA, DTGSNA, and DTGSYL.   
+/*  DERRGG tests the error exits for DGGES, DGGESX, DGGEV, DGGEVX, */
+/*  DGGGLM, DGGHRD, DGGLSE, DGGQRF, DGGRQF, DGGSVD, DGGSVP, DHGEQZ, */
+/*  DTGEVC, DTGEXC, DTGSEN, DTGSJA, DTGSNA, and DTGSYL. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -437,67 +443,67 @@ static integer c__20 = 20;
 
 	s_copy(srnamc_1.srnamt, "DGGSVP", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	dggsvp_("/", "N", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	dggsvp_("/", "N", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	dggsvp_("N", "/", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "/", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	dggsvp_("N", "N", "/", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "/", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	dggsvp_("N", "N", "N", &c_n1, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "N", &c_n1, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	dggsvp_("N", "N", "N", &c__0, &c_n1, &c__0, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "N", &c__0, &c_n1, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	dggsvp_("N", "N", "N", &c__0, &c__0, &c_n1, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "N", &c__0, &c__0, &c_n1, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 8;
-	dggsvp_("N", "N", "N", &c__2, &c__1, &c__1, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "N", &c__2, &c__1, &c__1, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 10;
-	dggsvp_("N", "N", "N", &c__1, &c__2, &c__1, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "N", &c__1, &c__2, &c__1, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
-	dggsvp_("U", "N", "N", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola,
+	dggsvp_("U", "N", "N", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 18;
-	dggsvp_("N", "V", "N", &c__1, &c__2, &c__1, a, &c__1, b, &c__2, &tola,
+	dggsvp_("N", "V", "N", &c__1, &c__2, &c__1, a, &c__1, b, &c__2, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 20;
-	dggsvp_("N", "N", "Q", &c__1, &c__1, &c__2, a, &c__1, b, &c__1, &tola,
+	dggsvp_("N", "N", "Q", &c__1, &c__1, &c__2, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		tau, w, &info);
 	chkxer_("DGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
@@ -618,7 +624,7 @@ static integer c__20 = 20;
 	chkxer_("DGGGLM", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 12;
-	dggglm_(&c__1, &c__1, &c__1, a, &c__1, b, &c__1, r1, r2, r3, w, &c__1,
+	dggglm_(&c__1, &c__1, &c__1, a, &c__1, b, &c__1, r1, r2, r3, w, &c__1, 
 		 &info);
 	chkxer_("DGGGLM", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -667,7 +673,7 @@ static integer c__20 = 20;
 	chkxer_("DGGLSE", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 12;
-	dgglse_(&c__1, &c__1, &c__1, a, &c__1, b, &c__1, r1, r2, r3, w, &c__1,
+	dgglse_(&c__1, &c__1, &c__1, a, &c__1, b, &c__1, r1, r2, r3, w, &c__1, 
 		 &info);
 	chkxer_("DGGLSE", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -757,57 +763,57 @@ static integer c__20 = 20;
 
 	s_copy(srnamc_1.srnamt, "DGGES ", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	dgges_("/", "N", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	dgges_("/", "N", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	dgges_("N", "/", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	dgges_("N", "/", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	dgges_("N", "V", "/", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	dgges_("N", "V", "/", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	dgges_("N", "V", "S", (L_fp)dlctes_, &c_n1, a, &c__1, b, &c__1, &sdim,
+	dgges_("N", "V", "S", (L_fp)dlctes_, &c_n1, a, &c__1, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 7;
-	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__0, b, &c__1, &sdim,
+	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__0, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
-	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__0, &sdim,
+	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__0, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__0, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	dgges_("V", "V", "S", (L_fp)dlctes_, &c__2, a, &c__2, b, &c__2, &sdim,
+	dgges_("V", "V", "S", (L_fp)dlctes_, &c__2, a, &c__2, b, &c__2, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__2, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 17;
-	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	dgges_("N", "V", "S", (L_fp)dlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 r1, r2, r3, q, &c__1, u, &c__0, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 17;
-	dgges_("V", "V", "S", (L_fp)dlctes_, &c__2, a, &c__2, b, &c__2, &sdim,
+	dgges_("V", "V", "S", (L_fp)dlctes_, &c__2, a, &c__2, b, &c__2, &sdim, 
 		 r1, r2, r3, q, &c__2, u, &c__1, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 19;
-	dgges_("V", "V", "S", (L_fp)dlctes_, &c__2, a, &c__2, b, &c__2, &sdim,
+	dgges_("V", "V", "S", (L_fp)dlctes_, &c__2, a, &c__2, b, &c__2, &sdim, 
 		 r1, r2, r3, q, &c__2, u, &c__2, w, &c__1, bw, &info);
 	chkxer_("DGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -818,84 +824,84 @@ static integer c__20 = 20;
 	s_copy(srnamc_1.srnamt, "DGGESX", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
 	dggesx_("/", "N", "S", (L_fp)dlctsx_, "N", &c__1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
 	dggesx_("N", "/", "S", (L_fp)dlctsx_, "N", &c__1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
 	dggesx_("V", "V", "/", (L_fp)dlctsx_, "N", &c__1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "/", &c__1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c_n1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 8;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__1, a, &c__0, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 10;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__1, a, &c__1, b, &c__0, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__0, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__0, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__2, a, &c__2, b, &c__2, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 18;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__1, a, &c__1, b, &c__1, 
-		&sdim, r1, r2, r3, q, &c__1, u, &c__0, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__1, u, &c__0, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 18;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__2, a, &c__2, b, &c__2, 
-		&sdim, r1, r2, r3, q, &c__2, u, &c__1, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__2, u, &c__1, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 22;
 	dggesx_("V", "V", "S", (L_fp)dlctsx_, "B", &c__2, a, &c__2, b, &c__2, 
-		&sdim, r1, r2, r3, q, &c__2, u, &c__2, rce, rcv, w, &c__1, iw,
+		&sdim, r1, r2, r3, q, &c__2, u, &c__2, rce, rcv, w, &c__1, iw, 
 		 &c__1, bw, &info)
 		;
 	chkxer_("DGGESX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
@@ -968,73 +974,73 @@ static integer c__20 = 20;
 	s_copy(srnamc_1.srnamt, "DGGEVX", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
 	dggevx_("/", "N", "N", "N", &c__1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
 	dggevx_("N", "/", "N", "N", &c__1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
 	dggevx_("N", "N", "/", "N", &c__1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
 	dggevx_("N", "N", "N", "/", &c__1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
 	dggevx_("N", "N", "N", "N", &c_n1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 7;
 	dggevx_("N", "N", "N", "N", &c__1, a, &c__0, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
 	dggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__0, r1, r2, r3, q, 
-		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 14;
 	dggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__0, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__0, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 14;
 	dggevx_("N", "V", "N", "N", &c__2, a, &c__2, b, &c__2, r1, r2, r3, q, 
-		&c__1, u, &c__2, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__2, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
 	dggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__1, r1, r2, r3, q, 
-		&c__1, u, &c__0, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__1, u, &c__0, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
 	dggevx_("N", "N", "V", "N", &c__2, a, &c__2, b, &c__2, r1, r2, r3, q, 
-		&c__2, u, &c__1, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__2, u, &c__1, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 26;
 	dggevx_("N", "N", "V", "N", &c__2, a, &c__2, b, &c__2, r1, r2, r3, q, 
-		&c__2, u, &c__2, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, rcv,
+		&c__2, u, &c__2, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, rcv, 
 		 w, &c__1, iw, bw, &info);
 	chkxer_("DGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -1090,55 +1096,55 @@ static integer c__20 = 20;
 	s_copy(srnamc_1.srnamt, "DTGSEN", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
 	dtgsen_(&c_n1, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
 	dtgsen_(&c__1, &c_true, &c_true, sel, &c_n1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 7;
 	dtgsen_(&c__1, &c_true, &c_true, sel, &c__1, a, &c__0, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
 	dtgsen_(&c__1, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__0, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 14;
 	dtgsen_(&c__1, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__0, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__0, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
 	dtgsen_(&c__1, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__0, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__0, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 22;
 	dtgsen_(&c__0, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 22;
 	dtgsen_(&c__1, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 22;
 	dtgsen_(&c__2, &c_true, &c_true, sel, &c__1, a, &c__1, b, &c__1, r1, 
-		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1,
+		r2, r3, q, &c__1, z__, &c__1, &m, &tola, &tolb, rcv, w, &c__1, 
 		 iw, &c__1, &info);
 	chkxer_("DTGSEN", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
