@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* derrhs.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -51,25 +39,23 @@ static integer c__4 = 4;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublereal a[9]	/* was [3][3] */, c__[9]	/* was [3][3] 
-	    */;
-    static integer i__, j, m;
-    static doublereal s[3], w[28];
-    static char c2[2];
-    static doublereal wi[3];
-    static integer nt;
-    static doublereal vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */, wr[
-	    3];
-    static integer ihi, ilo;
-    static logical sel[3];
-    static doublereal tau[3];
-    static integer info;
+    doublereal a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
+    integer i__, j, m;
+    doublereal s[3], w[28];
+    char c2[2];
+    doublereal wi[3];
+    integer nt;
+    doublereal vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */, wr[3];
+    integer ihi, ilo;
+    logical sel[3];
+    doublereal tau[3];
+    integer info;
     extern /* Subroutine */ int dgebak_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *), dgebal_(char *, integer *, doublereal 
 	    *, integer *, integer *, integer *, doublereal *, integer *), dgehrd_(integer *, integer *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *, integer *);
-    static integer ifaill[3], ifailr[3];
+    integer ifaill[3], ifailr[3];
     extern /* Subroutine */ int dhsein_(char *, char *, char *, logical *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *, 
@@ -93,28 +79,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DERRHS tests the error exits for DGEBAK, SGEBAL, SGEHRD, DORGHR,   
-    DORMHR, DHSEQR, SHSEIN, and DTREVC.   
+/*  DERRHS tests the error exits for DGEBAK, SGEBAL, SGEHRD, DORGHR, */
+/*  DORMHR, DHSEQR, SHSEIN, and DTREVC. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
