@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dget37.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -35,22 +23,21 @@ static integer c__0 = 0;
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, m, n;
-    static doublereal s[20], t[400]	/* was [20][20] */, v, le[400]	/* 
-	    was [20][20] */, re[400]	/* was [20][20] */, wi[20], wr[20], 
-	    val[3], dum[1], eps, sep[20], sin__[20], tol, tmp[400]	/* 
-	    was [20][20] */;
-    static integer ifnd, icmp, iscl, info, lcmp[3], kmin;
-    static doublereal wiin[20], vmax, tnrm, wrin[20], work[1200], vmul, stmp[
-	    20];
+    integer i__, j, m, n;
+    doublereal s[20], t[400]	/* was [20][20] */, v, le[400]	/* was [20][
+	    20] */, re[400]	/* was [20][20] */, wi[20], wr[20], val[3], 
+	    dum[1], eps, sep[20], sin__[20], tol, tmp[400]	/* was [20][
+	    20] */;
+    integer ifnd, icmp, iscl, info, lcmp[3], kmin;
+    doublereal wiin[20], vmax, tnrm, wrin[20], work[1200], vmul, stmp[20];
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
-    static doublereal sepin[20];
+    doublereal sepin[20];
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static doublereal vimin, tolin, vrmin;
-    static integer iwork[40];
-    static doublereal witmp[20], wrtmp[20];
+    doublereal vimin, tolin, vrmin;
+    integer iwork[40];
+    doublereal witmp[20], wrtmp[20];
     extern /* Subroutine */ int dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *), dlange_(char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *);
@@ -58,8 +45,8 @@ static integer c__0 = 0;
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    integer *), dlacpy_(char *, integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *);
-    static logical select[20];
-    static doublereal bignum;
+    logical select[20];
+    doublereal bignum;
     extern /* Subroutine */ int dhseqr_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *), dtrevc_(char *, char *, logical *, integer *, 
@@ -68,7 +55,7 @@ static integer c__0 = 0;
 	    *, integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *, integer *, doublereal *, 
 	    integer *, integer *, integer *);
-    static doublereal septmp[20], smlnum;
+    doublereal septmp[20], smlnum;
 
     /* Fortran I/O blocks */
     static cilist io___5 = { 0, 0, 0, 0, 0 };
@@ -77,53 +64,70 @@ static integer c__0 = 0;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DGET37 tests DTRSNA, a routine for estimating condition numbers of   
-    eigenvalues and/or right eigenvectors of a matrix.   
+/*  DGET37 tests DTRSNA, a routine for estimating condition numbers of */
+/*  eigenvalues and/or right eigenvectors of a matrix. */
 
-    The test matrices are read from a file with logical unit number NIN.   
+/*  The test matrices are read from a file with logical unit number NIN. */
 
-    Arguments   
-    ==========   
+/*  Arguments */
+/*  ========== */
 
-    RMAX    (output) DOUBLE PRECISION array, dimension (3)   
-            Value of the largest test ratio.   
-            RMAX(1) = largest ratio comparing different calls to DTRSNA   
-            RMAX(2) = largest error in reciprocal condition   
-                      numbers taking their conditioning into account   
-            RMAX(3) = largest error in reciprocal condition   
-                      numbers not taking their conditioning into   
-                      account (may be larger than RMAX(2))   
+/*  RMAX    (output) DOUBLE PRECISION array, dimension (3) */
+/*          Value of the largest test ratio. */
+/*          RMAX(1) = largest ratio comparing different calls to DTRSNA */
+/*          RMAX(2) = largest error in reciprocal condition */
+/*                    numbers taking their conditioning into account */
+/*          RMAX(3) = largest error in reciprocal condition */
+/*                    numbers not taking their conditioning into */
+/*                    account (may be larger than RMAX(2)) */
 
-    LMAX    (output) INTEGER array, dimension (3)   
-            LMAX(i) is example number where largest test ratio   
-            RMAX(i) is achieved. Also:   
-            If DGEHRD returns INFO nonzero on example i, LMAX(1)=i   
-            If DHSEQR returns INFO nonzero on example i, LMAX(2)=i   
-            If DTRSNA returns INFO nonzero on example i, LMAX(3)=i   
+/*  LMAX    (output) INTEGER array, dimension (3) */
+/*          LMAX(i) is example number where largest test ratio */
+/*          RMAX(i) is achieved. Also: */
+/*          If DGEHRD returns INFO nonzero on example i, LMAX(1)=i */
+/*          If DHSEQR returns INFO nonzero on example i, LMAX(2)=i */
+/*          If DTRSNA returns INFO nonzero on example i, LMAX(3)=i */
 
-    NINFO   (output) INTEGER array, dimension (3)   
-            NINFO(1) = No. of times DGEHRD returned INFO nonzero   
-            NINFO(2) = No. of times DHSEQR returned INFO nonzero   
-            NINFO(3) = No. of times DTRSNA returned INFO nonzero   
+/*  NINFO   (output) INTEGER array, dimension (3) */
+/*          NINFO(1) = No. of times DGEHRD returned INFO nonzero */
+/*          NINFO(2) = No. of times DHSEQR returned INFO nonzero */
+/*          NINFO(3) = No. of times DTRSNA returned INFO nonzero */
 
-    KNT     (output) INTEGER   
-            Total number of examples tested.   
+/*  KNT     (output) INTEGER */
+/*          Total number of examples tested. */
 
-    NIN     (input) INTEGER   
-            Input logical unit number   
+/*  NIN     (input) INTEGER */
+/*          Input logical unit number */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ninfo;
     --lmax;
     --rmax;
@@ -152,9 +156,9 @@ static integer c__0 = 0;
     val[1] = 1.;
     val[2] = sqrt(bignum);
 
-/*     Read input data until N=0.  Assume input eigenvalues are sorted   
-       lexicographically (increasing by real part, then decreasing by   
-       imaginary part) */
+/*     Read input data until N=0.  Assume input eigenvalues are sorted */
+/*     lexicographically (increasing by real part, then decreasing by */
+/*     imaginary part) */
 
 L10:
     io___5.ciunit = *nin;
@@ -255,8 +259,8 @@ L10:
 	    goto L240;
 	}
 
-/*        Sort eigenvalues and condition numbers lexicographically   
-          to compare with inputs */
+/*        Sort eigenvalues and condition numbers lexicographically */
+/*        to compare with inputs */
 
 	dcopy_(&n, wr, &c__1, wrtmp, &c__1);
 	dcopy_(&n, wi, &c__1, witmp, &c__1);
@@ -291,10 +295,10 @@ L10:
 /* L80: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          taking their condition numbers into account   
+/*        Compare condition numbers for eigenvalues */
+/*        taking their condition numbers into account */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = (doublereal) n * 2. * eps * tnrm;
 	v = max(d__1,smlnum);
 	if (tnrm == 0.) {
@@ -338,8 +342,8 @@ L10:
 /* L90: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -380,8 +384,8 @@ L10:
 /* L100: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvalues */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -408,8 +412,8 @@ L10:
 /* L110: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
