@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* serrhs.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -51,21 +39,21 @@ static integer c__4 = 4;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static real a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
-    static integer i__, j, m;
-    static real s[3], w[28];
-    static char c2[2];
-    static real wi[3];
-    static integer nt;
-    static real vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */, wr[3];
-    static integer ihi, ilo;
-    static logical sel[3];
-    static real tau[3];
-    static integer info;
+    real a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
+    integer i__, j, m;
+    real s[3], w[28];
+    char c2[2];
+    real wi[3];
+    integer nt;
+    real vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */, wr[3];
+    integer ihi, ilo;
+    logical sel[3];
+    real tau[3];
+    integer info;
     extern /* Subroutine */ int sgebak_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, integer *), sgebal_(char *, integer *, real *, integer *, 
 	    integer *, integer *, real *, integer *);
-    static integer ifaill[3], ifailr[3];
+    integer ifaill[3], ifailr[3];
     extern /* Subroutine */ int sgehrd_(integer *, integer *, integer *, real 
 	    *, integer *, real *, real *, integer *, integer *);
     extern logical lsamen_(integer *, char *, char *);
@@ -75,13 +63,13 @@ static integer c__4 = 4;
 	    real *, integer *, integer *, integer *, real *, integer *, 
 	    integer *, integer *), sorghr_(integer *, 
 	    integer *, integer *, real *, integer *, real *, real *, integer *
-	    , integer *), shseqr_(char *, char *, integer *, integer *, 
+, integer *), shseqr_(char *, char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, real *, real *, integer *, 
 	    real *, integer *, integer *), strevc_(char *, 
 	    char *, logical *, integer *, real *, integer *, real *, integer *
-	    , real *, integer *, integer *, integer *, real *, integer *), sormhr_(char *, char *, integer *, integer *, 
+, real *, integer *, integer *, integer *, real *, integer *), sormhr_(char *, char *, integer *, integer *, 
 	    integer *, integer *, real *, integer *, real *, real *, integer *
-	    , real *, integer *, integer *);
+, real *, integer *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 0, 0, 0, 0 };
@@ -90,28 +78,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SERRHS tests the error exits for SGEBAK, SGEBAL, SGEHRD, SORGHR,   
-    SORMHR, SHSEQR, SHSEIN, and STREVC.   
+/*  SERRHS tests the error exits for SGEBAK, SGEBAL, SGEHRD, SORGHR, */
+/*  SORMHR, SHSEQR, SHSEIN, and STREVC. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
