@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* sget24.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -56,38 +44,38 @@ static real c_b44 = -1.f;
     double r_sign(real *, real *), sqrt(doublereal);
 
     /* Local variables */
-    static integer i__, j;
-    static real v, eps, tol, tmp, ulp;
-    static integer sdim, kmin, itmp, ipnt[20], rsub;
-    static char sort[1];
-    static integer sdim1, iinfo;
+    integer i__, j;
+    real v, eps, tol, tmp, ulp;
+    integer sdim, kmin, itmp, ipnt[20], rsub;
+    char sort[1];
+    integer sdim1, iinfo;
     extern /* Subroutine */ int sgemm_(char *, char *, integer *, integer *, 
 	    integer *, real *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *);
-    static real anorm, vimin, tolin;
+    real anorm, vimin, tolin;
     extern /* Subroutine */ int sort01_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *, real *);
-    static real vrmin;
-    static integer isort;
-    static real wnorm;
+    real vrmin;
+    integer isort;
+    real wnorm;
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *);
-    static real rcnde1, rcndv1;
+    real rcnde1, rcndv1;
     extern doublereal slamch_(char *), slange_(char *, integer *, 
 	    integer *, real *, integer *, real *);
-    static real rconde;
+    real rconde;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static integer knteig;
-    static real rcondv;
+    integer knteig;
+    real rcondv;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *);
     extern logical sslect_(real *, real *);
     extern /* Subroutine */ int sgeesx_(char *, char *, L_fp, char *, integer 
 	    *, real *, integer *, integer *, real *, real *, real *, integer *
-	    , real *, real *, real *, integer *, integer *, integer *, 
+, real *, real *, real *, integer *, integer *, integer *, 
 	    logical *, integer *);
-    static integer liwork;
-    static real smlnum, ulpinv;
+    integer liwork;
+    real smlnum, ulpinv;
 
     /* Fortran I/O blocks */
     static cilist io___13 = { 0, 0, 0, fmt_9998, 0 };
@@ -110,218 +98,241 @@ static real c_b44 = -1.f;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       SGET24 checks the nonsymmetric eigenvalue (Schur form) problem   
-       expert driver SGEESX.   
+/*     SGET24 checks the nonsymmetric eigenvalue (Schur form) problem */
+/*     expert driver SGEESX. */
 
-       If COMP = .FALSE., the first 13 of the following tests will be   
-       be performed on the input matrix A, and also tests 14 and 15   
-       if LWORK is sufficiently large.   
-       If COMP = .TRUE., all 17 test will be performed.   
+/*     If COMP = .FALSE., the first 13 of the following tests will be */
+/*     be performed on the input matrix A, and also tests 14 and 15 */
+/*     if LWORK is sufficiently large. */
+/*     If COMP = .TRUE., all 17 test will be performed. */
 
-       (1)     0 if T is in Schur form, 1/ulp otherwise   
-              (no sorting of eigenvalues)   
+/*     (1)     0 if T is in Schur form, 1/ulp otherwise */
+/*            (no sorting of eigenvalues) */
 
-       (2)     | A - VS T VS' | / ( n |A| ulp )   
+/*     (2)     | A - VS T VS' | / ( n |A| ulp ) */
 
-         Here VS is the matrix of Schur eigenvectors, and T is in Schur   
-         form  (no sorting of eigenvalues).   
+/*       Here VS is the matrix of Schur eigenvectors, and T is in Schur */
+/*       form  (no sorting of eigenvalues). */
 
-       (3)     | I - VS VS' | / ( n ulp ) (no sorting of eigenvalues).   
+/*     (3)     | I - VS VS' | / ( n ulp ) (no sorting of eigenvalues). */
 
-       (4)     0     if WR+sqrt(-1)*WI are eigenvalues of T   
-               1/ulp otherwise   
-               (no sorting of eigenvalues)   
+/*     (4)     0     if WR+sqrt(-1)*WI are eigenvalues of T */
+/*             1/ulp otherwise */
+/*             (no sorting of eigenvalues) */
 
-       (5)     0     if T(with VS) = T(without VS),   
-               1/ulp otherwise   
-               (no sorting of eigenvalues)   
+/*     (5)     0     if T(with VS) = T(without VS), */
+/*             1/ulp otherwise */
+/*             (no sorting of eigenvalues) */
 
-       (6)     0     if eigenvalues(with VS) = eigenvalues(without VS),   
-               1/ulp otherwise   
-               (no sorting of eigenvalues)   
+/*     (6)     0     if eigenvalues(with VS) = eigenvalues(without VS), */
+/*             1/ulp otherwise */
+/*             (no sorting of eigenvalues) */
 
-       (7)     0 if T is in Schur form, 1/ulp otherwise   
-               (with sorting of eigenvalues)   
+/*     (7)     0 if T is in Schur form, 1/ulp otherwise */
+/*             (with sorting of eigenvalues) */
 
-       (8)     | A - VS T VS' | / ( n |A| ulp )   
+/*     (8)     | A - VS T VS' | / ( n |A| ulp ) */
 
-         Here VS is the matrix of Schur eigenvectors, and T is in Schur   
-         form  (with sorting of eigenvalues).   
+/*       Here VS is the matrix of Schur eigenvectors, and T is in Schur */
+/*       form  (with sorting of eigenvalues). */
 
-       (9)     | I - VS VS' | / ( n ulp ) (with sorting of eigenvalues).   
+/*     (9)     | I - VS VS' | / ( n ulp ) (with sorting of eigenvalues). */
 
-       (10)    0     if WR+sqrt(-1)*WI are eigenvalues of T   
-               1/ulp otherwise   
-               If workspace sufficient, also compare WR, WI with and   
-               without reciprocal condition numbers   
-               (with sorting of eigenvalues)   
+/*     (10)    0     if WR+sqrt(-1)*WI are eigenvalues of T */
+/*             1/ulp otherwise */
+/*             If workspace sufficient, also compare WR, WI with and */
+/*             without reciprocal condition numbers */
+/*             (with sorting of eigenvalues) */
 
-       (11)    0     if T(with VS) = T(without VS),   
-               1/ulp otherwise   
-               If workspace sufficient, also compare T with and without   
-               reciprocal condition numbers   
-               (with sorting of eigenvalues)   
+/*     (11)    0     if T(with VS) = T(without VS), */
+/*             1/ulp otherwise */
+/*             If workspace sufficient, also compare T with and without */
+/*             reciprocal condition numbers */
+/*             (with sorting of eigenvalues) */
 
-       (12)    0     if eigenvalues(with VS) = eigenvalues(without VS),   
-               1/ulp otherwise   
-               If workspace sufficient, also compare VS with and without   
-               reciprocal condition numbers   
-               (with sorting of eigenvalues)   
+/*     (12)    0     if eigenvalues(with VS) = eigenvalues(without VS), */
+/*             1/ulp otherwise */
+/*             If workspace sufficient, also compare VS with and without */
+/*             reciprocal condition numbers */
+/*             (with sorting of eigenvalues) */
 
-       (13)    if sorting worked and SDIM is the number of   
-               eigenvalues which were SELECTed   
-               If workspace sufficient, also compare SDIM with and   
-               without reciprocal condition numbers   
+/*     (13)    if sorting worked and SDIM is the number of */
+/*             eigenvalues which were SELECTed */
+/*             If workspace sufficient, also compare SDIM with and */
+/*             without reciprocal condition numbers */
 
-       (14)    if RCONDE the same no matter if VS and/or RCONDV computed   
+/*     (14)    if RCONDE the same no matter if VS and/or RCONDV computed */
 
-       (15)    if RCONDV the same no matter if VS and/or RCONDE computed   
+/*     (15)    if RCONDV the same no matter if VS and/or RCONDE computed */
 
-       (16)  |RCONDE - RCDEIN| / cond(RCONDE)   
+/*     (16)  |RCONDE - RCDEIN| / cond(RCONDE) */
 
-          RCONDE is the reciprocal average eigenvalue condition number   
-          computed by SGEESX and RCDEIN (the precomputed true value)   
-          is supplied as input.  cond(RCONDE) is the condition number   
-          of RCONDE, and takes errors in computing RCONDE into account,   
-          so that the resulting quantity should be O(ULP). cond(RCONDE)   
-          is essentially given by norm(A)/RCONDV.   
+/*        RCONDE is the reciprocal average eigenvalue condition number */
+/*        computed by SGEESX and RCDEIN (the precomputed true value) */
+/*        is supplied as input.  cond(RCONDE) is the condition number */
+/*        of RCONDE, and takes errors in computing RCONDE into account, */
+/*        so that the resulting quantity should be O(ULP). cond(RCONDE) */
+/*        is essentially given by norm(A)/RCONDV. */
 
-       (17)  |RCONDV - RCDVIN| / cond(RCONDV)   
+/*     (17)  |RCONDV - RCDVIN| / cond(RCONDV) */
 
-          RCONDV is the reciprocal right invariant subspace condition   
-          number computed by SGEESX and RCDVIN (the precomputed true   
-          value) is supplied as input. cond(RCONDV) is the condition   
-          number of RCONDV, and takes errors in computing RCONDV into   
-          account, so that the resulting quantity should be O(ULP).   
-          cond(RCONDV) is essentially given by norm(A)/RCONDE.   
+/*        RCONDV is the reciprocal right invariant subspace condition */
+/*        number computed by SGEESX and RCDVIN (the precomputed true */
+/*        value) is supplied as input. cond(RCONDV) is the condition */
+/*        number of RCONDV, and takes errors in computing RCONDV into */
+/*        account, so that the resulting quantity should be O(ULP). */
+/*        cond(RCONDV) is essentially given by norm(A)/RCONDE. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    COMP    (input) LOGICAL   
-            COMP describes which input tests to perform:   
-              = .FALSE. if the computed condition numbers are not to   
-                        be tested against RCDVIN and RCDEIN   
-              = .TRUE.  if they are to be compared   
+/*  COMP    (input) LOGICAL */
+/*          COMP describes which input tests to perform: */
+/*            = .FALSE. if the computed condition numbers are not to */
+/*                      be tested against RCDVIN and RCDEIN */
+/*            = .TRUE.  if they are to be compared */
 
-    JTYPE   (input) INTEGER   
-            Type of input matrix. Used to label output if error occurs.   
+/*  JTYPE   (input) INTEGER */
+/*          Type of input matrix. Used to label output if error occurs. */
 
-    ISEED   (input) INTEGER array, dimension (4)   
-            If COMP = .FALSE., the random number generator seed   
-            used to produce matrix.   
-            If COMP = .TRUE., ISEED(1) = the number of the example.   
-            Used to label output if error occurs.   
+/*  ISEED   (input) INTEGER array, dimension (4) */
+/*          If COMP = .FALSE., the random number generator seed */
+/*          used to produce matrix. */
+/*          If COMP = .TRUE., ISEED(1) = the number of the example. */
+/*          Used to label output if error occurs. */
 
-    THRESH  (input) REAL   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
+/*  THRESH  (input) REAL */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
 
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns INFO not equal to 0.)   
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns INFO not equal to 0.) */
 
-    N       (input) INTEGER   
-            The dimension of A. N must be at least 0.   
+/*  N       (input) INTEGER */
+/*          The dimension of A. N must be at least 0. */
 
-    A       (input/output) REAL array, dimension (LDA, N)   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.   
+/*  A       (input/output) REAL array, dimension (LDA, N) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed. */
 
-    LDA     (input) INTEGER   
-            The leading dimension of A, and H. LDA must be at   
-            least 1 and at least N.   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, and H. LDA must be at */
+/*          least 1 and at least N. */
 
-    H       (workspace) REAL array, dimension (LDA, N)   
-            Another copy of the test matrix A, modified by SGEESX.   
+/*  H       (workspace) REAL array, dimension (LDA, N) */
+/*          Another copy of the test matrix A, modified by SGEESX. */
 
-    HT      (workspace) REAL array, dimension (LDA, N)   
-            Yet another copy of the test matrix A, modified by SGEESX.   
+/*  HT      (workspace) REAL array, dimension (LDA, N) */
+/*          Yet another copy of the test matrix A, modified by SGEESX. */
 
-    WR      (workspace) REAL array, dimension (N)   
-    WI      (workspace) REAL array, dimension (N)   
-            The real and imaginary parts of the eigenvalues of A.   
-            On exit, WR + WI*i are the eigenvalues of the matrix in A.   
+/*  WR      (workspace) REAL array, dimension (N) */
+/*  WI      (workspace) REAL array, dimension (N) */
+/*          The real and imaginary parts of the eigenvalues of A. */
+/*          On exit, WR + WI*i are the eigenvalues of the matrix in A. */
 
-    WRT     (workspace) REAL array, dimension (N)   
-    WIT     (workspace) REAL array, dimension (N)   
-            Like WR, WI, these arrays contain the eigenvalues of A,   
-            but those computed when SGEESX only computes a partial   
-            eigendecomposition, i.e. not Schur vectors   
+/*  WRT     (workspace) REAL array, dimension (N) */
+/*  WIT     (workspace) REAL array, dimension (N) */
+/*          Like WR, WI, these arrays contain the eigenvalues of A, */
+/*          but those computed when SGEESX only computes a partial */
+/*          eigendecomposition, i.e. not Schur vectors */
 
-    WRTMP   (workspace) REAL array, dimension (N)   
-    WITMP   (workspace) REAL array, dimension (N)   
-            Like WR, WI, these arrays contain the eigenvalues of A,   
-            but sorted by increasing real part.   
+/*  WRTMP   (workspace) REAL array, dimension (N) */
+/*  WITMP   (workspace) REAL array, dimension (N) */
+/*          Like WR, WI, these arrays contain the eigenvalues of A, */
+/*          but sorted by increasing real part. */
 
-    VS      (workspace) REAL array, dimension (LDVS, N)   
-            VS holds the computed Schur vectors.   
+/*  VS      (workspace) REAL array, dimension (LDVS, N) */
+/*          VS holds the computed Schur vectors. */
 
-    LDVS    (input) INTEGER   
-            Leading dimension of VS. Must be at least max(1, N).   
+/*  LDVS    (input) INTEGER */
+/*          Leading dimension of VS. Must be at least max(1, N). */
 
-    VS1     (workspace) REAL array, dimension (LDVS, N)   
-            VS1 holds another copy of the computed Schur vectors.   
+/*  VS1     (workspace) REAL array, dimension (LDVS, N) */
+/*          VS1 holds another copy of the computed Schur vectors. */
 
-    RCDEIN  (input) REAL   
-            When COMP = .TRUE. RCDEIN holds the precomputed reciprocal   
-            condition number for the average of selected eigenvalues.   
+/*  RCDEIN  (input) REAL */
+/*          When COMP = .TRUE. RCDEIN holds the precomputed reciprocal */
+/*          condition number for the average of selected eigenvalues. */
 
-    RCDVIN  (input) REAL   
-            When COMP = .TRUE. RCDVIN holds the precomputed reciprocal   
-            condition number for the selected right invariant subspace.   
+/*  RCDVIN  (input) REAL */
+/*          When COMP = .TRUE. RCDVIN holds the precomputed reciprocal */
+/*          condition number for the selected right invariant subspace. */
 
-    NSLCT   (input) INTEGER   
-            When COMP = .TRUE. the number of selected eigenvalues   
-            corresponding to the precomputed values RCDEIN and RCDVIN.   
+/*  NSLCT   (input) INTEGER */
+/*          When COMP = .TRUE. the number of selected eigenvalues */
+/*          corresponding to the precomputed values RCDEIN and RCDVIN. */
 
-    ISLCT   (input) INTEGER array, dimension (NSLCT)   
-            When COMP = .TRUE. ISLCT selects the eigenvalues of the   
-            input matrix corresponding to the precomputed values RCDEIN   
-            and RCDVIN. For I=1, ... ,NSLCT, if ISLCT(I) = J, then the   
-            eigenvalue with the J-th largest real part is selected.   
-            Not referenced if COMP = .FALSE.   
+/*  ISLCT   (input) INTEGER array, dimension (NSLCT) */
+/*          When COMP = .TRUE. ISLCT selects the eigenvalues of the */
+/*          input matrix corresponding to the precomputed values RCDEIN */
+/*          and RCDVIN. For I=1, ... ,NSLCT, if ISLCT(I) = J, then the */
+/*          eigenvalue with the J-th largest real part is selected. */
+/*          Not referenced if COMP = .FALSE. */
 
-    RESULT  (output) REAL array, dimension (17)   
-            The values computed by the 17 tests described above.   
-            The values are currently limited to 1/ulp, to avoid   
-            overflow.   
+/*  RESULT  (output) REAL array, dimension (17) */
+/*          The values computed by the 17 tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid */
+/*          overflow. */
 
-    WORK    (workspace) REAL array, dimension (LWORK)   
+/*  WORK    (workspace) REAL array, dimension (LWORK) */
 
-    LWORK   (input) INTEGER   
-            The number of entries in WORK to be passed to SGEESX. This   
-            must be at least 3*N, and N+N**2 if tests 14--16 are to   
-            be performed.   
+/*  LWORK   (input) INTEGER */
+/*          The number of entries in WORK to be passed to SGEESX. This */
+/*          must be at least 3*N, and N+N**2 if tests 14--16 are to */
+/*          be performed. */
 
-    IWORK   (workspace) INTEGER array, dimension (N*N)   
+/*  IWORK   (workspace) INTEGER array, dimension (N*N) */
 
-    BWORK   (workspace) LOGICAL array, dimension (N)   
+/*  BWORK   (workspace) LOGICAL array, dimension (N) */
 
-    INFO    (output) INTEGER   
-            If 0,  successful exit.   
-            If <0, input parameter -INFO had an incorrect value.   
-            If >0, SGEESX returned an error code, the absolute   
-                   value of which is returned.   
+/*  INFO    (output) INTEGER */
+/*          If 0,  successful exit. */
+/*          If <0, input parameter -INFO had an incorrect value. */
+/*          If >0, SGEESX returned an error code, the absolute */
+/*                 value of which is returned. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. Arrays in Common .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors   
+/*     Check for errors */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --iseed;
     ht_dim1 = *lda;
     ht_offset = 1 + ht_dim1;
@@ -471,9 +482,9 @@ static real c_b44 = -1.f;
 /* L50: */
 	}
 
-/*        Test (2) or (8): Compute norm(A - Q*H*Q') / (norm(A) * N * ULP)   
+/*        Test (2) or (8): Compute norm(A - Q*H*Q') / (norm(A) * N * ULP) */
 
-          Copy A to VS1, used as workspace */
+/*        Copy A to VS1, used as workspace */
 
 	slacpy_(" ", n, n, &a[a_offset], lda, &vs1[vs1_offset], ldvs);
 
@@ -535,14 +546,14 @@ static real c_b44 = -1.f;
 		tmp = sqrt((r__1 = h__[i__ + 1 + i__ * h_dim1], dabs(r__1))) *
 			 sqrt((r__2 = h__[i__ + (i__ + 1) * h_dim1], dabs(
 			r__2)));
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 		r__4 = ulp * tmp;
 		r__2 = result[rsub + 4], r__3 = (r__1 = wi[i__] - tmp, dabs(
 			r__1)) / dmax(r__4,smlnum);
 		result[rsub + 4] = dmax(r__2,r__3);
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 		r__4 = ulp * tmp;
 		r__2 = result[rsub + 4], r__3 = (r__1 = wi[i__ + 1] + tmp, 
 			dabs(r__1)) / dmax(r__4,smlnum);
@@ -624,7 +635,9 @@ static real c_b44 = -1.f;
 		if (i__ < *n) {
 		    r__1 = -wi[i__ + 1];
 		    r__2 = -wi[i__];
-		    if ((sslect_(&wr[i__ + 1], &wi[i__ + 1]) || sslect_(&wr[ 			    i__ + 1], &r__1)) && ! (sslect_(&wr[i__], &wi[i__] 			    ) || sslect_(&wr[i__], &r__2)) && iinfo != *n + 2)
+		    if ((sslect_(&wr[i__ + 1], &wi[i__ + 1]) || sslect_(&wr[
+			    i__ + 1], &r__1)) && ! (sslect_(&wr[i__], &wi[i__]
+) || sslect_(&wr[i__], &r__2)) && iinfo != *n + 2)
 			     {
 			result[13] = ulpinv;
 		    }
@@ -639,8 +652,8 @@ static real c_b44 = -1.f;
 /* L120: */
     }
 
-/*     If there is enough workspace, perform tests (14) and (15)   
-       as well as (10) through (13) */
+/*     If there is enough workspace, perform tests (14) and (15) */
+/*     as well as (10) through (13) */
 
     if (*lwork >= *n + *n * *n / 2) {
 
@@ -650,7 +663,7 @@ static real c_b44 = -1.f;
 	result[14] = 0.f;
 	result[15] = 0.f;
 	slacpy_("F", n, n, &a[a_offset], lda, &ht[ht_offset], lda);
-	sgeesx_("V", sort, (L_fp)sslect_, "B", n, &ht[ht_offset], lda, &sdim1,
+	sgeesx_("V", sort, (L_fp)sslect_, "B", n, &ht[ht_offset], lda, &sdim1, 
 		 &wrt[1], &wit[1], &vs1[vs1_offset], ldvs, &rconde, &rcondv, &
 		work[1], lwork, &iwork[1], &liwork, &bwork[1], &iinfo);
 	if (iinfo != 0 && iinfo != *n + 2) {
@@ -704,7 +717,7 @@ static real c_b44 = -1.f;
 /*        Compute both RCONDE and RCONDV without VS, and compare */
 
 	slacpy_("F", n, n, &a[a_offset], lda, &ht[ht_offset], lda);
-	sgeesx_("N", sort, (L_fp)sslect_, "B", n, &ht[ht_offset], lda, &sdim1,
+	sgeesx_("N", sort, (L_fp)sslect_, "B", n, &ht[ht_offset], lda, &sdim1, 
 		 &wrt[1], &wit[1], &vs1[vs1_offset], ldvs, &rcnde1, &rcndv1, &
 		work[1], lwork, &iwork[1], &liwork, &bwork[1], &iinfo);
 	if (iinfo != 0 && iinfo != *n + 2) {
@@ -767,7 +780,7 @@ static real c_b44 = -1.f;
 /*        Compute RCONDE with VS, and compare */
 
 	slacpy_("F", n, n, &a[a_offset], lda, &ht[ht_offset], lda);
-	sgeesx_("V", sort, (L_fp)sslect_, "E", n, &ht[ht_offset], lda, &sdim1,
+	sgeesx_("V", sort, (L_fp)sslect_, "E", n, &ht[ht_offset], lda, &sdim1, 
 		 &wrt[1], &wit[1], &vs1[vs1_offset], ldvs, &rcnde1, &rcndv1, &
 		work[1], lwork, &iwork[1], &liwork, &bwork[1], &iinfo);
 	if (iinfo != 0 && iinfo != *n + 2) {
@@ -826,7 +839,7 @@ static real c_b44 = -1.f;
 /*        Compute RCONDE without VS, and compare */
 
 	slacpy_("F", n, n, &a[a_offset], lda, &ht[ht_offset], lda);
-	sgeesx_("N", sort, (L_fp)sslect_, "E", n, &ht[ht_offset], lda, &sdim1,
+	sgeesx_("N", sort, (L_fp)sslect_, "E", n, &ht[ht_offset], lda, &sdim1, 
 		 &wrt[1], &wit[1], &vs1[vs1_offset], ldvs, &rcnde1, &rcndv1, &
 		work[1], lwork, &iwork[1], &liwork, &bwork[1], &iinfo);
 	if (iinfo != 0 && iinfo != *n + 2) {
@@ -885,7 +898,7 @@ static real c_b44 = -1.f;
 /*        Compute RCONDV with VS, and compare */
 
 	slacpy_("F", n, n, &a[a_offset], lda, &ht[ht_offset], lda);
-	sgeesx_("V", sort, (L_fp)sslect_, "V", n, &ht[ht_offset], lda, &sdim1,
+	sgeesx_("V", sort, (L_fp)sslect_, "V", n, &ht[ht_offset], lda, &sdim1, 
 		 &wrt[1], &wit[1], &vs1[vs1_offset], ldvs, &rcnde1, &rcndv1, &
 		work[1], lwork, &iwork[1], &liwork, &bwork[1], &iinfo);
 	if (iinfo != 0 && iinfo != *n + 2) {
@@ -944,7 +957,7 @@ static real c_b44 = -1.f;
 /*        Compute RCONDV without VS, and compare */
 
 	slacpy_("F", n, n, &a[a_offset], lda, &ht[ht_offset], lda);
-	sgeesx_("N", sort, (L_fp)sslect_, "V", n, &ht[ht_offset], lda, &sdim1,
+	sgeesx_("N", sort, (L_fp)sslect_, "V", n, &ht[ht_offset], lda, &sdim1, 
 		 &wrt[1], &wit[1], &vs1[vs1_offset], ldvs, &rcnde1, &rcndv1, &
 		work[1], lwork, &iwork[1], &liwork, &bwork[1], &iinfo);
 	if (iinfo != 0 && iinfo != *n + 2) {
@@ -1004,14 +1017,14 @@ static real c_b44 = -1.f;
 
 L250:
 
-/*     If there are precomputed reciprocal condition numbers, compare   
-       computed values with them. */
+/*     If there are precomputed reciprocal condition numbers, compare */
+/*     computed values with them. */
 
     if (*comp) {
 
-/*        First set up SELOPT, SELDIM, SELVAL, SELWR, and SELWI so that   
-          the logical function SSLECT selects the eigenvalues specified   
-          by NSLCT and ISLCT. */
+/*        First set up SELOPT, SELDIM, SELVAL, SELWR, and SELWI so that */
+/*        the logical function SSLECT selects the eigenvalues specified */
+/*        by NSLCT and ISLCT. */
 
 	sslct_1.seldim = *n;
 	sslct_1.selopt = 1;
@@ -1073,8 +1086,8 @@ L250:
 	    goto L300;
 	}
 
-/*        Compare condition number for average of selected eigenvalues   
-          taking its condition number into account */
+/*        Compare condition number for average of selected eigenvalues */
+/*        taking its condition number into account */
 
 	anorm = slange_("1", n, n, &a[a_offset], lda, &work[1]);
 /* Computing MAX */
@@ -1111,8 +1124,8 @@ L250:
 	    result[16] = 1.f;
 	}
 
-/*        Compare condition numbers for right invariant subspace   
-          taking its condition number into account */
+/*        Compare condition numbers for right invariant subspace */
+/*        taking its condition number into account */
 
 	if (v > rcondv * rconde) {
 	    tol = rcondv;
