@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* sget37.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -35,39 +23,38 @@ static integer c__0 = 0;
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, m, n;
-    static real s[20], t[400]	/* was [20][20] */, v, le[400]	/* was [20][
-	    20] */, re[400]	/* was [20][20] */, wi[20], wr[20], val[3], 
-	    dum[1], eps, sep[20], sin__[20], tol, tmp[400]	/* was [20][
-	    20] */;
-    static integer ifnd, icmp, iscl, info, lcmp[3], kmin;
-    static real wiin[20], vmax, tnrm, wrin[20], work[1200], vmul, stmp[20];
+    integer i__, j, m, n;
+    real s[20], t[400]	/* was [20][20] */, v, le[400]	/* was [20][20] */, 
+	    re[400]	/* was [20][20] */, wi[20], wr[20], val[3], dum[1], 
+	    eps, sep[20], sin__[20], tol, tmp[400]	/* was [20][20] */;
+    integer ifnd, icmp, iscl, info, lcmp[3], kmin;
+    real wiin[20], vmax, tnrm, wrin[20], work[1200], vmul, stmp[20];
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static real sepin[20], vimin, tolin, vrmin;
-    static integer iwork[40];
+    real sepin[20], vimin, tolin, vrmin;
+    integer iwork[40];
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *);
-    static real witmp[20], wrtmp[20];
+    real witmp[20], wrtmp[20];
     extern /* Subroutine */ int slabad_(real *, real *);
     extern doublereal slamch_(char *), slange_(char *, integer *, 
 	    integer *, real *, integer *, real *);
     extern /* Subroutine */ int sgehrd_(integer *, integer *, integer *, real 
 	    *, integer *, real *, real *, integer *, integer *);
-    static logical select[20];
-    static real bignum;
+    logical select[20];
+    real bignum;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), shseqr_(char *, char *, 
 	    integer *, integer *, integer *, real *, integer *, real *, real *
-	    , real *, integer *, real *, integer *, integer *)
-	    , strevc_(char *, char *, logical *, integer *, real *, integer *,
+, real *, integer *, real *, integer *, integer *)
+	    , strevc_(char *, char *, logical *, integer *, real *, integer *, 
 	     real *, integer *, real *, integer *, integer *, integer *, real 
 	    *, integer *);
-    static real septmp[20];
+    real septmp[20];
     extern /* Subroutine */ int strsna_(char *, char *, logical *, integer *, 
 	    real *, integer *, real *, integer *, real *, integer *, real *, 
 	    real *, integer *, integer *, real *, integer *, integer *, 
 	    integer *);
-    static real smlnum;
+    real smlnum;
 
     /* Fortran I/O blocks */
     static cilist io___5 = { 0, 0, 0, 0, 0 };
@@ -76,53 +63,70 @@ static integer c__0 = 0;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SGET37 tests STRSNA, a routine for estimating condition numbers of   
-    eigenvalues and/or right eigenvectors of a matrix.   
+/*  SGET37 tests STRSNA, a routine for estimating condition numbers of */
+/*  eigenvalues and/or right eigenvectors of a matrix. */
 
-    The test matrices are read from a file with logical unit number NIN.   
+/*  The test matrices are read from a file with logical unit number NIN. */
 
-    Arguments   
-    ==========   
+/*  Arguments */
+/*  ========== */
 
-    RMAX    (output) REAL array, dimension (3)   
-            Value of the largest test ratio.   
-            RMAX(1) = largest ratio comparing different calls to STRSNA   
-            RMAX(2) = largest error in reciprocal condition   
-                      numbers taking their conditioning into account   
-            RMAX(3) = largest error in reciprocal condition   
-                      numbers not taking their conditioning into   
-                      account (may be larger than RMAX(2))   
+/*  RMAX    (output) REAL array, dimension (3) */
+/*          Value of the largest test ratio. */
+/*          RMAX(1) = largest ratio comparing different calls to STRSNA */
+/*          RMAX(2) = largest error in reciprocal condition */
+/*                    numbers taking their conditioning into account */
+/*          RMAX(3) = largest error in reciprocal condition */
+/*                    numbers not taking their conditioning into */
+/*                    account (may be larger than RMAX(2)) */
 
-    LMAX    (output) INTEGER array, dimension (3)   
-            LMAX(i) is example number where largest test ratio   
-            RMAX(i) is achieved. Also:   
-            If SGEHRD returns INFO nonzero on example i, LMAX(1)=i   
-            If SHSEQR returns INFO nonzero on example i, LMAX(2)=i   
-            If STRSNA returns INFO nonzero on example i, LMAX(3)=i   
+/*  LMAX    (output) INTEGER array, dimension (3) */
+/*          LMAX(i) is example number where largest test ratio */
+/*          RMAX(i) is achieved. Also: */
+/*          If SGEHRD returns INFO nonzero on example i, LMAX(1)=i */
+/*          If SHSEQR returns INFO nonzero on example i, LMAX(2)=i */
+/*          If STRSNA returns INFO nonzero on example i, LMAX(3)=i */
 
-    NINFO   (output) INTEGER array, dimension (3)   
-            NINFO(1) = No. of times SGEHRD returned INFO nonzero   
-            NINFO(2) = No. of times SHSEQR returned INFO nonzero   
-            NINFO(3) = No. of times STRSNA returned INFO nonzero   
+/*  NINFO   (output) INTEGER array, dimension (3) */
+/*          NINFO(1) = No. of times SGEHRD returned INFO nonzero */
+/*          NINFO(2) = No. of times SHSEQR returned INFO nonzero */
+/*          NINFO(3) = No. of times STRSNA returned INFO nonzero */
 
-    KNT     (output) INTEGER   
-            Total number of examples tested.   
+/*  KNT     (output) INTEGER */
+/*          Total number of examples tested. */
 
-    NIN     (input) INTEGER   
-            Input logical unit number   
+/*  NIN     (input) INTEGER */
+/*          Input logical unit number */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ninfo;
     --lmax;
     --rmax;
@@ -151,9 +155,9 @@ static integer c__0 = 0;
     val[1] = 1.f;
     val[2] = sqrt(bignum);
 
-/*     Read input data until N=0.  Assume input eigenvalues are sorted   
-       lexicographically (increasing by real part, then decreasing by   
-       imaginary part) */
+/*     Read input data until N=0.  Assume input eigenvalues are sorted */
+/*     lexicographically (increasing by real part, then decreasing by */
+/*     imaginary part) */
 
 L10:
     io___5.ciunit = *nin;
@@ -250,8 +254,8 @@ L10:
 	    goto L240;
 	}
 
-/*        Sort eigenvalues and condition numbers lexicographically   
-          to compare with inputs */
+/*        Sort eigenvalues and condition numbers lexicographically */
+/*        to compare with inputs */
 
 	scopy_(&n, wr, &c__1, wrtmp, &c__1);
 	scopy_(&n, wi, &c__1, witmp, &c__1);
@@ -286,10 +290,10 @@ L10:
 /* L80: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          taking their condition numbers into account   
+/*        Compare condition numbers for eigenvalues */
+/*        taking their condition numbers into account */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = (real) n * 2.f * eps * tnrm;
 	v = dmax(r__1,smlnum);
 	if (tnrm == 0.f) {
@@ -333,8 +337,8 @@ L10:
 /* L90: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -375,8 +379,8 @@ L10:
 /* L100: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvalues */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -403,8 +407,8 @@ L10:
 /* L110: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
