@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* slahd2.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -227,9 +215,9 @@ static integer c__2 = 2;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static integer j;
-    static char c2[2];
-    static logical sord, corz;
+    integer j;
+    char c2[2];
+    logical sord, corz;
     extern logical lsame_(char *, char *), lsamen_(integer *, 
 	    char *, char *);
 
@@ -287,38 +275,45 @@ static integer c__2 = 2;
 
 
 
-/*  -- LAPACK auxiliary test routine (version 2.0) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK auxiliary test routine (version 2.0) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SLAHD2 prints header information for the different test paths.   
+/*  SLAHD2 prints header information for the different test paths. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    IOUNIT  (input) INTEGER.   
-            On entry, IOUNIT specifies the unit number to which the   
-            header information should be printed.   
+/*  IOUNIT  (input) INTEGER. */
+/*          On entry, IOUNIT specifies the unit number to which the */
+/*          header information should be printed. */
 
-    PATH    (input) CHARACTER*3.   
-            On entry, PATH contains the name of the path for which the   
-            header information is to be printed.  Current paths are   
+/*  PATH    (input) CHARACTER*3. */
+/*          On entry, PATH contains the name of the path for which the */
+/*          header information is to be printed.  Current paths are */
 
-               SHS, CHS:  Non-symmetric eigenproblem.   
-               SST, CST:  Symmetric eigenproblem.   
-               SSG, CSG:  Symmetric Generalized eigenproblem.   
-               SBD, CBD:  Singular Value Decomposition (SVD)   
-               SBB, CBB:  General Banded reduction to bidiagonal form   
+/*             SHS, CHS:  Non-symmetric eigenproblem. */
+/*             SST, CST:  Symmetric eigenproblem. */
+/*             SSG, CSG:  Symmetric Generalized eigenproblem. */
+/*             SBD, CBD:  Singular Value Decomposition (SVD) */
+/*             SBB, CBB:  General Banded reduction to bidiagonal form */
 
-            These paths also are supplied in double precision (replace   
-            leading S by D and leading C by Z in path names).   
+/*          These paths also are supplied in double precision (replace */
+/*          leading S by D and leading C by Z in path names). */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     if (*iounit <= 0) {
 	return 0;
@@ -650,22 +645,22 @@ static integer c__2 = 2;
 
 
 
-/*     Symmetric/Hermitian eigenproblem   
+/*     Symmetric/Hermitian eigenproblem */
 
 
 
-       Symmetric/Hermitian Generalized eigenproblem   
+/*     Symmetric/Hermitian Generalized eigenproblem */
 
 
 
-       Singular Value Decomposition   
+/*     Singular Value Decomposition */
 
 
 
-       Band reduction to bidiagonal form   
+/*     Band reduction to bidiagonal form */
 
 
 
-       End of SLAHD2 */
+/*     End of SLAHD2 */
 
 } /* slahd2_ */
