@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zdrges.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -29,7 +17,7 @@ static integer c__0 = 0;
 	doublecomplex *a, integer *lda, doublecomplex *b, doublecomplex *s, 
 	doublecomplex *t, doublecomplex *q, integer *ldq, doublecomplex *z__, 
 	doublecomplex *alpha, doublecomplex *beta, doublecomplex *work, 
-	integer *lwork, doublereal *rwork, doublereal *result, logical *bwork,
+	integer *lwork, doublereal *rwork, doublereal *result, logical *bwork, 
 	 integer *info)
 {
     /* Initialized data */
@@ -127,42 +115,42 @@ static integer c__0 = 0;
     double d_imag(doublecomplex *);
 
     /* Local variables */
-    static integer i__, j, n, n1, jc, nb, in, jr;
-    static doublereal ulp;
-    static integer iadd, sdim, nmax, rsub;
-    static char sort[1];
-    static doublereal temp1, temp2;
-    static logical badnn;
-    static integer iinfo;
-    static doublereal rmagn[4];
-    static doublecomplex ctemp;
-    extern /* Subroutine */ int zget51_(integer *, integer *, doublecomplex *,
+    integer i__, j, n, n1, jc, nb, in, jr;
+    doublereal ulp;
+    integer iadd, sdim, nmax, rsub;
+    char sort[1];
+    doublereal temp1, temp2;
+    logical badnn;
+    integer iinfo;
+    doublereal rmagn[4];
+    doublecomplex ctemp;
+    extern /* Subroutine */ int zget51_(integer *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, integer *, doublecomplex *, integer *
-	    , doublecomplex *, integer *, doublecomplex *, doublereal *, 
+, doublecomplex *, integer *, doublecomplex *, doublereal *, 
 	    doublereal *), zgges_(char *, char *, char *, L_fp, integer *, 
-	    doublecomplex *, integer *, doublecomplex *, integer *, integer *,
+	    doublecomplex *, integer *, doublecomplex *, integer *, integer *, 
 	     doublecomplex *, doublecomplex *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, logical *, integer *);
-    static integer nmats, jsize;
-    extern /* Subroutine */ int zget54_(integer *, doublecomplex *, integer *,
+    integer nmats, jsize;
+    extern /* Subroutine */ int zget54_(integer *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublereal *);
-    static integer nerrs, jtype, ntest, isort;
+    integer nerrs, jtype, ntest, isort;
     extern /* Subroutine */ int dlabad_(doublereal *, doublereal *), zlatm4_(
 	    integer *, integer *, integer *, integer *, logical *, doublereal 
 	    *, doublereal *, doublereal *, integer *, integer *, 
 	    doublecomplex *, integer *);
-    static logical ilabad;
+    logical ilabad;
     extern doublereal dlamch_(char *);
     extern /* Subroutine */ int zunm2r_(char *, char *, integer *, integer *, 
 	    integer *, doublecomplex *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
-    static doublereal safmin, safmax;
-    static integer knteig, ioldsd[4];
+    doublereal safmin, safmax;
+    integer knteig, ioldsd[4];
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *), xerbla_(char *, integer *), 
 	    zlarfg_(integer *, doublecomplex *, doublecomplex *, integer *, 
@@ -174,9 +162,9 @@ static integer c__0 = 0;
 	    zlaset_(char *, integer *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, integer *);
     extern logical zlctes_(doublecomplex *, doublecomplex *);
-    static integer minwrk, maxwrk;
-    static doublereal ulpinv;
-    static integer mtypes, ntestt;
+    integer minwrk, maxwrk;
+    doublereal ulpinv;
+    integer mtypes, ntestt;
 
     /* Fortran I/O blocks */
     static cilist io___41 = { 0, 0, 0, fmt_9999, 0 };
@@ -192,278 +180,299 @@ static integer c__0 = 0;
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       February 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     February 2007 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZDRGES checks the nonsymmetric generalized eigenvalue (Schur form)   
-    problem driver ZGGES.   
+/*  ZDRGES checks the nonsymmetric generalized eigenvalue (Schur form) */
+/*  problem driver ZGGES. */
 
-    ZGGES factors A and B as Q*S*Z'  and Q*T*Z' , where ' means conjugate   
-    transpose, S and T are  upper triangular (i.e., in generalized Schur   
-    form), and Q and Z are unitary. It also computes the generalized   
-    eigenvalues (alpha(j),beta(j)), j=1,...,n.  Thus,   
-    w(j) = alpha(j)/beta(j) is a root of the characteristic equation   
+/*  ZGGES factors A and B as Q*S*Z'  and Q*T*Z' , where ' means conjugate */
+/*  transpose, S and T are  upper triangular (i.e., in generalized Schur */
+/*  form), and Q and Z are unitary. It also computes the generalized */
+/*  eigenvalues (alpha(j),beta(j)), j=1,...,n.  Thus, */
+/*  w(j) = alpha(j)/beta(j) is a root of the characteristic equation */
 
-                    det( A - w(j) B ) = 0   
+/*                  det( A - w(j) B ) = 0 */
 
-    Optionally it also reorder the eigenvalues so that a selected   
-    cluster of eigenvalues appears in the leading diagonal block of the   
-    Schur forms.   
+/*  Optionally it also reorder the eigenvalues so that a selected */
+/*  cluster of eigenvalues appears in the leading diagonal block of the */
+/*  Schur forms. */
 
-    When ZDRGES is called, a number of matrix "sizes" ("N's") and a   
-    number of matrix "TYPES" are specified.  For each size ("N")   
-    and each TYPE of matrix, a pair of matrices (A, B) will be generated   
-    and used for testing. For each matrix pair, the following 13 tests   
-    will be performed and compared with the threshhold THRESH except   
-    the tests (5), (11) and (13).   
+/*  When ZDRGES is called, a number of matrix "sizes" ("N's") and a */
+/*  number of matrix "TYPES" are specified.  For each size ("N") */
+/*  and each TYPE of matrix, a pair of matrices (A, B) will be generated */
+/*  and used for testing. For each matrix pair, the following 13 tests */
+/*  will be performed and compared with the threshhold THRESH except */
+/*  the tests (5), (11) and (13). */
 
 
-    (1)   | A - Q S Z' | / ( |A| n ulp ) (no sorting of eigenvalues)   
+/*  (1)   | A - Q S Z' | / ( |A| n ulp ) (no sorting of eigenvalues) */
 
 
-    (2)   | B - Q T Z' | / ( |B| n ulp ) (no sorting of eigenvalues)   
+/*  (2)   | B - Q T Z' | / ( |B| n ulp ) (no sorting of eigenvalues) */
 
 
-    (3)   | I - QQ' | / ( n ulp ) (no sorting of eigenvalues)   
+/*  (3)   | I - QQ' | / ( n ulp ) (no sorting of eigenvalues) */
 
 
-    (4)   | I - ZZ' | / ( n ulp ) (no sorting of eigenvalues)   
+/*  (4)   | I - ZZ' | / ( n ulp ) (no sorting of eigenvalues) */
 
-    (5)   if A is in Schur form (i.e. triangular form) (no sorting of   
-          eigenvalues)   
+/*  (5)   if A is in Schur form (i.e. triangular form) (no sorting of */
+/*        eigenvalues) */
 
-    (6)   if eigenvalues = diagonal elements of the Schur form (S, T),   
-          i.e., test the maximum over j of D(j)  where:   
+/*  (6)   if eigenvalues = diagonal elements of the Schur form (S, T), */
+/*        i.e., test the maximum over j of D(j)  where: */
 
-                        |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|   
-              D(j) = ------------------------ + -----------------------   
-                     max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)   
+/*                      |alpha(j) - S(j,j)|        |beta(j) - T(j,j)| */
+/*            D(j) = ------------------------ + ----------------------- */
+/*                   max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|) */
 
-          (no sorting of eigenvalues)   
+/*        (no sorting of eigenvalues) */
 
-    (7)   | (A,B) - Q (S,T) Z' | / ( |(A,B)| n ulp )   
-          (with sorting of eigenvalues).   
+/*  (7)   | (A,B) - Q (S,T) Z' | / ( |(A,B)| n ulp ) */
+/*        (with sorting of eigenvalues). */
 
-    (8)   | I - QQ' | / ( n ulp ) (with sorting of eigenvalues).   
+/*  (8)   | I - QQ' | / ( n ulp ) (with sorting of eigenvalues). */
 
-    (9)   | I - ZZ' | / ( n ulp ) (with sorting of eigenvalues).   
+/*  (9)   | I - ZZ' | / ( n ulp ) (with sorting of eigenvalues). */
 
-    (10)  if A is in Schur form (i.e. quasi-triangular form)   
-          (with sorting of eigenvalues).   
+/*  (10)  if A is in Schur form (i.e. quasi-triangular form) */
+/*        (with sorting of eigenvalues). */
 
-    (11)  if eigenvalues = diagonal elements of the Schur form (S, T),   
-          i.e. test the maximum over j of D(j)  where:   
+/*  (11)  if eigenvalues = diagonal elements of the Schur form (S, T), */
+/*        i.e. test the maximum over j of D(j)  where: */
 
-                        |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|   
-              D(j) = ------------------------ + -----------------------   
-                     max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)   
+/*                      |alpha(j) - S(j,j)|        |beta(j) - T(j,j)| */
+/*            D(j) = ------------------------ + ----------------------- */
+/*                   max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|) */
 
-          (with sorting of eigenvalues).   
+/*        (with sorting of eigenvalues). */
 
-    (12)  if sorting worked and SDIM is the number of eigenvalues   
-          which were CELECTed.   
+/*  (12)  if sorting worked and SDIM is the number of eigenvalues */
+/*        which were CELECTed. */
 
-    Test Matrices   
-    =============   
+/*  Test Matrices */
+/*  ============= */
 
-    The sizes of the test matrices are specified by an array   
-    NN(1:NSIZES); the value of each element NN(j) specifies one size.   
-    The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if   
-    DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-    Currently, the list of possible types is:   
+/*  The sizes of the test matrices are specified by an array */
+/*  NN(1:NSIZES); the value of each element NN(j) specifies one size. */
+/*  The "types" are specified by a logical array DOTYPE( 1:NTYPES ); if */
+/*  DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*  Currently, the list of possible types is: */
 
-    (1)  ( 0, 0 )         (a pair of zero matrices)   
+/*  (1)  ( 0, 0 )         (a pair of zero matrices) */
 
-    (2)  ( I, 0 )         (an identity and a zero matrix)   
+/*  (2)  ( I, 0 )         (an identity and a zero matrix) */
 
-    (3)  ( 0, I )         (an identity and a zero matrix)   
+/*  (3)  ( 0, I )         (an identity and a zero matrix) */
 
-    (4)  ( I, I )         (a pair of identity matrices)   
+/*  (4)  ( I, I )         (a pair of identity matrices) */
 
-            t   t   
-    (5)  ( J , J  )       (a pair of transposed Jordan blocks)   
+/*          t   t */
+/*  (5)  ( J , J  )       (a pair of transposed Jordan blocks) */
 
-                                        t                ( I   0  )   
-    (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t )   
-                                     ( 0   I  )          ( 0   J  )   
-                          and I is a k x k identity and J a (k+1)x(k+1)   
-                          Jordan block; k=(N-1)/2   
+/*                                      t                ( I   0  ) */
+/*  (6)  ( X, Y )         where  X = ( J   0  )  and Y = (      t ) */
+/*                                   ( 0   I  )          ( 0   J  ) */
+/*                        and I is a k x k identity and J a (k+1)x(k+1) */
+/*                        Jordan block; k=(N-1)/2 */
 
-    (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal   
-                          matrix with those diagonal entries.)   
-    (8)  ( I, D )   
+/*  (7)  ( D, I )         where D is diag( 0, 1,..., N-1 ) (a diagonal */
+/*                        matrix with those diagonal entries.) */
+/*  (8)  ( I, D ) */
 
-    (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big   
+/*  (9)  ( big*D, small*I ) where "big" is near overflow and small=1/big */
 
-    (10) ( small*D, big*I )   
+/*  (10) ( small*D, big*I ) */
 
-    (11) ( big*I, small*D )   
+/*  (11) ( big*I, small*D ) */
 
-    (12) ( small*I, big*D )   
+/*  (12) ( small*I, big*D ) */
 
-    (13) ( big*D, big*I )   
+/*  (13) ( big*D, big*I ) */
 
-    (14) ( small*D, small*I )   
+/*  (14) ( small*D, small*I ) */
 
-    (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and   
-                           D2 is diag( 0, N-3, N-4,..., 1, 0, 0 )   
-              t   t   
-    (16) Q ( J , J ) Z     where Q and Z are random orthogonal matrices.   
+/*  (15) ( D1, D2 )        where D1 is diag( 0, 0, 1, ..., N-3, 0 ) and */
+/*                         D2 is diag( 0, N-3, N-4,..., 1, 0, 0 ) */
+/*            t   t */
+/*  (16) Q ( J , J ) Z     where Q and Z are random orthogonal matrices. */
 
-    (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices   
-                           with random O(1) entries above the diagonal   
-                           and diagonal entries diag(T1) =   
-                           ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) =   
-                           ( 0, N-3, N-4,..., 1, 0, 0 )   
+/*  (17) Q ( T1, T2 ) Z    where T1 and T2 are upper triangular matrices */
+/*                         with random O(1) entries above the diagonal */
+/*                         and diagonal entries diag(T1) = */
+/*                         ( 0, 0, 1, ..., N-3, 0 ) and diag(T2) = */
+/*                         ( 0, N-3, N-4,..., 1, 0, 0 ) */
 
-    (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1,..., 1, 0 )   
-                           s = machine precision.   
+/*  (18) Q ( T1, T2 ) Z    diag(T1) = ( 0, 0, 1, 1, s, ..., s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1,..., 1, 0 ) */
+/*                         s = machine precision. */
 
-    (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 )   
+/*  (19) Q ( T1, T2 ) Z    diag(T1)=( 0,0,1,1, 1-d, ..., 1-(N-5)*d=s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0 ) */
 
-                                                           N-5   
-    (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
+/*                                                         N-5 */
+/*  (20) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, 1, a, ..., a   =s, 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
 
-    (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 )   
-                           diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 )   
-                           where r1,..., r(N-4) are random.   
+/*  (21) Q ( T1, T2 ) Z    diag(T1)=( 0, 0, 1, r1, r2, ..., r(N-4), 0 ) */
+/*                         diag(T2) = ( 0, 1, 0, 1, ..., 1, 0, 0 ) */
+/*                         where r1,..., r(N-4) are random. */
 
-    (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (22) Q ( big*T1, small*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (23) Q ( small*T1, big*T2 ) Z    diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (24) Q ( small*T1, small*T2 ) Z  diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 )   
-                                     diag(T2) = ( 0, 1, ..., 1, 0, 0 )   
+/*  (25) Q ( big*T1, big*T2 ) Z      diag(T1) = ( 0, 0, 1, ..., N-3, 0 ) */
+/*                                   diag(T2) = ( 0, 1, ..., 1, 0, 0 ) */
 
-    (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular   
-                            matrices.   
+/*  (26) Q ( T1, T2 ) Z     where T1 and T2 are random upper-triangular */
+/*                          matrices. */
 
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  If it is zero,   
-            DDRGES does nothing.  NSIZES >= 0.   
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  If it is zero, */
+/*          DDRGES does nothing.  NSIZES >= 0. */
 
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  NN >= 0.   
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  NN >= 0. */
 
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, DDRGES   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrix is in A on input.   
-            This is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, DDRGES */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrix is in A on input. */
+/*          This is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated. If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
-
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096. Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to DDRGES to continue the same random number   
-            sequence.   
-
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error is   
-            scaled to be O(1), so THRESH should be a reasonably small   
-            multiple of 1, e.g., 10 or 100.  In particular, it should   
-            not depend on the precision (single vs. double) or the size   
-            of the matrix.  THRESH >= 0.   
-
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns IINFO not equal to 0.)   
-
-    A       (input/workspace) COMPLEX*16 array, dimension(LDA, max(NN))   
-            Used to hold the original A matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, S, and T.   
-            It must be at least 1 and at least max( NN ).   
-
-    B       (input/workspace) COMPLEX*16 array, dimension(LDA, max(NN))   
-            Used to hold the original B matrix.  Used as input only   
-            if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and   
-            DOTYPE(MAXTYP+1)=.TRUE.   
-
-    S       (workspace) COMPLEX*16 array, dimension (LDA, max(NN))   
-            The Schur form matrix computed from A by ZGGES.  On exit, S   
-            contains the Schur form matrix corresponding to the matrix   
-            in A.   
-
-    T       (workspace) COMPLEX*16 array, dimension (LDA, max(NN))   
-            The upper triangular matrix computed from B by ZGGES.   
-
-    Q       (workspace) COMPLEX*16 array, dimension (LDQ, max(NN))   
-            The (left) orthogonal matrix computed by ZGGES.   
-
-    LDQ     (input) INTEGER   
-            The leading dimension of Q and Z. It must   
-            be at least 1 and at least max( NN ).   
-
-    Z       (workspace) COMPLEX*16 array, dimension( LDQ, max(NN) )   
-            The (right) orthogonal matrix computed by ZGGES.   
-
-    ALPHA   (workspace) COMPLEX*16 array, dimension (max(NN))   
-    BETA    (workspace) COMPLEX*16 array, dimension (max(NN))   
-            The generalized eigenvalues of (A,B) computed by ZGGES.   
-            ALPHA(k) / BETA(k) is the k-th generalized eigenvalue of A   
-            and B.   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= 3*N*N.   
-
-    RWORK   (workspace) DOUBLE PRECISION array, dimension ( 8*N )   
-            Real workspace.   
-
-    RESULT  (output) DOUBLE PRECISION array, dimension (15)   
-            The values computed by the tests described above.   
-            The values are currently limited to 1/ulp, to avoid overflow.   
-
-    BWORK   (workspace) LOGICAL array, dimension (N)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.  INFO is the   
-                  absolute value of the INFO value returned.   
-
-    =====================================================================   
-
-       Parameter adjustments */
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated. If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
+
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096. Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to DDRGES to continue the same random number */
+/*          sequence. */
+
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error is */
+/*          scaled to be O(1), so THRESH should be a reasonably small */
+/*          multiple of 1, e.g., 10 or 100.  In particular, it should */
+/*          not depend on the precision (single vs. double) or the size */
+/*          of the matrix.  THRESH >= 0. */
+
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns IINFO not equal to 0.) */
+
+/*  A       (input/workspace) COMPLEX*16 array, dimension(LDA, max(NN)) */
+/*          Used to hold the original A matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, S, and T. */
+/*          It must be at least 1 and at least max( NN ). */
+
+/*  B       (input/workspace) COMPLEX*16 array, dimension(LDA, max(NN)) */
+/*          Used to hold the original B matrix.  Used as input only */
+/*          if NTYPES=MAXTYP+1, DOTYPE(1:MAXTYP)=.FALSE., and */
+/*          DOTYPE(MAXTYP+1)=.TRUE. */
+
+/*  S       (workspace) COMPLEX*16 array, dimension (LDA, max(NN)) */
+/*          The Schur form matrix computed from A by ZGGES.  On exit, S */
+/*          contains the Schur form matrix corresponding to the matrix */
+/*          in A. */
+
+/*  T       (workspace) COMPLEX*16 array, dimension (LDA, max(NN)) */
+/*          The upper triangular matrix computed from B by ZGGES. */
+
+/*  Q       (workspace) COMPLEX*16 array, dimension (LDQ, max(NN)) */
+/*          The (left) orthogonal matrix computed by ZGGES. */
+
+/*  LDQ     (input) INTEGER */
+/*          The leading dimension of Q and Z. It must */
+/*          be at least 1 and at least max( NN ). */
+
+/*  Z       (workspace) COMPLEX*16 array, dimension( LDQ, max(NN) ) */
+/*          The (right) orthogonal matrix computed by ZGGES. */
+
+/*  ALPHA   (workspace) COMPLEX*16 array, dimension (max(NN)) */
+/*  BETA    (workspace) COMPLEX*16 array, dimension (max(NN)) */
+/*          The generalized eigenvalues of (A,B) computed by ZGGES. */
+/*          ALPHA(k) / BETA(k) is the k-th generalized eigenvalue of A */
+/*          and B. */
+
+/*  WORK    (workspace) COMPLEX*16 array, dimension (LWORK) */
+
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= 3*N*N. */
+
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension ( 8*N ) */
+/*          Real workspace. */
+
+/*  RESULT  (output) DOUBLE PRECISION array, dimension (15) */
+/*          The values computed by the tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid overflow. */
+
+/*  BWORK   (workspace) LOGICAL array, dimension (N) */
+
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code.  INFO is the */
+/*                absolute value of the INFO value returned. */
+
+/*  ===================================================================== */
+
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -492,9 +501,11 @@ static integer c__0 = 0;
     --result;
     --bwork;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Check for errors */
+/*     Check for errors */
 
     *info = 0;
 
@@ -525,24 +536,22 @@ static integer c__0 = 0;
 	*info = -14;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV. */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV. */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
 	minwrk = nmax * 3 * nmax;
 /* Computing MAX */
 	i__1 = 1, i__2 = ilaenv_(&c__1, "ZGEQRF", " ", &nmax, &nmax, &c_n1, &
-		c_n1, (ftnlen)6, (ftnlen)1), i__1 = max(i__1,i__2), i__2 = 
-		ilaenv_(&c__1, "ZUNMQR", "LC", &nmax, &nmax, &nmax, &c_n1, (
-		ftnlen)6, (ftnlen)2), i__1 = max(i__1,i__2), i__2 = ilaenv_(&
-		c__1, "ZUNGQR", " ", &nmax, &nmax, &nmax, &c_n1, (ftnlen)6, (
-		ftnlen)1);
-        nb = max(i__1,i__2);
+		c_n1), i__1 = max(i__1,i__2), i__2 = 
+		ilaenv_(&c__1, "ZUNMQR", "LC", &nmax, &nmax, &nmax, &c_n1), i__1 = max(i__1,i__2), i__2 = ilaenv_(&
+		c__1, "ZUNGQR", " ", &nmax, &nmax, &nmax, &c_n1);
+	nb = max(i__1,i__2);
 /* Computing MAX */
 	i__1 = nmax + nmax * nb, i__2 = nmax * 3 * nmax;
 	maxwrk = max(i__1,i__2);
@@ -620,26 +629,26 @@ static integer c__0 = 0;
 /* L30: */
 	    }
 
-/*           Generate test matrices A and B   
+/*           Generate test matrices A and B */
 
-             Description of control parameters:   
+/*           Description of control parameters: */
 
-             KZLASS: =1 means w/o rotation, =2 means w/ rotation,   
-                     =3 means random.   
-             KATYPE: the "type" to be passed to ZLATM4 for computing A.   
-             KAZERO: the pattern of zeros on the diagonal for A:   
-                     =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ),   
-                     =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ),   
-                     =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of   
-                     non-zero entries.)   
-             KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1),   
-                     =2: large, =3: small.   
-             LASIGN: .TRUE. if the diagonal elements of A are to be   
-                     multiplied by a random magnitude 1 number.   
-             KBTYPE, KBZERO, KBMAGN, LBSIGN: the same, but for B.   
-             KTRIAN: =0: don't fill in the upper triangle, =1: do.   
-             KZ1, KZ2, KADD: used to implement KAZERO and KBZERO.   
-             RMAGN: used to implement KAMAGN and KBMAGN. */
+/*           KZLASS: =1 means w/o rotation, =2 means w/ rotation, */
+/*                   =3 means random. */
+/*           KATYPE: the "type" to be passed to ZLATM4 for computing A. */
+/*           KAZERO: the pattern of zeros on the diagonal for A: */
+/*                   =1: ( xxx ), =2: (0, xxx ) =3: ( 0, 0, xxx, 0 ), */
+/*                   =4: ( 0, xxx, 0, 0 ), =5: ( 0, 0, 1, xxx, 0 ), */
+/*                   =6: ( 0, 1, 0, xxx, 0 ).  (xxx means a string of */
+/*                   non-zero entries.) */
+/*           KAMAGN: the magnitude of the matrix: =0: zero, =1: O(1), */
+/*                   =2: large, =3: small. */
+/*           LASIGN: .TRUE. if the diagonal elements of A are to be */
+/*                   multiplied by a random magnitude 1 number. */
+/*           KBTYPE, KBZERO, KBMAGN, LBSIGN: the same, but for B. */
+/*           KTRIAN: =0: don't fill in the upper triangle, =1: do. */
+/*           KZ1, KZ2, KADD: used to implement KAZERO and KBZERO. */
+/*           RMAGN: used to implement KAMAGN and KBMAGN. */
 
 	    if (mtypes > 26) {
 		goto L110;
@@ -695,10 +704,10 @@ static integer c__0 = 0;
 
 		if (kclass[jtype - 1] == 2 && n > 0) {
 
-/*                 Include rotations   
+/*                 Include rotations */
 
-                   Generate Q, Z as Householder transformations times   
-                   a diagonal matrix. */
+/*                 Generate Q, Z as Householder transformations times */
+/*                 a diagonal matrix. */
 
 		    i__3 = n - 1;
 		    for (jc = 1; jc <= i__3; ++jc) {
@@ -920,14 +929,14 @@ L110:
 
 		zget51_(&c__3, &n, &b[b_offset], lda, &t[t_offset], lda, &q[
 			q_offset], ldq, &q[q_offset], ldq, &work[1], &rwork[1]
-			, &result[rsub + 3]);
+, &result[rsub + 3]);
 		zget51_(&c__3, &n, &b[b_offset], lda, &t[t_offset], lda, &z__[
 			z_offset], ldq, &z__[z_offset], ldq, &work[1], &rwork[
 			1], &result[rsub + 4]);
 
-/*              Do test 5 and 6 (or Tests 10 and 11 when reordering):   
-                check Schur form of A and compare eigenvalues with   
-                diagonals. */
+/*              Do test 5 and 6 (or Tests 10 and 11 when reordering): */
+/*              check Schur form of A and compare eigenvalues with */
+/*              diagonals. */
 
 		ntest = rsub + 6;
 		temp1 = 0.;
@@ -1030,8 +1039,8 @@ L160:
 	    for (jr = 1; jr <= i__3; ++jr) {
 		if (result[jr] >= *thresh) {
 
-/*                 If this is the first test to fail,   
-                   print a header to the data file. */
+/*                 If this is the first test to fail, */
+/*                 print a header to the data file. */
 
 		    if (nerrs == 0) {
 			io___53.ciunit = *nounit;
