@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zdrgsx.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -103,23 +91,23 @@ static integer c__5 = 5;
 	    e_rsle(void);
 
     /* Local variables */
-    static integer i__, j, mm;
-    static doublereal pl[2];
-    static integer mn2, qba, qbb;
-    static doublereal ulp, temp1, temp2, abnrm;
-    static integer ifunc, linfo;
-    static char sense[1];
-    extern /* Subroutine */ int zget51_(integer *, integer *, doublecomplex *,
+    integer i__, j, mm;
+    doublereal pl[2];
+    integer mn2, qba, qbb;
+    doublereal ulp, temp1, temp2, abnrm;
+    integer ifunc, linfo;
+    char sense[1];
+    extern /* Subroutine */ int zget51_(integer *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, integer *, doublecomplex *, integer *
-	    , doublecomplex *, integer *, doublecomplex *, doublereal *, 
+, doublecomplex *, integer *, doublecomplex *, doublereal *, 
 	    doublereal *);
-    static integer nerrs, ntest;
-    static doublereal pltru;
-    extern /* Subroutine */ int zlakf2_(integer *, integer *, doublecomplex *,
+    integer nerrs, ntest;
+    doublereal pltru;
+    extern /* Subroutine */ int zlakf2_(integer *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, integer *), dlabad_(doublereal *, doublereal *);
-    static doublereal thrsh2;
-    static logical ilabad;
+    doublereal thrsh2;
+    logical ilabad;
     extern /* Subroutine */ int zlatm5_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
@@ -127,35 +115,35 @@ static integer c__5 = 5;
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, integer *, integer *);
     extern doublereal dlamch_(char *);
-    static integer bdspac;
+    integer bdspac;
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static doublereal difest[2];
+    doublereal difest[2];
     extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
-	    integer *, integer *, ftnlen, ftnlen);
+	    integer *, integer *);
     extern doublereal zlange_(char *, integer *, integer *, doublecomplex *, 
 	    integer *, doublereal *);
-    static doublereal bignum;
+    doublereal bignum;
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static doublereal weight, diftru;
+    doublereal weight, diftru;
     extern /* Subroutine */ int zgesvd_(char *, char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     doublereal *, integer *), zlacpy_(char *, 
-	    integer *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *), zlaset_(char *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, integer *);
-    static integer minwrk, maxwrk;
+    integer minwrk, maxwrk;
     extern /* Subroutine */ int zggesx_(char *, char *, char *, L_fp, char *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublecomplex *, integer *, doublereal *, integer *, integer *, 
 	    logical *, integer *);
-    static doublereal smlnum, ulpinv;
-    static integer nptknt;
-    static doublereal result[10];
-    static integer ntestt, prtype;
+    doublereal smlnum, ulpinv;
+    integer nptknt;
+    doublereal result[10];
+    integer ntestt, prtype;
     extern logical zlctsx_();
 
     /* Fortran I/O blocks */
@@ -181,244 +169,269 @@ static integer c__5 = 5;
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       February 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     February 2007 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  ZDRGSX checks the nonsymmetric generalized eigenvalue (Schur form) */
+/*  problem expert driver ZGGESX. */
+
+/*  ZGGES factors A and B as Q*S*Z'  and Q*T*Z' , where ' means conjugate */
+/*  transpose, S and T are  upper triangular (i.e., in generalized Schur */
+/*  form), and Q and Z are unitary. It also computes the generalized */
+/*  eigenvalues (alpha(j),beta(j)), j=1,...,n.  Thus, */
+/*  w(j) = alpha(j)/beta(j) is a root of the characteristic equation */
+
+/*                  det( A - w(j) B ) = 0 */
+
+/*  Optionally it also reorders the eigenvalues so that a selected */
+/*  cluster of eigenvalues appears in the leading diagonal block of the */
+/*  Schur forms; computes a reciprocal condition number for the average */
+/*  of the selected eigenvalues; and computes a reciprocal condition */
+/*  number for the right and left deflating subspaces corresponding to */
+/*  the selected eigenvalues. */
+
+/*  When ZDRGSX is called with NSIZE > 0, five (5) types of built-in */
+/*  matrix pairs are used to test the routine ZGGESX. */
+
+/*  When ZDRGSX is called with NSIZE = 0, it reads in test matrix data */
+/*  to test ZGGESX. */
+/*  (need more details on what kind of read-in data are needed). */
+
+/*  For each matrix pair, the following tests will be performed and */
+/*  compared with the threshhold THRESH except for the tests (7) and (9): */
+
+/*  (1)   | A - Q S Z' | / ( |A| n ulp ) */
+
+/*  (2)   | B - Q T Z' | / ( |B| n ulp ) */
+
+/*  (3)   | I - QQ' | / ( n ulp ) */
+
+/*  (4)   | I - ZZ' | / ( n ulp ) */
+
+/*  (5)   if A is in Schur form (i.e. triangular form) */
+
+/*  (6)   maximum over j of D(j)  where: */
+
+/*                      |alpha(j) - S(j,j)|        |beta(j) - T(j,j)| */
+/*            D(j) = ------------------------ + ----------------------- */
+/*                   max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|) */
+
+/*  (7)   if sorting worked and SDIM is the number of eigenvalues */
+/*        which were selected. */
+
+/*  (8)   the estimated value DIF does not differ from the true values of */
+/*        Difu and Difl more than a factor 10*THRESH. If the estimate DIF */
+/*        equals zero the corresponding true values of Difu and Difl */
+/*        should be less than EPS*norm(A, B). If the true value of Difu */
+/*        and Difl equal zero, the estimate DIF should be less than */
+/*        EPS*norm(A, B). */
+
+/*  (9)   If INFO = N+3 is returned by ZGGESX, the reordering "failed" */
+/*        and we check that DIF = PL = PR = 0 and that the true value of */
+/*        Difu and Difl is < EPS*norm(A, B). We count the events when */
+/*        INFO=N+3. */
+
+/*  For read-in test matrices, the same tests are run except that the */
+/*  exact value for DIF (and PL) is input data.  Additionally, there is */
+/*  one more test run for read-in test matrices: */
+
+/*  (10)  the estimated value PL does not differ from the true value of */
+/*        PLTRU more than a factor THRESH. If the estimate PL equals */
+/*        zero the corresponding true value of PLTRU should be less than */
+/*        EPS*norm(A, B). If the true value of PLTRU equal zero, the */
+/*        estimate PL should be less than EPS*norm(A, B). */
+
+/*  Note that for the built-in tests, a total of 10*NSIZE*(NSIZE-1) */
+/*  matrix pairs are generated and tested. NSIZE should be kept small. */
+
+/*  SVD (routine ZGESVD) is used for computing the true value of DIF_u */
+/*  and DIF_l when testing the built-in test problems. */
+
+/*  Built-in Test Matrices */
+/*  ====================== */
+
+/*  All built-in test matrices are the 2 by 2 block of triangular */
+/*  matrices */
+
+/*           A = [ A11 A12 ]    and      B = [ B11 B12 ] */
+/*               [     A22 ]                 [     B22 ] */
+
+/*  where for different type of A11 and A22 are given as the following. */
+/*  A12 and B12 are chosen so that the generalized Sylvester equation */
+
+/*           A11*R - L*A22 = -A12 */
+/*           B11*R - L*B22 = -B12 */
+
+/*  have prescribed solution R and L. */
+
+/*  Type 1:  A11 = J_m(1,-1) and A_22 = J_k(1-a,1). */
+/*           B11 = I_m, B22 = I_k */
+/*           where J_k(a,b) is the k-by-k Jordan block with ``a'' on */
+/*           diagonal and ``b'' on superdiagonal. */
+
+/*  Type 2:  A11 = (a_ij) = ( 2(.5-sin(i)) ) and */
+/*           B11 = (b_ij) = ( 2(.5-sin(ij)) ) for i=1,...,m, j=i,...,m */
+/*           A22 = (a_ij) = ( 2(.5-sin(i+j)) ) and */
+/*           B22 = (b_ij) = ( 2(.5-sin(ij)) ) for i=m+1,...,k, j=i,...,k */
+
+/*  Type 3:  A11, A22 and B11, B22 are chosen as for Type 2, but each */
+/*           second diagonal block in A_11 and each third diagonal block */
+/*           in A_22 are made as 2 by 2 blocks. */
+
+/*  Type 4:  A11 = ( 20(.5 - sin(ij)) ) and B22 = ( 2(.5 - sin(i+j)) ) */
+/*              for i=1,...,m,  j=1,...,m and */
+/*           A22 = ( 20(.5 - sin(i+j)) ) and B22 = ( 2(.5 - sin(ij)) ) */
+/*              for i=m+1,...,k,  j=m+1,...,k */
+
+/*  Type 5:  (A,B) and have potentially close or common eigenvalues and */
+/*           very large departure from block diagonality A_11 is chosen */
+/*           as the m x m leading submatrix of A_1: */
+/*                   |  1  b                            | */
+/*                   | -b  1                            | */
+/*                   |        1+d  b                    | */
+/*                   |         -b 1+d                   | */
+/*            A_1 =  |                  d  1            | */
+/*                   |                 -1  d            | */
+/*                   |                        -d  1     | */
+/*                   |                        -1 -d     | */
+/*                   |                               1  | */
+/*           and A_22 is chosen as the k x k leading submatrix of A_2: */
+/*                   | -1  b                            | */
+/*                   | -b -1                            | */
+/*                   |       1-d  b                     | */
+/*                   |       -b  1-d                    | */
+/*            A_2 =  |                 d 1+b            | */
+/*                   |               -1-b d             | */
+/*                   |                       -d  1+b    | */
+/*                   |                      -1+b  -d    | */
+/*                   |                              1-d | */
+/*           and matrix B are chosen as identity matrices (see DLATM5). */
 
 
-    Purpose   
-    =======   
+/*  Arguments */
+/*  ========= */
 
-    ZDRGSX checks the nonsymmetric generalized eigenvalue (Schur form)   
-    problem expert driver ZGGESX.   
+/*  NSIZE   (input) INTEGER */
+/*          The maximum size of the matrices to use. NSIZE >= 0. */
+/*          If NSIZE = 0, no built-in tests matrices are used, but */
+/*          read-in test matrices are used to test DGGESX. */
 
-    ZGGES factors A and B as Q*S*Z'  and Q*T*Z' , where ' means conjugate   
-    transpose, S and T are  upper triangular (i.e., in generalized Schur   
-    form), and Q and Z are unitary. It also computes the generalized   
-    eigenvalues (alpha(j),beta(j)), j=1,...,n.  Thus,   
-    w(j) = alpha(j)/beta(j) is a root of the characteristic equation   
+/*  NCMAX   (input) INTEGER */
+/*          Maximum allowable NMAX for generating Kroneker matrix */
+/*          in call to ZLAKF2 */
 
-                    det( A - w(j) B ) = 0   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  THRESH >= 0. */
 
-    Optionally it also reorders the eigenvalues so that a selected   
-    cluster of eigenvalues appears in the leading diagonal block of the   
-    Schur forms; computes a reciprocal condition number for the average   
-    of the selected eigenvalues; and computes a reciprocal condition   
-    number for the right and left deflating subspaces corresponding to   
-    the selected eigenvalues.   
+/*  NIN     (input) INTEGER */
+/*          The FORTRAN unit number for reading in the data file of */
+/*          problems to solve. */
 
-    When ZDRGSX is called with NSIZE > 0, five (5) types of built-in   
-    matrix pairs are used to test the routine ZGGESX.   
+/*  NOUT    (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns INFO not equal to 0.) */
 
-    When ZDRGSX is called with NSIZE = 0, it reads in test matrix data   
-    to test ZGGESX.   
-    (need more details on what kind of read-in data are needed).   
+/*  A       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE) */
+/*          Used to store the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
 
-    For each matrix pair, the following tests will be performed and   
-    compared with the threshhold THRESH except for the tests (7) and (9):   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, B, AI, BI, Z and Q, */
+/*          LDA >= max( 1, NSIZE ). For the read-in test, */
+/*          LDA >= max( 1, N ), N is the size of the test matrices. */
 
-    (1)   | A - Q S Z' | / ( |A| n ulp )   
+/*  B       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE) */
+/*          Used to store the matrix whose eigenvalues are to be */
+/*          computed.  On exit, B contains the last matrix actually used. */
 
-    (2)   | B - Q T Z' | / ( |B| n ulp )   
+/*  AI      (workspace) COMPLEX*16 array, dimension (LDA, NSIZE) */
+/*          Copy of A, modified by ZGGESX. */
 
-    (3)   | I - QQ' | / ( n ulp )   
+/*  BI      (workspace) COMPLEX*16 array, dimension (LDA, NSIZE) */
+/*          Copy of B, modified by ZGGESX. */
 
-    (4)   | I - ZZ' | / ( n ulp )   
+/*  Z       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE) */
+/*          Z holds the left Schur vectors computed by ZGGESX. */
 
-    (5)   if A is in Schur form (i.e. triangular form)   
+/*  Q       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE) */
+/*          Q holds the right Schur vectors computed by ZGGESX. */
 
-    (6)   maximum over j of D(j)  where:   
+/*  ALPHA   (workspace) COMPLEX*16 array, dimension (NSIZE) */
+/*  BETA    (workspace) COMPLEX*16 array, dimension (NSIZE) */
+/*          On exit, ALPHA/BETA are the eigenvalues. */
 
-                        |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|   
-              D(j) = ------------------------ + -----------------------   
-                     max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)   
+/*  C       (workspace) COMPLEX*16 array, dimension (LDC, LDC) */
+/*          Store the matrix generated by subroutine ZLAKF2, this is the */
+/*          matrix formed by Kronecker products used for estimating */
+/*          DIF. */
 
-    (7)   if sorting worked and SDIM is the number of eigenvalues   
-          which were selected.   
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of C. LDC >= max(1, LDA*LDA/2 ). */
 
-    (8)   the estimated value DIF does not differ from the true values of   
-          Difu and Difl more than a factor 10*THRESH. If the estimate DIF   
-          equals zero the corresponding true values of Difu and Difl   
-          should be less than EPS*norm(A, B). If the true value of Difu   
-          and Difl equal zero, the estimate DIF should be less than   
-          EPS*norm(A, B).   
+/*  S       (workspace) DOUBLE PRECISION array, dimension (LDC) */
+/*          Singular values of C */
 
-    (9)   If INFO = N+3 is returned by ZGGESX, the reordering "failed"   
-          and we check that DIF = PL = PR = 0 and that the true value of   
-          Difu and Difl is < EPS*norm(A, B). We count the events when   
-          INFO=N+3.   
+/*  WORK    (workspace) COMPLEX*16 array, dimension (LWORK) */
 
-    For read-in test matrices, the same tests are run except that the   
-    exact value for DIF (and PL) is input data.  Additionally, there is   
-    one more test run for read-in test matrices:   
+/*  LWORK   (input) INTEGER */
+/*          The dimension of the array WORK.  LWORK >= 3*NSIZE*NSIZE/2 */
 
-    (10)  the estimated value PL does not differ from the true value of   
-          PLTRU more than a factor THRESH. If the estimate PL equals   
-          zero the corresponding true value of PLTRU should be less than   
-          EPS*norm(A, B). If the true value of PLTRU equal zero, the   
-          estimate PL should be less than EPS*norm(A, B).   
+/*  RWORK   (workspace) DOUBLE PRECISION array, */
+/*                                 dimension (5*NSIZE*NSIZE/2 - 4) */
 
-    Note that for the built-in tests, a total of 10*NSIZE*(NSIZE-1)   
-    matrix pairs are generated and tested. NSIZE should be kept small.   
+/*  IWORK   (workspace) INTEGER array, dimension (LIWORK) */
 
-    SVD (routine ZGESVD) is used for computing the true value of DIF_u   
-    and DIF_l when testing the built-in test problems.   
+/*  LIWORK  (input) INTEGER */
+/*          The dimension of the array IWORK. LIWORK >= NSIZE + 2. */
 
-    Built-in Test Matrices   
-    ======================   
+/*  BWORK   (workspace) LOGICAL array, dimension (NSIZE) */
 
-    All built-in test matrices are the 2 by 2 block of triangular   
-    matrices   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value. */
+/*          > 0:  A routine returned an error code. */
 
-             A = [ A11 A12 ]    and      B = [ B11 B12 ]   
-                 [     A22 ]                 [     B22 ]   
+/*  ===================================================================== */
 
-    where for different type of A11 and A22 are given as the following.   
-    A12 and B12 are chosen so that the generalized Sylvester equation   
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Statement Functions .. */
+/*     .. */
+/*     .. Statement Function definitions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-             A11*R - L*A22 = -A12   
-             B11*R - L*B22 = -B12   
+/*     Check for errors */
 
-    have prescribed solution R and L.   
-
-    Type 1:  A11 = J_m(1,-1) and A_22 = J_k(1-a,1).   
-             B11 = I_m, B22 = I_k   
-             where J_k(a,b) is the k-by-k Jordan block with ``a'' on   
-             diagonal and ``b'' on superdiagonal.   
-
-    Type 2:  A11 = (a_ij) = ( 2(.5-sin(i)) ) and   
-             B11 = (b_ij) = ( 2(.5-sin(ij)) ) for i=1,...,m, j=i,...,m   
-             A22 = (a_ij) = ( 2(.5-sin(i+j)) ) and   
-             B22 = (b_ij) = ( 2(.5-sin(ij)) ) for i=m+1,...,k, j=i,...,k   
-
-    Type 3:  A11, A22 and B11, B22 are chosen as for Type 2, but each   
-             second diagonal block in A_11 and each third diagonal block   
-             in A_22 are made as 2 by 2 blocks.   
-
-    Type 4:  A11 = ( 20(.5 - sin(ij)) ) and B22 = ( 2(.5 - sin(i+j)) )   
-                for i=1,...,m,  j=1,...,m and   
-             A22 = ( 20(.5 - sin(i+j)) ) and B22 = ( 2(.5 - sin(ij)) )   
-                for i=m+1,...,k,  j=m+1,...,k   
-
-    Type 5:  (A,B) and have potentially close or common eigenvalues and   
-             very large departure from block diagonality A_11 is chosen   
-             as the m x m leading submatrix of A_1:   
-                     |  1  b                            |   
-                     | -b  1                            |   
-                     |        1+d  b                    |   
-                     |         -b 1+d                   |   
-              A_1 =  |                  d  1            |   
-                     |                 -1  d            |   
-                     |                        -d  1     |   
-                     |                        -1 -d     |   
-                     |                               1  |   
-             and A_22 is chosen as the k x k leading submatrix of A_2:   
-                     | -1  b                            |   
-                     | -b -1                            |   
-                     |       1-d  b                     |   
-                     |       -b  1-d                    |   
-              A_2 =  |                 d 1+b            |   
-                     |               -1-b d             |   
-                     |                       -d  1+b    |   
-                     |                      -1+b  -d    |   
-                     |                              1-d |   
-             and matrix B are chosen as identity matrices (see DLATM5).   
-
-
-    Arguments   
-    =========   
-
-    NSIZE   (input) INTEGER   
-            The maximum size of the matrices to use. NSIZE >= 0.   
-            If NSIZE = 0, no built-in tests matrices are used, but   
-            read-in test matrices are used to test DGGESX.   
-
-    NCMAX   (input) INTEGER   
-            Maximum allowable NMAX for generating Kroneker matrix   
-            in call to ZLAKF2   
-
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  THRESH >= 0.   
-
-    NIN     (input) INTEGER   
-            The FORTRAN unit number for reading in the data file of   
-            problems to solve.   
-
-    NOUT    (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns INFO not equal to 0.)   
-
-    A       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE)   
-            Used to store the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
-
-    LDA     (input) INTEGER   
-            The leading dimension of A, B, AI, BI, Z and Q,   
-            LDA >= max( 1, NSIZE ). For the read-in test,   
-            LDA >= max( 1, N ), N is the size of the test matrices.   
-
-    B       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE)   
-            Used to store the matrix whose eigenvalues are to be   
-            computed.  On exit, B contains the last matrix actually used.   
-
-    AI      (workspace) COMPLEX*16 array, dimension (LDA, NSIZE)   
-            Copy of A, modified by ZGGESX.   
-
-    BI      (workspace) COMPLEX*16 array, dimension (LDA, NSIZE)   
-            Copy of B, modified by ZGGESX.   
-
-    Z       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE)   
-            Z holds the left Schur vectors computed by ZGGESX.   
-
-    Q       (workspace) COMPLEX*16 array, dimension (LDA, NSIZE)   
-            Q holds the right Schur vectors computed by ZGGESX.   
-
-    ALPHA   (workspace) COMPLEX*16 array, dimension (NSIZE)   
-    BETA    (workspace) COMPLEX*16 array, dimension (NSIZE)   
-            On exit, ALPHA/BETA are the eigenvalues.   
-
-    C       (workspace) COMPLEX*16 array, dimension (LDC, LDC)   
-            Store the matrix generated by subroutine ZLAKF2, this is the   
-            matrix formed by Kronecker products used for estimating   
-            DIF.   
-
-    LDC     (input) INTEGER   
-            The leading dimension of C. LDC >= max(1, LDA*LDA/2 ).   
-
-    S       (workspace) DOUBLE PRECISION array, dimension (LDC)   
-            Singular values of C   
-
-    WORK    (workspace) COMPLEX*16 array, dimension (LWORK)   
-
-    LWORK   (input) INTEGER   
-            The dimension of the array WORK.  LWORK >= 3*NSIZE*NSIZE/2   
-
-    RWORK   (workspace) DOUBLE PRECISION array,   
-                                   dimension (5*NSIZE*NSIZE/2 - 4)   
-
-    IWORK   (workspace) INTEGER array, dimension (LIWORK)   
-
-    LIWORK  (input) INTEGER   
-            The dimension of the array IWORK. LIWORK >= NSIZE + 2.   
-
-    BWORK   (workspace) LOGICAL array, dimension (NSIZE)   
-
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value.   
-            > 0:  A routine returned an error code.   
-
-    =====================================================================   
-
-
-       Check for errors   
-
-       Parameter adjustments */
+    /* Parameter adjustments */
     q_dim1 = *lda;
     q_offset = 1 + q_dim1;
     q -= q_offset;
@@ -466,12 +479,12 @@ static integer c__5 = 5;
 	*info = -21;
     }
 
-/*     Compute workspace   
-        (Note: Comments in the code beginning "Workspace:" describe the   
-         minimal amount of workspace needed at that point in the code,   
-         as well as the preferred amount for good performance.   
-         NB refers to the optimal block size for the immediately   
-         following subroutine, as returned by ILAENV.) */
+/*     Compute workspace */
+/*      (Note: Comments in the code beginning "Workspace:" describe the */
+/*       minimal amount of workspace needed at that point in the code, */
+/*       as well as the preferred amount for good performance. */
+/*       NB refers to the optimal block size for the immediately */
+/*       following subroutine, as returned by ILAENV.) */
 
     minwrk = 1;
     if (*info == 0 && *lwork >= 1) {
@@ -480,10 +493,10 @@ static integer c__5 = 5;
 /*        workspace for cggesx */
 
 	maxwrk = *nsize * (ilaenv_(&c__1, "ZGEQRF", " ", nsize, &c__1, nsize, 
-		&c__0, (ftnlen)6, (ftnlen)1) + 1);
+		&c__0) + 1);
 /* Computing MAX */
 	i__1 = maxwrk, i__2 = *nsize * (ilaenv_(&c__1, "ZUNGQR", " ", nsize, &
-		c__1, nsize, &c_n1, (ftnlen)6, (ftnlen)1) + 1);
+		c__1, nsize, &c_n1) + 1);
 	maxwrk = max(i__1,i__2);
 
 /*        workspace for zgesvd */
@@ -493,7 +506,7 @@ static integer c__5 = 5;
 	i__3 = *nsize * *nsize / 2;
 	i__4 = *nsize * *nsize / 2;
 	i__1 = maxwrk, i__2 = *nsize * *nsize * (ilaenv_(&c__1, "ZGEBRD", 
-		" ", &i__3, &i__4, &c_n1, &c_n1, (ftnlen)6, (ftnlen)1) + 1);
+		" ", &i__3, &i__4, &c_n1, &c_n1) + 1);
 	maxwrk = max(i__1,i__2);
 	maxwrk = max(maxwrk,bdspac);
 
@@ -530,9 +543,9 @@ static integer c__5 = 5;
 	goto L70;
     }
 
-/*     Test the built-in matrix pairs.   
-       Loop over different functions (IFUNC) of ZGGESX, types (PRTYPE)   
-       of test matrices, different size (M+N) */
+/*     Test the built-in matrix pairs. */
+/*     Loop over different functions (IFUNC) of ZGGESX, types (PRTYPE) */
+/*     of test matrices, different size (M+N) */
 
     prtype = 0;
     qba = 3;
@@ -567,10 +580,10 @@ static integer c__5 = 5;
 			    q_offset], lda, &z__[z_offset], lda, &weight, &
 			    qba, &qbb);
 
-/*                 Compute the Schur factorization and swapping the   
-                   m-by-m (1,1)-blocks with n-by-n (2,2)-blocks.   
-                   Swapping is accomplished via the function ZLCTSX   
-                   which is supplied below. */
+/*                 Compute the Schur factorization and swapping the */
+/*                 m-by-m (1,1)-blocks with n-by-n (2,2)-blocks. */
+/*                 Swapping is accomplished via the function ZLCTSX */
+/*                 which is supplied below. */
 
 		    if (ifunc == 0) {
 			*(unsigned char *)sense = 'N';
@@ -583,11 +596,11 @@ static integer c__5 = 5;
 		    }
 
 		    zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset]
-			    , lda, &a[a_offset], lda);
+, lda, &a[a_offset], lda);
 		    zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset]
-			    , lda, &b[b_offset], lda);
+, lda, &b[b_offset], lda);
 
-		    zggesx_("V", "V", "S", (L_fp)zlctsx_, sense, &mn_1.mplusn,
+		    zggesx_("V", "V", "S", (L_fp)zlctsx_, sense, &mn_1.mplusn, 
 			     &ai[ai_offset], lda, &bi[bi_offset], lda, &mm, &
 			    alpha[1], &beta[1], &q[q_offset], lda, &z__[
 			    z_offset], lda, pl, difest, &work[1], lwork, &
@@ -602,7 +615,8 @@ static integer c__5 = 5;
 				;
 			do_fio(&c__1, (char *)&mn_1.mplusn, (ftnlen)sizeof(
 				integer));
-			do_fio(&c__1, (char *)&prtype, (ftnlen)sizeof(integer) );
+			do_fio(&c__1, (char *)&prtype, (ftnlen)sizeof(integer)
+				);
 			e_wsfe();
 			*info = linfo;
 			goto L30;
@@ -611,9 +625,9 @@ static integer c__5 = 5;
 /*                 Compute the norm(A, B) */
 
 		    zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset]
-			    , lda, &work[1], &mn_1.mplusn);
+, lda, &work[1], &mn_1.mplusn);
 		    zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset]
-			    , lda, &work[mn_1.mplusn * mn_1.mplusn + 1], &
+, lda, &work[mn_1.mplusn * mn_1.mplusn + 1], &
 			    mn_1.mplusn);
 		    i__3 = mn_1.mplusn << 1;
 		    abnrm = zlange_("Fro", &mn_1.mplusn, &i__3, &work[1], &
@@ -624,10 +638,10 @@ static integer c__5 = 5;
 		    result[1] = 0.;
 		    zget51_(&c__1, &mn_1.mplusn, &a[a_offset], lda, &ai[
 			    ai_offset], lda, &q[q_offset], lda, &z__[z_offset]
-			    , lda, &work[1], &rwork[1], result);
+, lda, &work[1], &rwork[1], result);
 		    zget51_(&c__1, &mn_1.mplusn, &b[b_offset], lda, &bi[
 			    bi_offset], lda, &q[q_offset], lda, &z__[z_offset]
-			    , lda, &work[1], &rwork[1], &result[1]);
+, lda, &work[1], &rwork[1], &result[1]);
 		    zget51_(&c__3, &mn_1.mplusn, &b[b_offset], lda, &bi[
 			    bi_offset], lda, &q[q_offset], lda, &q[q_offset], 
 			    lda, &work[1], &rwork[1], &result[2]);
@@ -636,8 +650,8 @@ static integer c__5 = 5;
 			    z_offset], lda, &work[1], &rwork[1], &result[3]);
 		    ntest = 4;
 
-/*                 Do tests (5) and (6): check Schur form of A and   
-                   compare eigenvalues with diagonals. */
+/*                 Do tests (5) and (6): check Schur form of A and */
+/*                 compare eigenvalues with diagonals. */
 
 		    temp1 = 0.;
 		    result[4] = 0.;
@@ -674,7 +688,9 @@ static integer c__5 = 5;
 				j * bi_dim1]), abs(d__8));
 			temp2 = (((d__9 = z__1.r, abs(d__9)) + (d__10 = 
 				d_imag(&z__1), abs(d__10))) / max(d__13,d__14)
-				 + ((d__11 = z__3.r, abs(d__11)) + (d__12 =  				d_imag(&z__3), abs(d__12))) / max(d__15,d__16) 				) / ulp;
+				 + ((d__11 = z__3.r, abs(d__11)) + (d__12 = 
+				d_imag(&z__3), abs(d__12))) / max(d__15,d__16)
+				) / ulp;
 			if (j < mn_1.mplusn) {
 			    i__4 = j + 1 + j * ai_dim1;
 			    if (ai[i__4].r != 0. || ai[i__4].i != 0.) {
@@ -716,15 +732,15 @@ static integer c__5 = 5;
 		    }
 		    ++ntest;
 
-/*                 Test (8): compare the estimated value DIF and its   
-                   value. first, compute the exact DIF. */
+/*                 Test (8): compare the estimated value DIF and its */
+/*                 value. first, compute the exact DIF. */
 
 		    result[7] = 0.;
 		    mn2 = mm * (mn_1.mplusn - mm) << 1;
 		    if (ifunc >= 2 && mn2 <= *ncmax * *ncmax) {
 
-/*                    Note: for either following two cases, there are   
-                      almost same number of test cases fail the test. */
+/*                    Note: for either following two cases, there are */
+/*                    almost same number of test cases fail the test. */
 
 			i__3 = mn_1.mplusn - mm;
 			zlakf2_(&mm, &i__3, &ai[ai_offset], lda, &ai[mm + 1 + 
@@ -734,7 +750,7 @@ static integer c__5 = 5;
 			i__3 = *lwork - 2;
 			zgesvd_("N", "N", &mn2, &mn2, &c__[c_offset], ldc, &s[
 				1], &work[1], &c__1, &work[2], &c__1, &work[3]
-				, &i__3, &rwork[1], info);
+, &i__3, &rwork[1], info);
 			diftru = s[mn2];
 
 			if (difest[1] == 0.) {
@@ -778,8 +794,8 @@ static integer c__5 = 5;
 		    for (j = 1; j <= 9; ++j) {
 			if (result[j - 1] >= *thresh) {
 
-/*                       If this is the first test to fail,   
-                         print a header to the data file. */
+/*                       If this is the first test to fail, */
+/*                       print a header to the data file. */
 
 			    if (nerrs == 0) {
 				io___32.ciunit = *nout;
@@ -858,8 +874,8 @@ L30:
 
 L70:
 
-/*     Read in data from file to check accuracy of condition estimation   
-       Read input data until N=0 */
+/*     Read in data from file to check accuracy of condition estimation */
+/*     Read input data until N=0 */
 
     nptknt = 0;
 
@@ -934,8 +950,8 @@ L80:
     zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset], lda, &b[
 	    b_offset], lda);
 
-/*     Compute the Schur factorization while swaping the   
-       m-by-m (1,1)-blocks with n-by-n (2,2)-blocks. */
+/*     Compute the Schur factorization while swaping the */
+/*     m-by-m (1,1)-blocks with n-by-n (2,2)-blocks. */
 
     zggesx_("V", "V", "S", (L_fp)zlctsx_, "B", &mn_1.mplusn, &ai[ai_offset], 
 	    lda, &bi[bi_offset], lda, &mm, &alpha[1], &beta[1], &q[q_offset], 
@@ -954,10 +970,10 @@ L80:
 	goto L130;
     }
 
-/*     Compute the norm(A, B)   
-          (should this be norm of (A,B) or (AI,BI)?) */
+/*     Compute the norm(A, B) */
+/*        (should this be norm of (A,B) or (AI,BI)?) */
 
-    zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset], lda, &work[1],
+    zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &ai[ai_offset], lda, &work[1], 
 	     &mn_1.mplusn);
     zlacpy_("Full", &mn_1.mplusn, &mn_1.mplusn, &bi[bi_offset], lda, &work[
 	    mn_1.mplusn * mn_1.mplusn + 1], &mn_1.mplusn);
@@ -973,13 +989,14 @@ L80:
 	    q_offset], lda, &z__[z_offset], lda, &work[1], &rwork[1], &result[
 	    1]);
     zget51_(&c__3, &mn_1.mplusn, &b[b_offset], lda, &bi[bi_offset], lda, &q[
-	    q_offset], lda, &q[q_offset], lda, &work[1], &rwork[1], &result[2] );
+	    q_offset], lda, &q[q_offset], lda, &work[1], &rwork[1], &result[2]
+);
     zget51_(&c__3, &mn_1.mplusn, &b[b_offset], lda, &bi[bi_offset], lda, &z__[
 	    z_offset], lda, &z__[z_offset], lda, &work[1], &rwork[1], &result[
 	    3]);
 
-/*     Do tests (5) and (6): check Schur form of A and compare   
-       eigenvalues with diagonals. */
+/*     Do tests (5) and (6): check Schur form of A and compare */
+/*     eigenvalues with diagonals. */
 
     ntest = 6;
     temp1 = 0.;
@@ -1110,8 +1127,8 @@ L80:
     for (j = 1; j <= i__1; ++j) {
 	if (result[j - 1] >= *thresh) {
 
-/*           If this is the first test to fail,   
-             print a header to the data file. */
+/*           If this is the first test to fail, */
+/*           print a header to the data file. */
 
 	    if (nerrs == 0) {
 		io___47.ciunit = *nout;
