@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zdrves.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -37,7 +25,7 @@ static integer c__2 = 2;
 
 /* Subroutine */ int zdrves_(integer *nsizes, integer *nn, integer *ntypes, 
 	logical *dotype, integer *iseed, doublereal *thresh, integer *nounit, 
-	doublecomplex *a, integer *lda, doublecomplex *h__, doublecomplex *ht,
+	doublecomplex *a, integer *lda, doublecomplex *h__, doublecomplex *ht, 
 	 doublecomplex *w, doublecomplex *wt, doublecomplex *vs, integer *
 	ldvs, doublereal *result, doublecomplex *work, integer *nwork, 
 	doublereal *rwork, integer *iwork, logical *bwork, integer *info)
@@ -104,63 +92,63 @@ static integer c__2 = 2;
 	    vs_offset, i__1, i__2, i__3, i__4, i__5, i__6;
     doublecomplex z__1;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, n;
-    static doublereal res[2];
-    static integer iwk;
-    static doublereal ulp, cond;
-    static integer jcol;
-    static char path[3];
-    static integer sdim, nmax;
-    static doublereal unfl, ovfl;
-    static integer rsub;
-    static char sort[1];
-    static logical badnn;
-    static integer nfail, imode, iinfo;
-    static doublereal conds, anorm;
+    integer i__, j, n;
+    doublereal res[2];
+    integer iwk;
+    doublereal ulp, cond;
+    integer jcol;
+    char path[3];
+    integer sdim, nmax;
+    doublereal unfl, ovfl;
+    integer rsub;
+    char sort[1];
+    logical badnn;
+    integer nfail, imode, iinfo;
+    doublereal conds, anorm;
     extern /* Subroutine */ int zgees_(char *, char *, L_fp, integer *, 
 	    doublecomplex *, integer *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, logical *, integer *);
-    static integer jsize, nerrs, itype, jtype, ntest, lwork, isort;
+    integer jsize, nerrs, itype, jtype, ntest, lwork, isort;
     extern /* Subroutine */ int zhst01_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *);
-    static doublereal rtulp;
+    doublereal rtulp;
     extern /* Subroutine */ int dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
-    static integer idumma[1], ioldsd[4];
+    integer idumma[1], ioldsd[4];
     extern /* Subroutine */ int xerbla_(char *, integer *);
-    static integer knteig;
+    integer knteig;
     extern /* Subroutine */ int dlasum_(char *, integer *, integer *, integer 
-	    *), zlatme_(integer *, char *, integer *, doublecomplex *,
-	     integer *, doublereal *, doublecomplex *, char *, char *, char *,
+	    *), zlatme_(integer *, char *, integer *, doublecomplex *, 
+	     integer *, doublereal *, doublecomplex *, char *, char *, char *, 
 	     char *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *, doublereal *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), zlacpy_(char *, integer *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *);
-    static integer ntestf;
+    integer ntestf;
     extern logical zslect_(doublecomplex *);
     extern /* Subroutine */ int zlaset_(char *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, integer *), zlatmr_(integer *, integer *, char *, integer *, char *, 
-	    doublecomplex *, integer *, doublereal *, doublecomplex *, char *,
+	    doublecomplex *, integer *, doublereal *, doublecomplex *, char *, 
 	     char *, doublecomplex *, integer *, doublereal *, doublecomplex *
-	    , integer *, doublereal *, char *, integer *, integer *, integer *
-	    , doublereal *, doublereal *, char *, doublecomplex *, integer *, 
+, integer *, doublereal *, char *, integer *, integer *, integer *
+, doublereal *, doublereal *, char *, doublecomplex *, integer *, 
 	    integer *, integer *), zlatms_(integer *, integer *, char *, integer *, char *, 
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    integer *, char *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *);
-    static integer nnwork;
-    static doublereal rtulpi;
-    static integer mtypes, ntestt;
-    static doublereal ulpinv;
+    integer nnwork;
+    doublereal rtulpi;
+    integer mtypes, ntestt;
+    doublereal ulpinv;
 
     /* Fortran I/O blocks */
     static cilist io___31 = { 0, 0, 0, fmt_9992, 0 };
@@ -176,279 +164,302 @@ static integer c__2 = 2;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       ZDRVES checks the nonsymmetric eigenvalue (Schur form) problem   
-       driver ZGEES.   
+/*     ZDRVES checks the nonsymmetric eigenvalue (Schur form) problem */
+/*     driver ZGEES. */
 
-       When ZDRVES is called, a number of matrix "sizes" ("n's") and a   
-       number of matrix "types" are specified.  For each size ("n")   
-       and each type of matrix, one matrix will be generated and used   
-       to test the nonsymmetric eigenroutines.  For each matrix, 13   
-       tests will be performed:   
+/*     When ZDRVES is called, a number of matrix "sizes" ("n's") and a */
+/*     number of matrix "types" are specified.  For each size ("n") */
+/*     and each type of matrix, one matrix will be generated and used */
+/*     to test the nonsymmetric eigenroutines.  For each matrix, 13 */
+/*     tests will be performed: */
 
-       (1)     0 if T is in Schur form, 1/ulp otherwise   
-              (no sorting of eigenvalues)   
+/*     (1)     0 if T is in Schur form, 1/ulp otherwise */
+/*            (no sorting of eigenvalues) */
 
-       (2)     | A - VS T VS' | / ( n |A| ulp )   
+/*     (2)     | A - VS T VS' | / ( n |A| ulp ) */
 
-         Here VS is the matrix of Schur eigenvectors, and T is in Schur   
-         form  (no sorting of eigenvalues).   
+/*       Here VS is the matrix of Schur eigenvectors, and T is in Schur */
+/*       form  (no sorting of eigenvalues). */
 
-       (3)     | I - VS VS' | / ( n ulp ) (no sorting of eigenvalues).   
+/*     (3)     | I - VS VS' | / ( n ulp ) (no sorting of eigenvalues). */
 
-       (4)     0     if W are eigenvalues of T   
-               1/ulp otherwise   
-               (no sorting of eigenvalues)   
+/*     (4)     0     if W are eigenvalues of T */
+/*             1/ulp otherwise */
+/*             (no sorting of eigenvalues) */
 
-       (5)     0     if T(with VS) = T(without VS),   
-               1/ulp otherwise   
-               (no sorting of eigenvalues)   
+/*     (5)     0     if T(with VS) = T(without VS), */
+/*             1/ulp otherwise */
+/*             (no sorting of eigenvalues) */
 
-       (6)     0     if eigenvalues(with VS) = eigenvalues(without VS),   
-               1/ulp otherwise   
-               (no sorting of eigenvalues)   
+/*     (6)     0     if eigenvalues(with VS) = eigenvalues(without VS), */
+/*             1/ulp otherwise */
+/*             (no sorting of eigenvalues) */
 
-       (7)     0 if T is in Schur form, 1/ulp otherwise   
-               (with sorting of eigenvalues)   
+/*     (7)     0 if T is in Schur form, 1/ulp otherwise */
+/*             (with sorting of eigenvalues) */
 
-       (8)     | A - VS T VS' | / ( n |A| ulp )   
+/*     (8)     | A - VS T VS' | / ( n |A| ulp ) */
 
-         Here VS is the matrix of Schur eigenvectors, and T is in Schur   
-         form  (with sorting of eigenvalues).   
+/*       Here VS is the matrix of Schur eigenvectors, and T is in Schur */
+/*       form  (with sorting of eigenvalues). */
 
-       (9)     | I - VS VS' | / ( n ulp ) (with sorting of eigenvalues).   
+/*     (9)     | I - VS VS' | / ( n ulp ) (with sorting of eigenvalues). */
 
-       (10)    0     if W are eigenvalues of T   
-               1/ulp otherwise   
-               (with sorting of eigenvalues)   
+/*     (10)    0     if W are eigenvalues of T */
+/*             1/ulp otherwise */
+/*             (with sorting of eigenvalues) */
 
-       (11)    0     if T(with VS) = T(without VS),   
-               1/ulp otherwise   
-               (with sorting of eigenvalues)   
+/*     (11)    0     if T(with VS) = T(without VS), */
+/*             1/ulp otherwise */
+/*             (with sorting of eigenvalues) */
 
-       (12)    0     if eigenvalues(with VS) = eigenvalues(without VS),   
-               1/ulp otherwise   
-               (with sorting of eigenvalues)   
+/*     (12)    0     if eigenvalues(with VS) = eigenvalues(without VS), */
+/*             1/ulp otherwise */
+/*             (with sorting of eigenvalues) */
 
-       (13)    if sorting worked and SDIM is the number of   
-               eigenvalues which were SELECTed   
+/*     (13)    if sorting worked and SDIM is the number of */
+/*             eigenvalues which were SELECTed */
 
-       The "sizes" are specified by an array NN(1:NSIZES); the value of   
-       each element NN(j) specifies one size.   
-       The "types" are specified by a logical array DOTYPE( 1:NTYPES );   
-       if DOTYPE(j) is .TRUE., then matrix type "j" will be generated.   
-       Currently, the list of possible types is:   
+/*     The "sizes" are specified by an array NN(1:NSIZES); the value of */
+/*     each element NN(j) specifies one size. */
+/*     The "types" are specified by a logical array DOTYPE( 1:NTYPES ); */
+/*     if DOTYPE(j) is .TRUE., then matrix type "j" will be generated. */
+/*     Currently, the list of possible types is: */
 
-       (1)  The zero matrix.   
-       (2)  The identity matrix.   
-       (3)  A (transposed) Jordan block, with 1's on the diagonal.   
+/*     (1)  The zero matrix. */
+/*     (2)  The identity matrix. */
+/*     (3)  A (transposed) Jordan block, with 1's on the diagonal. */
 
-       (4)  A diagonal matrix with evenly spaced entries   
-            1, ..., ULP  and random complex angles.   
-            (ULP = (first number larger than 1) - 1 )   
-       (5)  A diagonal matrix with geometrically spaced entries   
-            1, ..., ULP  and random complex angles.   
-       (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP   
-            and random complex angles.   
+/*     (4)  A diagonal matrix with evenly spaced entries */
+/*          1, ..., ULP  and random complex angles. */
+/*          (ULP = (first number larger than 1) - 1 ) */
+/*     (5)  A diagonal matrix with geometrically spaced entries */
+/*          1, ..., ULP  and random complex angles. */
+/*     (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP */
+/*          and random complex angles. */
 
-       (7)  Same as (4), but multiplied by a constant near   
-            the overflow threshold   
-       (8)  Same as (4), but multiplied by a constant near   
-            the underflow threshold   
+/*     (7)  Same as (4), but multiplied by a constant near */
+/*          the overflow threshold */
+/*     (8)  Same as (4), but multiplied by a constant near */
+/*          the underflow threshold */
 
-       (9)  A matrix of the form  U' T U, where U is unitary and   
-            T has evenly spaced entries 1, ..., ULP with random   
-            complex angles on the diagonal and random O(1) entries in   
-            the upper triangle.   
+/*     (9)  A matrix of the form  U' T U, where U is unitary and */
+/*          T has evenly spaced entries 1, ..., ULP with random */
+/*          complex angles on the diagonal and random O(1) entries in */
+/*          the upper triangle. */
 
-       (10) A matrix of the form  U' T U, where U is unitary and   
-            T has geometrically spaced entries 1, ..., ULP with random   
-            complex angles on the diagonal and random O(1) entries in   
-            the upper triangle.   
+/*     (10) A matrix of the form  U' T U, where U is unitary and */
+/*          T has geometrically spaced entries 1, ..., ULP with random */
+/*          complex angles on the diagonal and random O(1) entries in */
+/*          the upper triangle. */
 
-       (11) A matrix of the form  U' T U, where U is orthogonal and   
-            T has "clustered" entries 1, ULP,..., ULP with random   
-            complex angles on the diagonal and random O(1) entries in   
-            the upper triangle.   
+/*     (11) A matrix of the form  U' T U, where U is orthogonal and */
+/*          T has "clustered" entries 1, ULP,..., ULP with random */
+/*          complex angles on the diagonal and random O(1) entries in */
+/*          the upper triangle. */
 
-       (12) A matrix of the form  U' T U, where U is unitary and   
-            T has complex eigenvalues randomly chosen from   
-            ULP < |z| < 1   and random O(1) entries in the upper   
-            triangle.   
+/*     (12) A matrix of the form  U' T U, where U is unitary and */
+/*          T has complex eigenvalues randomly chosen from */
+/*          ULP < |z| < 1   and random O(1) entries in the upper */
+/*          triangle. */
 
-       (13) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP   
-            with random complex angles on the diagonal and random O(1)   
-            entries in the upper triangle.   
+/*     (13) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP */
+/*          with random complex angles on the diagonal and random O(1) */
+/*          entries in the upper triangle. */
 
-       (14) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has geometrically spaced entries   
-            1, ..., ULP with random complex angles on the diagonal   
-            and random O(1) entries in the upper triangle.   
+/*     (14) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has geometrically spaced entries */
+/*          1, ..., ULP with random complex angles on the diagonal */
+/*          and random O(1) entries in the upper triangle. */
 
-       (15) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP   
-            with random complex angles on the diagonal and random O(1)   
-            entries in the upper triangle.   
+/*     (15) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP */
+/*          with random complex angles on the diagonal and random O(1) */
+/*          entries in the upper triangle. */
 
-       (16) A matrix of the form  X' T X, where X has condition   
-            SQRT( ULP ) and T has complex eigenvalues randomly chosen   
-            from ULP < |z| < 1 and random O(1) entries in the upper   
-            triangle.   
+/*     (16) A matrix of the form  X' T X, where X has condition */
+/*          SQRT( ULP ) and T has complex eigenvalues randomly chosen */
+/*          from ULP < |z| < 1 and random O(1) entries in the upper */
+/*          triangle. */
 
-       (17) Same as (16), but multiplied by a constant   
-            near the overflow threshold   
-       (18) Same as (16), but multiplied by a constant   
-            near the underflow threshold   
+/*     (17) Same as (16), but multiplied by a constant */
+/*          near the overflow threshold */
+/*     (18) Same as (16), but multiplied by a constant */
+/*          near the underflow threshold */
 
-       (19) Nonsymmetric matrix with random entries chosen from (-1,1).   
-            If N is at least 4, all entries in first two rows and last   
-            row, and first column and last two columns are zero.   
-       (20) Same as (19), but multiplied by a constant   
-            near the overflow threshold   
-       (21) Same as (19), but multiplied by a constant   
-            near the underflow threshold   
+/*     (19) Nonsymmetric matrix with random entries chosen from (-1,1). */
+/*          If N is at least 4, all entries in first two rows and last */
+/*          row, and first column and last two columns are zero. */
+/*     (20) Same as (19), but multiplied by a constant */
+/*          near the overflow threshold */
+/*     (21) Same as (19), but multiplied by a constant */
+/*          near the underflow threshold */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    NSIZES  (input) INTEGER   
-            The number of sizes of matrices to use.  If it is zero,   
-            ZDRVES does nothing.  It must be at least zero.   
+/*  NSIZES  (input) INTEGER */
+/*          The number of sizes of matrices to use.  If it is zero, */
+/*          ZDRVES does nothing.  It must be at least zero. */
 
-    NN      (input) INTEGER array, dimension (NSIZES)   
-            An array containing the sizes to be used for the matrices.   
-            Zero values will be skipped.  The values must be at least   
-            zero.   
+/*  NN      (input) INTEGER array, dimension (NSIZES) */
+/*          An array containing the sizes to be used for the matrices. */
+/*          Zero values will be skipped.  The values must be at least */
+/*          zero. */
 
-    NTYPES  (input) INTEGER   
-            The number of elements in DOTYPE.   If it is zero, ZDRVES   
-            does nothing.  It must be at least zero.  If it is MAXTYP+1   
-            and NSIZES is 1, then an additional type, MAXTYP+1 is   
-            defined, which is to use whatever matrix is in A.  This   
-            is only useful if DOTYPE(1:MAXTYP) is .FALSE. and   
-            DOTYPE(MAXTYP+1) is .TRUE. .   
+/*  NTYPES  (input) INTEGER */
+/*          The number of elements in DOTYPE.   If it is zero, ZDRVES */
+/*          does nothing.  It must be at least zero.  If it is MAXTYP+1 */
+/*          and NSIZES is 1, then an additional type, MAXTYP+1 is */
+/*          defined, which is to use whatever matrix is in A.  This */
+/*          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and */
+/*          DOTYPE(MAXTYP+1) is .TRUE. . */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            If DOTYPE(j) is .TRUE., then for each size in NN a   
-            matrix of that size and of type j will be generated.   
-            If NTYPES is smaller than the maximum number of types   
-            defined (PARAMETER MAXTYP), then types NTYPES+1 through   
-            MAXTYP will not be generated.  If NTYPES is larger   
-            than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)   
-            will be ignored.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          If DOTYPE(j) is .TRUE., then for each size in NN a */
+/*          matrix of that size and of type j will be generated. */
+/*          If NTYPES is smaller than the maximum number of types */
+/*          defined (PARAMETER MAXTYP), then types NTYPES+1 through */
+/*          MAXTYP will not be generated.  If NTYPES is larger */
+/*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES) */
+/*          will be ignored. */
 
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            On entry ISEED specifies the seed of the random number   
-            generator. The array elements should be between 0 and 4095;   
-            if not they will be reduced mod 4096.  Also, ISEED(4) must   
-            be odd.  The random number generator uses a linear   
-            congruential sequence limited to small integers, and so   
-            should produce machine independent random numbers. The   
-            values of ISEED are changed on exit, and can be used in the   
-            next call to ZDRVES to continue the same random number   
-            sequence.   
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          On entry ISEED specifies the seed of the random number */
+/*          generator. The array elements should be between 0 and 4095; */
+/*          if not they will be reduced mod 4096.  Also, ISEED(4) must */
+/*          be odd.  The random number generator uses a linear */
+/*          congruential sequence limited to small integers, and so */
+/*          should produce machine independent random numbers. The */
+/*          values of ISEED are changed on exit, and can be used in the */
+/*          next call to ZDRVES to continue the same random number */
+/*          sequence. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            A test will count as "failed" if the "error", computed as   
-            described above, exceeds THRESH.  Note that the error   
-            is scaled to be O(1), so THRESH should be a reasonably   
-            small multiple of 1, e.g., 10 or 100.  In particular,   
-            it should not depend on the precision (single vs. double)   
-            or the size of the matrix.  It must be at least zero.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          A test will count as "failed" if the "error", computed as */
+/*          described above, exceeds THRESH.  Note that the error */
+/*          is scaled to be O(1), so THRESH should be a reasonably */
+/*          small multiple of 1, e.g., 10 or 100.  In particular, */
+/*          it should not depend on the precision (single vs. double) */
+/*          or the size of the matrix.  It must be at least zero. */
 
-    NOUNIT  (input) INTEGER   
-            The FORTRAN unit number for printing out error messages   
-            (e.g., if a routine returns INFO not equal to 0.)   
+/*  NOUNIT  (input) INTEGER */
+/*          The FORTRAN unit number for printing out error messages */
+/*          (e.g., if a routine returns INFO not equal to 0.) */
 
-    A       (workspace) COMPLEX*16 array, dimension (LDA, max(NN))   
-            Used to hold the matrix whose eigenvalues are to be   
-            computed.  On exit, A contains the last matrix actually used.   
+/*  A       (workspace) COMPLEX*16 array, dimension (LDA, max(NN)) */
+/*          Used to hold the matrix whose eigenvalues are to be */
+/*          computed.  On exit, A contains the last matrix actually used. */
 
-    LDA     (input) INTEGER   
-            The leading dimension of A, and H. LDA must be at   
-            least 1 and at least max( NN ).   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A, and H. LDA must be at */
+/*          least 1 and at least max( NN ). */
 
-    H       (workspace) COMPLEX*16 array, dimension (LDA, max(NN))   
-            Another copy of the test matrix A, modified by ZGEES.   
+/*  H       (workspace) COMPLEX*16 array, dimension (LDA, max(NN)) */
+/*          Another copy of the test matrix A, modified by ZGEES. */
 
-    HT      (workspace) COMPLEX*16 array, dimension (LDA, max(NN))   
-            Yet another copy of the test matrix A, modified by ZGEES.   
+/*  HT      (workspace) COMPLEX*16 array, dimension (LDA, max(NN)) */
+/*          Yet another copy of the test matrix A, modified by ZGEES. */
 
-    W       (workspace) COMPLEX*16 array, dimension (max(NN))   
-            The computed eigenvalues of A.   
+/*  W       (workspace) COMPLEX*16 array, dimension (max(NN)) */
+/*          The computed eigenvalues of A. */
 
-    WT      (workspace) COMPLEX*16 array, dimension (max(NN))   
-            Like W, this array contains the eigenvalues of A,   
-            but those computed when ZGEES only computes a partial   
-            eigendecomposition, i.e. not Schur vectors   
+/*  WT      (workspace) COMPLEX*16 array, dimension (max(NN)) */
+/*          Like W, this array contains the eigenvalues of A, */
+/*          but those computed when ZGEES only computes a partial */
+/*          eigendecomposition, i.e. not Schur vectors */
 
-    VS      (workspace) COMPLEX*16 array, dimension (LDVS, max(NN))   
-            VS holds the computed Schur vectors.   
+/*  VS      (workspace) COMPLEX*16 array, dimension (LDVS, max(NN)) */
+/*          VS holds the computed Schur vectors. */
 
-    LDVS    (input) INTEGER   
-            Leading dimension of VS. Must be at least max(1,max(NN)).   
+/*  LDVS    (input) INTEGER */
+/*          Leading dimension of VS. Must be at least max(1,max(NN)). */
 
-    RESULT  (output) DOUBLE PRECISION array, dimension (13)   
-            The values computed by the 13 tests described above.   
-            The values are currently limited to 1/ulp, to avoid overflow.   
+/*  RESULT  (output) DOUBLE PRECISION array, dimension (13) */
+/*          The values computed by the 13 tests described above. */
+/*          The values are currently limited to 1/ulp, to avoid overflow. */
 
-    WORK    (workspace) COMPLEX*16 array, dimension (NWORK)   
+/*  WORK    (workspace) COMPLEX*16 array, dimension (NWORK) */
 
-    NWORK   (input) INTEGER   
-            The number of entries in WORK.  This must be at least   
-            5*NN(j)+2*NN(j)**2 for all j.   
+/*  NWORK   (input) INTEGER */
+/*          The number of entries in WORK.  This must be at least */
+/*          5*NN(j)+2*NN(j)**2 for all j. */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (max(NN))   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (max(NN)) */
 
-    IWORK   (workspace) INTEGER array, dimension (max(NN))   
+/*  IWORK   (workspace) INTEGER array, dimension (max(NN)) */
 
-    INFO    (output) INTEGER   
-            If 0, then everything ran OK.   
-             -1: NSIZES < 0   
-             -2: Some NN(j) < 0   
-             -3: NTYPES < 0   
-             -6: THRESH < 0   
-             -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ).   
-            -15: LDVS < 1 or LDVS < NMAX, where NMAX is max( NN(j) ).   
-            -18: NWORK too small.   
-            If  ZLATMR, CLATMS, CLATME or ZGEES returns an error code,   
-                the absolute value of it is returned.   
+/*  INFO    (output) INTEGER */
+/*          If 0, then everything ran OK. */
+/*           -1: NSIZES < 0 */
+/*           -2: Some NN(j) < 0 */
+/*           -3: NTYPES < 0 */
+/*           -6: THRESH < 0 */
+/*           -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ). */
+/*          -15: LDVS < 1 or LDVS < NMAX, where NMAX is max( NN(j) ). */
+/*          -18: NWORK too small. */
+/*          If  ZLATMR, CLATMS, CLATME or ZGEES returns an error code, */
+/*              the absolute value of it is returned. */
 
-   -----------------------------------------------------------------------   
+/* ----------------------------------------------------------------------- */
 
-       Some Local Variables and Parameters:   
-       ---- ----- --------- --- ----------   
-       ZERO, ONE       Real 0 and 1.   
-       MAXTYP          The number of types defined.   
-       NMAX            Largest value in NN.   
-       NERRS           The number of tests which have exceeded THRESH   
-       COND, CONDS,   
-       IMODE           Values to be passed to the matrix generators.   
-       ANORM           Norm of A; passed to matrix generators.   
+/*     Some Local Variables and Parameters: */
+/*     ---- ----- --------- --- ---------- */
+/*     ZERO, ONE       Real 0 and 1. */
+/*     MAXTYP          The number of types defined. */
+/*     NMAX            Largest value in NN. */
+/*     NERRS           The number of tests which have exceeded THRESH */
+/*     COND, CONDS, */
+/*     IMODE           Values to be passed to the matrix generators. */
+/*     ANORM           Norm of A; passed to matrix generators. */
 
-       OVFL, UNFL      Overflow and underflow thresholds.   
-       ULP, ULPINV     Finest relative precision and its inverse.   
-       RTULP, RTULPI   Square roots of the previous 4 values.   
-               The following four arrays decode JTYPE:   
-       KTYPE(j)        The general type (1-10) for type "j".   
-       KMODE(j)        The MODE value to be passed to the matrix   
-                       generator for type "j".   
-       KMAGN(j)        The order of magnitude ( O(1),   
-                       O(overflow^(1/2) ), O(underflow^(1/2) )   
-       KCONDS(j)       Select whether CONDS is to be 1 or   
-                       1/sqrt(ulp).  (0 means irrelevant.)   
+/*     OVFL, UNFL      Overflow and underflow thresholds. */
+/*     ULP, ULPINV     Finest relative precision and its inverse. */
+/*     RTULP, RTULPI   Square roots of the previous 4 values. */
+/*             The following four arrays decode JTYPE: */
+/*     KTYPE(j)        The general type (1-10) for type "j". */
+/*     KMODE(j)        The MODE value to be passed to the matrix */
+/*                     generator for type "j". */
+/*     KMAGN(j)        The order of magnitude ( O(1), */
+/*                     O(overflow^(1/2) ), O(underflow^(1/2) ) */
+/*     KCONDS(j)       Select whether CONDS is to be 1 or */
+/*                     1/sqrt(ulp).  (0 means irrelevant.) */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. Arrays in Common .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --nn;
     --dotype;
     --iseed;
@@ -473,6 +484,8 @@ static integer c__2 = 2;
     --bwork;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Zomplex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "ES", (ftnlen)2, (ftnlen)2);
@@ -571,21 +584,21 @@ static integer c__2 = 2;
 /* L20: */
 	    }
 
-/*           Compute "A"   
+/*           Compute "A" */
 
-             Control parameters:   
+/*           Control parameters: */
 
-             KMAGN  KCONDS  KMODE        KTYPE   
-         =1  O(1)   1       clustered 1  zero   
-         =2  large  large   clustered 2  identity   
-         =3  small          exponential  Jordan   
-         =4                 arithmetic   diagonal, (w/ eigenvalues)   
-         =5                 random log   symmetric, w/ eigenvalues   
-         =6                 random       general, w/ eigenvalues   
-         =7                              random diagonal   
-         =8                              random symmetric   
-         =9                              random general   
-         =10                             random triangular */
+/*           KMAGN  KCONDS  KMODE        KTYPE */
+/*       =1  O(1)   1       clustered 1  zero */
+/*       =2  large  large   clustered 2  identity */
+/*       =3  small          exponential  Jordan */
+/*       =4                 arithmetic   diagonal, (w/ eigenvalues) */
+/*       =5                 random log   symmetric, w/ eigenvalues */
+/*       =6                 random       general, w/ eigenvalues */
+/*       =7                              random diagonal */
+/*       =8                              random symmetric */
+/*       =9                              random general */
+/*       =10                             random triangular */
 
 	    if (mtypes > 21) {
 		goto L90;
@@ -660,7 +673,7 @@ L60:
 
 /*              Diagonal Matrix, [Eigen]values Specified */
 
-		zlatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond,
+		zlatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond, 
 			 &anorm, &c__0, &c__0, "N", &a[a_offset], lda, &work[
 			n + 1], &iinfo);
 
@@ -668,8 +681,8 @@ L60:
 
 /*              Symmetric, eigenvalues specified */
 
-		zlatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond,
-			 &anorm, &n, &n, "N", &a[a_offset], lda, &work[n + 1],
+		zlatms_(&n, &n, "S", &iseed[1], "H", &rwork[1], &imode, &cond, 
+			 &anorm, &n, &n, "N", &a[a_offset], lda, &work[n + 1], 
 			 &iinfo);
 
 	    } else if (itype == 6) {
@@ -723,7 +736,7 @@ L60:
 			    lda);
 		    i__3 = n - 3;
 		    zlaset_("Full", &i__3, &c__1, &c_b1, &c_b1, &a[a_dim1 + 3]
-			    , lda);
+, lda);
 		    i__3 = n - 3;
 		    zlaset_("Full", &i__3, &c__2, &c_b1, &c_b1, &a[(n - 1) * 
 			    a_dim1 + 3], lda);
@@ -831,9 +844,9 @@ L90:
 /* L120: */
 		    }
 
-/*                 Do Tests (2) and (3) or Tests (8) and (9)   
+/*                 Do Tests (2) and (3) or Tests (8) and (9) */
 
-   Computing MAX */
+/* Computing MAX */
 		    i__3 = 1, i__4 = (n << 1) * n;
 		    lwork = max(i__3,i__4);
 		    zhst01_(&n, &c__1, &n, &a[a_offset], lda, &h__[h_offset], 
@@ -920,7 +933,9 @@ L90:
 			    if (zslect_(&w[i__])) {
 				++knteig;
 			    }
-			    if (i__ < n) { 				if (zslect_(&w[i__ + 1]) && ! zslect_(&w[i__]) 					) {
+			    if (i__ < n) {
+				if (zslect_(&w[i__ + 1]) && ! zslect_(&w[i__])
+					) {
 				    result[13] = ulpinv;
 				}
 			    }
