@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zerrgg.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -60,27 +48,27 @@ static integer c__5 = 5;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublecomplex a[9]	/* was [3][3] */, b[9]	/* was [3][3] */;
-    static integer i__, j, m;
-    static doublecomplex q[9]	/* was [3][3] */, u[9]	/* was [3][3] */, v[9]
-	    	/* was [3][3] */, w[18], z__[9]	/* was [3][3] */;
-    static char c2[2];
-    static doublereal r1[3], r2[3];
-    static logical bw[3];
-    static doublereal ls[3];
-    static integer iw[18], nt;
-    static doublereal rs[3], rw[18], dif, rce[3];
-    static logical sel[3];
-    static doublecomplex tau[3];
-    static doublereal rcv[3];
-    static doublecomplex beta[3];
-    static integer info, sdim;
-    static doublereal anrm, bnrm, tola, tolb;
-    static integer ifst, ilst;
-    static doublecomplex alpha[3];
-    static doublereal scale;
+    doublecomplex a[9]	/* was [3][3] */, b[9]	/* was [3][3] */;
+    integer i__, j, m;
+    doublecomplex q[9]	/* was [3][3] */, u[9]	/* was [3][3] */, v[9]	/* 
+	    was [3][3] */, w[18], z__[9]	/* was [3][3] */;
+    char c2[2];
+    doublereal r1[3], r2[3];
+    logical bw[3];
+    doublereal ls[3];
+    integer iw[18], nt;
+    doublereal rs[3], rw[18], dif, rce[3];
+    logical sel[3];
+    doublecomplex tau[3];
+    doublereal rcv[3];
+    doublecomplex beta[3];
+    integer info, sdim;
+    doublereal anrm, bnrm, tola, tolb;
+    integer ifst, ilst;
+    doublecomplex alpha[3];
+    doublereal scale;
     extern /* Subroutine */ int zgges_(char *, char *, char *, L_fp, integer *
-	    , doublecomplex *, integer *, doublecomplex *, integer *, integer 
+, doublecomplex *, integer *, doublecomplex *, integer *, integer 
 	    *, doublecomplex *, doublecomplex *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, logical *, integer *), 
@@ -88,19 +76,19 @@ static integer c__5 = 5;
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, integer *);
-    static integer ncycle;
+    integer ncycle;
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int chkxer_(char *, integer *, integer *, logical 
 	    *, logical *), zgghrd_(char *, char *, integer *, integer 
 	    *, integer *, doublecomplex *, integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     integer *), zggglm_(integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex 
-	    *, integer *, integer *), zgglse_(integer *, integer *, integer *,
+	    *, integer *, integer *), zgglse_(integer *, integer *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , integer *, integer *), zggqrf_(integer *, integer *, integer *, 
+, integer *, integer *), zggqrf_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *, integer *)
 	    , zggrqf_(integer *, integer *, integer *, doublecomplex *, 
@@ -108,20 +96,20 @@ static integer c__5 = 5;
 	    doublecomplex *, doublecomplex *, integer *, integer *), ztgevc_(
 	    char *, char *, logical *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublecomplex *, integer *, integer *, integer *, doublecomplex *,
+	    doublecomplex *, integer *, integer *, integer *, doublecomplex *, 
 	     doublereal *, integer *);
     extern logical zlctes_();
     extern /* Subroutine */ int zggsvd_(char *, char *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublereal *, 
 	    integer *, integer *);
-    static integer dummyk, dummyl;
+    integer dummyk, dummyl;
     extern /* Subroutine */ int zggesx_(char *, char *, char *, L_fp, char *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublecomplex *, integer *, doublereal *, integer *, integer *, 
 	    logical *, integer *), zhgeqz_(
 	    char *, char *, char *, integer *, integer *, integer *, 
@@ -131,28 +119,28 @@ static integer c__5 = 5;
 	    doublereal *, integer *), zggevx_(char *, 
 	    char *, char *, char *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
-	    doublecomplex *, integer *, doublecomplex *, integer *, integer *,
+	    doublecomplex *, integer *, doublecomplex *, integer *, integer *, 
 	     integer *, doublereal *, doublereal *, doublereal *, doublereal *
-	    , doublereal *, doublereal *, doublecomplex *, integer *, 
+, doublereal *, doublereal *, doublecomplex *, integer *, 
 	    doublereal *, integer *, logical *, integer *), ztgexc_(logical *, logical *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublecomplex *, integer *, doublecomplex *, integer *, integer *,
+	    doublecomplex *, integer *, doublecomplex *, integer *, integer *, 
 	     integer *, integer *), ztgsen_(integer *, logical *, logical *, 
-	    logical *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    logical *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, integer *, doublereal *, 
-	    doublereal *, doublereal *, doublecomplex *, integer *, integer *,
-	     integer *, integer *), ztgsja_(char *, char *, char *, integer *,
+	    doublereal *, doublereal *, doublecomplex *, integer *, integer *, 
+	     integer *, integer *), ztgsja_(char *, char *, char *, integer *, 
 	     integer *, integer *, integer *, integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, integer *), 
 	    ztgsna_(char *, char *, logical *, integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, doublereal *, doublereal *, integer *
-	    , integer *, doublecomplex *, integer *, integer *, integer *), zggsvp_(char *, char *, char *, integer *, 
-	    integer *, integer *, doublecomplex *, integer *, doublecomplex *,
+, integer *, doublecomplex *, integer *, integer *, integer *), zggsvp_(char *, char *, char *, integer *, 
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, doublereal *, doublereal *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, integer *, doublereal *, 
@@ -162,7 +150,7 @@ static integer c__5 = 5;
 	    *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublereal *, doublereal *, doublecomplex *, integer *, integer *,
+	    doublereal *, doublereal *, doublecomplex *, integer *, integer *, 
 	     integer *);
 
     /* Fortran I/O blocks */
@@ -172,29 +160,46 @@ static integer c__5 = 5;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZERRGG tests the error exits for ZGGES, ZGGESX, ZGGEV, ZGGEVX,   
-    ZGGGLM, ZGGHRD, ZGGLSE, ZGGQRF, ZGGRQF, ZGGSVD, ZGGSVP, ZHGEQZ,   
-    ZTGEVC, ZTGEXC, ZTGSEN, ZTGSJA, ZTGSNA, and ZTGSYL.   
+/*  ZERRGG tests the error exits for ZGGES, ZGGESX, ZGGEV, ZGGEVX, */
+/*  ZGGGLM, ZGGHRD, ZGGLSE, ZGGQRF, ZGGRQF, ZGGSVD, ZGGSVP, ZHGEQZ, */
+/*  ZTGEVC, ZTGEXC, ZTGSEN, ZTGSJA, ZTGSNA, and ZTGSYL. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -287,52 +292,52 @@ static integer c__5 = 5;
 
 	s_copy(srnamc_1.srnamt, "ZHGEQZ", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	zhgeqz_("/", "N", "N", &c__0, &c__1, &c__0, a, &c__1, b, &c__1, alpha,
+	zhgeqz_("/", "N", "N", &c__0, &c__1, &c__0, a, &c__1, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	zhgeqz_("E", "/", "N", &c__0, &c__1, &c__0, a, &c__1, b, &c__1, alpha,
+	zhgeqz_("E", "/", "N", &c__0, &c__1, &c__0, a, &c__1, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	zhgeqz_("E", "N", "/", &c__0, &c__1, &c__0, a, &c__1, b, &c__1, alpha,
+	zhgeqz_("E", "N", "/", &c__0, &c__1, &c__0, a, &c__1, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	zhgeqz_("E", "N", "N", &c_n1, &c__0, &c__0, a, &c__1, b, &c__1, alpha,
+	zhgeqz_("E", "N", "N", &c_n1, &c__0, &c__0, a, &c__1, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	zhgeqz_("E", "N", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, alpha,
+	zhgeqz_("E", "N", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	zhgeqz_("E", "N", "N", &c__0, &c__1, &c__1, a, &c__1, b, &c__1, alpha,
+	zhgeqz_("E", "N", "N", &c__0, &c__1, &c__1, a, &c__1, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 8;
-	zhgeqz_("E", "N", "N", &c__2, &c__1, &c__1, a, &c__1, b, &c__2, alpha,
+	zhgeqz_("E", "N", "N", &c__2, &c__1, &c__1, a, &c__1, b, &c__2, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 10;
-	zhgeqz_("E", "N", "N", &c__2, &c__1, &c__1, a, &c__2, b, &c__1, alpha,
+	zhgeqz_("E", "N", "N", &c__2, &c__1, &c__1, a, &c__2, b, &c__1, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 14;
-	zhgeqz_("E", "V", "N", &c__2, &c__1, &c__1, a, &c__2, b, &c__2, alpha,
+	zhgeqz_("E", "V", "N", &c__2, &c__1, &c__1, a, &c__2, b, &c__2, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
-	zhgeqz_("E", "N", "V", &c__2, &c__1, &c__1, a, &c__2, b, &c__2, alpha,
+	zhgeqz_("E", "N", "V", &c__2, &c__1, &c__1, a, &c__2, b, &c__2, alpha, 
 		 beta, q, &c__1, z__, &c__1, w, &c__1, rw, &info);
 	chkxer_("ZHGEQZ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -462,67 +467,67 @@ static integer c__5 = 5;
 
 	s_copy(srnamc_1.srnamt, "ZGGSVP", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	zggsvp_("/", "N", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	zggsvp_("/", "N", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	zggsvp_("N", "/", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "/", "N", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	zggsvp_("N", "N", "/", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "N", "/", &c__0, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	zggsvp_("N", "N", "N", &c_n1, &c__0, &c__0, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "N", "N", &c_n1, &c__0, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	zggsvp_("N", "N", "N", &c__0, &c_n1, &c__0, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "N", "N", &c__0, &c_n1, &c__0, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	zggsvp_("N", "N", "N", &c__0, &c__0, &c_n1, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "N", "N", &c__0, &c__0, &c_n1, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 8;
-	zggsvp_("N", "N", "N", &c__2, &c__1, &c__1, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "N", "N", &c__2, &c__1, &c__1, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 10;
-	zggsvp_("N", "N", "N", &c__1, &c__2, &c__1, a, &c__1, b, &c__1, &tola,
+	zggsvp_("N", "N", "N", &c__1, &c__2, &c__1, a, &c__1, b, &c__1, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
-	zggsvp_("U", "N", "N", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola,
+	zggsvp_("U", "N", "N", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__1, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 18;
-	zggsvp_("N", "V", "N", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola,
+	zggsvp_("N", "V", "N", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__2, v, &c__1, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 20;
-	zggsvp_("N", "N", "Q", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola,
+	zggsvp_("N", "N", "Q", &c__2, &c__2, &c__2, a, &c__2, b, &c__2, &tola, 
 		 &tolb, &dummyk, &dummyl, u, &c__2, v, &c__2, q, &c__1, iw, 
 		rw, tau, w, &info);
 	chkxer_("ZGGSVP", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
@@ -782,57 +787,57 @@ static integer c__5 = 5;
 
 	s_copy(srnamc_1.srnamt, "ZGGES ", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	zgges_("/", "N", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	zgges_("/", "N", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	zgges_("N", "/", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	zgges_("N", "/", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	zgges_("N", "V", "/", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	zgges_("N", "V", "/", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	zgges_("N", "V", "S", (L_fp)zlctes_, &c_n1, a, &c__1, b, &c__1, &sdim,
+	zgges_("N", "V", "S", (L_fp)zlctes_, &c_n1, a, &c__1, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 7;
-	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__0, b, &c__1, &sdim,
+	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__0, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
-	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__0, &sdim,
+	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__0, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 14;
-	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__0, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 14;
-	zgges_("V", "V", "S", (L_fp)zlctes_, &c__2, a, &c__2, b, &c__2, &sdim,
+	zgges_("V", "V", "S", (L_fp)zlctes_, &c__2, a, &c__2, b, &c__2, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__2, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
-	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim,
+	zgges_("N", "V", "S", (L_fp)zlctes_, &c__1, a, &c__1, b, &c__1, &sdim, 
 		 alpha, beta, q, &c__1, u, &c__0, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 16;
-	zgges_("V", "V", "S", (L_fp)zlctes_, &c__2, a, &c__2, b, &c__2, &sdim,
+	zgges_("V", "V", "S", (L_fp)zlctes_, &c__2, a, &c__2, b, &c__2, &sdim, 
 		 alpha, beta, q, &c__2, u, &c__1, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 18;
-	zgges_("V", "V", "S", (L_fp)zlctes_, &c__2, a, &c__2, b, &c__2, &sdim,
+	zgges_("V", "V", "S", (L_fp)zlctes_, &c__2, a, &c__2, b, &c__2, &sdim, 
 		 alpha, beta, q, &c__2, u, &c__2, w, &c__1, rw, bw, &info);
 	chkxer_("ZGGES ", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -980,73 +985,73 @@ static integer c__5 = 5;
 
 	s_copy(srnamc_1.srnamt, "ZGGEVX", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	zggevx_("/", "N", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("/", "N", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	zggevx_("N", "/", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("N", "/", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	zggevx_("N", "N", "/", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("N", "N", "/", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	zggevx_("N", "N", "N", "/", &c__1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("N", "N", "N", "/", &c__1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	zggevx_("N", "N", "N", "N", &c_n1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("N", "N", "N", "N", &c_n1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 7;
-	zggevx_("N", "N", "N", "N", &c__1, a, &c__0, b, &c__1, alpha, beta, q,
+	zggevx_("N", "N", "N", "N", &c__1, a, &c__0, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
-	zggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__0, alpha, beta, q,
+	zggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__0, alpha, beta, q, 
 		 &c__1, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	zggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__0, u, &c__1, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	zggevx_("N", "V", "N", "N", &c__2, a, &c__2, b, &c__2, alpha, beta, q,
+	zggevx_("N", "V", "N", "N", &c__2, a, &c__2, b, &c__2, alpha, beta, q, 
 		 &c__1, u, &c__2, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	zggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q,
+	zggevx_("N", "N", "N", "N", &c__1, a, &c__1, b, &c__1, alpha, beta, q, 
 		 &c__1, u, &c__0, &c__1, &c__1, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	zggevx_("N", "N", "V", "N", &c__2, a, &c__2, b, &c__2, alpha, beta, q,
+	zggevx_("N", "N", "V", "N", &c__2, a, &c__2, b, &c__2, alpha, beta, q, 
 		 &c__2, u, &c__1, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__1, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 25;
-	zggevx_("N", "N", "V", "N", &c__2, a, &c__2, b, &c__2, alpha, beta, q,
+	zggevx_("N", "N", "V", "N", &c__2, a, &c__2, b, &c__2, alpha, beta, q, 
 		 &c__2, u, &c__2, &c__1, &c__2, ls, rs, &anrm, &bnrm, rce, 
 		rcv, w, &c__0, rw, iw, bw, &info);
 	chkxer_("ZGGEVX", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
