@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zerrhs.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -55,43 +43,43 @@ static integer c__4 = 4;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublecomplex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] 
-	    */;
-    static integer i__, j, m;
-    static doublereal s[3];
-    static doublecomplex w[9], x[3];
-    static char c2[2];
-    static integer nt;
-    static doublecomplex vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */;
-    static doublereal rw[3];
-    static integer ihi, ilo;
-    static logical sel[3];
-    static doublecomplex tau[3];
-    static integer info, ifaill[3];
+    doublecomplex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
+    integer i__, j, m;
+    doublereal s[3];
+    doublecomplex w[9], x[3];
+    char c2[2];
+    integer nt;
+    doublecomplex vl[9]	/* was [3][3] */, vr[9]	/* was [3][3] */;
+    doublereal rw[3];
+    integer ihi, ilo;
+    logical sel[3];
+    doublecomplex tau[3];
+    integer info, ifaill[3];
     extern /* Subroutine */ int zgebak_(char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublecomplex *, integer *, 
 	    integer *), zgebal_(char *, integer *, 
 	    doublecomplex *, integer *, integer *, integer *, doublereal *, 
 	    integer *);
-    static integer ifailr[3];
+    integer ifailr[3];
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int zgehrd_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
-	    integer *, integer *), chkxer_(char *, integer *, integer *,	    logical *, logical *), zhsein_(char *, char *, char *, 
-	    logical *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    integer *, integer *), chkxer_(char *, integer *, integer *, 
+	    logical *, logical *), zhsein_(char *, char *, char *, 
+	    logical *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, integer *
-	    , integer *, doublecomplex *, doublereal *, integer *, integer *, 
+, integer *, doublecomplex *, doublereal *, integer *, integer *, 
 	    integer *), zhseqr_(char *, char *, 
 	    integer *, integer *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, integer *), ztrevc_(char *, char *, 
-	    logical *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    logical *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, integer *, integer *, integer *, 
 	    doublecomplex *, doublereal *, integer *), 
 	    zunghr_(integer *, integer *, integer *, doublecomplex *, integer 
 	    *, doublecomplex *, doublecomplex *, integer *, integer *), 
 	    zunmhr_(char *, char *, integer *, integer *, integer *, integer *
-	    , doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
+, doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, integer *);
 
     /* Fortran I/O blocks */
@@ -101,28 +89,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZERRHS tests the error exits for ZGEBAK, CGEBAL, CGEHRD, ZUNGHR,   
-    ZUNMHR, ZHSEQR, CHSEIN, and ZTREVC.   
+/*  ZERRHS tests the error exits for ZGEBAK, CGEBAL, CGEHRD, ZUNGHR, */
+/*  ZUNMHR, ZHSEQR, CHSEIN, and ZTREVC. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
