@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zerrst.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -64,24 +52,23 @@ static doublereal c_b472 = 1.;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublecomplex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] 
-	    */;
-    static doublereal d__[3], e[3];
-    static integer i__, j, m, n;
-    static doublecomplex q[9]	/* was [3][3] */;
-    static doublereal r__[60];
-    static doublecomplex w[60];
-    static doublereal x[3];
-    static doublecomplex z__[9]	/* was [3][3] */;
-    static char c2[2];
-    static integer i1[3], i2[3], i3[3], iw[36], nt;
-    static doublereal rw[60];
-    static doublecomplex tau[3];
-    static integer info;
+    doublecomplex a[9]	/* was [3][3] */, c__[9]	/* was [3][3] */;
+    doublereal d__[3], e[3];
+    integer i__, j, m, n;
+    doublecomplex q[9]	/* was [3][3] */;
+    doublereal r__[60];
+    doublecomplex w[60];
+    doublereal x[3];
+    doublecomplex z__[9]	/* was [3][3] */;
+    char c2[2];
+    integer i1[3], i2[3], i3[3], iw[36], nt;
+    doublereal rw[60];
+    doublecomplex tau[3];
+    integer info;
     extern /* Subroutine */ int zhbev_(char *, char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublecomplex *, 
 	    integer *, doublecomplex *, doublereal *, integer *), zheev_(char *, char *, integer *, doublecomplex *, 
-	    integer *, doublereal *, doublecomplex *, integer *, doublereal *,
+	    integer *, doublereal *, doublecomplex *, integer *, doublereal *, 
 	     integer *), zhpev_(char *, char *, integer *, 
 	    doublecomplex *, doublereal *, doublecomplex *, integer *, 
 	    doublecomplex *, doublereal *, integer *);
@@ -89,14 +76,15 @@ static doublereal c_b472 = 1.;
     extern /* Subroutine */ int zhbevd_(char *, char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublereal *, integer *, 
-	    integer *, integer *, integer *), chkxer_(char *,	    integer *, integer *, logical *, logical *), zheevd_(char 
+	    integer *, integer *, integer *), chkxer_(char *, 
+	    integer *, integer *, logical *, logical *), zheevd_(char 
 	    *, char *, integer *, doublecomplex *, integer *, doublereal *, 
 	    doublecomplex *, integer *, doublereal *, integer *, integer *, 
 	    integer *, integer *), zstedc_(char *, integer *, 
 	    doublereal *, doublereal *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, integer *, integer *, 
 	    integer *, integer *), zhbtrd_(char *, char *, integer *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *), zhetrd_(char *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublecomplex *, doublecomplex *, 
 	    integer *, integer *), zhpevd_(char *, char *, integer *, 
@@ -109,21 +97,21 @@ static doublereal c_b472 = 1.;
 	    doublecomplex *, integer *, doublereal *, integer *, integer *, 
 	    integer *, integer *), zhbevx_(char *, 
 	    char *, char *, integer *, integer *, doublecomplex *, integer *, 
-	    doublecomplex *, integer *, doublereal *, doublereal *, integer *,
+	    doublecomplex *, integer *, doublereal *, doublereal *, integer *, 
 	     integer *, doublereal *, integer *, doublereal *, doublecomplex *
-	    , integer *, doublecomplex *, doublereal *, integer *, integer *, 
+, integer *, doublecomplex *, doublereal *, integer *, integer *, 
 	    integer *), zheevx_(char *, char *, char *
-	    , integer *, doublecomplex *, integer *, doublereal *, doublereal 
+, integer *, doublecomplex *, integer *, doublereal *, doublereal 
 	    *, integer *, integer *, doublereal *, integer *, doublereal *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublereal *, integer *, integer *, integer *), zhptrd_(char *, integer *, doublecomplex *, doublereal *,
+	    doublereal *, integer *, integer *, integer *), zhptrd_(char *, integer *, doublecomplex *, doublereal *, 
 	     doublereal *, doublecomplex *, integer *), zstein_(
 	    integer *, doublereal *, doublereal *, integer *, doublereal *, 
 	    integer *, integer *, doublecomplex *, integer *, doublereal *, 
 	    integer *, integer *, integer *), zhpevx_(char *, char *, char *, 
-	    integer *, doublecomplex *, doublereal *, doublereal *, integer *,
+	    integer *, doublecomplex *, doublereal *, doublereal *, integer *, 
 	     integer *, doublereal *, integer *, doublereal *, doublecomplex *
-	    , integer *, doublecomplex *, doublereal *, integer *, integer *, 
+, integer *, doublecomplex *, doublereal *, integer *, integer *, 
 	    integer *), zpteqr_(char *, integer *, 
 	    doublereal *, doublereal *, doublecomplex *, integer *, 
 	    doublereal *, integer *), zsteqr_(char *, integer *, 
@@ -147,30 +135,49 @@ static doublereal c_b472 = 1.;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZERRST tests the error exits for ZHETRD, ZUNGTR, CUNMTR, ZHPTRD,   
-    ZUNGTR, ZUPMTR, ZSTEQR, CSTEIN, ZPTEQR, ZHBTRD,   
-    ZHEEV, CHEEVX, CHEEVD, ZHBEV, CHBEVX, CHBEVD,   
-    ZHPEV, CHPEVX, CHPEVD, and ZSTEDC.   
+/*  ZERRST tests the error exits for ZHETRD, ZUNGTR, CUNMTR, ZHPTRD, */
+/*  ZUNGTR, ZUPMTR, ZSTEQR, CSTEIN, ZPTEQR, ZHBTRD, */
+/*  ZHEEV, CHEEVX, CHEEVD, ZHBEV, CHBEVX, CHBEVD, */
+/*  ZHPEV, CHPEVX, CHPEVD, and ZSTEDC. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -921,77 +928,77 @@ static doublereal c_b472 = 1.;
 
 	s_copy(srnamc_1.srnamt, "ZHBEVD", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	zhbevd_("/", "U", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	zhbevd_("/", "U", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	zhbevd_("N", "/", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	zhbevd_("N", "/", &c__0, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	zhbevd_("N", "U", &c_n1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	zhbevd_("N", "U", &c_n1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	zhbevd_("N", "U", &c__0, &c_n1, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	zhbevd_("N", "U", &c__0, &c_n1, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	zhbevd_("N", "U", &c__2, &c__1, a, &c__1, x, z__, &c__1, w, &c__2, rw,
+	zhbevd_("N", "U", &c__2, &c__1, a, &c__1, x, z__, &c__1, w, &c__2, rw, 
 		 &c__2, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
-	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__1, w, &c__8, rw,
+	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__1, w, &c__8, rw, 
 		 &c__25, iw, &c__12, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	zhbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__0, rw,
+	zhbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__0, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	zhbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__1, rw,
+	zhbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__1, rw, 
 		 &c__2, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw,
+	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw, 
 		 &c__25, iw, &c__12, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	zhbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	zhbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__0, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	zhbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw,
+	zhbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw, 
 		 &c__1, iw, &c__1, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 13;
-	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw,
+	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw, 
 		 &c__2, iw, &c__12, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	zhbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw,
+	zhbevd_("N", "U", &c__1, &c__0, a, &c__1, x, z__, &c__1, w, &c__1, rw, 
 		 &c__1, iw, &c__0, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	zhbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw,
+	zhbevd_("N", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__2, rw, 
 		 &c__2, iw, &c__0, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 15;
-	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw,
+	zhbevd_("V", "U", &c__2, &c__1, a, &c__2, x, z__, &c__2, w, &c__8, rw, 
 		 &c__25, iw, &c__2, &info);
 	chkxer_("ZHBEVD", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
