@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zget37.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -37,50 +25,51 @@ static integer c__0 = 0;
     double d_imag(doublecomplex *);
 
     /* Local variables */
-    static integer i__, j, m, n;
-    static doublereal s[20];
-    static doublecomplex t[400]	/* was [20][20] */;
-    static doublereal v;
-    static doublecomplex w[20], le[400]	/* was [20][20] */, re[400]	/* 
+    integer i__, j, m, n;
+    doublereal s[20];
+    doublecomplex t[400]	/* was [20][20] */;
+    doublereal v;
+    doublecomplex w[20], le[400]	/* was [20][20] */, re[400]	/* 
 	    was [20][20] */;
-    static doublereal val[3], dum[1], eps, sep[20], sin__[20], tol;
-    static doublecomplex tmp[400]	/* was [20][20] */;
-    static integer icmp;
-    static doublecomplex cdum[1];
-    static integer iscl, info, lcmp[3], kmin;
-    static doublereal wiin[20], vmin, vmax, tnrm;
-    static integer isrt;
-    static doublereal wrin[20], vmul, stmp[20];
-    static doublecomplex work[1200], wtmp[20];
-    static doublereal wsrt[20];
+    doublereal val[3], dum[1], eps, sep[20], sin__[20], tol;
+    doublecomplex tmp[400]	/* was [20][20] */;
+    integer icmp;
+    doublecomplex cdum[1];
+    integer iscl, info, lcmp[3], kmin;
+    doublereal wiin[20], vmin, vmax, tnrm;
+    integer isrt;
+    doublereal wrin[20], vmul, stmp[20];
+    doublecomplex work[1200], wtmp[20];
+    doublereal wsrt[20];
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
-    static doublereal vcmin, sepin[20];
+    doublereal vcmin, sepin[20];
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static doublereal tolin, rwork[40];
+    doublereal tolin, rwork[40];
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *);
-    static logical select[20];
+    logical select[20];
     extern doublereal zlange_(char *, integer *, integer *, doublecomplex *, 
 	    integer *, doublereal *);
-    static doublereal bignum;
+    doublereal bignum;
     extern /* Subroutine */ int zdscal_(integer *, doublereal *, 
 	    doublecomplex *, integer *), zgehrd_(integer *, integer *, 
 	    integer *, doublecomplex *, integer *, doublecomplex *, 
-	    doublecomplex *, integer *, integer *), zlacpy_(char *, integer *,
-	     integer *, doublecomplex *, integer *, doublecomplex *, integer * );
-    static doublereal septmp[20], smlnum;
+	    doublecomplex *, integer *, integer *), zlacpy_(char *, integer *, 
+	     integer *, doublecomplex *, integer *, doublecomplex *, integer *
+);
+    doublereal septmp[20], smlnum;
     extern /* Subroutine */ int zhseqr_(char *, char *, integer *, integer *, 
 	    integer *, doublecomplex *, integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, integer *), ztrevc_(char *, char *, logical *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublecomplex *, integer *, integer *, integer *, doublecomplex *,
-	     doublereal *, integer *), ztrsna_(char *, char *,
+	    doublecomplex *, integer *, integer *, integer *, doublecomplex *, 
+	     doublereal *, integer *), ztrsna_(char *, char *, 
 	     logical *, integer *, doublecomplex *, integer *, doublecomplex *
-	    , integer *, doublecomplex *, integer *, doublereal *, doublereal 
-	    *, integer *, integer *, doublecomplex *, integer *, doublereal *,
+, integer *, doublecomplex *, integer *, doublereal *, doublereal 
+	    *, integer *, integer *, doublecomplex *, integer *, doublereal *, 
 	     integer *);
 
     /* Fortran I/O blocks */
@@ -90,53 +79,70 @@ static integer c__0 = 0;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZGET37 tests ZTRSNA, a routine for estimating condition numbers of   
-    eigenvalues and/or right eigenvectors of a matrix.   
+/*  ZGET37 tests ZTRSNA, a routine for estimating condition numbers of */
+/*  eigenvalues and/or right eigenvectors of a matrix. */
 
-    The test matrices are read from a file with logical unit number NIN.   
+/*  The test matrices are read from a file with logical unit number NIN. */
 
-    Arguments   
-    ==========   
+/*  Arguments */
+/*  ========== */
 
-    RMAX    (output) DOUBLE PRECISION array, dimension (3)   
-            Value of the largest test ratio.   
-            RMAX(1) = largest ratio comparing different calls to ZTRSNA   
-            RMAX(2) = largest error in reciprocal condition   
-                      numbers taking their conditioning into account   
-            RMAX(3) = largest error in reciprocal condition   
-                      numbers not taking their conditioning into   
-                      account (may be larger than RMAX(2))   
+/*  RMAX    (output) DOUBLE PRECISION array, dimension (3) */
+/*          Value of the largest test ratio. */
+/*          RMAX(1) = largest ratio comparing different calls to ZTRSNA */
+/*          RMAX(2) = largest error in reciprocal condition */
+/*                    numbers taking their conditioning into account */
+/*          RMAX(3) = largest error in reciprocal condition */
+/*                    numbers not taking their conditioning into */
+/*                    account (may be larger than RMAX(2)) */
 
-    LMAX    (output) INTEGER array, dimension (3)   
-            LMAX(i) is example number where largest test ratio   
-            RMAX(i) is achieved. Also:   
-            If ZGEHRD returns INFO nonzero on example i, LMAX(1)=i   
-            If ZHSEQR returns INFO nonzero on example i, LMAX(2)=i   
-            If ZTRSNA returns INFO nonzero on example i, LMAX(3)=i   
+/*  LMAX    (output) INTEGER array, dimension (3) */
+/*          LMAX(i) is example number where largest test ratio */
+/*          RMAX(i) is achieved. Also: */
+/*          If ZGEHRD returns INFO nonzero on example i, LMAX(1)=i */
+/*          If ZHSEQR returns INFO nonzero on example i, LMAX(2)=i */
+/*          If ZTRSNA returns INFO nonzero on example i, LMAX(3)=i */
 
-    NINFO   (output) INTEGER array, dimension (3)   
-            NINFO(1) = No. of times ZGEHRD returned INFO nonzero   
-            NINFO(2) = No. of times ZHSEQR returned INFO nonzero   
-            NINFO(3) = No. of times ZTRSNA returned INFO nonzero   
+/*  NINFO   (output) INTEGER array, dimension (3) */
+/*          NINFO(1) = No. of times ZGEHRD returned INFO nonzero */
+/*          NINFO(2) = No. of times ZHSEQR returned INFO nonzero */
+/*          NINFO(3) = No. of times ZTRSNA returned INFO nonzero */
 
-    KNT     (output) INTEGER   
-            Total number of examples tested.   
+/*  KNT     (output) INTEGER */
+/*          Total number of examples tested. */
 
-    NIN     (input) INTEGER   
-            Input logical unit number   
+/*  NIN     (input) INTEGER */
+/*          Input logical unit number */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --ninfo;
     --lmax;
     --rmax;
@@ -164,9 +170,9 @@ static integer c__0 = 0;
     val[1] = 1.;
     val[2] = sqrt(bignum);
 
-/*     Read input data until N=0.  Assume input eigenvalues are sorted   
-       lexicographically (increasing by real part if ISRT = 0,   
-       increasing by imaginary part if ISRT = 1) */
+/*     Read input data until N=0.  Assume input eigenvalues are sorted */
+/*     lexicographically (increasing by real part if ISRT = 0, */
+/*     increasing by imaginary part if ISRT = 1) */
 
 L10:
     io___5.ciunit = *nin;
@@ -271,8 +277,8 @@ L10:
 	    goto L260;
 	}
 
-/*        Sort eigenvalues and condition numbers lexicographically   
-          to compare with inputs */
+/*        Sort eigenvalues and condition numbers lexicographically */
+/*        to compare with inputs */
 
 	zcopy_(&n, w, &c__1, wtmp, &c__1);
 	if (isrt == 0) {
@@ -329,10 +335,10 @@ L10:
 /* L110: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          taking their condition numbers into account   
+/*        Compare condition numbers for eigenvalues */
+/*        taking their condition numbers into account */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = (doublereal) n * 2. * eps * tnrm;
 	v = max(d__1,smlnum);
 	if (tnrm == 0.) {
@@ -376,8 +382,8 @@ L10:
 /* L120: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -418,8 +424,8 @@ L10:
 /* L130: */
 	}
 
-/*        Compare condition numbers for eigenvalues   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvalues */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -446,8 +452,8 @@ L10:
 /* L140: */
 	}
 
-/*        Compare condition numbers for eigenvectors   
-          without taking their condition numbers into account */
+/*        Compare condition numbers for eigenvectors */
+/*        without taking their condition numbers into account */
 
 	i__1 = n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -479,7 +485,7 @@ L10:
 	dum[0] = -1.;
 	dcopy_(&n, dum, &c__0, stmp, &c__1);
 	dcopy_(&n, dum, &c__0, septmp, &c__1);
-	ztrsna_("E", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("E", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -502,7 +508,7 @@ L10:
 
 	dcopy_(&n, dum, &c__0, stmp, &c__1);
 	dcopy_(&n, dum, &c__0, septmp, &c__1);
-	ztrsna_("V", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("V", "A", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -530,7 +536,7 @@ L10:
 	}
 	dcopy_(&n, dum, &c__0, stmp, &c__1);
 	dcopy_(&n, dum, &c__0, septmp, &c__1);
-	ztrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -553,7 +559,7 @@ L10:
 
 	dcopy_(&n, dum, &c__0, stmp, &c__1);
 	dcopy_(&n, dum, &c__0, septmp, &c__1);
-	ztrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -576,7 +582,7 @@ L10:
 
 	dcopy_(&n, dum, &c__0, stmp, &c__1);
 	dcopy_(&n, dum, &c__0, septmp, &c__1);
-	ztrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -628,7 +634,7 @@ L10:
 
 	dcopy_(&icmp, dum, &c__0, stmp, &c__1);
 	dcopy_(&icmp, dum, &c__0, septmp, &c__1);
-	ztrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("B", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -652,7 +658,7 @@ L10:
 
 	dcopy_(&icmp, dum, &c__0, stmp, &c__1);
 	dcopy_(&icmp, dum, &c__0, septmp, &c__1);
-	ztrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("E", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
@@ -676,7 +682,7 @@ L10:
 
 	dcopy_(&icmp, dum, &c__0, stmp, &c__1);
 	dcopy_(&icmp, dum, &c__0, septmp, &c__1);
-	ztrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp,
+	ztrsna_("V", "S", select, &n, t, &c__20, le, &c__20, re, &c__20, stmp, 
 		 septmp, &n, &m, work, &n, rwork, &info)
 		;
 	if (info != 0) {
