@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* aladhd.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -125,149 +113,137 @@ static integer c__7 = 7;
 	    "rm(A) * EPS )\002)";
     static char fmt_9990[] = "(/1x,a3,\002:  No header available\002)";
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* System generated locals */
+    cilist ci__1;
+
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static char c1[1], c3[1], p2[2], sym[9];
-    static logical sord, corz;
+    char c1[1], c3[1], p2[2], sym[9];
+    logical sord, corz;
     extern logical lsame_(char *, char *), lsamen_(integer *, 
 	    char *, char *);
 
     /* Fortran I/O blocks */
     static cilist io___6 = { 0, 0, 0, fmt_9999, 0 };
-    static cilist io___7 = { 0, 0, 0, "( ' Matrix types:' )", 0 };
-    static cilist io___8 = { 0, 0, 0, fmt_9989, 0 };
-    static cilist io___9 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___10 = { 0, 0, 0, fmt_9981, 0 };
-    static cilist io___11 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___12 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___13 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___14 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___15 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___16 = { 0, 0, 0, fmt_9972, 0 };
-    static cilist io___17 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___18 = { 0, 0, 0, fmt_9998, 0 };
-    static cilist io___19 = { 0, 0, 0, "( ' Matrix types:' )", 0 };
-    static cilist io___20 = { 0, 0, 0, fmt_9988, 0 };
-    static cilist io___21 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___22 = { 0, 0, 0, fmt_9981, 0 };
-    static cilist io___23 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___24 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___25 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___26 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___27 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___28 = { 0, 0, 0, fmt_9972, 0 };
-    static cilist io___29 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___30 = { 0, 0, 0, fmt_9997, 0 };
-    static cilist io___31 = { 0, 0, 0, fmt_9987, 0 };
-    static cilist io___32 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___33 = { 0, 0, 0, fmt_9981, 0 };
-    static cilist io___34 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___35 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___36 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___37 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___38 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___39 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___41 = { 0, 0, 0, fmt_9996, 0 };
-    static cilist io___42 = { 0, 0, 0, fmt_9995, 0 };
-    static cilist io___43 = { 0, 0, 0, "( ' Matrix types:' )", 0 };
-    static cilist io___44 = { 0, 0, 0, fmt_9985, 0 };
-    static cilist io___45 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___46 = { 0, 0, 0, fmt_9975, 0 };
-    static cilist io___47 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___48 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___49 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___50 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___51 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___52 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___53 = { 0, 0, 0, fmt_9994, 0 };
-    static cilist io___54 = { 0, 0, 0, fmt_9994, 0 };
-    static cilist io___55 = { 0, 0, 0, "( ' Matrix types:' )", 0 };
-    static cilist io___56 = { 0, 0, 0, fmt_9984, 0 };
-    static cilist io___57 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___58 = { 0, 0, 0, fmt_9975, 0 };
-    static cilist io___59 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___60 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___61 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___62 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___63 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___64 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___65 = { 0, 0, 0, fmt_9993, 0 };
-    static cilist io___66 = { 0, 0, 0, fmt_9993, 0 };
-    static cilist io___67 = { 0, 0, 0, fmt_9986, 0 };
-    static cilist io___68 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___69 = { 0, 0, 0, fmt_9973, 0 };
-    static cilist io___70 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___71 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___72 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___73 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___74 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___75 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___76 = { 0, 0, 0, fmt_9992, 0 };
-    static cilist io___77 = { 0, 0, 0, fmt_9991, 0 };
-    static cilist io___78 = { 0, 0, 0, "( ' Matrix types:' )", 0 };
-    static cilist io___79 = { 0, 0, 0, fmt_9983, 0 };
-    static cilist io___80 = { 0, 0, 0, fmt_9982, 0 };
-    static cilist io___81 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___82 = { 0, 0, 0, fmt_9974, 0 };
-    static cilist io___83 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___84 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___85 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___86 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___87 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___88 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___89 = { 0, 0, 0, fmt_9992, 0 };
-    static cilist io___90 = { 0, 0, 0, fmt_9991, 0 };
-    static cilist io___91 = { 0, 0, 0, "( ' Matrix types:' )", 0 };
-    static cilist io___92 = { 0, 0, 0, fmt_9983, 0 };
-    static cilist io___93 = { 0, 0, 0, "( ' Test ratios:' )", 0 };
-    static cilist io___94 = { 0, 0, 0, fmt_9974, 0 };
-    static cilist io___95 = { 0, 0, 0, fmt_9980, 0 };
-    static cilist io___96 = { 0, 0, 0, fmt_9979, 0 };
-    static cilist io___97 = { 0, 0, 0, fmt_9977, 0 };
-    static cilist io___98 = { 0, 0, 0, fmt_9978, 0 };
-    static cilist io___99 = { 0, 0, 0, fmt_9976, 0 };
-    static cilist io___100 = { 0, 0, 0, "( ' Messages:' )", 0 };
-    static cilist io___101 = { 0, 0, 0, fmt_9990, 0 };
+    static cilist io___7 = { 0, 0, 0, fmt_9989, 0 };
+    static cilist io___8 = { 0, 0, 0, fmt_9981, 0 };
+    static cilist io___9 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___10 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___11 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___12 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___13 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___14 = { 0, 0, 0, fmt_9972, 0 };
+    static cilist io___15 = { 0, 0, 0, fmt_9998, 0 };
+    static cilist io___16 = { 0, 0, 0, fmt_9988, 0 };
+    static cilist io___17 = { 0, 0, 0, fmt_9981, 0 };
+    static cilist io___18 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___19 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___20 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___21 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___22 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___23 = { 0, 0, 0, fmt_9972, 0 };
+    static cilist io___24 = { 0, 0, 0, fmt_9997, 0 };
+    static cilist io___25 = { 0, 0, 0, fmt_9987, 0 };
+    static cilist io___26 = { 0, 0, 0, fmt_9981, 0 };
+    static cilist io___27 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___28 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___29 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___30 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___31 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___33 = { 0, 0, 0, fmt_9996, 0 };
+    static cilist io___34 = { 0, 0, 0, fmt_9995, 0 };
+    static cilist io___35 = { 0, 0, 0, fmt_9985, 0 };
+    static cilist io___36 = { 0, 0, 0, fmt_9975, 0 };
+    static cilist io___37 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___38 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___39 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___40 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___41 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___42 = { 0, 0, 0, fmt_9994, 0 };
+    static cilist io___43 = { 0, 0, 0, fmt_9994, 0 };
+    static cilist io___44 = { 0, 0, 0, fmt_9984, 0 };
+    static cilist io___45 = { 0, 0, 0, fmt_9975, 0 };
+    static cilist io___46 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___47 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___48 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___49 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___50 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___51 = { 0, 0, 0, fmt_9993, 0 };
+    static cilist io___52 = { 0, 0, 0, fmt_9993, 0 };
+    static cilist io___53 = { 0, 0, 0, fmt_9986, 0 };
+    static cilist io___54 = { 0, 0, 0, fmt_9973, 0 };
+    static cilist io___55 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___56 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___57 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___58 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___59 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___60 = { 0, 0, 0, fmt_9992, 0 };
+    static cilist io___61 = { 0, 0, 0, fmt_9991, 0 };
+    static cilist io___62 = { 0, 0, 0, fmt_9983, 0 };
+    static cilist io___63 = { 0, 0, 0, fmt_9982, 0 };
+    static cilist io___64 = { 0, 0, 0, fmt_9974, 0 };
+    static cilist io___65 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___66 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___67 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___68 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___69 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___70 = { 0, 0, 0, fmt_9992, 0 };
+    static cilist io___71 = { 0, 0, 0, fmt_9991, 0 };
+    static cilist io___72 = { 0, 0, 0, fmt_9983, 0 };
+    static cilist io___73 = { 0, 0, 0, fmt_9974, 0 };
+    static cilist io___74 = { 0, 0, 0, fmt_9980, 0 };
+    static cilist io___75 = { 0, 0, 0, fmt_9979, 0 };
+    static cilist io___76 = { 0, 0, 0, fmt_9977, 0 };
+    static cilist io___77 = { 0, 0, 0, fmt_9978, 0 };
+    static cilist io___78 = { 0, 0, 0, fmt_9976, 0 };
+    static cilist io___79 = { 0, 0, 0, fmt_9990, 0 };
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ALADHD prints header information for the driver routines test paths.   
+/*  ALADHD prints header information for the driver routines test paths. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    IOUNIT  (input) INTEGER   
-            The unit number to which the header information should be   
-            printed.   
+/*  IOUNIT  (input) INTEGER */
+/*          The unit number to which the header information should be */
+/*          printed. */
 
-    PATH    (input) CHARACTER*3   
-            The name of the path for which the header information is to   
-            be printed.  Current paths are   
-               _GE:  General matrices   
-               _GB:  General band   
-               _GT:  General Tridiagonal   
-               _PO:  Symmetric or Hermitian positive definite   
-               _PP:  Symmetric or Hermitian positive definite packed   
-               _PB:  Symmetric or Hermitian positive definite band   
-               _PT:  Symmetric or Hermitian positive definite tridiagonal   
-               _SY:  Symmetric indefinite   
-               _SP:  Symmetric indefinite packed   
-               _HE:  (complex) Hermitian indefinite   
-               _HP:  (complex) Hermitian indefinite packed   
-            The first character must be one of S, D, C, or Z (C or Z only   
-            if complex). */
+/*  PATH    (input) CHARACTER*3 */
+/*          The name of the path for which the header information is to */
+/*          be printed.  Current paths are */
+/*             _GE:  General matrices */
+/*             _GB:  General band */
+/*             _GT:  General Tridiagonal */
+/*             _PO:  Symmetric or Hermitian positive definite */
+/*             _PP:  Symmetric or Hermitian positive definite packed */
+/*             _PB:  Symmetric or Hermitian positive definite band */
+/*             _PT:  Symmetric or Hermitian positive definite tridiagonal */
+/*             _SY:  Symmetric indefinite */
+/*             _SP:  Symmetric indefinite packed */
+/*             _HE:  (complex) Hermitian indefinite */
+/*             _HP:  (complex) Hermitian indefinite packed */
+/*          The first character must be one of S, D, C, or Z (C or Z only */
+/*          if complex). */
 
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     if (*iounit <= 0) {
 	return 0;
@@ -289,143 +265,159 @@ static integer c__7 = 7;
 	s_wsfe(&io___6);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Matrix types:' )";
+	s_wsfe(&ci__1);
+	e_wsfe();
 	io___7.ciunit = *iounit;
 	s_wsfe(&io___7);
 	e_wsfe();
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
+	e_wsfe();
 	io___8.ciunit = *iounit;
 	s_wsfe(&io___8);
+	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___9.ciunit = *iounit;
 	s_wsfe(&io___9);
+	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___10.ciunit = *iounit;
 	s_wsfe(&io___10);
-	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
+	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___11.ciunit = *iounit;
 	s_wsfe(&io___11);
-	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
+	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___12.ciunit = *iounit;
 	s_wsfe(&io___12);
-	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
+	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___13.ciunit = *iounit;
 	s_wsfe(&io___13);
-	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
+	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___14.ciunit = *iounit;
 	s_wsfe(&io___14);
-	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___15.ciunit = *iounit;
-	s_wsfe(&io___15);
-	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___16.ciunit = *iounit;
-	s_wsfe(&io___16);
 	do_fio(&c__1, (char *)&c__7, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___17.ciunit = *iounit;
-	s_wsfe(&io___17);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "GB")) {
 
 /*        GB: General band */
 
+	io___15.ciunit = *iounit;
+	s_wsfe(&io___15);
+	do_fio(&c__1, path, (ftnlen)3);
+	e_wsfe();
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Matrix types:' )";
+	s_wsfe(&ci__1);
+	e_wsfe();
+	io___16.ciunit = *iounit;
+	s_wsfe(&io___16);
+	e_wsfe();
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
+	e_wsfe();
+	io___17.ciunit = *iounit;
+	s_wsfe(&io___17);
+	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
+	e_wsfe();
 	io___18.ciunit = *iounit;
 	s_wsfe(&io___18);
-	do_fio(&c__1, path, (ftnlen)3);
+	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___19.ciunit = *iounit;
 	s_wsfe(&io___19);
+	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___20.ciunit = *iounit;
 	s_wsfe(&io___20);
+	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___21.ciunit = *iounit;
 	s_wsfe(&io___21);
+	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___22.ciunit = *iounit;
 	s_wsfe(&io___22);
-	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
+	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___23.ciunit = *iounit;
 	s_wsfe(&io___23);
-	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___24.ciunit = *iounit;
-	s_wsfe(&io___24);
-	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___25.ciunit = *iounit;
-	s_wsfe(&io___25);
-	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___26.ciunit = *iounit;
-	s_wsfe(&io___26);
-	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___27.ciunit = *iounit;
-	s_wsfe(&io___27);
-	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___28.ciunit = *iounit;
-	s_wsfe(&io___28);
 	do_fio(&c__1, (char *)&c__7, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___29.ciunit = *iounit;
-	s_wsfe(&io___29);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "GT")) {
 
 /*        GT: General tridiagonal */
 
+	io___24.ciunit = *iounit;
+	s_wsfe(&io___24);
+	do_fio(&c__1, path, (ftnlen)3);
+	e_wsfe();
+	io___25.ciunit = *iounit;
+	s_wsfe(&io___25);
+	e_wsfe();
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
+	e_wsfe();
+	io___26.ciunit = *iounit;
+	s_wsfe(&io___26);
+	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
+	e_wsfe();
+	io___27.ciunit = *iounit;
+	s_wsfe(&io___27);
+	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
+	e_wsfe();
+	io___28.ciunit = *iounit;
+	s_wsfe(&io___28);
+	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
+	e_wsfe();
+	io___29.ciunit = *iounit;
+	s_wsfe(&io___29);
+	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
+	e_wsfe();
 	io___30.ciunit = *iounit;
 	s_wsfe(&io___30);
-	do_fio(&c__1, path, (ftnlen)3);
+	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
 	io___31.ciunit = *iounit;
 	s_wsfe(&io___31);
-	e_wsfe();
-	io___32.ciunit = *iounit;
-	s_wsfe(&io___32);
-	e_wsfe();
-	io___33.ciunit = *iounit;
-	s_wsfe(&io___33);
-	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___34.ciunit = *iounit;
-	s_wsfe(&io___34);
-	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___35.ciunit = *iounit;
-	s_wsfe(&io___35);
-	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___36.ciunit = *iounit;
-	s_wsfe(&io___36);
-	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___37.ciunit = *iounit;
-	s_wsfe(&io___37);
-	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
-	e_wsfe();
-	io___38.ciunit = *iounit;
-	s_wsfe(&io___38);
 	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___39.ciunit = *iounit;
-	s_wsfe(&io___39);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "PO") || lsamen_(&
 	    c__2, p2, "PP")) {
 
-/*        PO: Positive definite full   
-          PP: Positive definite packed */
+/*        PO: Positive definite full */
+/*        PP: Positive definite packed */
 
 	if (sord) {
 	    s_copy(sym, "Symmetric", (ftnlen)9, (ftnlen)9);
@@ -433,54 +425,60 @@ static integer c__7 = 7;
 	    s_copy(sym, "Hermitian", (ftnlen)9, (ftnlen)9);
 	}
 	if (lsame_(c3, "O")) {
-	    io___41.ciunit = *iounit;
-	    s_wsfe(&io___41);
+	    io___33.ciunit = *iounit;
+	    s_wsfe(&io___33);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, sym, (ftnlen)9);
 	    e_wsfe();
 	} else {
-	    io___42.ciunit = *iounit;
-	    s_wsfe(&io___42);
+	    io___34.ciunit = *iounit;
+	    s_wsfe(&io___34);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, sym, (ftnlen)9);
 	    e_wsfe();
 	}
-	io___43.ciunit = *iounit;
-	s_wsfe(&io___43);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Matrix types:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___44.ciunit = *iounit;
-	s_wsfe(&io___44);
+	io___35.ciunit = *iounit;
+	s_wsfe(&io___35);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
-	io___45.ciunit = *iounit;
-	s_wsfe(&io___45);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___46.ciunit = *iounit;
-	s_wsfe(&io___46);
+	io___36.ciunit = *iounit;
+	s_wsfe(&io___36);
 	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___47.ciunit = *iounit;
-	s_wsfe(&io___47);
+	io___37.ciunit = *iounit;
+	s_wsfe(&io___37);
 	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___48.ciunit = *iounit;
-	s_wsfe(&io___48);
+	io___38.ciunit = *iounit;
+	s_wsfe(&io___38);
 	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___49.ciunit = *iounit;
-	s_wsfe(&io___49);
+	io___39.ciunit = *iounit;
+	s_wsfe(&io___39);
 	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___50.ciunit = *iounit;
-	s_wsfe(&io___50);
+	io___40.ciunit = *iounit;
+	s_wsfe(&io___40);
 	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___51.ciunit = *iounit;
-	s_wsfe(&io___51);
+	io___41.ciunit = *iounit;
+	s_wsfe(&io___41);
 	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___52.ciunit = *iounit;
-	s_wsfe(&io___52);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "PB")) {
@@ -488,54 +486,60 @@ static integer c__7 = 7;
 /*        PB: Positive definite band */
 
 	if (sord) {
-	    io___53.ciunit = *iounit;
-	    s_wsfe(&io___53);
+	    io___42.ciunit = *iounit;
+	    s_wsfe(&io___42);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Symmetric", (ftnlen)9);
 	    e_wsfe();
 	} else {
-	    io___54.ciunit = *iounit;
-	    s_wsfe(&io___54);
+	    io___43.ciunit = *iounit;
+	    s_wsfe(&io___43);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Hermitian", (ftnlen)9);
 	    e_wsfe();
 	}
-	io___55.ciunit = *iounit;
-	s_wsfe(&io___55);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Matrix types:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___56.ciunit = *iounit;
-	s_wsfe(&io___56);
+	io___44.ciunit = *iounit;
+	s_wsfe(&io___44);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
-	io___57.ciunit = *iounit;
-	s_wsfe(&io___57);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___58.ciunit = *iounit;
-	s_wsfe(&io___58);
+	io___45.ciunit = *iounit;
+	s_wsfe(&io___45);
 	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___59.ciunit = *iounit;
-	s_wsfe(&io___59);
+	io___46.ciunit = *iounit;
+	s_wsfe(&io___46);
 	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___60.ciunit = *iounit;
-	s_wsfe(&io___60);
+	io___47.ciunit = *iounit;
+	s_wsfe(&io___47);
 	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___61.ciunit = *iounit;
-	s_wsfe(&io___61);
+	io___48.ciunit = *iounit;
+	s_wsfe(&io___48);
 	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___62.ciunit = *iounit;
-	s_wsfe(&io___62);
+	io___49.ciunit = *iounit;
+	s_wsfe(&io___49);
 	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___63.ciunit = *iounit;
-	s_wsfe(&io___63);
+	io___50.ciunit = *iounit;
+	s_wsfe(&io___50);
 	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___64.ciunit = *iounit;
-	s_wsfe(&io___64);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "PT")) {
@@ -543,208 +547,224 @@ static integer c__7 = 7;
 /*        PT: Positive definite tridiagonal */
 
 	if (sord) {
-	    io___65.ciunit = *iounit;
-	    s_wsfe(&io___65);
+	    io___51.ciunit = *iounit;
+	    s_wsfe(&io___51);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Symmetric", (ftnlen)9);
 	    e_wsfe();
 	} else {
-	    io___66.ciunit = *iounit;
-	    s_wsfe(&io___66);
+	    io___52.ciunit = *iounit;
+	    s_wsfe(&io___52);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Hermitian", (ftnlen)9);
 	    e_wsfe();
 	}
-	io___67.ciunit = *iounit;
-	s_wsfe(&io___67);
+	io___53.ciunit = *iounit;
+	s_wsfe(&io___53);
 	e_wsfe();
-	io___68.ciunit = *iounit;
-	s_wsfe(&io___68);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___69.ciunit = *iounit;
-	s_wsfe(&io___69);
+	io___54.ciunit = *iounit;
+	s_wsfe(&io___54);
 	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___70.ciunit = *iounit;
-	s_wsfe(&io___70);
+	io___55.ciunit = *iounit;
+	s_wsfe(&io___55);
 	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___71.ciunit = *iounit;
-	s_wsfe(&io___71);
+	io___56.ciunit = *iounit;
+	s_wsfe(&io___56);
 	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___72.ciunit = *iounit;
-	s_wsfe(&io___72);
+	io___57.ciunit = *iounit;
+	s_wsfe(&io___57);
 	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___73.ciunit = *iounit;
-	s_wsfe(&io___73);
+	io___58.ciunit = *iounit;
+	s_wsfe(&io___58);
 	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___74.ciunit = *iounit;
-	s_wsfe(&io___74);
+	io___59.ciunit = *iounit;
+	s_wsfe(&io___59);
 	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___75.ciunit = *iounit;
-	s_wsfe(&io___75);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "SY") || lsamen_(&
 	    c__2, p2, "SP")) {
 
-/*        SY: Symmetric indefinite full   
-          SP: Symmetric indefinite packed */
+/*        SY: Symmetric indefinite full */
+/*        SP: Symmetric indefinite packed */
 
 	if (lsame_(c3, "Y")) {
-	    io___76.ciunit = *iounit;
-	    s_wsfe(&io___76);
+	    io___60.ciunit = *iounit;
+	    s_wsfe(&io___60);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Symmetric", (ftnlen)9);
 	    e_wsfe();
 	} else {
-	    io___77.ciunit = *iounit;
-	    s_wsfe(&io___77);
+	    io___61.ciunit = *iounit;
+	    s_wsfe(&io___61);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Symmetric", (ftnlen)9);
 	    e_wsfe();
 	}
-	io___78.ciunit = *iounit;
-	s_wsfe(&io___78);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Matrix types:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 	if (sord) {
-	    io___79.ciunit = *iounit;
-	    s_wsfe(&io___79);
+	    io___62.ciunit = *iounit;
+	    s_wsfe(&io___62);
 	    e_wsfe();
 	} else {
-	    io___80.ciunit = *iounit;
-	    s_wsfe(&io___80);
+	    io___63.ciunit = *iounit;
+	    s_wsfe(&io___63);
 	    e_wsfe();
 	}
-	io___81.ciunit = *iounit;
-	s_wsfe(&io___81);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___82.ciunit = *iounit;
-	s_wsfe(&io___82);
+	io___64.ciunit = *iounit;
+	s_wsfe(&io___64);
 	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___83.ciunit = *iounit;
-	s_wsfe(&io___83);
+	io___65.ciunit = *iounit;
+	s_wsfe(&io___65);
 	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___84.ciunit = *iounit;
-	s_wsfe(&io___84);
+	io___66.ciunit = *iounit;
+	s_wsfe(&io___66);
 	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___85.ciunit = *iounit;
-	s_wsfe(&io___85);
+	io___67.ciunit = *iounit;
+	s_wsfe(&io___67);
 	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___86.ciunit = *iounit;
-	s_wsfe(&io___86);
+	io___68.ciunit = *iounit;
+	s_wsfe(&io___68);
 	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___87.ciunit = *iounit;
-	s_wsfe(&io___87);
+	io___69.ciunit = *iounit;
+	s_wsfe(&io___69);
 	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___88.ciunit = *iounit;
-	s_wsfe(&io___88);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else if (lsamen_(&c__2, p2, "HE") || lsamen_(&
 	    c__2, p2, "HP")) {
 
-/*        HE: Hermitian indefinite full   
-          HP: Hermitian indefinite packed */
+/*        HE: Hermitian indefinite full */
+/*        HP: Hermitian indefinite packed */
 
 	if (lsame_(c3, "E")) {
-	    io___89.ciunit = *iounit;
-	    s_wsfe(&io___89);
+	    io___70.ciunit = *iounit;
+	    s_wsfe(&io___70);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Hermitian", (ftnlen)9);
 	    e_wsfe();
 	} else {
-	    io___90.ciunit = *iounit;
-	    s_wsfe(&io___90);
+	    io___71.ciunit = *iounit;
+	    s_wsfe(&io___71);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    do_fio(&c__1, "Hermitian", (ftnlen)9);
 	    e_wsfe();
 	}
-	io___91.ciunit = *iounit;
-	s_wsfe(&io___91);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Matrix types:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___92.ciunit = *iounit;
-	s_wsfe(&io___92);
+	io___72.ciunit = *iounit;
+	s_wsfe(&io___72);
 	e_wsfe();
-	io___93.ciunit = *iounit;
-	s_wsfe(&io___93);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Test ratios:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
-	io___94.ciunit = *iounit;
-	s_wsfe(&io___94);
+	io___73.ciunit = *iounit;
+	s_wsfe(&io___73);
 	do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___95.ciunit = *iounit;
-	s_wsfe(&io___95);
+	io___74.ciunit = *iounit;
+	s_wsfe(&io___74);
 	do_fio(&c__1, (char *)&c__2, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___96.ciunit = *iounit;
-	s_wsfe(&io___96);
+	io___75.ciunit = *iounit;
+	s_wsfe(&io___75);
 	do_fio(&c__1, (char *)&c__3, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___97.ciunit = *iounit;
-	s_wsfe(&io___97);
+	io___76.ciunit = *iounit;
+	s_wsfe(&io___76);
 	do_fio(&c__1, (char *)&c__4, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___98.ciunit = *iounit;
-	s_wsfe(&io___98);
+	io___77.ciunit = *iounit;
+	s_wsfe(&io___77);
 	do_fio(&c__1, (char *)&c__5, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___99.ciunit = *iounit;
-	s_wsfe(&io___99);
+	io___78.ciunit = *iounit;
+	s_wsfe(&io___78);
 	do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(integer));
 	e_wsfe();
-	io___100.ciunit = *iounit;
-	s_wsfe(&io___100);
+	ci__1.cierr = 0;
+	ci__1.ciunit = *iounit;
+	ci__1.cifmt = "( ' Messages:' )";
+	s_wsfe(&ci__1);
 	e_wsfe();
 
     } else {
 
 /*        Print error message if no header is available. */
 
-	io___101.ciunit = *iounit;
-	s_wsfe(&io___101);
+	io___79.ciunit = *iounit;
+	s_wsfe(&io___79);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
     }
 
-/*     First line of header   
+/*     First line of header */
 
 
-       GE matrix types   
+/*     GE matrix types */
 
 
-       GB matrix types   
+/*     GB matrix types */
 
 
-       GT matrix types   
+/*     GT matrix types */
 
 
-       PT matrix types   
+/*     PT matrix types */
 
 
-       PO, PP matrix types   
+/*     PO, PP matrix types */
 
 
-       PB matrix types   
+/*     PB matrix types */
 
 
-       SSY, SSP, CHE, CHP matrix types   
+/*     SSY, SSP, CHE, CHP matrix types */
 
 
-       CSY, CSP matrix types   
+/*     CSY, CSP matrix types */
 
 
-       Test ratios */
+/*     Test ratios */
 
 
     return 0;
