@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchkaa.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -81,6 +69,7 @@ static integer c__6 = 6;
     /* System generated locals */
     integer i__1, i__2;
     real r__1;
+    cilist ci__1;
     cllist cl__1;
 
     /* Builtin functions */
@@ -93,30 +82,29 @@ static integer c__6 = 6;
     integer f_clos(cllist *);
 
     /* Local variables */
-    static complex a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][
-	    4] */;
-    static integer i__, j, k;
-    static real s[264];
-    static char c1[1], c2[2];
-    static real s1, s2;
-    static integer ic, la, nb, nm, nn, vers_patch__, vers_major__, 
-	    vers_minor__, lda, nnb;
-    static real eps;
-    static integer nns, nnb2;
-    static char path[3];
-    static integer mval[12], nval[12], nrhs;
-    static complex work[20856]	/* was [132][158] */;
-    static integer lafac;
-    static logical fatal;
-    static char aline[72];
+    complex a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][4] */;
+    integer i__, j, k;
+    real s[264];
+    char c1[1], c2[2];
+    real s1, s2;
+    integer ic, la, nb, nm, nn, vers_patch__, vers_major__, vers_minor__, lda,
+	     nnb;
+    real eps;
+    integer nns, nnb2;
+    char path[3];
+    integer mval[12], nval[12], nrhs;
+    complex work[20856]	/* was [132][158] */;
+    integer lafac;
+    logical fatal;
+    char aline[72];
     extern logical lsame_(char *, char *);
-    static integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
-    static real rwork[19832];
+    integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
+    real rwork[19832];
     extern /* Subroutine */ int cchkq3_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, real *, 
 	    complex *, complex *, real *, real *, complex *, complex *, real *
-	    , integer *, integer *);
-    static integer nbval2[12];
+, integer *, integer *);
+    integer nbval2[12];
     extern /* Subroutine */ int cchkgb_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    real *, logical *, complex *, integer *, complex *, integer *, 
@@ -132,7 +120,7 @@ static integer c__6 = 6;
 	    integer *, integer *, integer *, integer *, integer *, real *, 
 	    logical *, integer *, complex *, complex *, complex *, complex *, 
 	    complex *, complex *, complex *, real *, integer *), cchkeq_(real 
-	    *, integer *), cchktb_(logical *, integer *, integer *, integer *,
+	    *, integer *), cchktb_(logical *, integer *, integer *, integer *, 
 	     integer *, real *, logical *, integer *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, real *, integer *), 
 	    cchkhp_(logical *, integer *, integer *, integer *, integer *, 
@@ -165,7 +153,7 @@ static integer c__6 = 6;
 	    complex *, complex *, complex *, complex *, complex *, real *, 
 	    integer *), cchkqp_(logical *, integer *, integer *, integer *, 
 	    integer *, real *, logical *, complex *, complex *, real *, real *
-	    , complex *, complex *, real *, integer *, integer *), cchkqr_(
+, complex *, complex *, real *, integer *, integer *), cchkqr_(
 	    logical *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, real *, logical *, integer *, 
 	    complex *, complex *, complex *, complex *, complex *, complex *, 
@@ -195,7 +183,7 @@ static integer c__6 = 6;
 	    real *, complex *, real *, integer *, integer *), cchktz_(logical 
 	    *, integer *, integer *, integer *, integer *, real *, logical *, 
 	    complex *, complex *, real *, real *, complex *, complex *, real *
-	    , integer *), cdrvge_(logical *, integer *, integer *, integer *, 
+, integer *), cdrvge_(logical *, integer *, integer *, integer *, 
 	    real *, logical *, integer *, complex *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, real *, complex *, 
 	    real *, integer *, integer *), cdrvgt_(logical *, integer *, 
@@ -211,16 +199,16 @@ static integer c__6 = 6;
 	    real *, logical *, integer *, complex *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, real *, complex *, 
 	    real *, integer *);
-    static real thresh;
+    real thresh;
     extern /* Subroutine */ int cdrvls_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, real *, logical *, complex *, complex *, complex *, 
 	    complex *, complex *, real *, real *, complex *, real *, integer *
-	    , integer *), cdrvpo_(logical *, integer *, integer *, integer *, 
+, integer *), cdrvpo_(logical *, integer *, integer *, integer *, 
 	    real *, logical *, integer *, complex *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, real *, complex *, 
 	    real *, integer *);
-    static logical tstchk;
+    logical tstchk;
     extern /* Subroutine */ int cdrvpp_(logical *, integer *, integer *, 
 	    integer *, real *, logical *, integer *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, complex *, real *, 
@@ -228,7 +216,7 @@ static integer c__6 = 6;
 	    integer *, integer *, real *, logical *, complex *, real *, 
 	    complex *, complex *, complex *, complex *, complex *, real *, 
 	    integer *);
-    static logical dotype[30];
+    logical dotype[30];
     extern /* Subroutine */ int cdrvsp_(logical *, integer *, integer *, 
 	    integer *, real *, logical *, integer *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, complex *, real *, 
@@ -236,8 +224,8 @@ static integer c__6 = 6;
 	    cdrvsy_(logical *, integer *, integer *, integer *, real *, 
 	    logical *, integer *, complex *, complex *, complex *, complex *, 
 	    complex *, complex *, complex *, real *, integer *, integer *);
-    static integer ntypes;
-    static logical tsterr, tstdrv;
+    integer ntypes;
+    logical tsterr, tstdrv;
 
     /* Fortran I/O blocks */
     static cilist io___6 = { 0, 5, 0, 0, 0 };
@@ -282,31 +270,31 @@ static integer c__6 = 6;
     static cilist io___67 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___68 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___69 = { 0, 6, 0, 0, 0 };
-    static cilist io___71 = { 0, 5, 1, "(A72)", 0 };
-    static cilist io___79 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___80 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___88 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___90 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___93 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___94 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___95 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___96 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___97 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___98 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___99 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___100 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___101 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___102 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___103 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___104 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___105 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___106 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___107 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___108 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___109 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___110 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___111 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___112 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___78 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___79 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___87 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___89 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___92 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___93 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___94 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___95 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___96 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___97 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___98 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___99 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___100 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___101 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___102 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___103 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___104 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___105 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___106 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___107 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___108 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___109 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___110 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___111 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___112 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___113 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___114 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___115 = { 0, 6, 0, fmt_9989, 0 };
@@ -317,87 +305,105 @@ static integer c__6 = 6;
     static cilist io___120 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___121 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___122 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___123 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___124 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___126 = { 0, 6, 0, fmt_9998, 0 };
-    static cilist io___127 = { 0, 6, 0, fmt_9997, 0 };
+    static cilist io___123 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___125 = { 0, 6, 0, fmt_9998, 0 };
+    static cilist io___126 = { 0, 6, 0, fmt_9997, 0 };
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKAA is the main test program for the COMPLEX linear equation   
-    routines.   
+/*  CCHKAA is the main test program for the COMPLEX linear equation */
+/*  routines. */
 
-    The program must be driven by a short data file. The first 14 records   
-    specify problem dimensions and program options using list-directed   
-    input.  The remaining lines specify the LAPACK test paths and the   
-    number of matrix types to use in testing.  An annotated example of a   
-    data file can be obtained by deleting the first 3 characters from the   
-    following 38 lines:   
-    Data file for testing COMPLEX LAPACK linear equation routines   
-    7                      Number of values of M   
-    0 1 2 3 5 10 16        Values of M (row dimension)   
-    7                      Number of values of N   
-    0 1 2 3 5 10 16        Values of N (column dimension)   
-    1                      Number of values of NRHS   
-    2                      Values of NRHS (number of right hand sides)   
-    5                      Number of values of NB   
-    1 3 3 3 20             Values of NB (the blocksize)   
-    1 0 5 9 1              Values of NX (crossover point)   
-    30.0                   Threshold value of test ratio   
-    T                      Put T to test the LAPACK routines   
-    T                      Put T to test the driver routines   
-    T                      Put T to test the error exits   
-    CGE   11               List types on next line if 0 < NTYPES < 11   
-    CGB    8               List types on next line if 0 < NTYPES <  8   
-    CGT   12               List types on next line if 0 < NTYPES < 12   
-    CPO    9               List types on next line if 0 < NTYPES <  9   
-    CPP    9               List types on next line if 0 < NTYPES <  9   
-    CPB    8               List types on next line if 0 < NTYPES <  8   
-    CPT   12               List types on next line if 0 < NTYPES < 12   
-    CHE   10               List types on next line if 0 < NTYPES < 10   
-    CHP   10               List types on next line if 0 < NTYPES < 10   
-    CSY   11               List types on next line if 0 < NTYPES < 11   
-    CSP   11               List types on next line if 0 < NTYPES < 11   
-    CTR   18               List types on next line if 0 < NTYPES < 18   
-    CTP   18               List types on next line if 0 < NTYPES < 18   
-    CTB   17               List types on next line if 0 < NTYPES < 17   
-    CQR    8               List types on next line if 0 < NTYPES <  8   
-    CRQ    8               List types on next line if 0 < NTYPES <  8   
-    CLQ    8               List types on next line if 0 < NTYPES <  8   
-    CQL    8               List types on next line if 0 < NTYPES <  8   
-    CQP    6               List types on next line if 0 < NTYPES <  6   
-    CTZ    3               List types on next line if 0 < NTYPES <  3   
-    CLS    6               List types on next line if 0 < NTYPES <  6   
-    CEQ   
+/*  The program must be driven by a short data file. The first 14 records */
+/*  specify problem dimensions and program options using list-directed */
+/*  input.  The remaining lines specify the LAPACK test paths and the */
+/*  number of matrix types to use in testing.  An annotated example of a */
+/*  data file can be obtained by deleting the first 3 characters from the */
+/*  following 38 lines: */
+/*  Data file for testing COMPLEX LAPACK linear equation routines */
+/*  7                      Number of values of M */
+/*  0 1 2 3 5 10 16        Values of M (row dimension) */
+/*  7                      Number of values of N */
+/*  0 1 2 3 5 10 16        Values of N (column dimension) */
+/*  1                      Number of values of NRHS */
+/*  2                      Values of NRHS (number of right hand sides) */
+/*  5                      Number of values of NB */
+/*  1 3 3 3 20             Values of NB (the blocksize) */
+/*  1 0 5 9 1              Values of NX (crossover point) */
+/*  30.0                   Threshold value of test ratio */
+/*  T                      Put T to test the LAPACK routines */
+/*  T                      Put T to test the driver routines */
+/*  T                      Put T to test the error exits */
+/*  CGE   11               List types on next line if 0 < NTYPES < 11 */
+/*  CGB    8               List types on next line if 0 < NTYPES <  8 */
+/*  CGT   12               List types on next line if 0 < NTYPES < 12 */
+/*  CPO    9               List types on next line if 0 < NTYPES <  9 */
+/*  CPP    9               List types on next line if 0 < NTYPES <  9 */
+/*  CPB    8               List types on next line if 0 < NTYPES <  8 */
+/*  CPT   12               List types on next line if 0 < NTYPES < 12 */
+/*  CHE   10               List types on next line if 0 < NTYPES < 10 */
+/*  CHP   10               List types on next line if 0 < NTYPES < 10 */
+/*  CSY   11               List types on next line if 0 < NTYPES < 11 */
+/*  CSP   11               List types on next line if 0 < NTYPES < 11 */
+/*  CTR   18               List types on next line if 0 < NTYPES < 18 */
+/*  CTP   18               List types on next line if 0 < NTYPES < 18 */
+/*  CTB   17               List types on next line if 0 < NTYPES < 17 */
+/*  CQR    8               List types on next line if 0 < NTYPES <  8 */
+/*  CRQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  CLQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  CQL    8               List types on next line if 0 < NTYPES <  8 */
+/*  CQP    6               List types on next line if 0 < NTYPES <  6 */
+/*  CTZ    3               List types on next line if 0 < NTYPES <  3 */
+/*  CLS    6               List types on next line if 0 < NTYPES <  6 */
+/*  CEQ */
 
-    Internal Parameters   
-    ===================   
+/*  Internal Parameters */
+/*  =================== */
 
-    NMAX    INTEGER   
-            The maximum allowable value for N.   
+/*  NMAX    INTEGER */
+/*          The maximum allowable value for N. */
 
-    MAXIN   INTEGER   
-            The number of different values that can be used for each of   
-            M, N, or NB   
+/*  MAXIN   INTEGER */
+/*          The number of different values that can be used for each of */
+/*          M, N, or NB */
 
-    MAXRHS  INTEGER   
-            The maximum number of right hand sides   
+/*  MAXRHS  INTEGER */
+/*          The maximum number of right hand sides */
 
-    NIN     INTEGER   
-            The unit number for input   
+/*  NIN     INTEGER */
+/*          The unit number for input */
 
-    NOUT    INTEGER   
-            The unit number for output   
+/*  NOUT    INTEGER */
+/*          The unit number for output */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Arrays in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s1 = second_();
     lda = 132;
@@ -748,7 +754,11 @@ L80:
 
 /*     Read a test path and the number of matrix types to use. */
 
-    i__1 = s_rsfe(&io___71);
+    ci__1.cierr = 0;
+    ci__1.ciend = 1;
+    ci__1.ciunit = 5;
+    ci__1.cifmt = "(A72)";
+    i__1 = s_rsfe(&ci__1);
     if (i__1 != 0) {
 	goto L140;
     }
@@ -796,7 +806,7 @@ L130:
 /*     Check first character for correct precision. */
 
     if (! lsame_(c1, "Complex precision")) {
-	s_wsfe(&io___79);
+	s_wsfe(&io___78);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -804,7 +814,7 @@ L130:
 
 /*        Check for a positive number of tests requested. */
 
-	s_wsfe(&io___80);
+	s_wsfe(&io___79);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -820,7 +830,7 @@ L130:
 		    &thresh, &tsterr, &lda, a, &a[21912], &a[43824], b, &b[
 		    2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___88);
+	    s_wsfe(&io___87);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -830,7 +840,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___90);
+	    s_wsfe(&io___89);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -849,7 +859,7 @@ L130:
 		    &thresh, &tsterr, a, &la, &a[43824], &lafac, b, &b[2112], 
 		    &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___93);
+	    s_wsfe(&io___92);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -859,7 +869,7 @@ L130:
 		    43824], &lafac, &a[109560], b, &b[2112], &b[4224], &b[
 		    6336], s, work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___94);
+	    s_wsfe(&io___93);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -875,7 +885,7 @@ L130:
 	    cchkgt_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___95);
+	    s_wsfe(&io___94);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -884,7 +894,7 @@ L130:
 	    cdrvgt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, &a[21912], 
 		    b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___96);
+	    s_wsfe(&io___95);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -901,7 +911,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___97);
+	    s_wsfe(&io___96);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -911,7 +921,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___98);
+	    s_wsfe(&io___97);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -924,11 +934,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    cchkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    cchkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     &c__6);
 	} else {
-	    s_wsfe(&io___99);
+	    s_wsfe(&io___98);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -938,7 +948,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___100);
+	    s_wsfe(&io___99);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -955,7 +965,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___101);
+	    s_wsfe(&io___100);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -965,7 +975,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___102);
+	    s_wsfe(&io___101);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -981,7 +991,7 @@ L130:
 	    cchkpt_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, a, s, &
 		    a[21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___103);
+	    s_wsfe(&io___102);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -990,7 +1000,7 @@ L130:
 	    cdrvpt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, s, &a[
 		    21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___104);
+	    s_wsfe(&io___103);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1007,7 +1017,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___105);
+	    s_wsfe(&io___104);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1017,7 +1027,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___106);
+	    s_wsfe(&io___105);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1030,11 +1040,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    cchkhp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    cchkhp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___107);
+	    s_wsfe(&io___106);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1044,7 +1054,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___108);
+	    s_wsfe(&io___107);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1061,7 +1071,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___109);
+	    s_wsfe(&io___108);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1071,7 +1081,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___110);
+	    s_wsfe(&io___109);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1084,11 +1094,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    cchksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    cchksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___111);
+	    s_wsfe(&io___110);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1098,7 +1108,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___112);
+	    s_wsfe(&io___111);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1115,7 +1125,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], b, &b[2112], &b[4224], work, 
 		    rwork, &c__6);
 	} else {
-	    s_wsfe(&io___113);
+	    s_wsfe(&io___112);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1128,10 +1138,10 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    cchktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    cchktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___114);
+	    s_wsfe(&io___113);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1144,10 +1154,10 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    cchktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    cchktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___115);
+	    s_wsfe(&io___114);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1165,7 +1175,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___116);
+	    s_wsfe(&io___115);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1183,7 +1193,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___117);
+	    s_wsfe(&io___116);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1201,7 +1211,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___118);
+	    s_wsfe(&io___117);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1219,20 +1229,20 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___119);
+	    s_wsfe(&io___118);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else if (lsamen_(&c__2, c2, "EQ")) {
 
-/*        EQ:  Equilibration routines for general and positive definite   
-               matrices (THREQ should be between 2 and 10) */
+/*        EQ:  Equilibration routines for general and positive definite */
+/*             matrices (THREQ should be between 2 and 10) */
 
 	if (tstchk) {
 	    cchkeq_(&threq, &c__6);
 	} else {
-	    s_wsfe(&io___120);
+	    s_wsfe(&io___119);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1248,7 +1258,7 @@ L130:
 	    cchktz_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], s, &s[132], b, work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___121);
+	    s_wsfe(&io___120);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1263,10 +1273,10 @@ L130:
 	if (tstchk) {
 	    cchkqp_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], s, &s[132], b, work, rwork, iwork, &c__6);
-	    cchkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh,
+	    cchkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh, 
 		     a, &a[21912], s, &s[132], b, work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___122);
+	    s_wsfe(&io___121);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1283,14 +1293,14 @@ L130:
 		    nxval, &thresh, &tsterr, a, &a[21912], &a[43824], &a[
 		    65736], &a[87648], s, &s[132], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___123);
+	    s_wsfe(&io___122);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else {
 
-	s_wsfe(&io___124);
+	s_wsfe(&io___123);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
     }
@@ -1307,9 +1317,9 @@ L140:
     cl__1.csta = 0;
     f_clos(&cl__1);
     s2 = second_();
-    s_wsfe(&io___126);
+    s_wsfe(&io___125);
     e_wsfe();
-    s_wsfe(&io___127);
+    s_wsfe(&io___126);
     r__1 = s2 - s1;
     do_fio(&c__1, (char *)&r__1, (ftnlen)sizeof(real));
     e_wsfe();
@@ -1318,6 +1328,6 @@ L140:
 /*     End of CCHKAA */
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Main program alias */ int cchkaa_ () { MAIN__ (); return 0; }
+/* Main program alias */ int cchkaa_ () { MAIN__ (); return 0; }
