@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchkeq.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -42,25 +30,25 @@ static integer c__1 = 1;
     real r__1, r__2, r__3;
     complex q__1;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double pow_ri(real *, integer *);
     integer pow_ii(integer *, integer *), s_wsle(cilist *), e_wsle(void), 
 	    s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static complex a[25]	/* was [5][5] */;
-    static real c__[5];
-    static integer i__, j, m, n;
-    static real r__[5];
-    static complex ab[65]	/* was [13][5] */, ap[15];
-    static integer kl;
-    static logical ok;
-    static integer ku;
-    static real eps, pow[11];
-    static integer info;
-    static char path[3];
-    static real norm, rpow[11], ccond, rcond, rcmin, rcmax, ratio;
+    complex a[25]	/* was [5][5] */;
+    real c__[5];
+    integer i__, j, m, n;
+    real r__[5];
+    complex ab[65]	/* was [13][5] */, ap[15];
+    integer kl;
+    logical ok;
+    integer ku;
+    real eps, pow[11];
+    integer info;
+    char path[3];
+    real norm, rpow[11], ccond, rcond, rcmin, rcmax, ratio;
     extern /* Subroutine */ int cgbequ_(integer *, integer *, integer *, 
 	    integer *, complex *, integer *, real *, real *, real *, real *, 
 	    real *, integer *);
@@ -68,10 +56,10 @@ static integer c__1 = 1;
     extern /* Subroutine */ int cgeequ_(integer *, integer *, complex *, 
 	    integer *, real *, real *, real *, real *, real *, integer *), 
 	    cpbequ_(char *, integer *, integer *, complex *, integer *, real *
-	    , real *, real *, integer *), cpoequ_(integer *, complex *
-	    , integer *, real *, real *, real *, integer *), cppequ_(char *, 
+, real *, real *, integer *), cpoequ_(integer *, complex *
+, integer *, real *, real *, real *, integer *), cppequ_(char *, 
 	    integer *, complex *, real *, real *, real *, integer *);
-    static real reslts[5];
+    real reslts[5];
 
     /* Fortran I/O blocks */
     static cilist io___25 = { 0, 0, 0, 0, 0 };
@@ -84,27 +72,42 @@ static integer c__1 = 1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKEQ tests CGEEQU, CGBEQU, CPOEQU, CPPEQU and CPBEQU   
+/*  CCHKEQ tests CGEEQU, CGBEQU, CPOEQU, CPPEQU and CPBEQU */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    THRESH  (input) REAL   
-            Threshold for testing routines. Should be between 2 and 10.   
+/*  THRESH  (input) REAL */
+/*          Threshold for testing routines. Should be between 2 and 10. */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "EQ", (ftnlen)2, (ftnlen)2);
@@ -388,7 +391,13 @@ static integer c__1 = 1;
 		reslts[2] = dmax(r__2,r__3);
 /* Computing MAX */
 		r__2 = reslts[2], r__3 = (r__1 = (norm - pow[n * 2]) / pow[n *
-			 2], dabs(r__1)); 		reslts[2] = dmax(r__2,r__3); 		i__1 = n; 		for (i__ = 1; i__ <= i__1; ++i__) { /* Computing MAX */ 		    r__2 = reslts[2], r__3 = (r__1 = (r__[i__ - 1] - rpow[i__] 			    ) / rpow[i__], dabs(r__1));
+			 2], dabs(r__1));
+		reslts[2] = dmax(r__2,r__3);
+		i__1 = n;
+		for (i__ = 1; i__ <= i__1; ++i__) {
+/* Computing MAX */
+		    r__2 = reslts[2], r__3 = (r__1 = (r__[i__ - 1] - rpow[i__]
+			    ) / rpow[i__], dabs(r__1));
 		    reslts[2] = dmax(r__2,r__3);
 /* L280: */
 		}
@@ -436,7 +445,13 @@ static integer c__1 = 1;
 		reslts[3] = dmax(r__2,r__3);
 /* Computing MAX */
 		r__2 = reslts[3], r__3 = (r__1 = (norm - pow[n * 2]) / pow[n *
-			 2], dabs(r__1)); 		reslts[3] = dmax(r__2,r__3); 		i__1 = n; 		for (i__ = 1; i__ <= i__1; ++i__) { /* Computing MAX */ 		    r__2 = reslts[3], r__3 = (r__1 = (r__[i__ - 1] - rpow[i__] 			    ) / rpow[i__], dabs(r__1));
+			 2], dabs(r__1));
+		reslts[3] = dmax(r__2,r__3);
+		i__1 = n;
+		for (i__ = 1; i__ <= i__1; ++i__) {
+/* Computing MAX */
+		    r__2 = reslts[3], r__3 = (r__1 = (r__[i__ - 1] - rpow[i__]
+			    ) / rpow[i__], dabs(r__1));
 		    reslts[3] = dmax(r__2,r__3);
 /* L320: */
 		}
@@ -473,7 +488,13 @@ static integer c__1 = 1;
 		reslts[3] = dmax(r__2,r__3);
 /* Computing MAX */
 		r__2 = reslts[3], r__3 = (r__1 = (norm - pow[n * 2]) / pow[n *
-			 2], dabs(r__1)); 		reslts[3] = dmax(r__2,r__3); 		i__1 = n; 		for (i__ = 1; i__ <= i__1; ++i__) { /* Computing MAX */ 		    r__2 = reslts[3], r__3 = (r__1 = (r__[i__ - 1] - rpow[i__] 			    ) / rpow[i__], dabs(r__1));
+			 2], dabs(r__1));
+		reslts[3] = dmax(r__2,r__3);
+		i__1 = n;
+		for (i__ = 1; i__ <= i__1; ++i__) {
+/* Computing MAX */
+		    r__2 = reslts[3], r__3 = (r__1 = (r__[i__ - 1] - rpow[i__]
+			    ) / rpow[i__], dabs(r__1));
 		    reslts[3] = dmax(r__2,r__3);
 /* L350: */
 		}
