@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchkgt.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -63,42 +51,48 @@ static real c_b64 = 0.f;
     integer i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, m, n;
-    static complex z__[3];
-    static integer in, kl, ku, ix, lda;
-    static real cond;
-    static integer mode, koff, imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char norm[1], type__[1];
-    static integer nrun;
+    integer i__, j, k, m, n;
+    complex z__[3];
+    integer in, kl, ku, ix, lda;
+    real cond;
+    integer mode, koff, imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char norm[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *), cget04_(
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    real *, real *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern /* Subroutine */ int cgtt01_(integer *, complex *, complex *, 
 	    complex *, complex *, complex *, complex *, complex *, integer *, 
 	    complex *, integer *, real *, real *), cgtt02_(char *, integer *, 
 	    integer *, complex *, complex *, complex *, complex *, integer *, 
 	    complex *, integer *, real *, real *);
-    static real rcond;
+    real rcond;
     extern /* Subroutine */ int cgtt05_(char *, integer *, integer *, complex 
 	    *, complex *, complex *, complex *, integer *, complex *, integer 
 	    *, complex *, integer *, real *, real *, real *);
-    static integer nimat;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
-    static real anorm;
-    static integer itran;
+    real anorm;
+    integer itran;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
-	    complex *, integer *);     static char trans[1];     static integer izero, nerrs;     static logical zerot;     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), alaerh_(char *, char *, integer *, 
+	    complex *, integer *);
+    char trans[1];
+    integer izero, nerrs;
+    logical zerot;
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), alaerh_(char *, char *, integer *, 
 	    integer *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *), cerrge_(char *, integer *);
-    static real rcondc;
+    real rcondc;
     extern doublereal clangt_(char *, integer *, complex *, complex *, 
 	    complex *);
     extern /* Subroutine */ int clagtm_(char *, integer *, integer *, real *, 
@@ -108,26 +102,26 @@ static real c_b64 = 0.f;
 	    integer *, real *, complex *, integer *), cgtcon_(char *, integer 
 	    *, complex *, complex *, complex *, complex *, integer *, real *, 
 	    real *, complex *, integer *);
-    static real rcondi;
+    real rcondi;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real rcondo;
+    real rcondo;
     extern /* Subroutine */ int clarnv_(integer *, integer *, integer *, 
 	    complex *), clatms_(integer *, integer *, char *, integer *, char 
 	    *, real *, integer *, real *, real *, integer *, integer *, char *
-	    , complex *, integer *, complex *, integer *);
-    static real ainvnm;
+, complex *, integer *, complex *, integer *);
+    real ainvnm;
     extern /* Subroutine */ int cgtrfs_(char *, integer *, integer *, complex 
 	    *, complex *, complex *, complex *, complex *, complex *, complex 
 	    *, integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, complex *, real *, integer *), cgttrf_(integer *, 
 	    complex *, complex *, complex *, complex *, integer *, integer *);
-    static logical trfcon;
+    logical trfcon;
     extern doublereal scasum_(integer *, complex *, integer *);
     extern /* Subroutine */ int cgttrs_(char *, integer *, integer *, complex 
 	    *, complex *, complex *, complex *, integer *, complex *, integer 
 	    *, integer *);
-    static real result[7];
+    real result[7];
 
     /* Fortran I/O blocks */
     static cilist io___29 = { 0, 0, 0, fmt_9999, 0 };
@@ -136,69 +130,90 @@ static real c_b64 = 0.f;
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKGT tests CGTTRF, -TRS, -RFS, and -CON   
+/*  CCHKGT tests CGTTRF, -TRS, -RFS, and -CON */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*4)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*4) */
 
-    AF      (workspace) COMPLEX array, dimension (NMAX*4)   
+/*  AF      (workspace) COMPLEX array, dimension (NMAX*4) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) REAL array, dimension   
-                        (max(NMAX)+2*NSMAX)   
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (max(NMAX)+2*NSMAX) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -212,6 +227,8 @@ static real c_b64 = 0.f;
     --dotype;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "GT", (ftnlen)2, (ftnlen)2);
@@ -262,9 +279,9 @@ static real c_b64 = 0.f;
 	    zerot = imat >= 8 && imat <= 10;
 	    if (imat <= 6) {
 
-/*              Types 1-6:  generate matrices of known condition number.   
+/*              Types 1-6:  generate matrices of known condition number. */
 
-   Computing MAX */
+/* Computing MAX */
 		i__3 = 2 - ku, i__4 = 3 - max(1,n);
 		koff = max(i__3,i__4);
 		s_copy(srnamc_1.srnamt, "CLATMS", (ftnlen)6, (ftnlen)6);
@@ -290,13 +307,13 @@ static real c_b64 = 0.f;
 		ccopy_(&n, &af[2], &c__3, &a[m + 1], &c__1);
 	    } else {
 
-/*              Types 7-12:  generate tridiagonal matrices with   
-                unknown condition numbers. */
+/*              Types 7-12:  generate tridiagonal matrices with */
+/*              unknown condition numbers. */
 
 		if (! zerot || ! dotype[7]) {
 
-/*                 Generate a matrix with elements whose real and   
-                   imaginary parts are from [-1,1]. */
+/*                 Generate a matrix with elements whose real and */
+/*                 imaginary parts are from [-1,1]. */
 
 		    i__3 = n + (m << 1);
 		    clarnv_(&c__2, iseed, &i__3, &a[1]);
@@ -306,8 +323,8 @@ static real c_b64 = 0.f;
 		    }
 		} else if (izero > 0) {
 
-/*                 Reuse the last matrix by copying back the zeroed out   
-                   elements. */
+/*                 Reuse the last matrix by copying back the zeroed out */
+/*                 elements. */
 
 		    if (izero == 1) {
 			i__3 = n;
@@ -373,9 +390,9 @@ static real c_b64 = 0.f;
 		}
 	    }
 
-/* +    TEST 1   
-             Factor A as L*U and compute the ratio   
-                norm(L*U - A) / (n * norm(A) * EPS ) */
+/* +    TEST 1 */
+/*           Factor A as L*U and compute the ratio */
+/*              norm(L*U - A) / (n * norm(A) * EPS ) */
 
 	    i__3 = n + (m << 1);
 	    ccopy_(&i__3, &a[1], &c__1, &af[1], &c__1);
@@ -392,7 +409,7 @@ static real c_b64 = 0.f;
 	    trfcon = info != 0;
 
 	    cgtt01_(&n, &a[1], &a[m + 1], &a[n + m + 1], &af[1], &af[m + 1], &
-		    af[n + m + 1], &af[n + (m << 1) + 1], &iwork[1], &work[1],
+		    af[n + m + 1], &af[n + (m << 1) + 1], &iwork[1], &work[1], 
 		     &lda, &rwork[1], result);
 
 /*           Print the test ratio if it is .GE. THRESH. */
@@ -424,8 +441,8 @@ static real c_b64 = 0.f;
 
 		if (! trfcon) {
 
-/*                 Use CGTTRS to solve for one column at a time of   
-                   inv(A), computing the maximum column sum as we go. */
+/*                 Use CGTTRS to solve for one column at a time of */
+/*                 inv(A), computing the maximum column sum as we go. */
 
 		    ainvnm = 0.f;
 		    i__3 = n;
@@ -463,9 +480,9 @@ static real c_b64 = 0.f;
 		    rcondc = 0.f;
 		}
 
-/* +    TEST 7   
-                Estimate the reciprocal of the condition number of the   
-                matrix. */
+/* +    TEST 7 */
+/*              Estimate the reciprocal of the condition number of the */
+/*              matrix. */
 
 		s_copy(srnamc_1.srnamt, "CGTCON", (ftnlen)6, (ftnlen)6);
 		cgtcon_(norm, &n, &af[1], &af[m + 1], &af[n + m + 1], &af[n + 
@@ -475,7 +492,7 @@ static real c_b64 = 0.f;
 /*              Check error code from CGTCON. */
 
 		if (info != 0) {
-		    alaerh_(path, "CGTCON", &info, &c__0, norm, &n, &n, &c_n1,
+		    alaerh_(path, "CGTCON", &info, &c__0, norm, &n, &n, &c_n1, 
 			     &c_n1, &c_n1, &imat, &nfail, &nerrs, nout);
 		}
 
@@ -535,13 +552,13 @@ static real c_b64 = 0.f;
 		    clagtm_(trans, &n, &nrhs, &c_b63, &a[1], &a[m + 1], &a[n 
 			    + m + 1], &xact[1], &lda, &c_b64, &b[1], &lda);
 
-/* +    TEST 2   
-                Solve op(A) * X = B and compute the residual. */
+/* +    TEST 2 */
+/*              Solve op(A) * X = B and compute the residual. */
 
 		    clacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &lda);
 		    s_copy(srnamc_1.srnamt, "CGTTRS", (ftnlen)6, (ftnlen)6);
 		    cgttrs_(trans, &n, &nrhs, &af[1], &af[m + 1], &af[n + m + 
-			    1], &af[n + (m << 1) + 1], &iwork[1], &x[1], &lda,
+			    1], &af[n + (m << 1) + 1], &iwork[1], &x[1], &lda, 
 			     &info);
 
 /*              Check error code from CGTTRS. */
@@ -553,21 +570,21 @@ static real c_b64 = 0.f;
 		    }
 
 		    clacpy_("Full", &n, &nrhs, &b[1], &lda, &work[1], &lda);
-		    cgtt02_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1],
+		    cgtt02_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1], 
 			     &x[1], &lda, &work[1], &lda, &rwork[1], &result[
 			    1]);
 
-/* +    TEST 3   
-                Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*              Check solution from generated exact solution. */
 
 		    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &rcondc, &
 			    result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                Use iterative refinement to improve the solution. */
+/* +    TESTS 4, 5, and 6 */
+/*              Use iterative refinement to improve the solution. */
 
 		    s_copy(srnamc_1.srnamt, "CGTRFS", (ftnlen)6, (ftnlen)6);
-		    cgtrfs_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1],
+		    cgtrfs_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1], 
 			     &af[1], &af[m + 1], &af[n + m + 1], &af[n + (m <<
 			     1) + 1], &iwork[1], &b[1], &lda, &x[1], &lda, &
 			    rwork[1], &rwork[nrhs + 1], &work[1], &rwork[(
@@ -583,12 +600,12 @@ static real c_b64 = 0.f;
 
 		    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &rcondc, &
 			    result[3]);
-		    cgtt05_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1],
+		    cgtt05_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1], 
 			     &b[1], &lda, &x[1], &lda, &xact[1], &lda, &rwork[
 			    1], &rwork[nrhs + 1], &result[4]);
 
-/*              Print information about the tests that did not pass the   
-                threshold. */
+/*              Print information about the tests that did not pass the */
+/*              threshold. */
 
 		    for (k = 2; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
