@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchkpt.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -59,43 +47,49 @@ static integer c__7 = 7;
     integer i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double c_abs(complex *);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n;
-    static complex z__[3];
-    static integer ia, in, kl, ku, ix, lda;
-    static real cond;
-    static integer mode;
-    static real dmax__;
-    static integer imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char uplo[1], type__[1];
-    static integer nrun;
+    integer i__, j, k, n;
+    complex z__[3];
+    integer ia, in, kl, ku, ix, lda;
+    real cond;
+    integer mode;
+    real dmax__;
+    integer imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char uplo[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *), cget04_(
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    real *, real *);
-    static integer nfail, iseed[4];
-    static real rcond;
+    integer nfail, iseed[4];
+    real rcond;
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static integer nimat;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int cptt01_(integer *, real *, complex *, real *, 
 	    complex *, complex *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), cptt02_(char *, integer *, integer *, real 
 	    *, complex *, complex *, integer *, complex *, integer *, real *), cptt05_(integer *, integer *, real *, complex *, complex 
 	    *, integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, real *);
-    static integer iuplo, izero, nerrs;     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *,  	    integer *);     static logical zerot;     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), alaerh_(char *, char *, integer *, 
+    integer iuplo, izero, nerrs;
+    extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
+	    integer *);
+    logical zerot;
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), alaerh_(char *, char *, integer *, 
 	    integer *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *);
-    static real rcondc;
+    real rcondc;
     extern doublereal clanht_(char *, integer *, real *, complex *);
     extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
 	    *), clacpy_(char *, integer *, integer *, complex *, integer *, 
@@ -105,11 +99,11 @@ static integer c__7 = 7;
     extern integer isamax_(integer *, real *, integer *);
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *), clarnv_(integer *, integer *, integer *, 
-	    complex *), cerrgt_(char *, integer *), clatms_(integer *,
+	    complex *), cerrgt_(char *, integer *), clatms_(integer *, 
 	     integer *, char *, integer *, char *, real *, integer *, real *, 
 	    real *, integer *, integer *, char *, complex *, integer *, 
 	    complex *, integer *);
-    static real ainvnm;
+    real ainvnm;
     extern /* Subroutine */ int cptcon_(integer *, real *, complex *, real *, 
 	    real *, real *, integer *);
     extern doublereal scasum_(integer *, complex *, integer *);
@@ -118,7 +112,7 @@ static integer c__7 = 7;
 	    integer *, real *, real *, complex *, real *, integer *), 
 	    cpttrf_(integer *, real *, complex *, integer *), slarnv_(integer 
 	    *, integer *, integer *, real *);
-    static real result[7];
+    real result[7];
     extern /* Subroutine */ int cpttrs_(char *, integer *, integer *, real *, 
 	    complex *, complex *, integer *, integer *);
 
@@ -129,69 +123,90 @@ static integer c__7 = 7;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKPT tests CPTTRF, -TRS, -RFS, and -CON   
+/*  CCHKPT tests CPTTRF, -TRS, -RFS, and -CON */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*2)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*2) */
 
-    D       (workspace) REAL array, dimension (NMAX*2)   
+/*  D       (workspace) REAL array, dimension (NMAX*2) */
 
-    E       (workspace) COMPLEX array, dimension (NMAX*2)   
+/*  E       (workspace) COMPLEX array, dimension (NMAX*2) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) REAL array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --xact;
@@ -205,6 +220,8 @@ static integer c__7 = 7;
     --dotype;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "PT", (ftnlen)2, (ftnlen)2);
@@ -252,8 +269,8 @@ static integer c__7 = 7;
 	    zerot = imat >= 8 && imat <= 10;
 	    if (imat <= 6) {
 
-/*              Type 1-6:  generate a Hermitian tridiagonal matrix of   
-                known condition number in lower triangular band storage. */
+/*              Type 1-6:  generate a Hermitian tridiagonal matrix of */
+/*              known condition number in lower triangular band storage. */
 
 		s_copy(srnamc_1.srnamt, "CLATMS", (ftnlen)6, (ftnlen)6);
 		clatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode, &cond, 
@@ -287,8 +304,8 @@ static integer c__7 = 7;
 		}
 	    } else {
 
-/*              Type 7-12:  generate a diagonally dominant matrix with   
-                unknown condition number in the vectors D and E. */
+/*              Type 7-12:  generate a diagonally dominant matrix with */
+/*              unknown condition number in the vectors D and E. */
 
 		if (! zerot || ! dotype[7]) {
 
@@ -304,7 +321,8 @@ static integer c__7 = 7;
 			d__[1] = dabs(d__[1]);
 		    } else {
 			d__[1] = dabs(d__[1]) + c_abs(&e[1]);
-			d__[n] = (r__1 = d__[n], dabs(r__1)) + c_abs(&e[n - 1] );
+			d__[n] = (r__1 = d__[n], dabs(r__1)) + c_abs(&e[n - 1]
+				);
 			i__3 = n - 1;
 			for (i__ = 2; i__ <= i__3; ++i__) {
 			    d__[i__] = (r__1 = d__[i__], dabs(r__1)) + c_abs(&
@@ -325,8 +343,8 @@ static integer c__7 = 7;
 
 		} else if (izero > 0) {
 
-/*                 Reuse the last matrix by copying back the zeroed out   
-                   elements. */
+/*                 Reuse the last matrix by copying back the zeroed out */
+/*                 elements. */
 
 		    if (izero == 1) {
 			d__[1] = z__[1].r;
@@ -348,8 +366,8 @@ static integer c__7 = 7;
 		    }
 		}
 
-/*              For types 8-10, set one row and column of the matrix to   
-                zero. */
+/*              For types 8-10, set one row and column of the matrix to */
+/*              zero. */
 
 		izero = 0;
 		if (imat == 8) {
@@ -395,9 +413,9 @@ static integer c__7 = 7;
 		ccopy_(&i__3, &e[1], &c__1, &e[n + 1], &c__1);
 	    }
 
-/* +    TEST 1   
-             Factor A as L*D*L' and compute the ratio   
-                norm(L*D*L' - A) / (n * norm(A) * EPS ) */
+/* +    TEST 1 */
+/*           Factor A as L*D*L' and compute the ratio */
+/*              norm(L*D*L' - A) / (n * norm(A) * EPS ) */
 
 	    cpttrf_(&n, &d__[n + 1], &e[n + 1], &info);
 
@@ -434,14 +452,14 @@ static integer c__7 = 7;
 	    }
 	    ++nrun;
 
-/*           Compute RCONDC = 1 / (norm(A) * norm(inv(A))   
+/*           Compute RCONDC = 1 / (norm(A) * norm(inv(A)) */
 
-             Compute norm(A). */
+/*           Compute norm(A). */
 
 	    anorm = clanht_("1", &n, &d__[1], &e[1]);
 
-/*           Use CPTTRS to solve for one column at a time of inv(A),   
-             computing the maximum column sum as we go. */
+/*           Use CPTTRS to solve for one column at a time of inv(A), */
+/*           computing the maximum column sum as we go. */
 
 	    ainvnm = 0.f;
 	    i__3 = n;
@@ -488,11 +506,11 @@ static integer c__7 = 7;
 
 /*              Set the right hand side. */
 
-		    claptm_(uplo, &n, &nrhs, &c_b48, &d__[1], &e[1], &xact[1],
+		    claptm_(uplo, &n, &nrhs, &c_b48, &d__[1], &e[1], &xact[1], 
 			     &lda, &c_b49, &b[1], &lda);
 
-/* +    TEST 2   
-                Solve A*x = b and compute the residual. */
+/* +    TEST 2 */
+/*              Solve A*x = b and compute the residual. */
 
 		    clacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &lda);
 		    cpttrs_(uplo, &n, &nrhs, &d__[n + 1], &e[n + 1], &x[1], &
@@ -510,20 +528,20 @@ static integer c__7 = 7;
 		    cptt02_(uplo, &n, &nrhs, &d__[1], &e[1], &x[1], &lda, &
 			    work[1], &lda, &result[1]);
 
-/* +    TEST 3   
-                Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*              Check solution from generated exact solution. */
 
 		    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &rcondc, &
 			    result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                Use iterative refinement to improve the solution. */
+/* +    TESTS 4, 5, and 6 */
+/*              Use iterative refinement to improve the solution. */
 
 		    s_copy(srnamc_1.srnamt, "CPTRFS", (ftnlen)6, (ftnlen)6);
 		    cptrfs_(uplo, &n, &nrhs, &d__[1], &e[1], &d__[n + 1], &e[
 			    n + 1], &b[1], &lda, &x[1], &lda, &rwork[1], &
 			    rwork[nrhs + 1], &work[1], &rwork[(nrhs << 1) + 1]
-			    , &info);
+, &info);
 
 /*              Check error code from CPTRFS. */
 
@@ -539,8 +557,8 @@ static integer c__7 = 7;
 			    lda, &xact[1], &lda, &rwork[1], &rwork[nrhs + 1], 
 			    &result[4]);
 
-/*              Print information about the tests that did not pass the   
-                threshold. */
+/*              Print information about the tests that did not pass the */
+/*              threshold. */
 
 		    for (k = 2; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
@@ -572,9 +590,9 @@ static integer c__7 = 7;
 /* L90: */
 	    }
 
-/* +    TEST 7   
-             Estimate the reciprocal of the condition number of the   
-             matrix. */
+/* +    TEST 7 */
+/*           Estimate the reciprocal of the condition number of the */
+/*           matrix. */
 
 L100:
 	    s_copy(srnamc_1.srnamt, "CPTCON", (ftnlen)6, (ftnlen)6);
