@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchksy.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -60,54 +48,67 @@ static integer c__8 = 8;
     /* System generated locals */
     integer i__1, i__2, i__3, i__4, i__5;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, nb, in, kl, ku, nt, lda, inb, ioff, 
-	    mode, imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char uplo[1], type__[1];
-    static integer nrun;
+    integer i__, j, k, n, i1, i2, nb, in, kl, ku, nt, lda, inb, ioff, mode, 
+	    imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char uplo[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *), cget04_(
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    real *, real *);
-    static integer nfail, iseed[4];
-    static real rcond;
-    static integer nimat;
+    integer nfail, iseed[4];
+    real rcond;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int cpot05_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *, complex *, integer *, complex 
 	    *, integer *, real *, real *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int csyt01_(char *, integer *, complex *, integer 
 	    *, complex *, integer *, integer *, complex *, integer *, real *, 
 	    real *), csyt02_(char *, integer *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *), csyt03_(char *, integer *, complex *, integer *, 
-	    complex *, integer *, complex *, integer *, real *, real *, real * );     static integer iuplo, izero, nerrs, lwork;     static logical zerot;     static char xtype[1];     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), alaerh_(char *, char *, integer *, 
+	    complex *, integer *, complex *, integer *, real *, real *, real *
+);
+    integer iuplo, izero, nerrs, lwork;
+    logical zerot;
+    char xtype[1];
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), alaerh_(char *, char *, integer *, 
 	    integer *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *);
-    static real rcondc;
+    real rcondc;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), clarhs_(char *, char 
 	    *, char *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, integer *, integer *), 
 	    alasum_(char *, integer *, integer *, integer *, integer *);
-    static real cndnum;
+    real cndnum;
     extern /* Subroutine */ int clatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, complex *, integer *, complex *, integer *);
-    extern doublereal clansy_(char *, char *, integer *, complex *, integer *,
+, char *, complex *, integer *, complex *, integer *);
+    extern doublereal clansy_(char *, char *, integer *, complex *, integer *, 
 	     real *);
-    static logical trfcon;     extern /* Subroutine */ int csycon_(char *, integer *, complex *, integer  	    *, integer *, real *, real *, complex *, integer *),  	    clatsy_(char *, integer *, complex *, integer *, integer *), xlaenv_(integer *, integer *), cerrsy_(char *, integer *), csyrfs_(char *, integer *, integer *, complex *,  	    integer *, complex *, integer *, integer *, complex *, integer *,  	    complex *, integer *, real *, real *, complex *, real *, integer * 	    ), csytrf_(char *, integer *, complex *, integer *, 
+    logical trfcon;
+    extern /* Subroutine */ int csycon_(char *, integer *, complex *, integer 
+	    *, integer *, real *, real *, complex *, integer *), 
+	    clatsy_(char *, integer *, complex *, integer *, integer *), xlaenv_(integer *, integer *), cerrsy_(char *, integer *), csyrfs_(char *, integer *, integer *, complex *, 
+	    integer *, complex *, integer *, integer *, complex *, integer *, 
+	    complex *, integer *, real *, real *, complex *, real *, integer *
+), csytrf_(char *, integer *, complex *, integer *, 
 	    integer *, complex *, integer *, integer *), csytri_(char 
 	    *, integer *, complex *, integer *, integer *, complex *, integer 
 	    *);
-    static real result[8];
+    real result[8];
     extern /* Subroutine */ int csytrs_(char *, integer *, integer *, complex 
 	    *, integer *, integer *, complex *, integer *, integer *);
 
@@ -118,81 +119,102 @@ static integer c__8 = 8;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKSY tests CSYTRF, -TRI, -TRS, -RFS, and -CON.   
+/*  CCHKSY tests CSYTRF, -TRI, -TRS, -RFS, and -CON. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB contained in the vector NBVAL.   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB contained in the vector NBVAL. */
 
-    NBVAL   (input) INTEGER array, dimension (NBVAL)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NBVAL) */
+/*          The values of the blocksize NB. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(2,NSMAX))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(2,NSMAX)) */
 
-    RWORK   (workspace) REAL array,   
-                                   dimension (NMAX+2*NSMAX)   
+/*  RWORK   (workspace) REAL array, */
+/*                                 dimension (NMAX+2*NSMAX) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -207,9 +229,11 @@ static integer c__8 = 8;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "SY", (ftnlen)2, (ftnlen)2);
@@ -264,8 +288,8 @@ static integer c__8 = 8;
 
 		if (imat != 11) {
 
-/*                 Set up parameters with CLATB4 and generate a test   
-                   matrix with CLATMS. */
+/*                 Set up parameters with CLATB4 and generate a test */
+/*                 matrix with CLATMS. */
 
 		    clatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &
 			    mode, &cndnum, dist);
@@ -284,8 +308,8 @@ static integer c__8 = 8;
 			goto L160;
 		    }
 
-/*                 For types 3-6, zero one or more rows and columns of   
-                   the matrix to test that INFO is returned correctly. */
+/*                 For types 3-6, zero one or more rows and columns of */
+/*                 the matrix to test that INFO is returned correctly. */
 
 		    if (zerot) {
 			if (imat == 3) {
@@ -375,8 +399,8 @@ static integer c__8 = 8;
 		    }
 		} else {
 
-/*                 Use a special block diagonal matrix to test alternate   
-                   code for the 2 x 2 blocks. */
+/*                 Use a special block diagonal matrix to test alternate */
+/*                 code for the 2 x 2 blocks. */
 
 		    clatsy_(uplo, &n, &a[1], &lda, iseed);
 		}
@@ -388,8 +412,8 @@ static integer c__8 = 8;
 		    nb = nbval[inb];
 		    xlaenv_(&c__1, &nb);
 
-/*                 Compute the L*D*L' or U*D*U' factorization of the   
-                   matrix. */
+/*                 Compute the L*D*L' or U*D*U' factorization of the */
+/*                 matrix. */
 
 		    clacpy_(uplo, &n, &n, &a[1], &lda, &afac[1], &lda);
 		    lwork = max(2,nb) * lda;
@@ -397,8 +421,8 @@ static integer c__8 = 8;
 		    csytrf_(uplo, &n, &afac[1], &lda, &iwork[1], &ainv[1], &
 			    lwork, &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -426,21 +450,21 @@ L100:
 			trfcon = FALSE_;
 		    }
 
-/* +    TEST 1   
-                   Reconstruct matrix from factors and compute residual. */
+/* +    TEST 1 */
+/*                 Reconstruct matrix from factors and compute residual. */
 
 		    csyt01_(uplo, &n, &a[1], &lda, &afac[1], &lda, &iwork[1], 
 			    &ainv[1], &lda, &rwork[1], result);
 		    nt = 1;
 
-/* +    TEST 2   
-                   Form the inverse and compute the residual. */
+/* +    TEST 2 */
+/*                 Form the inverse and compute the residual. */
 
 		    if (inb == 1 && ! trfcon) {
 			clacpy_(uplo, &n, &n, &afac[1], &lda, &ainv[1], &lda);
 			s_copy(srnamc_1.srnamt, "CSYTRI", (ftnlen)6, (ftnlen)
 				6);
-			csytri_(uplo, &n, &ainv[1], &lda, &iwork[1], &work[1],
+			csytri_(uplo, &n, &ainv[1], &lda, &iwork[1], &work[1], 
 				 &info);
 
 /*                 Check error code from CSYTRI. */
@@ -456,8 +480,8 @@ L100:
 			nt = 2;
 		    }
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    i__4 = nt;
 		    for (k = 1; k <= i__4; ++k) {
@@ -470,7 +494,8 @@ L100:
 			    do_fio(&c__1, uplo, (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&k, (ftnlen)sizeof(integer))
@@ -484,8 +509,8 @@ L100:
 		    }
 		    nrun += nt;
 
-/*                 Skip the other tests if this is not the first block   
-                   size. */
+/*                 Skip the other tests if this is not the first block */
+/*                 size. */
 
 		    if (inb > 1) {
 			goto L150;
@@ -502,8 +527,8 @@ L100:
 		    for (irhs = 1; irhs <= i__4; ++irhs) {
 			nrhs = nsval[irhs];
 
-/* +    TEST 3   
-                   Solve and compute residual for  A * X = B. */
+/* +    TEST 3 */
+/*                 Solve and compute residual for  A * X = B. */
 
 			s_copy(srnamc_1.srnamt, "CLARHS", (ftnlen)6, (ftnlen)
 				6);
@@ -530,20 +555,20 @@ L100:
 			csyt02_(uplo, &n, &nrhs, &a[1], &lda, &x[1], &lda, &
 				work[1], &lda, &rwork[1], &result[2]);
 
-/* +    TEST 4   
-                   Check solution from generated exact solution. */
+/* +    TEST 4 */
+/*                 Check solution from generated exact solution. */
 
 			cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				rcondc, &result[3]);
 
-/* +    TESTS 5, 6, and 7   
-                   Use iterative refinement to improve the solution. */
+/* +    TESTS 5, 6, and 7 */
+/*                 Use iterative refinement to improve the solution. */
 
 			s_copy(srnamc_1.srnamt, "CSYRFS", (ftnlen)6, (ftnlen)
 				6);
 			csyrfs_(uplo, &n, &nrhs, &a[1], &lda, &afac[1], &lda, 
 				&iwork[1], &b[1], &lda, &x[1], &lda, &rwork[1]
-				, &rwork[nrhs + 1], &work[1], &rwork[(nrhs << 
+, &rwork[nrhs + 1], &work[1], &rwork[(nrhs << 
 				1) + 1], &info);
 
 /*                 Check error code from CSYRFS. */
@@ -560,8 +585,8 @@ L100:
 				1], &lda, &xact[1], &lda, &rwork[1], &rwork[
 				nrhs + 1], &result[5]);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			for (k = 3; k <= 7; ++k) {
 			    if (result[k - 1] >= *thresh) {
@@ -590,8 +615,8 @@ L100:
 /* L130: */
 		    }
 
-/* +    TEST 8   
-                   Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 8 */
+/*                 Get an estimate of RCOND = 1/CNDNUM. */
 
 L140:
 		    anorm = clansy_("1", uplo, &n, &a[1], &lda, &rwork[1]);
@@ -609,8 +634,8 @@ L140:
 
 		    result[7] = sget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    if (result[7] >= *thresh) {
 			if (nfail == 0 && nerrs == 0) {
@@ -622,7 +647,8 @@ L140:
 			do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__8, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[7], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[7], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
