@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchktb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -70,73 +58,80 @@ static integer c__8 = 8;
     integer i__1, i__2, i__3, i__4, i__5, i__6[3], i__7[4];
     char ch__1[3], ch__2[4];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n, kd, ik, in, nk, lda, ldab;
-    static char diag[1];
-    static integer imat, info;
-    static char path[3];
-    static integer irhs, nrhs;
-    static char norm[1], uplo[1];
-    static integer nrun;
+    integer i__, j, k, n, kd, ik, in, nk, lda, ldab;
+    char diag[1];
+    integer imat, info;
+    char path[3];
+    integer irhs, nrhs;
+    char norm[1], uplo[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer idiag;
+    integer idiag;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static real scale;
-    static integer nfail, iseed[4];
+    real scale;
+    integer nfail, iseed[4];
     extern /* Subroutine */ int ctbt02_(char *, char *, char *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, complex *, real *, real *), ctbt03_(char *, char *, char *, integer *, integer *, 
-	    integer *, complex *, integer *, real *, real *, real *, complex * 	    , integer *, complex *, integer *, complex *, real *);     extern logical lsame_(char *, char *);     extern /* Subroutine */ int ctbt05_(char *, char *, char *, integer *,  	    integer *, integer *, complex *, integer *, complex *, integer *,  	    complex *, integer *, complex *, integer *, real *, real *, real * 	    ), ctbt06_(real *, real *, char *, char *,
+	    integer *, complex *, integer *, real *, real *, real *, complex *
+, integer *, complex *, integer *, complex *, real *);
+    extern logical lsame_(char *, char *);
+    extern /* Subroutine */ int ctbt05_(char *, char *, char *, integer *, 
+	    integer *, integer *, complex *, integer *, complex *, integer *, 
+	    complex *, integer *, complex *, integer *, real *, real *, real *
+), ctbt06_(real *, real *, char *, char *, 
 	     integer *, integer *, complex *, integer *, real *, real *);
-    static real rcond;
-    static integer nimat;
-    static real anorm;
-    static integer itran;
+    real rcond;
+    integer nimat;
+    real anorm;
+    integer itran;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), ctbsv_(char *, char *, char *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *);
-    static char trans[1];
-    static integer iuplo, nerrs;
-    static char xtype[1];
-    static integer nimat2;
+    char trans[1];
+    integer iuplo, nerrs;
+    char xtype[1];
+    integer nimat2;
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
     extern doublereal clantb_(char *, char *, char *, integer *, integer *, 
 	    complex *, integer *, real *);
-    static real rcondc;
+    real rcondc;
     extern /* Subroutine */ int clatbs_(char *, char *, char *, char *, 
 	    integer *, integer *, complex *, integer *, complex *, real *, 
 	    real *, integer *), clattb_(
 	    integer *, char *, char *, char *, integer *, integer *, integer *
-	    , complex *, integer *, complex *, complex *, real *, integer *), clacpy_(char *, integer *, integer *, 
+, complex *, integer *, complex *, complex *, real *, integer *), clacpy_(char *, integer *, integer *, 
 	    complex *, integer *, complex *, integer *), clarhs_(char 
 	    *, char *, char *, char *, integer *, integer *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, integer *, integer *), claset_(char *, integer *, integer *, complex *, 
 	    complex *, complex *, integer *);
-    static real rcondi;
+    real rcondi;
     extern /* Subroutine */ int ctbcon_(char *, char *, char *, integer *, 
 	    integer *, complex *, integer *, real *, complex *, real *, 
 	    integer *);
     extern doublereal clantr_(char *, char *, char *, integer *, integer *, 
 	    complex *, integer *, real *);
-    static real rcondo;
+    real rcondo;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *), ctbrfs_(char *, char *, char *, integer *, 
 	    integer *, integer *, complex *, integer *, complex *, integer *, 
-	    complex *, integer *, real *, real *, complex *, real *, integer * );
-    static real ainvnm;
+	    complex *, integer *, real *, real *, complex *, real *, integer *
+);
+    real ainvnm;
     extern /* Subroutine */ int cerrtr_(char *, integer *), ctbtrs_(
 	    char *, char *, char *, integer *, integer *, integer *, complex *
-	    , integer *, complex *, integer *, integer *);
-    static real result[8];
+, integer *, complex *, integer *, integer *);
+    real result[8];
 
     /* Fortran I/O blocks */
     static cilist io___39 = { 0, 0, 0, fmt_9999, 0 };
@@ -146,71 +141,92 @@ static integer c__8 = 8;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKTB tests CTBTRS, -RFS, and -CON, and CLATBS.   
+/*  CCHKTB tests CTBTRS, -RFS, and -CON, and CLATBS. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The leading dimension of the work arrays.   
-            NMAX >= the maximum value of N in NVAL.   
+/*  NMAX    (input) INTEGER */
+/*          The leading dimension of the work arrays. */
+/*          NMAX >= the maximum value of N in NVAL. */
 
-    AB      (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AB      (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) REAL array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --xact;
@@ -222,9 +238,11 @@ static integer c__8 = 8;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "TB", (ftnlen)2, (ftnlen)2);
@@ -264,8 +282,8 @@ static integer c__8 = 8;
 	i__2 = nk;
 	for (ik = 1; ik <= i__2; ++ik) {
 
-/*           Do for KD = 0, N, (3N-1)/4, and (N+1)/4. This order makes   
-             it easier to skip redundant values for small values of N. */
+/*           Do for KD = 0, N, (3N-1)/4, and (N+1)/4. This order makes */
+/*           it easier to skip redundant values for small values of N. */
 
 	    if (ik == 1) {
 		kd = 0;
@@ -297,7 +315,7 @@ static integer c__8 = 8;
 /*                 Call CLATTB to generate a triangular test matrix. */
 
 		    s_copy(srnamc_1.srnamt, "CLATTB", (ftnlen)6, (ftnlen)6);
-		    clattb_(&imat, uplo, "No transpose", diag, iseed, &n, &kd,
+		    clattb_(&imat, uplo, "No transpose", diag, iseed, &n, &kd, 
 			     &ab[1], &ldab, &x[1], &work[1], &rwork[1], &info);
 
 /*                 Set IDIAG = 1 for non-unit matrices, 2 for unit. */
@@ -308,8 +326,8 @@ static integer c__8 = 8;
 			idiag = 2;
 		    }
 
-/*                 Form the inverse of A so we can get a good estimate   
-                   of RCONDC = 1/(norm(A) * norm(inv(A))). */
+/*                 Form the inverse of A so we can get a good estimate */
+/*                 of RCONDC = 1/(norm(A) * norm(inv(A))). */
 
 		    claset_("Full", &n, &n, &c_b14, &c_b15, &ainv[1], &lda);
 		    if (lsame_(uplo, "U")) {
@@ -373,8 +391,8 @@ static integer c__8 = 8;
 				rcondc = rcondi;
 			    }
 
-/* +    TEST 1   
-                      Solve and compute residual for op(A)*x = b. */
+/* +    TEST 1 */
+/*                    Solve and compute residual for op(A)*x = b. */
 
 			    s_copy(srnamc_1.srnamt, "CLARHS", (ftnlen)6, (
 				    ftnlen)6);
@@ -387,7 +405,7 @@ static integer c__8 = 8;
 
 			    s_copy(srnamc_1.srnamt, "CTBTRS", (ftnlen)6, (
 				    ftnlen)6);
-			    ctbtrs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    ctbtrs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &x[1], &lda, &info);
 
 /*                    Check error code from CTBTRS. */
@@ -399,27 +417,27 @@ static integer c__8 = 8;
 				i__6[2] = 1, a__1[2] = diag;
 				s_cat(ch__1, a__1, i__6, &c__3, (ftnlen)3);
 				alaerh_(path, "CTBTRS", &info, &c__0, ch__1, &
-					n, &n, &kd, &kd, &nrhs, &imat, &nfail,
+					n, &n, &kd, &kd, &nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 			    }
 
-			    ctbt02_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    ctbt02_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &x[1], &lda, &b[1], &lda, &work[1]
-				    , &rwork[1], result);
+, &rwork[1], result);
 
-/* +    TEST 2   
-                      Check solution from generated exact solution. */
+/* +    TEST 2 */
+/*                    Check solution from generated exact solution. */
 
 			    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[1]);
 
-/* +    TESTS 3, 4, and 5   
-                      Use iterative refinement to improve the solution   
-                      and compute error bounds. */
+/* +    TESTS 3, 4, and 5 */
+/*                    Use iterative refinement to improve the solution */
+/*                    and compute error bounds. */
 
 			    s_copy(srnamc_1.srnamt, "CTBRFS", (ftnlen)6, (
 				    ftnlen)6);
-			    ctbrfs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    ctbrfs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &b[1], &lda, &x[1], &lda, &rwork[
 				    1], &rwork[nrhs + 1], &work[1], &rwork[(
 				    nrhs << 1) + 1], &info);
@@ -433,19 +451,19 @@ static integer c__8 = 8;
 				i__6[2] = 1, a__1[2] = diag;
 				s_cat(ch__1, a__1, i__6, &c__3, (ftnlen)3);
 				alaerh_(path, "CTBRFS", &info, &c__0, ch__1, &
-					n, &n, &kd, &kd, &nrhs, &imat, &nfail,
+					n, &n, &kd, &kd, &nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 			    }
 
 			    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[2]);
-			    ctbt05_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    ctbt05_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &b[1], &lda, &x[1], &lda, &xact[1]
-				    , &lda, &rwork[1], &rwork[nrhs + 1], &
+, &lda, &rwork[1], &rwork[nrhs + 1], &
 				    result[3]);
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 1; k <= 5; ++k) {
 				if (result[k - 1] >= *thresh) {
@@ -480,8 +498,8 @@ static integer c__8 = 8;
 /* L60: */
 		    }
 
-/* +    TEST 6   
-                      Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 6 */
+/*                    Get an estimate of RCOND = 1/CNDNUM. */
 
 		    for (itran = 1; itran <= 2; ++itran) {
 			if (itran == 1) {
@@ -505,7 +523,7 @@ static integer c__8 = 8;
 			    i__6[2] = 1, a__1[2] = diag;
 			    s_cat(ch__1, a__1, i__6, &c__3, (ftnlen)3);
 			    alaerh_(path, "CTBCON", &info, &c__0, ch__1, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
@@ -526,7 +544,8 @@ static integer c__8 = 8;
 			    do_fio(&c__1, diag, (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(
@@ -576,8 +595,8 @@ L90:
 			clattb_(&imat, uplo, trans, diag, iseed, &n, &kd, &ab[
 				1], &ldab, &x[1], &work[1], &rwork[1], &info);
 
-/* +    TEST 7   
-                      Solve the system op(A)*x = b */
+/* +    TEST 7 */
+/*                    Solve the system op(A)*x = b */
 
 			s_copy(srnamc_1.srnamt, "CLATBS", (ftnlen)6, (ftnlen)
 				6);
@@ -595,7 +614,7 @@ L90:
 			    i__7[3] = 1, a__2[3] = "N";
 			    s_cat(ch__2, a__2, i__7, &c__4, (ftnlen)4);
 			    alaerh_(path, "CLATBS", &info, &c__0, ch__2, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
@@ -603,8 +622,8 @@ L90:
 				ldab, &scale, &rwork[1], &c_b90, &b[1], &lda, 
 				&x[1], &lda, &work[1], &result[6]);
 
-/* +    TEST 8   
-                      Solve op(A)*x = b again with NORMIN = 'Y'. */
+/* +    TEST 8 */
+/*                    Solve op(A)*x = b again with NORMIN = 'Y'. */
 
 			ccopy_(&n, &x[1], &c__1, &b[1], &c__1);
 			clatbs_(uplo, trans, diag, "Y", &n, &kd, &ab[1], &
@@ -620,7 +639,7 @@ L90:
 			    i__7[3] = 1, a__2[3] = "Y";
 			    s_cat(ch__2, a__2, i__7, &c__4, (ftnlen)4);
 			    alaerh_(path, "CLATBS", &info, &c__0, ch__2, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
@@ -628,8 +647,8 @@ L90:
 				ldab, &scale, &rwork[1], &c_b90, &b[1], &lda, 
 				&x[1], &lda, &work[1], &result[7]);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			if (result[6] >= *thresh) {
 			    if (nfail == 0 && nerrs == 0) {
@@ -644,7 +663,8 @@ L90:
 			    do_fio(&c__1, "N", (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__7, (ftnlen)sizeof(
@@ -667,7 +687,8 @@ L90:
 			    do_fio(&c__1, "Y", (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__8, (ftnlen)sizeof(
