@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cchktr.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -73,28 +61,28 @@ static integer c__9 = 9;
     integer i__1, i__2, i__3[2], i__4, i__5[3], i__6[4];
     char ch__1[2], ch__2[3], ch__3[4];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, k, n, nb, in, lda, inb;
-    static char diag[1];
-    static integer imat, info;
-    static char path[3];
-    static integer irhs, nrhs;
-    static char norm[1], uplo[1];
-    static integer nrun;
+    integer i__, k, n, nb, in, lda, inb;
+    char diag[1];
+    integer imat, info;
+    char path[3];
+    integer irhs, nrhs;
+    char norm[1], uplo[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer idiag;
+    integer idiag;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static real scale;
-    static integer nfail, iseed[4];
+    real scale;
+    integer nfail, iseed[4];
     extern logical lsame_(char *, char *);
-    static real rcond, anorm;
-    static integer itran;
+    real rcond, anorm;
+    integer itran;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), ctrt01_(char *, char *, integer *, complex 
 	    *, integer *, complex *, integer *, real *, real *, real *), ctrt02_(char *, char *, char *, integer *, 
@@ -102,45 +90,46 @@ static integer c__9 = 9;
 	    integer *, complex *, real *, real *), 
 	    ctrt03_(char *, char *, char *, integer *, integer *, complex *, 
 	    integer *, real *, real *, real *, complex *, integer *, complex *
-	    , integer *, complex *, real *), ctrt05_(
+, integer *, complex *, real *), ctrt05_(
 	    char *, char *, char *, integer *, integer *, complex *, integer *
-	    , complex *, integer *, complex *, integer *, complex *, integer *
-	    , real *, real *, real *), ctrt06_(real *,
+, complex *, integer *, complex *, integer *, complex *, integer *
+, real *, real *, real *), ctrt06_(real *, 
 	     real *, char *, char *, integer *, complex *, integer *, real *, 
 	    real *);
-    static char trans[1];
-    static integer iuplo, nerrs;
-    static real dummy;
-    static char xtype[1];
+    char trans[1];
+    integer iuplo, nerrs;
+    real dummy;
+    char xtype[1];
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static real rcondc;
+    real rcondc;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), clarhs_(char *, char 
 	    *, char *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, integer *, integer *);
-    static real rcondi;
+    real rcondi;
     extern doublereal clantr_(char *, char *, char *, integer *, integer *, 
 	    complex *, integer *, real *);
-    static real rcondo;
+    real rcondo;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real ainvnm;
+    real ainvnm;
     extern /* Subroutine */ int clatrs_(char *, char *, char *, char *, 
 	    integer *, complex *, integer *, complex *, real *, real *, 
 	    integer *), clattr_(integer *, 
 	    char *, char *, char *, integer *, integer *, complex *, integer *
-	    , complex *, complex *, real *, integer *)
-	    , ctrcon_(char *, char *, char *, integer *, complex *, integer *,
+, complex *, complex *, real *, integer *)
+	    , ctrcon_(char *, char *, char *, integer *, complex *, integer *, 
 	     real *, complex *, real *, integer *), 
 	    xlaenv_(integer *, integer *), cerrtr_(char *, integer *),
 	     ctrrfs_(char *, char *, char *, integer *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, complex *, real *, integer *), 
-	    ctrtri_(char *, char *, integer *, complex *, integer *, integer * );
-    static real result[9];
+	    ctrtri_(char *, char *, integer *, complex *, integer *, integer *
+);
+    real result[9];
     extern /* Subroutine */ int ctrtrs_(char *, char *, char *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, integer *);
 
@@ -153,77 +142,98 @@ static integer c__9 = 9;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS   
+/*  CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB contained in the vector NBVAL.   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB contained in the vector NBVAL. */
 
-    NBVAL   (input) INTEGER array, dimension (NNB)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NNB) */
+/*          The values of the blocksize NB. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The leading dimension of the work arrays.   
-            NMAX >= the maximum value of N in NVAL.   
+/*  NMAX    (input) INTEGER */
+/*          The leading dimension of the work arrays. */
+/*          NMAX >= the maximum value of N in NVAL. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) REAL array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --xact;
@@ -236,9 +246,11 @@ static integer c__9 = 9;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "TR", (ftnlen)2, (ftnlen)2);
@@ -302,8 +314,8 @@ static integer c__9 = 9;
 		    nb = nbval[inb];
 		    xlaenv_(&c__1, &nb);
 
-/* +    TEST 1   
-                   Form the inverse of A. */
+/* +    TEST 1 */
+/*                 Form the inverse of A. */
 
 		    clacpy_(uplo, &n, &n, &a[1], &lda, &ainv[1], &lda);
 		    s_copy(srnamc_1.srnamt, "CTRTRI", (ftnlen)6, (ftnlen)6);
@@ -332,9 +344,9 @@ static integer c__9 = 9;
 			rcondi = 1.f / anorm / ainvnm;
 		    }
 
-/*                 Compute the residual for the triangular matrix times   
-                   its inverse.  Also compute the 1-norm condition number   
-                   of A. */
+/*                 Compute the residual for the triangular matrix times */
+/*                 its inverse.  Also compute the 1-norm condition number */
+/*                 of A. */
 
 		    ctrt01_(uplo, diag, &n, &a[1], &lda, &ainv[1], &lda, &
 			    rcondo, &rwork[1], result);
@@ -352,7 +364,8 @@ static integer c__9 = 9;
 			do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[0], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[0], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
@@ -383,13 +396,13 @@ static integer c__9 = 9;
 				rcondc = rcondi;
 			    }
 
-/* +    TEST 2   
-                         Solve and compute residual for op(A)*x = b. */
+/* +    TEST 2 */
+/*                       Solve and compute residual for op(A)*x = b. */
 
 			    s_copy(srnamc_1.srnamt, "CLARHS", (ftnlen)6, (
 				    ftnlen)6);
 			    clarhs_(path, xtype, uplo, trans, &n, &n, &c__0, &
-				    idiag, &nrhs, &a[1], &lda, &xact[1], &lda,
+				    idiag, &nrhs, &a[1], &lda, &xact[1], &lda, 
 				     &b[1], &lda, iseed, &info);
 			    *(unsigned char *)xtype = 'C';
 			    clacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &
@@ -397,7 +410,7 @@ static integer c__9 = 9;
 
 			    s_copy(srnamc_1.srnamt, "CTRTRS", (ftnlen)6, (
 				    ftnlen)6);
-			    ctrtrs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
+			    ctrtrs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
 				     &x[1], &lda, &info);
 
 /*                       Check error code from CTRTRS. */
@@ -419,23 +432,23 @@ static integer c__9 = 9;
 				dummy = a[1].r;
 			    }
 
-			    ctrt02_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
+			    ctrt02_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
 				     &x[1], &lda, &b[1], &lda, &work[1], &
 				    rwork[1], &result[1]);
 
-/* +    TEST 3   
-                         Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*                       Check solution from generated exact solution. */
 
 			    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                         Use iterative refinement to improve the solution   
-                         and compute error bounds. */
+/* +    TESTS 4, 5, and 6 */
+/*                       Use iterative refinement to improve the solution */
+/*                       and compute error bounds. */
 
 			    s_copy(srnamc_1.srnamt, "CTRRFS", (ftnlen)6, (
 				    ftnlen)6);
-			    ctrrfs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
+			    ctrrfs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
 				     &b[1], &lda, &x[1], &lda, &rwork[1], &
 				    rwork[nrhs + 1], &work[1], &rwork[(nrhs <<
 				     1) + 1], &info);
@@ -455,12 +468,12 @@ static integer c__9 = 9;
 
 			    cget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[3]);
-			    ctrt05_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
-				     &b[1], &lda, &x[1], &lda, &xact[1], &lda,
+			    ctrt05_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
+				     &b[1], &lda, &x[1], &lda, &xact[1], &lda, 
 				     &rwork[1], &rwork[nrhs + 1], &result[4]);
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 2; k <= 6; ++k) {
 				if (result[k - 1] >= *thresh) {
@@ -493,8 +506,8 @@ static integer c__9 = 9;
 /* L40: */
 		    }
 
-/* +    TEST 7   
-                         Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 7 */
+/*                       Get an estimate of RCOND = 1/CNDNUM. */
 
 		    for (itran = 1; itran <= 2; ++itran) {
 			if (itran == 1) {
@@ -586,8 +599,8 @@ L80:
 		    clattr_(&imat, uplo, trans, diag, iseed, &n, &a[1], &lda, 
 			    &x[1], &work[1], &rwork[1], &info);
 
-/* +    TEST 8   
-                   Solve the system op(A)*x = b. */
+/* +    TEST 8 */
+/*                 Solve the system op(A)*x = b. */
 
 		    s_copy(srnamc_1.srnamt, "CLATRS", (ftnlen)6, (ftnlen)6);
 		    ccopy_(&n, &x[1], &c__1, &b[1], &c__1);
@@ -608,16 +621,16 @@ L80:
 				nout);
 		    }
 
-		    ctrt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale,
+		    ctrt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale, 
 			     &rwork[1], &c_b99, &b[1], &lda, &x[1], &lda, &
 			    work[1], &result[7]);
 
-/* +    TEST 9   
-                   Solve op(A)*X = b again with NORMIN = 'Y'. */
+/* +    TEST 9 */
+/*                 Solve op(A)*X = b again with NORMIN = 'Y'. */
 
 		    ccopy_(&n, &x[1], &c__1, &b[n + 1], &c__1);
 		    clatrs_(uplo, trans, diag, "Y", &n, &a[1], &lda, &b[n + 1]
-			    , &scale, &rwork[1], &info);
+, &scale, &rwork[1], &info);
 
 /*                 Check error code from CLATRS. */
 
@@ -633,12 +646,12 @@ L80:
 				nout);
 		    }
 
-		    ctrt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale,
+		    ctrt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale, 
 			     &rwork[1], &c_b99, &b[n + 1], &lda, &x[1], &lda, 
 			    &work[1], &result[8]);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    if (result[7] >= *thresh) {
 			if (nfail == 0 && nerrs == 0) {
@@ -654,7 +667,8 @@ L80:
 			do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__8, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[7], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[7], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
@@ -672,7 +686,8 @@ L80:
 			do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__9, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[8], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[8], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
