@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvpb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -64,24 +52,24 @@ static complex c_b48 = {1.f,0.f};
     integer i__1, i__2, i__3, i__4, i__5, i__6, i__7[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, k, n, i1, i2, k1, kd, nb, in, kl, iw, ku, nt, lda, 
-	    ikd, nkd, ldab;
-    static char fact[1];
-    static integer ioff, mode, koff;
-    static real amax;
-    static char path[3];
-    static integer imat, info;
-    static char dist[1], uplo[1], type__[1];
-    static integer nrun, ifact;
+    integer i__, k, n, i1, i2, k1, kd, nb, in, kl, iw, ku, nt, lda, ikd, nkd, 
+	    ldab;
+    char fact[1];
+    integer ioff, mode, koff;
+    real amax;
+    char path[3];
+    integer imat, info;
+    char dist[1], uplo[1], type__[1];
+    integer nrun, ifact;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static integer nfail, iseed[4], nfact;
+    integer nfail, iseed[4], nfact;
     extern /* Subroutine */ int cpbt01_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *, real *, real *), 
 	    cpbt02_(char *, integer *, integer *, integer *, complex *, 
@@ -89,21 +77,27 @@ static complex c_b48 = {1.f,0.f};
 	    real *), cpbt05_(char *, integer *, integer *, integer *, 
 	    complex *, integer *, complex *, integer *, complex *, integer *, 
 	    complex *, integer *, real *, real *, real *);
-    static integer kdval[4];
+    integer kdval[4];
     extern logical lsame_(char *, char *);
-    static char equed[1];
-    static integer nbmin;
-    static real rcond, roldc, scond;
-    static integer nimat;
+    char equed[1];
+    integer nbmin;
+    real rcond, roldc, scond;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), cpbsv_(char *, integer *, integer *, 
 	    integer *, complex *, integer *, complex *, integer *, integer *);
-    static logical equil;
+    logical equil;
     extern /* Subroutine */ int cswap_(integer *, complex *, integer *, 
-	    complex *, integer *);     static integer iuplo, izero, nerrs;     static logical zerot;     static char xtype[1];     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), aladhd_(integer *, char *);
-    extern doublereal clanhb_(char *, char *, integer *, integer *, complex *,
+	    complex *, integer *);
+    integer iuplo, izero, nerrs;
+    logical zerot;
+    char xtype[1];
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), aladhd_(integer *, char *);
+    extern doublereal clanhb_(char *, char *, integer *, integer *, complex *, 
 	     integer *, real *), clange_(char *, integer *, 
 	    integer *, complex *, integer *, real *);
     extern /* Subroutine */ int claqhb_(char *, integer *, integer *, complex 
@@ -112,11 +106,11 @@ static complex c_b48 = {1.f,0.f};
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *), claipd_(integer *, 
 	    complex *, integer *, integer *);
-    static logical prefac;
-    static real rcondc;
-    static logical nofact;
-    static char packit[1];
-    static integer iequed;
+    logical prefac;
+    real rcondc;
+    logical nofact;
+    char packit[1];
+    integer iequed;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), clarhs_(char *, char 
 	    *, char *, char *, integer *, integer *, integer *, integer *, 
@@ -126,19 +120,19 @@ static complex c_b48 = {1.f,0.f};
 	    complex *, integer *), cpbequ_(char *, integer *, integer 
 	    *, complex *, integer *, real *, real *, real *, integer *), alasvm_(char *, integer *, integer *, integer *, integer 
 	    *);
-    static real cndnum;
+    real cndnum;
     extern /* Subroutine */ int clatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, complex *, integer *, complex *, integer *), cpbtrf_(char *, integer *, integer *, complex *, 
+, char *, complex *, integer *, complex *, integer *), cpbtrf_(char *, integer *, integer *, complex *, 
 	    integer *, integer *);
-    static real ainvnm;
+    real ainvnm;
     extern /* Subroutine */ int cpbtrs_(char *, integer *, integer *, integer 
 	    *, complex *, integer *, complex *, integer *, integer *),
-	     xlaenv_(integer *, integer *), cpbsvx_(char *, char *, integer *,
-	     integer *, integer *, complex *, integer *, complex *, integer *,
+	     xlaenv_(integer *, integer *), cpbsvx_(char *, char *, integer *, 
+	     integer *, integer *, complex *, integer *, complex *, integer *, 
 	     char *, real *, complex *, integer *, complex *, integer *, real 
 	    *, real *, real *, complex *, real *, integer *), cerrvx_(char *, integer *);
-    static real result[6];
+    real result[6];
 
     /* Fortran I/O blocks */
     static cilist io___57 = { 0, 0, 0, fmt_9999, 0 };
@@ -147,73 +141,94 @@ static complex c_b48 = {1.f,0.f};
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRVPB tests the driver routines CPBSV and -SVX.   
+/*  CDRVPB tests the driver routines CPBSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    ASAV    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  ASAV    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    BSAV    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  BSAV    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    S       (workspace) REAL array, dimension (NMAX)   
+/*  S       (workspace) REAL array, dimension (NMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NRHS))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --s;
@@ -227,9 +242,11 @@ static complex c_b48 = {1.f,0.f};
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "PB", (ftnlen)2, (ftnlen)2);
@@ -264,9 +281,9 @@ static complex c_b48 = {1.f,0.f};
 	lda = max(n,1);
 	*(unsigned char *)xtype = 'N';
 
-/*        Set limits on the number of loop iterations.   
+/*        Set limits on the number of loop iterations. */
 
-   Computing MAX */
+/* Computing MAX */
 	i__2 = 1, i__3 = min(n,4);
 	nkd = max(i__2,i__3);
 	nimat = 8;
@@ -281,9 +298,9 @@ static complex c_b48 = {1.f,0.f};
 	i__2 = nkd;
 	for (ikd = 1; ikd <= i__2; ++ikd) {
 
-/*           Do for KD = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This order   
-             makes it easier to skip redundant values for small values   
-             of N. */
+/*           Do for KD = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This order */
+/*           makes it easier to skip redundant values for small values */
+/*           of N. */
 
 	    kd = kdval[ikd - 1];
 	    ldab = kd + 1;
@@ -321,15 +338,15 @@ static complex c_b48 = {1.f,0.f};
 
 		    if (! zerot || ! dotype[1]) {
 
-/*                    Set up parameters with CLATB4 and generate a test   
-                      matrix with CLATMS. */
+/*                    Set up parameters with CLATB4 and generate a test */
+/*                    matrix with CLATMS. */
 
-			clatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm,
+			clatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, 
 				 &mode, &cndnum, dist);
 
 			s_copy(srnamc_1.srnamt, "CLATMS", (ftnlen)6, (ftnlen)
 				6);
-			clatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode,
+			clatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode, 
 				 &cndnum, &anorm, &kd, &kd, packit, &a[koff], 
 				&ldab, &work[1], &info);
 
@@ -343,8 +360,8 @@ static complex c_b48 = {1.f,0.f};
 			}
 		    } else if (izero > 0) {
 
-/*                    Use the same matrix for types 3 and 4 as for type   
-                      2 by copying back the zeroed out column, */
+/*                    Use the same matrix for types 3 and 4 as for type */
+/*                    2 by copying back the zeroed out column, */
 
 			iw = (lda << 1) + 1;
 			if (iuplo == 1) {
@@ -373,8 +390,8 @@ static complex c_b48 = {1.f,0.f};
 			}
 		    }
 
-/*                 For types 2-4, zero one row and column of the matrix   
-                   to test that INFO is returned correctly. */
+/*                 For types 2-4, zero one row and column of the matrix */
+/*                 to test that INFO is returned correctly. */
 
 		    izero = 0;
 		    if (zerot) {
@@ -469,18 +486,18 @@ static complex c_b48 = {1.f,0.f};
 
 			    } else if (! lsame_(fact, "N")) {
 
-/*                          Compute the condition number for comparison   
-                            with the value returned by CPBSVX (FACT =   
-                            'N' reuses the condition number from the   
-                            previous iteration with FACT = 'F'). */
+/*                          Compute the condition number for comparison */
+/*                          with the value returned by CPBSVX (FACT = */
+/*                          'N' reuses the condition number from the */
+/*                          previous iteration with FACT = 'F'). */
 
 				i__5 = kd + 1;
 				clacpy_("Full", &i__5, &n, &asav[1], &ldab, &
 					afac[1], &ldab);
 				if (equil || iequed > 1) {
 
-/*                             Compute row and column scale factors to   
-                               equilibrate the matrix A. */
+/*                             Compute row and column scale factors to */
+/*                             equilibrate the matrix A. */
 
 				    cpbequ_(uplo, &n, &kd, &afac[1], &ldab, &
 					    s[1], &scond, &amax, &info);
@@ -497,8 +514,8 @@ static complex c_b48 = {1.f,0.f};
 				    }
 				}
 
-/*                          Save the condition number of the   
-                            non-equilibrated system for use in CGET04. */
+/*                          Save the condition number of the */
+/*                          non-equilibrated system for use in CGET04. */
 
 				if (equil) {
 				    roldc = rcondc;
@@ -515,7 +532,7 @@ static complex c_b48 = {1.f,0.f};
 
 /*                          Form the inverse of A. */
 
-				claset_("Full", &n, &n, &c_b47, &c_b48, &a[1],
+				claset_("Full", &n, &n, &c_b47, &c_b48, &a[1], 
 					 &lda);
 				s_copy(srnamc_1.srnamt, "CPBTRS", (ftnlen)6, (
 					ftnlen)6);
@@ -536,16 +553,16 @@ static complex c_b48 = {1.f,0.f};
 /*                       Restore the matrix A. */
 
 			    i__5 = kd + 1;
-			    clacpy_("Full", &i__5, &n, &asav[1], &ldab, &a[1],
+			    clacpy_("Full", &i__5, &n, &asav[1], &ldab, &a[1], 
 				     &ldab);
 
-/*                       Form an exact solution and set the right hand   
-                         side. */
+/*                       Form an exact solution and set the right hand */
+/*                       side. */
 
 			    s_copy(srnamc_1.srnamt, "CLARHS", (ftnlen)6, (
 				    ftnlen)6);
 			    clarhs_(path, xtype, uplo, " ", &n, &n, &kd, &kd, 
-				    nrhs, &a[1], &ldab, &xact[1], &lda, &b[1],
+				    nrhs, &a[1], &ldab, &xact[1], &lda, &b[1], 
 				     &lda, iseed, &info);
 			    *(unsigned char *)xtype = 'C';
 			    clacpy_("Full", &n, nrhs, &b[1], &lda, &bsav[1], &
@@ -553,10 +570,10 @@ static complex c_b48 = {1.f,0.f};
 
 			    if (nofact) {
 
-/*                          --- Test CPBSV  ---   
+/*                          --- Test CPBSV  --- */
 
-                            Compute the L*L' or U'*U factorization of the   
-                            matrix and solve the system. */
+/*                          Compute the L*L' or U'*U factorization of the */
+/*                          matrix and solve the system. */
 
 				i__5 = kd + 1;
 				clacpy_("Full", &i__5, &n, &a[1], &ldab, &
@@ -580,10 +597,10 @@ static complex c_b48 = {1.f,0.f};
 				    goto L40;
 				}
 
-/*                          Reconstruct matrix from factors and compute   
-                            residual. */
+/*                          Reconstruct matrix from factors and compute */
+/*                          residual. */
 
-				cpbt01_(uplo, &n, &kd, &a[1], &ldab, &afac[1],
+				cpbt01_(uplo, &n, &kd, &a[1], &ldab, &afac[1], 
 					 &ldab, &rwork[1], result);
 
 /*                          Compute residual of the computed solution. */
@@ -596,12 +613,12 @@ static complex c_b48 = {1.f,0.f};
 
 /*                          Check solution from generated exact solution. */
 
-				cget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				cget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &rcondc, &result[2]);
 				nt = 3;
 
-/*                          Print information about the tests that did   
-                            not pass the threshold. */
+/*                          Print information about the tests that did */
+/*                          not pass the threshold. */
 
 				i__5 = nt;
 				for (k = 1; k <= i__5; ++k) {
@@ -644,20 +661,20 @@ L40:
 				    lda);
 			    if (iequed > 1 && n > 0) {
 
-/*                          Equilibrate the matrix if FACT='F' and   
-                            EQUED='Y' */
+/*                          Equilibrate the matrix if FACT='F' and */
+/*                          EQUED='Y' */
 
 				claqhb_(uplo, &n, &kd, &a[1], &ldab, &s[1], &
 					scond, &amax, equed);
 			    }
 
-/*                       Solve the system and compute the condition   
-                         number and error bounds using CPBSVX. */
+/*                       Solve the system and compute the condition */
+/*                       number and error bounds using CPBSVX. */
 
 			    s_copy(srnamc_1.srnamt, "CPBSVX", (ftnlen)6, (
 				    ftnlen)6);
 			    cpbsvx_(fact, uplo, &n, &kd, nrhs, &a[1], &ldab, &
-				    afac[1], &ldab, equed, &s[1], &b[1], &lda,
+				    afac[1], &ldab, equed, &s[1], &b[1], &lda, 
 				     &x[1], &lda, &rcond, &rwork[1], &rwork[*
 				    nrhs + 1], &work[1], &rwork[(*nrhs << 1) 
 				    + 1], &info);
@@ -670,7 +687,7 @@ L40:
 				i__7[1] = 1, a__1[1] = uplo;
 				s_cat(ch__1, a__1, i__7, &c__2, (ftnlen)2);
 				alaerh_(path, "CPBSVX", &info, &izero, ch__1, 
-					&n, &n, &kd, &kd, nrhs, &imat, &nfail,
+					&n, &n, &kd, &kd, nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 				goto L60;
 			    }
@@ -678,8 +695,8 @@ L40:
 			    if (info == 0) {
 				if (! prefac) {
 
-/*                             Reconstruct matrix from factors and   
-                               compute residual. */
+/*                             Reconstruct matrix from factors and */
+/*                             compute residual. */
 
 				    cpbt01_(uplo, &n, &kd, &a[1], &ldab, &
 					    afac[1], &ldab, &rwork[(*nrhs << 
@@ -707,8 +724,8 @@ L40:
 					    lda, &roldc, &result[2]);
 				}
 
-/*                          Check the error bounds from iterative   
-                            refinement. */
+/*                          Check the error bounds from iterative */
+/*                          refinement. */
 
 				cpbt05_(uplo, &n, &kd, nrhs, &asav[1], &ldab, 
 					&b[1], &lda, &x[1], &lda, &xact[1], &
@@ -718,13 +735,13 @@ L40:
 				k1 = 6;
 			    }
 
-/*                       Compare RCOND from CPBSVX with the computed   
-                         value in RCONDC. */
+/*                       Compare RCOND from CPBSVX with the computed */
+/*                       value in RCONDC. */
 
 			    result[5] = sget06_(&rcond, &rcondc);
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = k1; k <= 6; ++k) {
 				if (result[k - 1] >= *thresh) {
