@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvpp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -64,52 +52,58 @@ static complex c_b63 = {0.f,0.f};
     integer i__1, i__2, i__3, i__4, i__5[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, k, n, k1, in, kl, ku, nt, lda, npp;
-    static char fact[1];
-    static integer ioff, mode;
-    static real amax;
-    static char path[3];
-    static integer imat, info;
-    static char dist[1], uplo[1], type__[1];
-    static integer nrun, ifact;
+    integer i__, k, n, k1, in, kl, ku, nt, lda, npp;
+    char fact[1];
+    integer ioff, mode;
+    real amax;
+    char path[3];
+    integer imat, info;
+    char dist[1], uplo[1], type__[1];
+    integer nrun, ifact;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static integer nfail, iseed[4], nfact;
+    integer nfail, iseed[4], nfact;
     extern logical lsame_(char *, char *);
-    static char equed[1];
-    static real roldc, rcond, scond;
+    char equed[1];
+    real roldc, rcond, scond;
     extern /* Subroutine */ int cppt01_(char *, integer *, complex *, complex 
 	    *, real *, real *);
-    static integer nimat;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int cppt02_(char *, integer *, integer *, complex 
 	    *, complex *, integer *, complex *, integer *, real *, real *), cppt05_(char *, integer *, integer *, complex *, complex 
 	    *, integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *);
-    static logical equil;
-    static integer iuplo, izero, nerrs;
-    extern /* Subroutine */ int cppsv_(char *, integer *, integer *, complex * 	    , complex *, integer *, integer *);     static logical zerot;     static char xtype[1];     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), aladhd_(integer *, char *), 
+    logical equil;
+    integer iuplo, izero, nerrs;
+    extern /* Subroutine */ int cppsv_(char *, integer *, integer *, complex *
+, complex *, integer *, integer *);
+    logical zerot;
+    char xtype[1];
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), aladhd_(integer *, char *), 
 	    alaerh_(char *, char *, integer *, integer *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *), claipd_(integer *, 
 	    complex *, integer *, integer *);
-    static logical prefac;
+    logical prefac;
     extern doublereal clanhp_(char *, char *, integer *, complex *, real *);
-    static real rcondc;
+    real rcondc;
     extern /* Subroutine */ int claqhp_(char *, integer *, complex *, real *, 
 	    real *, real *, char *);
-    static logical nofact;
-    static char packit[1];
-    static integer iequed;
+    logical nofact;
+    char packit[1];
+    integer iequed;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), clarhs_(char *, char 
 	    *, char *, char *, integer *, integer *, integer *, integer *, 
@@ -118,16 +112,16 @@ static complex c_b63 = {0.f,0.f};
 	    claset_(char *, integer *, integer *, complex *, complex *, 
 	    complex *, integer *), alasvm_(char *, integer *, integer 
 	    *, integer *, integer *);
-    static real cndnum;
+    real cndnum;
     extern /* Subroutine */ int clatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, complex *, integer *, complex *, integer *);
-    static real ainvnm;
+, char *, complex *, integer *, complex *, integer *);
+    real ainvnm;
     extern /* Subroutine */ int cppequ_(char *, integer *, complex *, real *, 
 	    real *, real *, integer *), cpptrf_(char *, integer *, 
 	    complex *, integer *), cpptri_(char *, integer *, complex 
 	    *, integer *), cerrvx_(char *, integer *);
-    static real result[6];
+    real result[6];
     extern /* Subroutine */ int cppsvx_(char *, char *, integer *, integer *, 
 	    complex *, complex *, char *, real *, complex *, integer *, 
 	    complex *, integer *, real *, real *, real *, complex *, real *, 
@@ -140,73 +134,94 @@ static complex c_b63 = {0.f,0.f};
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRVPP tests the driver routines CPPSV and -SVX.   
+/*  CDRVPP tests the driver routines CPPSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*(NMAX+1)/2)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*(NMAX+1)/2) */
 
-    AFAC    (workspace) COMPLEX array, dimension (NMAX*(NMAX+1)/2)   
+/*  AFAC    (workspace) COMPLEX array, dimension (NMAX*(NMAX+1)/2) */
 
-    ASAV    (workspace) COMPLEX array, dimension (NMAX*(NMAX+1)/2)   
+/*  ASAV    (workspace) COMPLEX array, dimension (NMAX*(NMAX+1)/2) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    BSAV    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  BSAV    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    S       (workspace) REAL array, dimension (NMAX)   
+/*  S       (workspace) REAL array, dimension (NMAX) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NRHS))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --s;
@@ -220,9 +235,11 @@ static complex c_b63 = {0.f,0.f};
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "PP", (ftnlen)2, (ftnlen)2);
@@ -277,8 +294,8 @@ static complex c_b63 = {0.f,0.f};
 		*(unsigned char *)packit = *(unsigned char *)&packs[iuplo - 1]
 			;
 
-/*              Set up parameters with CLATB4 and generate a test matrix   
-                with CLATMS. */
+/*              Set up parameters with CLATB4 and generate a test matrix */
+/*              with CLATMS. */
 
 		clatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, 
 			&cndnum, dist);
@@ -292,13 +309,13 @@ static complex c_b63 = {0.f,0.f};
 /*              Check error code from CLATMS. */
 
 		if (info != 0) {
-		    alaerh_(path, "CLATMS", &info, &c__0, uplo, &n, &n, &c_n1,
+		    alaerh_(path, "CLATMS", &info, &c__0, uplo, &n, &n, &c_n1, 
 			     &c_n1, &c_n1, &imat, &nfail, &nerrs, nout);
 		    goto L120;
 		}
 
-/*              For types 3-5, zero one row and column of the matrix to   
-                test that INFO is returned correctly. */
+/*              For types 3-5, zero one row and column of the matrix to */
+/*              test that INFO is returned correctly. */
 
 		if (zerot) {
 		    if (imat == 3) {
@@ -386,16 +403,16 @@ static complex c_b63 = {0.f,0.f};
 			} else if (! lsame_(fact, "N")) 
 				{
 
-/*                       Compute the condition number for comparison with   
-                         the value returned by CPPSVX (FACT = 'N' reuses   
-                         the condition number from the previous iteration   
-                            with FACT = 'F'). */
+/*                       Compute the condition number for comparison with */
+/*                       the value returned by CPPSVX (FACT = 'N' reuses */
+/*                       the condition number from the previous iteration */
+/*                          with FACT = 'F'). */
 
 			    ccopy_(&npp, &asav[1], &c__1, &afac[1], &c__1);
 			    if (equil || iequed > 1) {
 
-/*                          Compute row and column scale factors to   
-                            equilibrate the matrix A. */
+/*                          Compute row and column scale factors to */
+/*                          equilibrate the matrix A. */
 
 				cppequ_(uplo, &n, &afac[1], &s[1], &scond, &
 					amax, &info);
@@ -406,13 +423,13 @@ static complex c_b63 = {0.f,0.f};
 
 /*                             Equilibrate the matrix. */
 
-				    claqhp_(uplo, &n, &afac[1], &s[1], &scond,
+				    claqhp_(uplo, &n, &afac[1], &s[1], &scond, 
 					     &amax, equed);
 				}
 			    }
 
-/*                       Save the condition number of the   
-                         non-equilibrated system for use in CGET04. */
+/*                       Save the condition number of the */
+/*                       non-equilibrated system for use in CGET04. */
 
 			    if (equil) {
 				roldc = rcondc;
@@ -420,7 +437,8 @@ static complex c_b63 = {0.f,0.f};
 
 /*                       Compute the 1-norm of A. */
 
-			    anorm = clanhp_("1", uplo, &n, &afac[1], &rwork[1] );
+			    anorm = clanhp_("1", uplo, &n, &afac[1], &rwork[1]
+);
 
 /*                       Factor the matrix A. */
 
@@ -457,10 +475,10 @@ static complex c_b63 = {0.f,0.f};
 
 			if (nofact) {
 
-/*                       --- Test CPPSV  ---   
+/*                       --- Test CPPSV  --- */
 
-                         Compute the L*L' or U'*U factorization of the   
-                         matrix and solve the system. */
+/*                       Compute the L*L' or U'*U factorization of the */
+/*                       matrix and solve the system. */
 
 			    ccopy_(&npp, &a[1], &c__1, &afac[1], &c__1);
 			    clacpy_("Full", &n, nrhs, &b[1], &lda, &x[1], &
@@ -482,8 +500,8 @@ static complex c_b63 = {0.f,0.f};
 				goto L70;
 			    }
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    cppt01_(uplo, &n, &a[1], &afac[1], &rwork[1], 
 				    result);
@@ -501,8 +519,8 @@ static complex c_b63 = {0.f,0.f};
 				    rcondc, &result[2]);
 			    nt = 3;
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    i__4 = nt;
 			    for (k = 1; k <= i__4; ++k) {
@@ -541,15 +559,15 @@ L70:
 			claset_("Full", &n, nrhs, &c_b63, &c_b63, &x[1], &lda);
 			if (iequed > 1 && n > 0) {
 
-/*                       Equilibrate the matrix if FACT='F' and   
-                         EQUED='Y'. */
+/*                       Equilibrate the matrix if FACT='F' and */
+/*                       EQUED='Y'. */
 
 			    claqhp_(uplo, &n, &a[1], &s[1], &scond, &amax, 
 				    equed);
 			}
 
-/*                    Solve the system and compute the condition number   
-                      and error bounds using CPPSVX. */
+/*                    Solve the system and compute the condition number */
+/*                    and error bounds using CPPSVX. */
 
 			s_copy(srnamc_1.srnamt, "CPPSVX", (ftnlen)6, (ftnlen)
 				6);
@@ -574,8 +592,8 @@ L70:
 			if (info == 0) {
 			    if (! prefac) {
 
-/*                          Reconstruct matrix from factors and compute   
-                            residual. */
+/*                          Reconstruct matrix from factors and compute */
+/*                          residual. */
 
 				cppt01_(uplo, &n, &a[1], &afac[1], &rwork[(*
 					nrhs << 1) + 1], result);
@@ -587,7 +605,7 @@ L70:
 /*                       Compute residual of the computed solution. */
 
 			    clacpy_("Full", &n, nrhs, &bsav[1], &lda, &work[1]
-				    , &lda);
+, &lda);
 			    cppt02_(uplo, &n, nrhs, &asav[1], &x[1], &lda, &
 				    work[1], &lda, &rwork[(*nrhs << 1) + 1], &
 				    result[1]);
@@ -595,15 +613,15 @@ L70:
 /*                       Check solution from generated exact solution. */
 
 			    if (nofact || prefac && lsame_(equed, "N")) {
-				cget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				cget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &rcondc, &result[2]);
 			    } else {
-				cget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				cget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &roldc, &result[2]);
 			    }
 
-/*                       Check the error bounds from iterative   
-                         refinement. */
+/*                       Check the error bounds from iterative */
+/*                       refinement. */
 
 			    cppt05_(uplo, &n, nrhs, &asav[1], &b[1], &lda, &x[
 				    1], &lda, &xact[1], &lda, &rwork[1], &
@@ -612,13 +630,13 @@ L70:
 			    k1 = 6;
 			}
 
-/*                    Compare RCOND from CPPSVX with the computed value   
-                      in RCONDC. */
+/*                    Compare RCOND from CPPSVX with the computed value */
+/*                    in RCONDC. */
 
 			result[5] = sget06_(&rcond, &rcondc);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			for (k = k1; k <= 6; ++k) {
 			    if (result[k - 1] >= *thresh) {
