@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvpt.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -57,67 +45,73 @@ static complex c_b62 = {0.f,0.f};
     integer i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double c_abs(complex *);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n;
-    static real z__[3];
-    static integer k1, ia, in, kl, ku, ix, nt, lda;
-    static char fact[1];
-    static real cond;
-    static integer mode;
-    static real dmax__;
-    static integer imat, info;
-    static char path[3], dist[1], type__[1];
-    static integer nrun, ifact;
+    integer i__, j, k, n;
+    real z__[3];
+    integer k1, ia, in, kl, ku, ix, nt, lda;
+    char fact[1];
+    real cond;
+    integer mode;
+    real dmax__;
+    integer imat, info;
+    char path[3], dist[1], type__[1];
+    integer nrun, ifact;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static integer nfail, iseed[4];
-    static real rcond;
+    integer nfail, iseed[4];
+    real rcond;
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static integer nimat;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int cptt01_(integer *, real *, complex *, real *, 
 	    complex *, complex *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), cptt02_(char *, integer *, integer *, real 
 	    *, complex *, complex *, integer *, complex *, integer *, real *), cptt05_(integer *, integer *, real *, complex *, complex 
 	    *, integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, real *);
-    static integer izero, nerrs;
-    extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *,  	    integer *), cptsv_(integer *, integer *, real *, complex *,  	    complex *, integer *, integer *);     static logical zerot;     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), aladhd_(integer *, char *), 
+    integer izero, nerrs;
+    extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
+	    integer *), cptsv_(integer *, integer *, real *, complex *, 
+	    complex *, integer *, integer *);
+    logical zerot;
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), aladhd_(integer *, char *), 
 	    alaerh_(char *, char *, integer *, integer *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *);
-    static real rcondc;
+    real rcondc;
     extern doublereal clanht_(char *, integer *, real *, complex *);
     extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
 	    *), clacpy_(char *, integer *, integer *, complex *, integer *, 
 	    complex *, integer *), claset_(char *, integer *, integer 
 	    *, complex *, complex *, complex *, integer *), claptm_(
 	    char *, integer *, integer *, real *, real *, complex *, complex *
-	    , integer *, real *, complex *, integer *);
+, integer *, real *, complex *, integer *);
     extern integer isamax_(integer *, real *, integer *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *), clarnv_(integer *, integer *, integer *, 
 	    complex *), clatms_(integer *, integer *, char *, integer *, char 
 	    *, real *, integer *, real *, real *, integer *, integer *, char *
-	    , complex *, integer *, complex *, integer *);
-    static real ainvnm;
+, complex *, integer *, complex *, integer *);
+    real ainvnm;
     extern doublereal scasum_(integer *, complex *, integer *);
     extern /* Subroutine */ int cpttrf_(integer *, real *, complex *, integer 
 	    *), slarnv_(integer *, integer *, integer *, real *), cerrvx_(
 	    char *, integer *);
-    static real result[6];
+    real result[6];
     extern /* Subroutine */ int cpttrs_(char *, integer *, integer *, real *, 
 	    complex *, complex *, integer *, integer *), cptsvx_(char 
 	    *, integer *, integer *, real *, complex *, real *, complex *, 
 	    complex *, integer *, complex *, integer *, real *, real *, real *
-	    , complex *, real *, integer *);
+, complex *, real *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___35 = { 0, 0, 0, fmt_9999, 0 };
@@ -125,65 +119,86 @@ static complex c_b62 = {0.f,0.f};
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRVPT tests CPTSV and -SVX.   
+/*  CDRVPT tests CPTSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*2)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*2) */
 
-    D       (workspace) REAL array, dimension (NMAX*2)   
+/*  D       (workspace) REAL array, dimension (NMAX*2) */
 
-    E       (workspace) COMPLEX array, dimension (NMAX*2)   
+/*  E       (workspace) COMPLEX array, dimension (NMAX*2) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(3,NRHS))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(3,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --xact;
@@ -196,6 +211,8 @@ static complex c_b62 = {0.f,0.f};
     --dotype;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "PT", (ftnlen)2, (ftnlen)2);
@@ -243,8 +260,8 @@ static complex c_b62 = {0.f,0.f};
 	    zerot = imat >= 8 && imat <= 10;
 	    if (imat <= 6) {
 
-/*              Type 1-6:  generate a symmetric tridiagonal matrix of   
-                known condition number in lower triangular band storage. */
+/*              Type 1-6:  generate a symmetric tridiagonal matrix of */
+/*              known condition number in lower triangular band storage. */
 
 		s_copy(srnamc_1.srnamt, "CLATMS", (ftnlen)6, (ftnlen)6);
 		clatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode, &cond, 
@@ -280,8 +297,8 @@ static complex c_b62 = {0.f,0.f};
 		}
 	    } else {
 
-/*              Type 7-12:  generate a diagonally dominant matrix with   
-                unknown condition number in the vectors D and E. */
+/*              Type 7-12:  generate a diagonally dominant matrix with */
+/*              unknown condition number in the vectors D and E. */
 
 		if (! zerot || ! dotype[7]) {
 
@@ -297,7 +314,8 @@ static complex c_b62 = {0.f,0.f};
 			d__[1] = dabs(d__[1]);
 		    } else {
 			d__[1] = dabs(d__[1]) + c_abs(&e[1]);
-			d__[n] = (r__1 = d__[n], dabs(r__1)) + c_abs(&e[n - 1] );
+			d__[n] = (r__1 = d__[n], dabs(r__1)) + c_abs(&e[n - 1]
+				);
 			i__3 = n - 1;
 			for (i__ = 2; i__ <= i__3; ++i__) {
 			    d__[i__] = (r__1 = d__[i__], dabs(r__1)) + c_abs(&
@@ -320,8 +338,8 @@ static complex c_b62 = {0.f,0.f};
 
 		} else if (izero > 0) {
 
-/*                 Reuse the last matrix by copying back the zeroed out   
-                   elements. */
+/*                 Reuse the last matrix by copying back the zeroed out */
+/*                 elements. */
 
 		    if (izero == 1) {
 			d__[1] = z__[1];
@@ -341,8 +359,8 @@ static complex c_b62 = {0.f,0.f};
 		    }
 		}
 
-/*              For types 8-10, set one row and column of the matrix to   
-                zero. */
+/*              For types 8-10, set one row and column of the matrix to */
+/*              zero. */
 
 		izero = 0;
 		if (imat == 8) {
@@ -392,7 +410,7 @@ static complex c_b62 = {0.f,0.f};
 
 /*           Set the right hand side. */
 
-	    claptm_("Lower", &n, nrhs, &c_b24, &d__[1], &e[1], &xact[1], &lda,
+	    claptm_("Lower", &n, nrhs, &c_b24, &d__[1], &e[1], &xact[1], &lda, 
 		     &c_b25, &b[1], &lda);
 
 	    for (ifact = 1; ifact <= 2; ++ifact) {
@@ -402,8 +420,8 @@ static complex c_b62 = {0.f,0.f};
 		    *(unsigned char *)fact = 'N';
 		}
 
-/*              Compute the condition number for comparison with   
-                the value returned by CPTSVX. */
+/*              Compute the condition number for comparison with */
+/*              the value returned by CPTSVX. */
 
 		if (zerot) {
 		    if (ifact == 1) {
@@ -427,8 +445,8 @@ static complex c_b62 = {0.f,0.f};
 
 		    cpttrf_(&n, &d__[n + 1], &e[n + 1], &info);
 
-/*                 Use CPTTRS to solve for one column at a time of   
-                   inv(A), computing the maximum column sum as we go. */
+/*                 Use CPTTRS to solve for one column at a time of */
+/*                 inv(A), computing the maximum column sum as we go. */
 
 		    ainvnm = 0.f;
 		    i__3 = n;
@@ -485,8 +503,8 @@ static complex c_b62 = {0.f,0.f};
 		    nt = 0;
 		    if (izero == 0) {
 
-/*                    Check the factorization by computing the ratio   
-                         norm(L*D*L' - A) / (n * norm(A) * EPS ) */
+/*                    Check the factorization by computing the ratio */
+/*                       norm(L*D*L' - A) / (n * norm(A) * EPS ) */
 
 			cptt01_(&n, &d__[1], &e[1], &d__[n + 1], &e[n + 1], &
 				work[1], result);
@@ -504,8 +522,8 @@ static complex c_b62 = {0.f,0.f};
 			nt = 3;
 		    }
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    i__3 = nt;
 		    for (k = 1; k <= i__3; ++k) {
@@ -552,12 +570,12 @@ static complex c_b62 = {0.f,0.f};
 
 		claset_("Full", &n, nrhs, &c_b62, &c_b62, &x[1], &lda);
 
-/*              Solve the system and compute the condition number and   
-                error bounds using CPTSVX. */
+/*              Solve the system and compute the condition number and */
+/*              error bounds using CPTSVX. */
 
 		s_copy(srnamc_1.srnamt, "CPTSVX", (ftnlen)6, (ftnlen)6);
 		cptsvx_(fact, &n, nrhs, &d__[1], &e[1], &d__[n + 1], &e[n + 1]
-			, &b[1], &lda, &x[1], &lda, &rcond, &rwork[1], &rwork[
+, &b[1], &lda, &x[1], &lda, &rcond, &rwork[1], &rwork[
 			*nrhs + 1], &work[1], &rwork[(*nrhs << 1) + 1], &info);
 
 /*              Check the error code from CPTSVX. */
@@ -569,8 +587,8 @@ static complex c_b62 = {0.f,0.f};
 		if (izero == 0) {
 		    if (ifact == 2) {
 
-/*                    Check the factorization by computing the ratio   
-                         norm(L*D*L' - A) / (n * norm(A) * EPS ) */
+/*                    Check the factorization by computing the ratio */
+/*                       norm(L*D*L' - A) / (n * norm(A) * EPS ) */
 
 			k1 = 1;
 			cptt01_(&n, &d__[1], &e[1], &d__[n + 1], &e[n + 1], &
@@ -593,7 +611,7 @@ static complex c_b62 = {0.f,0.f};
 /*                 Check error bounds from iterative refinement. */
 
 		    cptt05_(&n, nrhs, &d__[1], &e[1], &b[1], &lda, &x[1], &
-			    lda, &xact[1], &lda, &rwork[1], &rwork[*nrhs + 1],
+			    lda, &xact[1], &lda, &rwork[1], &rwork[*nrhs + 1], 
 			     &result[3]);
 		} else {
 		    k1 = 6;
@@ -603,8 +621,8 @@ static complex c_b62 = {0.f,0.f};
 
 		result[5] = sget06_(&rcond, &rcondc);
 
-/*              Print information about the tests that did not pass   
-                the threshold. */
+/*              Print information about the tests that did not pass */
+/*              the threshold. */
 
 		for (k = k1; k <= 6; ++k) {
 		    if (result[k - 1] >= *thresh) {
