@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvsp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -58,40 +46,46 @@ static complex c_b61 = {0.f,0.f};
     integer i__1, i__2, i__3, i__4, i__5, i__6[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda, npp;
-    static char fact[1];
-    static integer ioff, mode, imat, info;
-    static char path[3], dist[1], uplo[1], type__[1];
-    static integer nrun, ifact;
+    integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda, npp;
+    char fact[1];
+    integer ioff, mode, imat, info;
+    char path[3], dist[1], uplo[1], type__[1];
+    integer nrun, ifact;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static integer nfail, iseed[4], nbmin;
-    static real rcond;
-    static integer nimat;
+    integer nfail, iseed[4], nbmin;
+    real rcond;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int cspt01_(char *, integer *, complex *, complex 
 	    *, integer *, complex *, integer *, real *, real *), 
 	    cppt05_(char *, integer *, integer *, complex *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), cspt02_(char *, integer *, integer *, 
 	    complex *, complex *, integer *, complex *, integer *, real *, 
 	    real *);
-    static integer iuplo, izero, nerrs;
-    extern /* Subroutine */ int cspsv_(char *, integer *, integer *, complex * 	    , integer *, complex *, integer *, integer *);     static logical zerot;     static char xtype[1];     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), aladhd_(integer *, char *), 
+    integer iuplo, izero, nerrs;
+    extern /* Subroutine */ int cspsv_(char *, integer *, integer *, complex *
+, integer *, complex *, integer *, integer *);
+    logical zerot;
+    char xtype[1];
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), aladhd_(integer *, char *), 
 	    alaerh_(char *, char *, integer *, integer *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *);
-    static real rcondc;
-    static char packit[1];
+    real rcondc;
+    char packit[1];
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), clarhs_(char *, char 
 	    *, char *, char *, integer *, integer *, integer *, integer *, 
@@ -102,15 +96,15 @@ static complex c_b61 = {0.f,0.f};
     extern doublereal clansp_(char *, char *, integer *, complex *, real *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real cndnum;
+    real cndnum;
     extern /* Subroutine */ int clatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, complex *, integer *, complex *, integer *), clatsp_(char *, integer *, complex *, integer * );
-    static real ainvnm;
-    extern /* Subroutine */ int xlaenv_(integer *, integer *), csptrf_(char *,
+, char *, complex *, integer *, complex *, integer *), clatsp_(char *, integer *, complex *, integer *);
+    real ainvnm;
+    extern /* Subroutine */ int xlaenv_(integer *, integer *), csptrf_(char *, 
 	     integer *, complex *, integer *, integer *), csptri_(
 	    char *, integer *, complex *, integer *, complex *, integer *), cerrvx_(char *, integer *);
-    static real result[6];
+    real result[6];
     extern /* Subroutine */ int cspsvx_(char *, char *, integer *, integer *, 
 	    complex *, complex *, integer *, complex *, integer *, complex *, 
 	    integer *, real *, real *, real *, complex *, real *, integer *);
@@ -121,74 +115,95 @@ static complex c_b61 = {0.f,0.f};
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRVSP tests the driver routines CSPSV and -SVX.   
+/*  CDRVSP tests the driver routines CSPSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  A       (workspace) COMPLEX array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AFAC    (workspace) COMPLEX array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AFAC    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AINV    (workspace) COMPLEX array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AINV    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(2,NRHS))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(2,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -201,9 +216,11 @@ static complex c_b61 = {0.f,0.f};
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "SP", (ftnlen)2, (ftnlen)2);
@@ -271,8 +288,8 @@ static complex c_b61 = {0.f,0.f};
 
 		if (imat != 11) {
 
-/*                 Set up parameters with CLATB4 and generate a test   
-                   matrix with CLATMS. */
+/*                 Set up parameters with CLATB4 and generate a test */
+/*                 matrix with CLATMS. */
 
 		    clatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &
 			    mode, &cndnum, dist);
@@ -291,8 +308,8 @@ static complex c_b61 = {0.f,0.f};
 			goto L160;
 		    }
 
-/*                 For types 3-6, zero one or more rows and columns of   
-                   the matrix to test that INFO is returned correctly. */
+/*                 For types 3-6, zero one or more rows and columns of */
+/*                 the matrix to test that INFO is returned correctly. */
 
 		    if (zerot) {
 			if (imat == 3) {
@@ -382,8 +399,8 @@ static complex c_b61 = {0.f,0.f};
 		    }
 		} else {
 
-/*                 Use a special block diagonal matrix to test alternate   
-                   code for the 2-by-2 blocks. */
+/*                 Use a special block diagonal matrix to test alternate */
+/*                 code for the 2-by-2 blocks. */
 
 		    clatsp_(uplo, &n, &a[1], iseed);
 		}
@@ -395,8 +412,8 @@ static complex c_b61 = {0.f,0.f};
 		    *(unsigned char *)fact = *(unsigned char *)&facts[ifact - 
 			    1];
 
-/*                 Compute the condition number for comparison with   
-                   the value returned by CSPSVX. */
+/*                 Compute the condition number for comparison with */
+/*                 the value returned by CSPSVX. */
 
 		    if (zerot) {
 			if (ifact == 1) {
@@ -452,8 +469,8 @@ static complex c_b61 = {0.f,0.f};
 			cspsv_(uplo, &n, nrhs, &afac[1], &iwork[1], &x[1], &
 				lda, &info);
 
-/*                    Adjust the expected value of INFO to account for   
-                      pivoting. */
+/*                    Adjust the expected value of INFO to account for */
+/*                    pivoting. */
 
 			k = izero;
 			if (k > 0) {
@@ -480,11 +497,11 @@ L100:
 			    goto L120;
 			}
 
-/*                    Reconstruct matrix from factors and compute   
-                      residual. */
+/*                    Reconstruct matrix from factors and compute */
+/*                    residual. */
 
 			cspt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &ainv[1]
-				, &lda, &rwork[1], result);
+, &lda, &rwork[1], result);
 
 /*                    Compute residual of the computed solution. */
 
@@ -498,8 +515,8 @@ L100:
 				rcondc, &result[2]);
 			nt = 3;
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			i__3 = nt;
 			for (k = 1; k <= i__3; ++k) {
@@ -532,13 +549,13 @@ L120:
 /*                 --- Test CSPSVX --- */
 
 		    if (ifact == 2 && npp > 0) {
-			claset_("Full", &npp, &c__1, &c_b61, &c_b61, &afac[1],
+			claset_("Full", &npp, &c__1, &c_b61, &c_b61, &afac[1], 
 				 &npp);
 		    }
 		    claset_("Full", &n, nrhs, &c_b61, &c_b61, &x[1], &lda);
 
-/*                 Solve the system and compute the condition number and   
-                   error bounds using CSPSVX. */
+/*                 Solve the system and compute the condition number and */
+/*                 error bounds using CSPSVX. */
 
 		    s_copy(srnamc_1.srnamt, "CSPSVX", (ftnlen)6, (ftnlen)6);
 		    cspsvx_(fact, uplo, &n, nrhs, &a[1], &afac[1], &iwork[1], 
@@ -546,8 +563,8 @@ L120:
 			    rwork[*nrhs + 1], &work[1], &rwork[(*nrhs << 1) + 
 			    1], &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -579,8 +596,8 @@ L130:
 		    if (info == 0) {
 			if (ifact >= 2) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    cspt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &
 				    ainv[1], &lda, &rwork[(*nrhs << 1) + 1], 
@@ -610,13 +627,13 @@ L130:
 			k1 = 6;
 		    }
 
-/*                 Compare RCOND from CSPSVX with the computed value   
-                   in RCONDC. */
+/*                 Compare RCOND from CSPSVX with the computed value */
+/*                 in RCONDC. */
 
 		    result[5] = sget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    for (k = k1; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
