@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cdrvsy.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -59,39 +47,45 @@ static complex c_b49 = {0.f,0.f};
     integer i__1, i__2, i__3, i__4, i__5, i__6[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda;
-    static char fact[1];
-    static integer ioff, mode, imat, info;
-    static char path[3], dist[1], uplo[1], type__[1];
-    static integer nrun, ifact;
+    integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda;
+    char fact[1];
+    integer ioff, mode, imat, info;
+    char path[3], dist[1], uplo[1], type__[1];
+    integer nrun, ifact;
     extern /* Subroutine */ int cget04_(integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *);
-    static integer nfail, iseed[4], nbmin;
-    static real rcond;
-    static integer nimat;
+    integer nfail, iseed[4], nbmin;
+    real rcond;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int cpot05_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *, complex *, integer *, complex 
 	    *, integer *, real *, real *, real *);
-    static real anorm;
+    real anorm;
     extern /* Subroutine */ int csyt01_(char *, integer *, complex *, integer 
 	    *, complex *, integer *, integer *, complex *, integer *, real *, 
 	    real *), csyt02_(char *, integer *, integer *, complex *, 
 	    integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *);
-    static integer iuplo, izero, nerrs, lwork;
-    static logical zerot;
-    extern /* Subroutine */ int csysv_(char *, integer *, integer *, complex * 	    , integer *, integer *, complex *, integer *, complex *, integer * 	    , integer *);     static char xtype[1];     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), aladhd_(integer *, char *), 
+    integer iuplo, izero, nerrs, lwork;
+    logical zerot;
+    extern /* Subroutine */ int csysv_(char *, integer *, integer *, complex *
+, integer *, integer *, complex *, integer *, complex *, integer *
+, integer *);
+    char xtype[1];
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), aladhd_(integer *, char *), 
 	    alaerh_(char *, char *, integer *, integer *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *);
-    static real rcondc;
+    real rcondc;
     extern /* Subroutine */ int clacpy_(char *, integer *, integer *, complex 
 	    *, integer *, complex *, integer *), clarhs_(char *, char 
 	    *, char *, char *, integer *, integer *, integer *, integer *, 
@@ -100,24 +94,24 @@ static complex c_b49 = {0.f,0.f};
 	    claset_(char *, integer *, integer *, complex *, complex *, 
 	    complex *, integer *), alasvm_(char *, integer *, integer 
 	    *, integer *, integer *);
-    static real cndnum;
+    real cndnum;
     extern /* Subroutine */ int clatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, complex *, integer *, complex *, integer *);
-    static real ainvnm;
-    extern doublereal clansy_(char *, char *, integer *, complex *, integer *,
+, char *, complex *, integer *, complex *, integer *);
+    real ainvnm;
+    extern doublereal clansy_(char *, char *, integer *, complex *, integer *, 
 	     real *);
-    extern /* Subroutine */ int xlaenv_(integer *, integer *), clatsy_(char *,
+    extern /* Subroutine */ int xlaenv_(integer *, integer *), clatsy_(char *, 
 	     integer *, complex *, integer *, integer *), cerrvx_(
 	    char *, integer *), csytrf_(char *, integer *, complex *, 
 	    integer *, integer *, complex *, integer *, integer *), 
 	    csytri_(char *, integer *, complex *, integer *, integer *, 
 	    complex *, integer *);
-    static real result[6];
+    real result[6];
     extern /* Subroutine */ int csysvx_(char *, char *, integer *, integer *, 
 	    complex *, integer *, complex *, integer *, integer *, complex *, 
 	    integer *, complex *, integer *, real *, real *, real *, complex *
-	    , integer *, real *, integer *);
+, integer *, real *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___42 = { 0, 0, 0, fmt_9999, 0 };
@@ -125,71 +119,92 @@ static complex c_b49 = {0.f,0.f};
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CDRVSY tests the driver routines CSYSV and -SVX.   
+/*  CDRVSY tests the driver routines CSYSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX) */
 
-    B       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS) */
 
-    WORK    (workspace) COMPLEX array, dimension   
-                        (NMAX*max(2,NRHS))   
+/*  WORK    (workspace) COMPLEX array, dimension */
+/*                      (NMAX*max(2,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -202,9 +217,11 @@ static complex c_b49 = {0.f,0.f};
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Complex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "SY", (ftnlen)2, (ftnlen)2);
@@ -268,8 +285,8 @@ static complex c_b49 = {0.f,0.f};
 
 		if (imat != 11) {
 
-/*                 Set up parameters with CLATB4 and generate a test   
-                   matrix with CLATMS. */
+/*                 Set up parameters with CLATB4 and generate a test */
+/*                 matrix with CLATMS. */
 
 		    clatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &
 			    mode, &cndnum, dist);
@@ -288,8 +305,8 @@ static complex c_b49 = {0.f,0.f};
 			goto L160;
 		    }
 
-/*                 For types 3-6, zero one or more rows and columns of   
-                   the matrix to test that INFO is returned correctly. */
+/*                 For types 3-6, zero one or more rows and columns of */
+/*                 the matrix to test that INFO is returned correctly. */
 
 		    if (zerot) {
 			if (imat == 3) {
@@ -379,8 +396,8 @@ static complex c_b49 = {0.f,0.f};
 		    }
 		} else {
 
-/*                 IMAT = NTYPES:  Use a special block diagonal matrix to   
-                   test alternate code for the 2-by-2 blocks. */
+/*                 IMAT = NTYPES:  Use a special block diagonal matrix to */
+/*                 test alternate code for the 2-by-2 blocks. */
 
 		    clatsy_(uplo, &n, &a[1], &lda, iseed);
 		}
@@ -392,8 +409,8 @@ static complex c_b49 = {0.f,0.f};
 		    *(unsigned char *)fact = *(unsigned char *)&facts[ifact - 
 			    1];
 
-/*                 Compute the condition number for comparison with   
-                   the value returned by CSYSVX. */
+/*                 Compute the condition number for comparison with */
+/*                 the value returned by CSYSVX. */
 
 		    if (zerot) {
 			if (ifact == 1) {
@@ -410,13 +427,13 @@ static complex c_b49 = {0.f,0.f};
 /*                    Factor the matrix A. */
 
 			clacpy_(uplo, &n, &n, &a[1], &lda, &afac[1], &lda);
-			csytrf_(uplo, &n, &afac[1], &lda, &iwork[1], &work[1],
+			csytrf_(uplo, &n, &afac[1], &lda, &iwork[1], &work[1], 
 				 &lwork, &info);
 
 /*                    Compute inv(A) and take its norm. */
 
 			clacpy_(uplo, &n, &n, &afac[1], &lda, &ainv[1], &lda);
-			csytri_(uplo, &n, &ainv[1], &lda, &iwork[1], &work[1],
+			csytri_(uplo, &n, &ainv[1], &lda, &iwork[1], &work[1], 
 				 &info);
 			ainvnm = clansy_("1", uplo, &n, &ainv[1], &lda, &
 				rwork[1]);
@@ -451,8 +468,8 @@ static complex c_b49 = {0.f,0.f};
 			csysv_(uplo, &n, nrhs, &afac[1], &lda, &iwork[1], &x[
 				1], &lda, &work[1], &lwork, &info);
 
-/*                    Adjust the expected value of INFO to account for   
-                      pivoting. */
+/*                    Adjust the expected value of INFO to account for */
+/*                    pivoting. */
 
 			k = izero;
 			if (k > 0) {
@@ -479,8 +496,8 @@ L100:
 			    goto L120;
 			}
 
-/*                    Reconstruct matrix from factors and compute   
-                      residual. */
+/*                    Reconstruct matrix from factors and compute */
+/*                    residual. */
 
 			csyt01_(uplo, &n, &a[1], &lda, &afac[1], &lda, &iwork[
 				1], &ainv[1], &lda, &rwork[1], result);
@@ -497,8 +514,8 @@ L100:
 				rcondc, &result[2]);
 			nt = 3;
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			i__3 = nt;
 			for (k = 1; k <= i__3; ++k) {
@@ -535,17 +552,17 @@ L120:
 		    }
 		    claset_("Full", &n, nrhs, &c_b49, &c_b49, &x[1], &lda);
 
-/*                 Solve the system and compute the condition number and   
-                   error bounds using CSYSVX. */
+/*                 Solve the system and compute the condition number and */
+/*                 error bounds using CSYSVX. */
 
 		    s_copy(srnamc_1.srnamt, "CSYSVX", (ftnlen)6, (ftnlen)6);
-		    csysvx_(fact, uplo, &n, nrhs, &a[1], &lda, &afac[1], &lda,
+		    csysvx_(fact, uplo, &n, nrhs, &a[1], &lda, &afac[1], &lda, 
 			     &iwork[1], &b[1], &lda, &x[1], &lda, &rcond, &
 			    rwork[1], &rwork[*nrhs + 1], &work[1], &lwork, &
 			    rwork[(*nrhs << 1) + 1], &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -577,8 +594,8 @@ L130:
 		    if (info == 0) {
 			if (ifact >= 2) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    csyt01_(uplo, &n, &a[1], &lda, &afac[1], &lda, &
 				    iwork[1], &ainv[1], &lda, &rwork[(*nrhs <<
@@ -609,13 +626,13 @@ L130:
 			k1 = 6;
 		    }
 
-/*                 Compare RCOND from CSYSVX with the computed value   
-                   in RCONDC. */
+/*                 Compare RCOND from CSYSVX with the computed value */
+/*                 in RCONDC. */
 
 		    result[5] = sget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    for (k = k1; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
