@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cerrge.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -49,27 +37,33 @@ static integer c__4 = 4;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static complex a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static real r__[4];
-    static complex w[8], x[4];
-    static char c2[2];
-    static real r1[4], r2[4];
-    static complex af[16]	/* was [4][4] */;
-    static integer ip[4], info;
-    static real anrm, ccond, rcond;     extern /* Subroutine */ int cgbtf2_(integer *, integer *, integer *,  	    integer *, complex *, integer *, integer *, integer *), cgetf2_( 	    integer *, integer *, complex *, integer *, integer *, integer *), 	     cgbcon_(char *, integer *, integer *, integer *, complex *,  	    integer *, integer *, real *, real *, complex *, real *, integer * 	    ), cgecon_(char *, integer *, complex *, integer *, real *
-	    , real *, complex *, real *, integer *), alaesm_(char *, 
+    complex a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    real r__[4];
+    complex w[8], x[4];
+    char c2[2];
+    real r1[4], r2[4];
+    complex af[16]	/* was [4][4] */;
+    integer ip[4], info;
+    real anrm, ccond, rcond;
+    extern /* Subroutine */ int cgbtf2_(integer *, integer *, integer *, 
+	    integer *, complex *, integer *, integer *, integer *), cgetf2_(
+	    integer *, integer *, complex *, integer *, integer *, integer *),
+	     cgbcon_(char *, integer *, integer *, integer *, complex *, 
+	    integer *, integer *, real *, real *, complex *, real *, integer *
+), cgecon_(char *, integer *, complex *, integer *, real *
+, real *, complex *, real *, integer *), alaesm_(char *, 
 	    logical *, integer *), cgbequ_(integer *, integer *, 
 	    integer *, integer *, complex *, integer *, real *, real *, real *
-	    , real *, real *, integer *), cgbrfs_(char *, integer *, integer *
-	    , integer *, integer *, complex *, integer *, complex *, integer *
-	    , integer *, complex *, integer *, complex *, integer *, real *, 
+, real *, real *, integer *), cgbrfs_(char *, integer *, integer *
+, integer *, integer *, complex *, integer *, complex *, integer *
+, integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, complex *, real *, integer *), cgbtrf_(integer *, 
 	    integer *, integer *, integer *, complex *, integer *, integer *, 
 	    integer *), cgeequ_(integer *, integer *, complex *, integer *, 
 	    real *, real *, real *, real *, real *, integer *), cgerfs_(char *
-	    , integer *, integer *, complex *, integer *, complex *, integer *
-	    , integer *, complex *, integer *, complex *, integer *, real *, 
+, integer *, integer *, complex *, integer *, complex *, integer *
+, integer *, complex *, integer *, complex *, integer *, real *, 
 	    real *, complex *, real *, integer *), cgetrf_(integer *, 
 	    integer *, complex *, integer *, integer *, integer *), cgetri_(
 	    integer *, complex *, integer *, integer *, complex *, integer *, 
@@ -77,7 +71,8 @@ static integer c__4 = 4;
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int cgbtrs_(char *, integer *, integer *, integer 
 	    *, integer *, complex *, integer *, integer *, complex *, integer 
-	    *, integer *), chkxer_(char *, integer *, integer *,	    logical *, logical *), cgetrs_(char *, integer *, integer 
+	    *, integer *), chkxer_(char *, integer *, integer *, 
+	    logical *, logical *), cgetrs_(char *, integer *, integer 
 	    *, complex *, integer *, integer *, complex *, integer *, integer 
 	    *);
 
@@ -86,28 +81,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CERRGE tests the error exits for the COMPLEX routines   
-    for general matrices.   
+/*  CERRGE tests the error exits for the COMPLEX routines */
+/*  for general matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -144,8 +158,8 @@ static integer c__4 = 4;
     }
     infoc_1.ok = TRUE_;
 
-/*     Test error exits of the routines that use the LU decomposition   
-       of a general matrix. */
+/*     Test error exits of the routines that use the LU decomposition */
+/*     of a general matrix. */
 
     if (lsamen_(&c__2, c2, "GE")) {
 
@@ -295,8 +309,8 @@ static integer c__4 = 4;
 	chkxer_("CGEEQU", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 
-/*     Test error exits of the routines that use the LU decomposition   
-       of a general band matrix. */
+/*     Test error exits of the routines that use the LU decomposition */
+/*     of a general band matrix. */
 
     } else if (lsamen_(&c__2, c2, "GB")) {
 
@@ -440,27 +454,27 @@ static integer c__4 = 4;
 
 	s_copy(srnamc_1.srnamt, "CGBCON", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	cgbcon_("/", &c__0, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__,
+	cgbcon_("/", &c__0, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("CGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	cgbcon_("1", &c_n1, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__,
+	cgbcon_("1", &c_n1, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("CGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	cgbcon_("1", &c__1, &c_n1, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__,
+	cgbcon_("1", &c__1, &c_n1, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("CGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	cgbcon_("1", &c__1, &c__0, &c_n1, a, &c__1, ip, &anrm, &rcond, w, r__,
+	cgbcon_("1", &c__1, &c__0, &c_n1, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("CGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	cgbcon_("1", &c__2, &c__1, &c__1, a, &c__3, ip, &anrm, &rcond, w, r__,
+	cgbcon_("1", &c__2, &c__1, &c__1, a, &c__3, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("CGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
