@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* cerrpo.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -47,20 +35,21 @@ static integer c_n1 = -1;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static complex a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static real r__[4];
-    static complex w[8], x[4];
-    static char c2[2];
-    static real r1[4], r2[4];
-    static complex af[16]	/* was [4][4] */;
-    static integer info;
-    static real anrm, rcond;
+    complex a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    real r__[4];
+    complex w[8], x[4];
+    char c2[2];
+    real r1[4], r2[4];
+    complex af[16]	/* was [4][4] */;
+    integer info;
+    real anrm, rcond;
     extern /* Subroutine */ int cpbtf2_(char *, integer *, integer *, complex 
 	    *, integer *, integer *), cpotf2_(char *, integer *, 
 	    complex *, integer *, integer *), alaesm_(char *, logical 
 	    *, integer *), cpbcon_(char *, integer *, integer *, 
-	    complex *, integer *, real *, real *, complex *, real *, integer * );
+	    complex *, integer *, real *, real *, complex *, real *, integer *
+);
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int cpbequ_(char *, integer *, integer *, complex 
 	    *, integer *, real *, real *, real *, integer *), cpbrfs_(
@@ -68,7 +57,8 @@ static integer c_n1 = -1;
 	    complex *, integer *, complex *, integer *, complex *, integer *, 
 	    real *, real *, complex *, real *, integer *), cpbtrf_(
 	    char *, integer *, integer *, complex *, integer *, integer *), cpocon_(char *, integer *, complex *, integer *, real *, 
-	    real *, complex *, real *, integer *), chkxer_(char *,	    integer *, integer *, logical *, logical *), cppcon_(char 
+	    real *, complex *, real *, integer *), chkxer_(char *, 
+	    integer *, integer *, logical *, logical *), cppcon_(char 
 	    *, integer *, complex *, real *, real *, complex *, real *, 
 	    integer *), cpoequ_(integer *, complex *, integer *, real 
 	    *, real *, real *, integer *), cpbtrs_(char *, integer *, integer 
@@ -92,28 +82,47 @@ static integer c_n1 = -1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CERRPO tests the error exits for the COMPLEX routines   
-    for Hermitian positive definite matrices.   
+/*  CERRPO tests the error exits for the COMPLEX routines */
+/*  for Hermitian positive definite matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -150,8 +159,8 @@ static integer c_n1 = -1;
     anrm = 1.f;
     infoc_1.ok = TRUE_;
 
-/*     Test error exits of the routines that use the Cholesky   
-       decomposition of a Hermitian positive definite matrix. */
+/*     Test error exits of the routines that use the Cholesky */
+/*     decomposition of a Hermitian positive definite matrix. */
 
     if (lsamen_(&c__2, c2, "PO")) {
 
@@ -303,8 +312,8 @@ static integer c_n1 = -1;
 	chkxer_("CPOEQU", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 
-/*     Test error exits of the routines that use the Cholesky   
-       decomposition of a Hermitian positive definite packed matrix. */
+/*     Test error exits of the routines that use the Cholesky */
+/*     decomposition of a Hermitian positive definite packed matrix. */
 
     } else if (lsamen_(&c__2, c2, "PP")) {
 
@@ -410,8 +419,8 @@ static integer c_n1 = -1;
 	chkxer_("CPPEQU", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 
-/*     Test error exits of the routines that use the Cholesky   
-       decomposition of a Hermitian positive definite band matrix. */
+/*     Test error exits of the routines that use the Cholesky */
+/*     decomposition of a Hermitian positive definite band matrix. */
 
     } else if (lsamen_(&c__2, c2, "PB")) {
 
