@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* clattr.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -21,7 +9,10 @@ static integer c__1 = 1;
 static integer c__4 = 4;
 static real c_b92 = 2.f;
 static integer c_n1 = -1;
- /* Subroutine */ int clattr_(integer *imat, char *uplo, char *trans, char * 	diag, integer *iseed, integer *n, complex *a, integer *lda, complex * 	b, complex *work, real *rwork, integer *info  	)
+
+/* Subroutine */ int clattr_(integer *imat, char *uplo, char *trans, char *
+	diag, integer *iseed, integer *n, complex *a, integer *lda, complex *
+	b, complex *work, real *rwork, integer *info)
 {
     /* System generated locals */
     integer a_dim1, a_offset, i__1, i__2, i__3, i__4;
@@ -29,125 +20,144 @@ static integer c_n1 = -1;
     doublereal d__1, d__2;
     complex q__1, q__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     void c_div(complex *, complex *, complex *);
     double pow_dd(doublereal *, doublereal *), sqrt(doublereal);
     void r_cnjg(complex *, complex *);
     double c_abs(complex *);
 
     /* Local variables */
-    static real c__;
-    static integer i__, j;
-    static complex s;
-    static real x, y, z__;
-    static complex ra, rb;
-    static integer kl, ku, iy;
-    static real ulp, sfac;
-    static integer mode;
-    static char path[3], dist[1];
-    static real unfl;
+    real c__;
+    integer i__, j;
+    complex s;
+    real x, y, z__;
+    complex ra, rb;
+    integer kl, ku, iy;
+    real ulp, sfac;
+    integer mode;
+    char path[3], dist[1];
+    real unfl;
     extern /* Subroutine */ int crot_(integer *, complex *, integer *, 
 	    complex *, integer *, real *, complex *);
-    static real rexp;
-    static char type__[1];
-    static real texp;
-    static complex star1, plus1, plus2;
-    static real bscal;
+    real rexp;
+    char type__[1];
+    real texp;
+    complex star1, plus1, plus2;
+    real bscal;
     extern logical lsame_(char *, char *);
-    static real tscal, anorm, bnorm, tleft;
+    real tscal, anorm, bnorm, tleft;
     extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
 	    complex *, integer *), crotg_(complex *, complex *, real *, 
 	    complex *), cswap_(integer *, complex *, integer *, complex *, 
-	    integer *);     static logical upper;     extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), slabad_(real *, real *);
+	    integer *);
+    logical upper;
+    extern /* Subroutine */ int clatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), slabad_(real *, real *);
     extern integer icamax_(integer *, complex *, integer *);
     extern /* Complex */ VOID clarnd_(complex *, integer *, integer *);
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
 	    *);
-    static real bignum;
+    real bignum;
     extern doublereal slarnd_(integer *, integer *);
-    static real cndnum;
+    real cndnum;
     extern /* Subroutine */ int clarnv_(integer *, integer *, integer *, 
 	    complex *), clatms_(integer *, integer *, char *, integer *, char 
 	    *, real *, integer *, real *, real *, integer *, integer *, char *
-	    , complex *, integer *, complex *, integer *);
-    static integer jcount;
+, complex *, integer *, complex *, integer *);
+    integer jcount;
     extern /* Subroutine */ int slarnv_(integer *, integer *, integer *, real 
 	    *);
-    static real smlnum;
+    real smlnum;
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    CLATTR generates a triangular test matrix in 2-dimensional storage.   
-    IMAT and UPLO uniquely specify the properties of the test matrix,   
-    which is returned in the array A.   
+/*  CLATTR generates a triangular test matrix in 2-dimensional storage. */
+/*  IMAT and UPLO uniquely specify the properties of the test matrix, */
+/*  which is returned in the array A. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    IMAT    (input) INTEGER   
-            An integer key describing which matrix to generate for this   
-            path.   
+/*  IMAT    (input) INTEGER */
+/*          An integer key describing which matrix to generate for this */
+/*          path. */
 
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A will be upper or lower   
-            triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A will be upper or lower */
+/*          triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
 
-    TRANS   (input) CHARACTER*1   
-            Specifies whether the matrix or its transpose will be used.   
-            = 'N':  No transpose   
-            = 'T':  Transpose   
-            = 'C':  Conjugate transpose   
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies whether the matrix or its transpose will be used. */
+/*          = 'N':  No transpose */
+/*          = 'T':  Transpose */
+/*          = 'C':  Conjugate transpose */
 
-    DIAG    (output) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
+/*  DIAG    (output) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
 
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            The seed vector for the random number generator (used in   
-            CLATMS).  Modified on exit.   
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          The seed vector for the random number generator (used in */
+/*          CLATMS).  Modified on exit. */
 
-    N       (input) INTEGER   
-            The order of the matrix to be generated.   
+/*  N       (input) INTEGER */
+/*          The order of the matrix to be generated. */
 
-    A       (output) COMPLEX array, dimension (LDA,N)   
-            The triangular matrix A.  If UPLO = 'U', the leading N x N   
-            upper triangular part of the array A contains the upper   
-            triangular matrix, and the strictly lower triangular part of   
-            A is not referenced.  If UPLO = 'L', the leading N x N lower   
-            triangular part of the array A contains the lower triangular   
-            matrix and the strictly upper triangular part of A is not   
-            referenced.   
+/*  A       (output) COMPLEX array, dimension (LDA,N) */
+/*          The triangular matrix A.  If UPLO = 'U', the leading N x N */
+/*          upper triangular part of the array A contains the upper */
+/*          triangular matrix, and the strictly lower triangular part of */
+/*          A is not referenced.  If UPLO = 'L', the leading N x N lower */
+/*          triangular part of the array A contains the lower triangular */
+/*          matrix and the strictly upper triangular part of A is not */
+/*          referenced. */
 
-    LDA     (input) INTEGER   
-            The leading dimension of the array A.  LDA >= max(1,N).   
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of the array A.  LDA >= max(1,N). */
 
-    B       (output) COMPLEX array, dimension (N)   
-            The right hand side vector, if IMAT > 10.   
+/*  B       (output) COMPLEX array, dimension (N) */
+/*          The right hand side vector, if IMAT > 10. */
 
-    WORK    (workspace) COMPLEX array, dimension (2*N)   
+/*  WORK    (workspace) COMPLEX array, dimension (2*N) */
 
-    RWORK   (workspace) REAL array, dimension (N)   
+/*  RWORK   (workspace) REAL array, dimension (N) */
 
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --iseed;
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
@@ -196,10 +206,10 @@ static integer c_n1 = -1;
 		anorm, &kl, &ku, "No packing", &a[a_offset], lda, &work[1], 
 		info);
 
-/*     IMAT > 6:  Unit triangular matrix   
-       The diagonal is deliberately set to something other than 1.   
+/*     IMAT > 6:  Unit triangular matrix */
+/*     The diagonal is deliberately set to something other than 1. */
 
-       IMAT = 7:  Matrix is the identity */
+/*     IMAT = 7:  Matrix is the identity */
 
     } else if (*imat == 7) {
 	if (upper) {
@@ -230,11 +240,11 @@ static integer c_n1 = -1;
 	    }
 	}
 
-/*     IMAT > 7:  Non-trivial unit triangular matrix   
+/*     IMAT > 7:  Non-trivial unit triangular matrix */
 
-       Generate a unit triangular matrix T with condition CNDNUM by   
-       forming a triangular matrix with known singular values and   
-       filling in the zero entries with Givens rotations. */
+/*     Generate a unit triangular matrix T with condition CNDNUM by */
+/*     forming a triangular matrix with known singular values and */
+/*     filling in the zero entries with Givens rotations. */
 
     } else if (*imat <= 10) {
 	if (upper) {
@@ -265,63 +275,63 @@ static integer c_n1 = -1;
 	    }
 	}
 
-/*        Since the trace of a unit triangular matrix is 1, the product   
-          of its singular values must be 1.  Let s = sqrt(CNDNUM),   
-          x = sqrt(s) - 1/sqrt(s), y = sqrt(2/(n-2))*x, and z = x**2.   
-          The following triangular matrix has singular values s, 1, 1,   
-          ..., 1, 1/s:   
+/*        Since the trace of a unit triangular matrix is 1, the product */
+/*        of its singular values must be 1.  Let s = sqrt(CNDNUM), */
+/*        x = sqrt(s) - 1/sqrt(s), y = sqrt(2/(n-2))*x, and z = x**2. */
+/*        The following triangular matrix has singular values s, 1, 1, */
+/*        ..., 1, 1/s: */
 
-          1  y  y  y  ...  y  y  z   
-             1  0  0  ...  0  0  y   
-                1  0  ...  0  0  y   
-                   .  ...  .  .  .   
-                       .   .  .  .   
-                           1  0  y   
-                              1  y   
-                                 1   
+/*        1  y  y  y  ...  y  y  z */
+/*           1  0  0  ...  0  0  y */
+/*              1  0  ...  0  0  y */
+/*                 .  ...  .  .  . */
+/*                     .   .  .  . */
+/*                         1  0  y */
+/*                            1  y */
+/*                               1 */
 
-          To fill in the zeros, we first multiply by a matrix with small   
-          condition number of the form   
+/*        To fill in the zeros, we first multiply by a matrix with small */
+/*        condition number of the form */
 
-          1  0  0  0  0  ...   
-             1  +  *  0  0  ...   
-                1  +  0  0  0   
-                   1  +  *  0  0   
-                      1  +  0  0   
-                         ...   
-                            1  +  0   
-                               1  0   
-                                  1   
+/*        1  0  0  0  0  ... */
+/*           1  +  *  0  0  ... */
+/*              1  +  0  0  0 */
+/*                 1  +  *  0  0 */
+/*                    1  +  0  0 */
+/*                       ... */
+/*                          1  +  0 */
+/*                             1  0 */
+/*                                1 */
 
-          Each element marked with a '*' is formed by taking the product   
-          of the adjacent elements marked with '+'.  The '*'s can be   
-          chosen freely, and the '+'s are chosen so that the inverse of   
-          T will have elements of the same magnitude as T.  If the *'s in   
-          both T and inv(T) have small magnitude, T is well conditioned.   
-          The two offdiagonals of T are stored in WORK.   
+/*        Each element marked with a '*' is formed by taking the product */
+/*        of the adjacent elements marked with '+'.  The '*'s can be */
+/*        chosen freely, and the '+'s are chosen so that the inverse of */
+/*        T will have elements of the same magnitude as T.  If the *'s in */
+/*        both T and inv(T) have small magnitude, T is well conditioned. */
+/*        The two offdiagonals of T are stored in WORK. */
 
-          The product of these two matrices has the form   
+/*        The product of these two matrices has the form */
 
-          1  y  y  y  y  y  .  y  y  z   
-             1  +  *  0  0  .  0  0  y   
-                1  +  0  0  .  0  0  y   
-                   1  +  *  .  .  .  .   
-                      1  +  .  .  .  .   
-                         .  .  .  .  .   
-                            .  .  .  .   
-                               1  +  y   
-                                  1  y   
-                                     1   
+/*        1  y  y  y  y  y  .  y  y  z */
+/*           1  +  *  0  0  .  0  0  y */
+/*              1  +  0  0  .  0  0  y */
+/*                 1  +  *  .  .  .  . */
+/*                    1  +  .  .  .  . */
+/*                       .  .  .  .  . */
+/*                          .  .  .  . */
+/*                             1  +  y */
+/*                                1  y */
+/*                                   1 */
 
-          Now we multiply by Givens rotations, using the fact that   
+/*        Now we multiply by Givens rotations, using the fact that */
 
-                [  c   s ] [  1   w ] [ -c  -s ] =  [  1  -w ]   
-                [ -s   c ] [  0   1 ] [  s  -c ]    [  0   1 ]   
-          and   
-                [ -c  -s ] [  1   0 ] [  c   s ] =  [  1   0 ]   
-                [  s  -c ] [  w   1 ] [ -s   c ]    [ -w   1 ]   
+/*              [  c   s ] [  1   w ] [ -c  -s ] =  [  1  -w ] */
+/*              [ -s   c ] [  0   1 ] [  s  -c ]    [  0   1 ] */
+/*        and */
+/*              [ -c  -s ] [  1   0 ] [  c   s ] =  [  1   0 ] */
+/*              [  s  -c ] [  w   1 ] [ -s   c ]    [ -w   1 ] */
 
-          where c = w / sqrt(w**2+4) and s = 2 / sqrt(w**2+4). */
+/*        where c = w / sqrt(w**2+4) and s = 2 / sqrt(w**2+4). */
 
 	clarnd_(&q__2, &c__5, &iseed[1]);
 	q__1.r = q__2.r * .25f, q__1.i = q__2.i * .25f;
@@ -479,7 +489,7 @@ static integer c_n1 = -1;
 		if (j > 1) {
 		    i__2 = j - 1;
 		    r__1 = -c__;
-		    crot_(&i__2, &a[j + a_dim1], lda, &a[j + 1 + a_dim1], lda,
+		    crot_(&i__2, &a[j + a_dim1], lda, &a[j + 1 + a_dim1], lda, 
 			     &r__1, &s);
 		}
 
@@ -493,15 +503,15 @@ static integer c_n1 = -1;
 	    }
 	}
 
-/*     IMAT > 10:  Pathological test cases.  These triangular matrices   
-       are badly scaled or badly conditioned, so when used in solving a   
-       triangular system they may cause overflow in the solution vector. */
+/*     IMAT > 10:  Pathological test cases.  These triangular matrices */
+/*     are badly scaled or badly conditioned, so when used in solving a */
+/*     triangular system they may cause overflow in the solution vector. */
 
     } else if (*imat == 11) {
 
-/*        Type 11:  Generate a triangular matrix with elements between   
-          -1 and 1. Give the diagonal norm 2 to make it well-conditioned.   
-          Make the right hand side large so that it requires scaling. */
+/*        Type 11:  Generate a triangular matrix with elements between */
+/*        -1 and 1. Give the diagonal norm 2 to make it well-conditioned. */
+/*        Make the right hand side large so that it requires scaling. */
 
 	if (upper) {
 	    i__1 = *n;
@@ -539,9 +549,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 12) {
 
-/*        Type 12:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 12, the offdiagonal elements are small (CNORM(j) < 1). */
+/*        Type 12:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 12, the offdiagonal elements are small (CNORM(j) < 1). */
 
 	clarnv_(&c__2, &iseed[1], n, &b[1]);
 /* Computing MAX */
@@ -585,9 +595,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 13) {
 
-/*        Type 13:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 13, the offdiagonal elements are O(1) (CNORM(j) > 1). */
+/*        Type 13:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 13, the offdiagonal elements are O(1) (CNORM(j) > 1). */
 
 	clarnv_(&c__2, &iseed[1], n, &b[1]);
 	if (upper) {
@@ -624,9 +634,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 14) {
 
-/*        Type 14:  T is diagonal with small numbers on the diagonal to   
-          make the growth factor underflow, but a small right hand side   
-          chosen so that the solution does not overflow. */
+/*        Type 14:  T is diagonal with small numbers on the diagonal to */
+/*        make the growth factor underflow, but a small right hand side */
+/*        chosen so that the solution does not overflow. */
 
 	if (upper) {
 	    jcount = 1;
@@ -711,11 +721,11 @@ static integer c_n1 = -1;
 
     } else if (*imat == 15) {
 
-/*        Type 15:  Make the diagonal elements small to cause gradual   
-          overflow when dividing by T(j,j).  To control the amount of   
-          scaling needed, the matrix is bidiagonal.   
+/*        Type 15:  Make the diagonal elements small to cause gradual */
+/*        overflow when dividing by T(j,j).  To control the amount of */
+/*        scaling needed, the matrix is bidiagonal. */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = 1.f, r__2 = (real) (*n - 1);
 	texp = 1.f / dmax(r__1,r__2);
 	d__1 = (doublereal) smlnum;
@@ -810,10 +820,10 @@ static integer c_n1 = -1;
 
     } else if (*imat == 17) {
 
-/*        Type 17:  Make the offdiagonal elements large to cause overflow   
-          when adding a column of T.  In the non-transposed case, the   
-          matrix is constructed to cause overflow when adding a column in   
-          every other step. */
+/*        Type 17:  Make the offdiagonal elements large to cause overflow */
+/*        when adding a column of T.  In the non-transposed case, the */
+/*        matrix is constructed to cause overflow when adding a column in */
+/*        every other step. */
 
 	tscal = unfl / ulp;
 	tscal = (1.f - ulp) / tscal;
@@ -880,9 +890,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 18) {
 
-/*        Type 18:  Generate a unit triangular matrix with elements   
-          between -1 and 1, and make the right hand side large so that it   
-          requires scaling. */
+/*        Type 18:  Generate a unit triangular matrix with elements */
+/*        between -1 and 1, and make the right hand side large so that it */
+/*        requires scaling. */
 
 	if (upper) {
 	    i__1 = *n;
@@ -916,12 +926,12 @@ static integer c_n1 = -1;
 
     } else if (*imat == 19) {
 
-/*        Type 19:  Generate a triangular matrix with elements between   
-          BIGNUM/(n-1) and BIGNUM so that at least one of the column   
-          norms will exceed BIGNUM.   
-          1/3/91:  CLATRS no longer can handle this case   
+/*        Type 19:  Generate a triangular matrix with elements between */
+/*        BIGNUM/(n-1) and BIGNUM so that at least one of the column */
+/*        norms will exceed BIGNUM. */
+/*        1/3/91:  CLATRS no longer can handle this case */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = 1.f, r__2 = (real) (*n - 1);
 	tleft = bignum / dmax(r__1,r__2);
 /* Computing MAX */
