@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* clavsy.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -27,9 +15,9 @@ static integer c__1 = 1;
     complex q__1, q__2, q__3;
 
     /* Local variables */
-    static integer j, k;
-    static complex t1, t2, d11, d12, d21, d22;
-    static integer kp;
+    integer j, k;
+    complex t1, t2, d11, d12, d21, d22;
+    integer kp;
     extern /* Subroutine */ int cscal_(integer *, complex *, complex *, 
 	    integer *);
     extern logical lsame_(char *, char *);
@@ -39,116 +27,131 @@ static integer c__1 = 1;
 	    complex *, integer *, complex *, integer *, complex *, integer *),
 	     cswap_(integer *, complex *, integer *, complex *, integer *), 
 	    xerbla_(char *, integer *);
-    static logical nounit;
+    logical nounit;
 
 
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       CLAVSY  performs one of the matrix-vector operations   
-          x := A*x  or  x := A'*x,   
-       where x is an N element vector and  A is one of the factors   
-       from the symmetric factorization computed by CSYTRF.   
-       CSYTRF produces a factorization of the form   
-            U * D * U'      or     L * D * L' ,   
-       where U (or L) is a product of permutation and unit upper (lower)   
-       triangular matrices, U' (or L') is the transpose of   
-       U (or L), and D is symmetric and block diagonal with 1 x 1 and   
-       2 x 2 diagonal blocks.  The multipliers for the transformations   
-       and the upper or lower triangular parts of the diagonal blocks   
-       are stored in the leading upper or lower triangle of the 2-D   
-       array A.   
+/*     CLAVSY  performs one of the matrix-vector operations */
+/*        x := A*x  or  x := A'*x, */
+/*     where x is an N element vector and  A is one of the factors */
+/*     from the symmetric factorization computed by CSYTRF. */
+/*     CSYTRF produces a factorization of the form */
+/*          U * D * U'      or     L * D * L' , */
+/*     where U (or L) is a product of permutation and unit upper (lower) */
+/*     triangular matrices, U' (or L') is the transpose of */
+/*     U (or L), and D is symmetric and block diagonal with 1 x 1 and */
+/*     2 x 2 diagonal blocks.  The multipliers for the transformations */
+/*     and the upper or lower triangular parts of the diagonal blocks */
+/*     are stored in the leading upper or lower triangle of the 2-D */
+/*     array A. */
 
-       If TRANS = 'N' or 'n', CLAVSY multiplies either by U or U * D   
-       (or L or L * D).   
-       If TRANS = 'T' or 't', CLAVSY multiplies either by U' or D * U'   
-       (or L' or D * L' ).   
+/*     If TRANS = 'N' or 'n', CLAVSY multiplies either by U or U * D */
+/*     (or L or L * D). */
+/*     If TRANS = 'T' or 't', CLAVSY multiplies either by U' or D * U' */
+/*     (or L' or D * L' ). */
 
-    Arguments   
-    ==========   
+/*  Arguments */
+/*  ========== */
 
-    UPLO   - CHARACTER*1   
-             On entry, UPLO specifies whether the triangular matrix   
-             stored in A is upper or lower triangular.   
-                UPLO = 'U' or 'u'   The matrix is upper triangular.   
-                UPLO = 'L' or 'l'   The matrix is lower triangular.   
-             Unchanged on exit.   
+/*  UPLO   - CHARACTER*1 */
+/*           On entry, UPLO specifies whether the triangular matrix */
+/*           stored in A is upper or lower triangular. */
+/*              UPLO = 'U' or 'u'   The matrix is upper triangular. */
+/*              UPLO = 'L' or 'l'   The matrix is lower triangular. */
+/*           Unchanged on exit. */
 
-    TRANS  - CHARACTER*1   
-             On entry, TRANS specifies the operation to be performed as   
-             follows:   
-                TRANS = 'N' or 'n'   x := A*x.   
-                TRANS = 'T' or 't'   x := A'*x.   
-             Unchanged on exit.   
+/*  TRANS  - CHARACTER*1 */
+/*           On entry, TRANS specifies the operation to be performed as */
+/*           follows: */
+/*              TRANS = 'N' or 'n'   x := A*x. */
+/*              TRANS = 'T' or 't'   x := A'*x. */
+/*           Unchanged on exit. */
 
-    DIAG   - CHARACTER*1   
-             On entry, DIAG specifies whether the diagonal blocks are   
-             assumed to be unit matrices:   
-                DIAG = 'U' or 'u'   Diagonal blocks are unit matrices.   
-                DIAG = 'N' or 'n'   Diagonal blocks are non-unit.   
-             Unchanged on exit.   
+/*  DIAG   - CHARACTER*1 */
+/*           On entry, DIAG specifies whether the diagonal blocks are */
+/*           assumed to be unit matrices: */
+/*              DIAG = 'U' or 'u'   Diagonal blocks are unit matrices. */
+/*              DIAG = 'N' or 'n'   Diagonal blocks are non-unit. */
+/*           Unchanged on exit. */
 
-    N      - INTEGER   
-             On entry, N specifies the order of the matrix A.   
-             N must be at least zero.   
-             Unchanged on exit.   
+/*  N      - INTEGER */
+/*           On entry, N specifies the order of the matrix A. */
+/*           N must be at least zero. */
+/*           Unchanged on exit. */
 
-    NRHS   - INTEGER   
-             On entry, NRHS specifies the number of right hand sides,   
-             i.e., the number of vectors x to be multiplied by A.   
-             NRHS must be at least zero.   
-             Unchanged on exit.   
+/*  NRHS   - INTEGER */
+/*           On entry, NRHS specifies the number of right hand sides, */
+/*           i.e., the number of vectors x to be multiplied by A. */
+/*           NRHS must be at least zero. */
+/*           Unchanged on exit. */
 
-    A      - COMPLEX array, dimension( LDA, N )   
-             On entry, A contains a block diagonal matrix and the   
-             multipliers of the transformations used to obtain it,   
-             stored as a 2-D triangular matrix.   
-             Unchanged on exit.   
+/*  A      - COMPLEX array, dimension( LDA, N ) */
+/*           On entry, A contains a block diagonal matrix and the */
+/*           multipliers of the transformations used to obtain it, */
+/*           stored as a 2-D triangular matrix. */
+/*           Unchanged on exit. */
 
-    LDA    - INTEGER   
-             On entry, LDA specifies the first dimension of A as declared   
-             in the calling ( sub ) program. LDA must be at least   
-             max( 1, N ).   
-             Unchanged on exit.   
+/*  LDA    - INTEGER */
+/*           On entry, LDA specifies the first dimension of A as declared */
+/*           in the calling ( sub ) program. LDA must be at least */
+/*           max( 1, N ). */
+/*           Unchanged on exit. */
 
-    IPIV   - INTEGER array, dimension( N )   
-             On entry, IPIV contains the vector of pivot indices as   
-             determined by CSYTRF or CHETRF.   
-             If IPIV( K ) = K, no interchange was done.   
-             If IPIV( K ) <> K but IPIV( K ) > 0, then row K was inter-   
-             changed with row IPIV( K ) and a 1 x 1 pivot block was used.   
-             If IPIV( K ) < 0 and UPLO = 'U', then row K-1 was exchanged   
-             with row | IPIV( K ) | and a 2 x 2 pivot block was used.   
-             If IPIV( K ) < 0 and UPLO = 'L', then row K+1 was exchanged   
-             with row | IPIV( K ) | and a 2 x 2 pivot block was used.   
+/*  IPIV   - INTEGER array, dimension( N ) */
+/*           On entry, IPIV contains the vector of pivot indices as */
+/*           determined by CSYTRF or CHETRF. */
+/*           If IPIV( K ) = K, no interchange was done. */
+/*           If IPIV( K ) <> K but IPIV( K ) > 0, then row K was inter- */
+/*           changed with row IPIV( K ) and a 1 x 1 pivot block was used. */
+/*           If IPIV( K ) < 0 and UPLO = 'U', then row K-1 was exchanged */
+/*           with row | IPIV( K ) | and a 2 x 2 pivot block was used. */
+/*           If IPIV( K ) < 0 and UPLO = 'L', then row K+1 was exchanged */
+/*           with row | IPIV( K ) | and a 2 x 2 pivot block was used. */
 
-    B      - COMPLEX array, dimension( LDB, NRHS )   
-             On entry, B contains NRHS vectors of length N.   
-             On exit, B is overwritten with the product A * B.   
+/*  B      - COMPLEX array, dimension( LDB, NRHS ) */
+/*           On entry, B contains NRHS vectors of length N. */
+/*           On exit, B is overwritten with the product A * B. */
 
-    LDB    - INTEGER   
-             On entry, LDB contains the leading dimension of B as   
-             declared in the calling program.  LDB must be at least   
-             max( 1, N ).   
-             Unchanged on exit.   
+/*  LDB    - INTEGER */
+/*           On entry, LDB contains the leading dimension of B as */
+/*           declared in the calling program.  LDB must be at least */
+/*           max( 1, N ). */
+/*           Unchanged on exit. */
 
-    INFO   - INTEGER   
-             INFO is the error flag.   
-             On exit, a value of 0 indicates a successful exit.   
-             A negative value, say -K, indicates that the K-th argument   
-             has an illegal value.   
+/*  INFO   - INTEGER */
+/*           INFO is the error flag. */
+/*           On exit, a value of 0 indicates a successful exit. */
+/*           A negative value, say -K, indicates that the K-th argument */
+/*           has an illegal value. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Test the input parameters.   
+/*     Test the input parameters. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
@@ -187,15 +190,15 @@ static integer c__1 = 1;
     }
 
     nounit = lsame_(diag, "N");
-/* ------------------------------------------   
+/* ------------------------------------------ */
 
-       Compute  B := A * B  (No transpose)   
+/*     Compute  B := A * B  (No transpose) */
 
-   ------------------------------------------ */
+/* ------------------------------------------ */
     if (lsame_(trans, "N")) {
 
-/*        Compute  B := U*B   
-          where U = P(m)*inv(U(m))* ... *P(1)*inv(U(1)) */
+/*        Compute  B := U*B */
+/*        where U = P(m)*inv(U(m))* ... *P(1)*inv(U(1)) */
 
 	if (lsame_(uplo, "U")) {
 
@@ -208,9 +211,9 @@ L10:
 	    }
 	    if (ipiv[k] > 0) {
 
-/*              1 x 1 pivot block   
+/*              1 x 1 pivot block */
 
-                Multiply by the diagonal element if forming U * D. */
+/*              Multiply by the diagonal element if forming U * D. */
 
 		if (nounit) {
 		    cscal_(nrhs, &a[k + k * a_dim1], &b[k + b_dim1], ldb);
@@ -237,9 +240,9 @@ L10:
 		++k;
 	    } else {
 
-/*              2 x 2 pivot block   
+/*              2 x 2 pivot block */
 
-                Multiply by the diagonal block if forming U * D. */
+/*              Multiply by the diagonal block if forming U * D. */
 
 		if (nounit) {
 		    i__1 = k + k * a_dim1;
@@ -300,8 +303,8 @@ L10:
 	    goto L10;
 L30:
 
-/*        Compute  B := L*B   
-          where L = P(1)*inv(L(1))* ... *P(m)*inv(L(m)) . */
+/*        Compute  B := L*B */
+/*        where L = P(1)*inv(L(1))* ... *P(m)*inv(L(m)) . */
 
 	    ;
 	} else {
@@ -314,14 +317,14 @@ L40:
 		goto L60;
 	    }
 
-/*           Test the pivot index.  If greater than zero, a 1 x 1   
-             pivot was used, otherwise a 2 x 2 pivot was used. */
+/*           Test the pivot index.  If greater than zero, a 1 x 1 */
+/*           pivot was used, otherwise a 2 x 2 pivot was used. */
 
 	    if (ipiv[k] > 0) {
 
-/*              1 x 1 pivot block:   
+/*              1 x 1 pivot block: */
 
-                Multiply by the diagonal element if forming L * D. */
+/*              Multiply by the diagonal element if forming L * D. */
 
 		if (nounit) {
 		    cscal_(nrhs, &a[k + k * a_dim1], &b[k + b_dim1], ldb);
@@ -338,8 +341,8 @@ L40:
 		    cgeru_(&i__1, nrhs, &c_b1, &a[k + 1 + k * a_dim1], &c__1, 
 			    &b[k + b_dim1], ldb, &b[k + 1 + b_dim1], ldb);
 
-/*                 Interchange if a permutation was applied at the   
-                   K-th step of the factorization. */
+/*                 Interchange if a permutation was applied at the */
+/*                 K-th step of the factorization. */
 
 		    if (kp != k) {
 			cswap_(nrhs, &b[k + b_dim1], ldb, &b[kp + b_dim1], 
@@ -350,9 +353,9 @@ L40:
 
 	    } else {
 
-/*              2 x 2 pivot block:   
+/*              2 x 2 pivot block: */
 
-                Multiply by the diagonal block if forming L * D. */
+/*              Multiply by the diagonal block if forming L * D. */
 
 		if (nounit) {
 		    i__1 = k - 1 + (k - 1) * a_dim1;
@@ -400,8 +403,8 @@ L40:
 			    c__1, &b[k - 1 + b_dim1], ldb, &b[k + 1 + b_dim1], 
 			     ldb);
 
-/*                 Interchange if a permutation was applied at the   
-                   K-th step of the factorization. */
+/*                 Interchange if a permutation was applied at the */
+/*                 K-th step of the factorization. */
 
 		    kp = (i__1 = ipiv[k], abs(i__1));
 		    if (kp != k) {
@@ -415,16 +418,16 @@ L40:
 L60:
 	    ;
 	}
-/* ----------------------------------------   
+/* ---------------------------------------- */
 
-       Compute  B := A' * B  (transpose)   
+/*     Compute  B := A' * B  (transpose) */
 
-   ---------------------------------------- */
+/* ---------------------------------------- */
     } else if (lsame_(trans, "T")) {
 
-/*        Form  B := U'*B   
-          where U  = P(m)*inv(U(m))* ... *P(1)*inv(U(1))   
-          and   U' = inv(U'(1))*P(1)* ... *inv(U'(m))*P(m) */
+/*        Form  B := U'*B */
+/*        where U  = P(m)*inv(U(m))* ... *P(1)*inv(U(1)) */
+/*        and   U' = inv(U'(1))*P(1)* ... *inv(U'(m))*P(m) */
 
 	if (lsame_(uplo, "U")) {
 
@@ -524,9 +527,9 @@ L70:
 	    goto L70;
 L90:
 
-/*        Form  B := L'*B   
-          where L  = P(1)*inv(L(1))* ... *P(m)*inv(L(m))   
-          and   L' = inv(L'(m))*P(m)* ... *inv(L'(1))*P(1) */
+/*        Form  B := L'*B */
+/*        where L  = P(1)*inv(L(1))* ... *P(m)*inv(L(m)) */
+/*        and   L' = inv(L'(m))*P(m)* ... *inv(L'(1))*P(1) */
 
 	    ;
 	} else {
