@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dchkaa.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -80,6 +68,7 @@ static integer c__6 = 6;
     /* System generated locals */
     integer i__1, i__2;
     doublereal d__1;
+    cilist ci__1;
     cllist cl__1;
 
     /* Builtin functions */
@@ -92,37 +81,37 @@ static integer c__6 = 6;
     integer f_clos(cllist *);
 
     /* Local variables */
-    static doublereal a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][
+    doublereal a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][
 	    4] */;
-    static integer i__, j, k;
-    static doublereal s[264];
-    static char c1[1], c2[2];
-    static doublereal s1, s2;
-    static integer ic, la, nb, nm, nn, vers_patch__, vers_major__, 
-	    vers_minor__, lda, nnb;
-    static doublereal eps;
-    static integer nns, nnb2;
-    static char path[3];
-    static integer mval[12], nval[12], nrhs;
-    static doublereal work[23496]	/* was [132][178] */;
-    static integer lafac;
-    static logical fatal;
-    static char aline[72];
+    integer i__, j, k;
+    doublereal s[264];
+    char c1[1], c2[2];
+    doublereal s1, s2;
+    integer ic, la, nb, nm, nn, vers_patch__, vers_major__, vers_minor__, lda,
+	     nnb;
+    doublereal eps;
+    integer nns, nnb2;
+    char path[3];
+    integer mval[12], nval[12], nrhs;
+    doublereal work[23496]	/* was [132][178] */;
+    integer lafac;
+    logical fatal;
+    char aline[72];
     extern logical lsame_(char *, char *);
-    static integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
-    static doublereal rwork[692];
+    integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
+    doublereal rwork[692];
     extern /* Subroutine */ int dchkq3_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, doublereal 
 	    *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, integer *, integer *);
-    static integer nbval2[12];
+    integer nbval2[12];
     extern /* Subroutine */ int dchkgb_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    doublereal *, logical *, doublereal *, integer *, doublereal *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *, integer *), dchkge_(logical *, integer *
-	    , integer *, integer *, integer *, integer *, integer *, integer *
-	    , integer *, doublereal *, logical *, integer *, doublereal *, 
+, integer *, integer *, integer *, integer *, integer *, integer *
+, integer *, doublereal *, logical *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *);
     extern doublereal dlamch_(char *);
@@ -138,9 +127,9 @@ static integer c__6 = 6;
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *), 
 	    dchkgt_(logical *, integer *, integer *, integer *, integer *, 
-	    doublereal *, logical *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, logical *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, doublereal *, integer *
-	    , integer *), alareq_(char *, integer *, logical *, integer *, 
+, integer *), alareq_(char *, integer *, logical *, integer *, 
 	    integer *, integer *), dchklq_(logical *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublereal *, 
@@ -155,23 +144,23 @@ static integer c__6 = 6;
 	    dchkpo_(logical *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, doublereal *, logical *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *), dchkpp_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *), 
 	    dchkqp_(logical *, integer *, integer *, integer *, integer *, 
-	    doublereal *, logical *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, logical *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, integer *, integer *), 
 	    ddrvgb_(logical *, integer *, integer *, integer *, doublereal *, 
 	    logical *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *), dchkqr_(logical *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, doublereal 
-	    *, logical *, integer *, doublereal *, doublereal *, doublereal *,
+	    *, logical *, integer *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *), dchkpt_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
@@ -185,7 +174,7 @@ static integer c__6 = 6;
     extern /* Subroutine */ int dchksp_(logical *, integer *, integer *, 
 	    integer *, integer *, doublereal *, logical *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *), dchktp_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
@@ -205,7 +194,7 @@ static integer c__6 = 6;
 	    dchksy_(logical *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, doublereal *, logical *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *), ilaver_(integer *, integer *, integer *), dchktz_(
 	    logical *, integer *, integer *, integer *, integer *, doublereal 
 	    *, logical *, doublereal *, doublereal *, doublereal *, 
@@ -213,7 +202,7 @@ static integer c__6 = 6;
 	    logical *, integer *, integer *, integer *, doublereal *, logical 
 	    *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *);
-    static doublereal thresh;
+    doublereal thresh;
     extern /* Subroutine */ int ddrvls_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, doublereal *, doublereal *, 
@@ -223,16 +212,16 @@ static integer c__6 = 6;
 	    *, integer *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *);
-    static logical tstchk;
+    logical tstchk;
     extern /* Subroutine */ int ddrvpp_(logical *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, integer *, integer *), ddrvpt_(logical *, integer *,
+	    doublereal *, integer *, integer *), ddrvpt_(logical *, integer *, 
 	     integer *, integer *, doublereal *, logical *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *);
-    static logical dotype[30];
+    logical dotype[30];
     extern /* Subroutine */ int ddrvsp_(logical *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
@@ -241,8 +230,8 @@ static integer c__6 = 6;
 	    logical *, integer *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, integer *, integer *);
-    static integer ntypes;
-    static logical tsterr, tstdrv;
+    integer ntypes;
+    logical tsterr, tstdrv;
 
     /* Fortran I/O blocks */
     static cilist io___6 = { 0, 5, 0, 0, 0 };
@@ -287,27 +276,27 @@ static integer c__6 = 6;
     static cilist io___67 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___68 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___69 = { 0, 6, 0, 0, 0 };
-    static cilist io___70 = { 0, 5, 1, "(A72)", 0 };
-    static cilist io___79 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___80 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___88 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___90 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___93 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___94 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___95 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___96 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___97 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___98 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___99 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___100 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___101 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___102 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___103 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___104 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___105 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___106 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___107 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___108 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___78 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___79 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___87 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___89 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___92 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___93 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___94 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___95 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___96 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___97 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___98 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___99 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___100 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___101 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___102 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___103 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___104 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___105 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___106 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___107 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___108 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___109 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___110 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___111 = { 0, 6, 0, fmt_9989, 0 };
@@ -316,87 +305,105 @@ static integer c__6 = 6;
     static cilist io___114 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___115 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___116 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___117 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___118 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___119 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___120 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___122 = { 0, 6, 0, fmt_9998, 0 };
-    static cilist io___123 = { 0, 6, 0, fmt_9997, 0 };
+    static cilist io___117 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___118 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___119 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___121 = { 0, 6, 0, fmt_9998, 0 };
+    static cilist io___122 = { 0, 6, 0, fmt_9997, 0 };
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DCHKAA is the main test program for the DOUBLE PRECISION LAPACK   
-    linear equation routines   
+/*  DCHKAA is the main test program for the DOUBLE PRECISION LAPACK */
+/*  linear equation routines */
 
-    The program must be driven by a short data file. The first 14 records   
-    specify problem dimensions and program options using list-directed   
-    input.  The remaining lines specify the LAPACK test paths and the   
-    number of matrix types to use in testing.  An annotated example of a   
-    data file can be obtained by deleting the first 3 characters from the   
-    following 36 lines:   
-    Data file for testing DOUBLE PRECISION LAPACK linear eqn. routines   
-    7                      Number of values of M   
-    0 1 2 3 5 10 16        Values of M (row dimension)   
-    7                      Number of values of N   
-    0 1 2 3 5 10 16        Values of N (column dimension)   
-    1                      Number of values of NRHS   
-    2                      Values of NRHS (number of right hand sides)   
-    5                      Number of values of NB   
-    1 3 3 3 20             Values of NB (the blocksize)   
-    1 0 5 9 1              Values of NX (crossover point)   
-    20.0                   Threshold value of test ratio   
-    T                      Put T to test the LAPACK routines   
-    T                      Put T to test the driver routines   
-    T                      Put T to test the error exits   
-    DGE   11               List types on next line if 0 < NTYPES < 11   
-    DGB    8               List types on next line if 0 < NTYPES <  8   
-    DGT   12               List types on next line if 0 < NTYPES < 12   
-    DPO    9               List types on next line if 0 < NTYPES <  9   
-    DPP    9               List types on next line if 0 < NTYPES <  9   
-    DPB    8               List types on next line if 0 < NTYPES <  8   
-    DPT   12               List types on next line if 0 < NTYPES < 12   
-    DSY   10               List types on next line if 0 < NTYPES < 10   
-    DSP   10               List types on next line if 0 < NTYPES < 10   
-    DTR   18               List types on next line if 0 < NTYPES < 18   
-    DTP   18               List types on next line if 0 < NTYPES < 18   
-    DTB   17               List types on next line if 0 < NTYPES < 17   
-    DQR    8               List types on next line if 0 < NTYPES <  8   
-    DRQ    8               List types on next line if 0 < NTYPES <  8   
-    DLQ    8               List types on next line if 0 < NTYPES <  8   
-    DQL    8               List types on next line if 0 < NTYPES <  8   
-    DQP    6               List types on next line if 0 < NTYPES <  6   
-    DTZ    3               List types on next line if 0 < NTYPES <  3   
-    DLS    6               List types on next line if 0 < NTYPES <  6   
-    DEQ   
+/*  The program must be driven by a short data file. The first 14 records */
+/*  specify problem dimensions and program options using list-directed */
+/*  input.  The remaining lines specify the LAPACK test paths and the */
+/*  number of matrix types to use in testing.  An annotated example of a */
+/*  data file can be obtained by deleting the first 3 characters from the */
+/*  following 36 lines: */
+/*  Data file for testing DOUBLE PRECISION LAPACK linear eqn. routines */
+/*  7                      Number of values of M */
+/*  0 1 2 3 5 10 16        Values of M (row dimension) */
+/*  7                      Number of values of N */
+/*  0 1 2 3 5 10 16        Values of N (column dimension) */
+/*  1                      Number of values of NRHS */
+/*  2                      Values of NRHS (number of right hand sides) */
+/*  5                      Number of values of NB */
+/*  1 3 3 3 20             Values of NB (the blocksize) */
+/*  1 0 5 9 1              Values of NX (crossover point) */
+/*  20.0                   Threshold value of test ratio */
+/*  T                      Put T to test the LAPACK routines */
+/*  T                      Put T to test the driver routines */
+/*  T                      Put T to test the error exits */
+/*  DGE   11               List types on next line if 0 < NTYPES < 11 */
+/*  DGB    8               List types on next line if 0 < NTYPES <  8 */
+/*  DGT   12               List types on next line if 0 < NTYPES < 12 */
+/*  DPO    9               List types on next line if 0 < NTYPES <  9 */
+/*  DPP    9               List types on next line if 0 < NTYPES <  9 */
+/*  DPB    8               List types on next line if 0 < NTYPES <  8 */
+/*  DPT   12               List types on next line if 0 < NTYPES < 12 */
+/*  DSY   10               List types on next line if 0 < NTYPES < 10 */
+/*  DSP   10               List types on next line if 0 < NTYPES < 10 */
+/*  DTR   18               List types on next line if 0 < NTYPES < 18 */
+/*  DTP   18               List types on next line if 0 < NTYPES < 18 */
+/*  DTB   17               List types on next line if 0 < NTYPES < 17 */
+/*  DQR    8               List types on next line if 0 < NTYPES <  8 */
+/*  DRQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  DLQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  DQL    8               List types on next line if 0 < NTYPES <  8 */
+/*  DQP    6               List types on next line if 0 < NTYPES <  6 */
+/*  DTZ    3               List types on next line if 0 < NTYPES <  3 */
+/*  DLS    6               List types on next line if 0 < NTYPES <  6 */
+/*  DEQ */
 
-    Internal Parameters   
-    ===================   
+/*  Internal Parameters */
+/*  =================== */
 
-    NMAX    INTEGER   
-            The maximum allowable value for N   
+/*  NMAX    INTEGER */
+/*          The maximum allowable value for N */
 
-    MAXIN   INTEGER   
-            The number of different values that can be used for each of   
-            M, N, NRHS, NB, and NX   
+/*  MAXIN   INTEGER */
+/*          The number of different values that can be used for each of */
+/*          M, N, NRHS, NB, and NX */
 
-    MAXRHS  INTEGER   
-            The maximum number of right hand sides   
+/*  MAXRHS  INTEGER */
+/*          The maximum number of right hand sides */
 
-    NIN     INTEGER   
-            The unit number for input   
+/*  NIN     INTEGER */
+/*          The unit number for input */
 
-    NOUT    INTEGER   
-            The unit number for output   
+/*  NOUT    INTEGER */
+/*          The unit number for output */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Arrays in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s1 = dsecnd_();
     lda = 132;
@@ -746,7 +753,11 @@ L80:
 
 /*     Read a test path and the number of matrix types to use. */
 
-    i__1 = s_rsfe(&io___70);
+    ci__1.cierr = 0;
+    ci__1.ciend = 1;
+    ci__1.ciunit = 5;
+    ci__1.cifmt = "(A72)";
+    i__1 = s_rsfe(&ci__1);
     if (i__1 != 0) {
 	goto L140;
     }
@@ -796,7 +807,7 @@ L130:
 /*     Check first character for correct precision. */
 
     if (! lsame_(c1, "Double precision")) {
-	s_wsfe(&io___79);
+	s_wsfe(&io___78);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -804,7 +815,7 @@ L130:
 
 /*        Check for a positive number of tests requested. */
 
-	s_wsfe(&io___80);
+	s_wsfe(&io___79);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -820,7 +831,7 @@ L130:
 		    &thresh, &tsterr, &lda, a, &a[21912], &a[43824], b, &b[
 		    2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___88);
+	    s_wsfe(&io___87);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -830,7 +841,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___90);
+	    s_wsfe(&io___89);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -849,7 +860,7 @@ L130:
 		    &thresh, &tsterr, a, &la, &a[43824], &lafac, b, &b[2112], 
 		    &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___93);
+	    s_wsfe(&io___92);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -859,7 +870,7 @@ L130:
 		    43824], &lafac, &a[109560], b, &b[2112], &b[4224], &b[
 		    6336], s, work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___94);
+	    s_wsfe(&io___93);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -875,7 +886,7 @@ L130:
 	    dchkgt_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___95);
+	    s_wsfe(&io___94);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -884,7 +895,7 @@ L130:
 	    ddrvgt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, &a[21912], 
 		    b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___96);
+	    s_wsfe(&io___95);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -901,7 +912,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___97);
+	    s_wsfe(&io___96);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -911,7 +922,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___98);
+	    s_wsfe(&io___97);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -924,11 +935,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    dchkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    dchkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___99);
+	    s_wsfe(&io___98);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -938,7 +949,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___100);
+	    s_wsfe(&io___99);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -955,7 +966,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___101);
+	    s_wsfe(&io___100);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -965,7 +976,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___102);
+	    s_wsfe(&io___101);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -982,7 +993,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, &
 		    c__6);
 	} else {
-	    s_wsfe(&io___103);
+	    s_wsfe(&io___102);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -991,7 +1002,7 @@ L130:
 	    ddrvpt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, &a[21912], 
 		    &a[43824], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___104);
+	    s_wsfe(&io___103);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1008,7 +1019,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___105);
+	    s_wsfe(&io___104);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1018,7 +1029,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___106);
+	    s_wsfe(&io___105);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1031,11 +1042,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    dchksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    dchksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___107);
+	    s_wsfe(&io___106);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1045,7 +1056,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___108);
+	    s_wsfe(&io___107);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1062,7 +1073,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], b, &b[2112], &b[4224], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___109);
+	    s_wsfe(&io___108);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1075,11 +1086,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    dchktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    dchktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, iwork, &
 		    c__6);
 	} else {
-	    s_wsfe(&io___110);
+	    s_wsfe(&io___109);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1092,11 +1103,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    dchktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    dchktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, iwork, &
 		    c__6);
 	} else {
-	    s_wsfe(&io___111);
+	    s_wsfe(&io___110);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1114,7 +1125,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___112);
+	    s_wsfe(&io___111);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1132,7 +1143,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___113);
+	    s_wsfe(&io___112);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1150,7 +1161,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___114);
+	    s_wsfe(&io___113);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1168,7 +1179,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___115);
+	    s_wsfe(&io___114);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1183,10 +1194,10 @@ L130:
 	if (tstchk) {
 	    dchkqp_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, iwork, &c__6);
-	    dchkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh,
+	    dchkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh, 
 		     a, &a[21912], b, &b[2112], &b[4224], work, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___116);
+	    s_wsfe(&io___115);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1202,7 +1213,7 @@ L130:
 	    dchktz_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, &c__6);
 	} else {
-	    s_wsfe(&io___117);
+	    s_wsfe(&io___116);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1219,27 +1230,27 @@ L130:
 		    nxval, &thresh, &tsterr, a, &a[21912], b, &b[2112], &b[
 		    4224], rwork, &rwork[132], work, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___118);
+	    s_wsfe(&io___117);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else if (lsamen_(&c__2, c2, "EQ")) {
 
-/*        EQ:  Equilibration routines for general and positive definite   
-               matrices (THREQ should be between 2 and 10) */
+/*        EQ:  Equilibration routines for general and positive definite */
+/*             matrices (THREQ should be between 2 and 10) */
 
 	if (tstchk) {
 	    dchkeq_(&threq, &c__6);
 	} else {
-	    s_wsfe(&io___119);
+	    s_wsfe(&io___118);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else {
 
-	s_wsfe(&io___120);
+	s_wsfe(&io___119);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
     }
@@ -1256,9 +1267,9 @@ L140:
     cl__1.csta = 0;
     f_clos(&cl__1);
     s2 = dsecnd_();
-    s_wsfe(&io___122);
+    s_wsfe(&io___121);
     e_wsfe();
-    s_wsfe(&io___123);
+    s_wsfe(&io___122);
     d__1 = s2 - s1;
     do_fio(&c__1, (char *)&d__1, (ftnlen)sizeof(doublereal));
     e_wsfe();
@@ -1267,6 +1278,6 @@ L140:
 /*     End of DCHKAA */
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Main program alias */ int dchkaa_ () { MAIN__ (); return 0; }
+/* Main program alias */ int dchkaa_ () { MAIN__ (); return 0; }
