@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dchkgt.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -42,7 +30,7 @@ static doublereal c_b64 = 0.;
 /* Subroutine */ int dchkgt_(logical *dotype, integer *nn, integer *nval, 
 	integer *nns, integer *nsval, doublereal *thresh, logical *tsterr, 
 	doublereal *a, doublereal *af, doublereal *b, doublereal *x, 
-	doublereal *xact, doublereal *work, doublereal *rwork, integer *iwork,
+	doublereal *xact, doublereal *work, doublereal *rwork, integer *iwork, 
 	 integer *nout)
 {
     /* Initialized data */
@@ -64,84 +52,84 @@ static doublereal c_b64 = 0.;
     integer i__1, i__2, i__3, i__4;
     doublereal d__1, d__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, m, n;
-    static doublereal z__[3];
-    static integer in, kl, ku, ix, lda;
-    static doublereal cond;
-    static integer mode, koff, imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char norm[1], type__[1];
-    static integer nrun;
+    integer i__, j, k, m, n;
+    doublereal z__[3];
+    integer in, kl, ku, ix, lda;
+    doublereal cond;
+    integer mode, koff, imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char norm[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *), dscal_(
 	    integer *, doublereal *, doublereal *, integer *), dget04_(
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern doublereal dget06_(doublereal *, doublereal *);
-    extern /* Subroutine */ int dgtt01_(integer *, doublereal *, doublereal *,
+    extern /* Subroutine */ int dgtt01_(integer *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
-	    doublereal *), dgtt02_(char *, integer *, integer *, doublereal *,
+	    doublereal *), dgtt02_(char *, integer *, integer *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, integer *, doublereal *
-	    , integer *, doublereal *, doublereal *);
-    static doublereal rcond;
+, integer *, doublereal *, doublereal *);
+    doublereal rcond;
     extern /* Subroutine */ int dgtt05_(char *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, doublereal *);
-    static integer nimat;
+    integer nimat;
     extern doublereal dasum_(integer *, doublereal *, integer *);
-    static doublereal anorm;
-    static integer itran;
+    doublereal anorm;
+    integer itran;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static char trans[1];
-    static integer izero, nerrs;
-    static logical zerot;
+    char trans[1];
+    integer izero, nerrs;
+    logical zerot;
     extern /* Subroutine */ int dlatb4_(char *, integer *, integer *, integer 
 	    *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, char *), alaerh_(char *, 
 	    char *, integer *, integer *, char *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *);
-    static doublereal rcondc;
+    doublereal rcondc;
     extern doublereal dlangt_(char *, integer *, doublereal *, doublereal *, 
 	    doublereal *);
     extern /* Subroutine */ int derrge_(char *, integer *), dlagtm_(
 	    char *, integer *, integer *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, integer *, doublereal *,
+	    doublereal *, doublereal *, doublereal *, integer *, doublereal *, 
 	     doublereal *, integer *), dlacpy_(char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *);
-    static doublereal rcondi;
+    doublereal rcondi;
     extern /* Subroutine */ int dgtcon_(char *, integer *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, integer *, doublereal *,
+	    doublereal *, doublereal *, doublereal *, integer *, doublereal *, 
 	     doublereal *, doublereal *, integer *, integer *), 
 	    alasum_(char *, integer *, integer *, integer *, integer *);
-    static doublereal rcondo;
+    doublereal rcondo;
     extern /* Subroutine */ int dlatms_(integer *, integer *, char *, integer 
 	    *, char *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, char *, doublereal *, integer *, doublereal 
 	    *, integer *), dlarnv_(integer *, integer 
 	    *, integer *, doublereal *);
-    static doublereal ainvnm;
+    doublereal ainvnm;
     extern /* Subroutine */ int dgtrfs_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, integer *, doublereal *,
+	    doublereal *, doublereal *, doublereal *, integer *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *, integer *), dgttrf_(integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     integer *);
-    static logical trfcon;
+    logical trfcon;
     extern /* Subroutine */ int dgttrs_(char *, integer *, integer *, 
-	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
+	    doublereal *, doublereal *, doublereal *, doublereal *, integer *, 
 	     doublereal *, integer *, integer *);
-    static doublereal result[7];
+    doublereal result[7];
 
     /* Fortran I/O blocks */
     static cilist io___29 = { 0, 0, 0, fmt_9999, 0 };
@@ -150,69 +138,90 @@ static doublereal c_b64 = 0.;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DCHKGT tests DGTTRF, -TRS, -RFS, and -CON   
+/*  DCHKGT tests DGTTRF, -TRS, -RFS, and -CON */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) DOUBLE PRECISION array, dimension (NMAX*4)   
+/*  A       (workspace) DOUBLE PRECISION array, dimension (NMAX*4) */
 
-    AF      (workspace) DOUBLE PRECISION array, dimension (NMAX*4)   
+/*  AF      (workspace) DOUBLE PRECISION array, dimension (NMAX*4) */
 
-    B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    IWORK   (workspace) INTEGER array, dimension (2*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (2*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -226,6 +235,8 @@ static doublereal c_b64 = 0.;
     --dotype;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Double precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "GT", (ftnlen)2, (ftnlen)2);
@@ -276,9 +287,9 @@ static doublereal c_b64 = 0.;
 	    zerot = imat >= 8 && imat <= 10;
 	    if (imat <= 6) {
 
-/*              Types 1-6:  generate matrices of known condition number.   
+/*              Types 1-6:  generate matrices of known condition number. */
 
-   Computing MAX */
+/* Computing MAX */
 		i__3 = 2 - ku, i__4 = 3 - max(1,n);
 		koff = max(i__3,i__4);
 		s_copy(srnamc_1.srnamt, "DLATMS", (ftnlen)6, (ftnlen)6);
@@ -304,8 +315,8 @@ static doublereal c_b64 = 0.;
 		dcopy_(&n, &af[2], &c__3, &a[m + 1], &c__1);
 	    } else {
 
-/*              Types 7-12:  generate tridiagonal matrices with   
-                unknown condition numbers. */
+/*              Types 7-12:  generate tridiagonal matrices with */
+/*              unknown condition numbers. */
 
 		if (! zerot || ! dotype[7]) {
 
@@ -319,8 +330,8 @@ static doublereal c_b64 = 0.;
 		    }
 		} else if (izero > 0) {
 
-/*                 Reuse the last matrix by copying back the zeroed out   
-                   elements. */
+/*                 Reuse the last matrix by copying back the zeroed out */
+/*                 elements. */
 
 		    if (izero == 1) {
 			a[n] = z__[1];
@@ -369,9 +380,9 @@ static doublereal c_b64 = 0.;
 		}
 	    }
 
-/* +    TEST 1   
-             Factor A as L*U and compute the ratio   
-                norm(L*U - A) / (n * norm(A) * EPS ) */
+/* +    TEST 1 */
+/*           Factor A as L*U and compute the ratio */
+/*              norm(L*U - A) / (n * norm(A) * EPS ) */
 
 	    i__3 = n + (m << 1);
 	    dcopy_(&i__3, &a[1], &c__1, &af[1], &c__1);
@@ -388,7 +399,7 @@ static doublereal c_b64 = 0.;
 	    trfcon = info != 0;
 
 	    dgtt01_(&n, &a[1], &a[m + 1], &a[n + m + 1], &af[1], &af[m + 1], &
-		    af[n + m + 1], &af[n + (m << 1) + 1], &iwork[1], &work[1],
+		    af[n + m + 1], &af[n + (m << 1) + 1], &iwork[1], &work[1], 
 		     &lda, &rwork[1], result);
 
 /*           Print the test ratio if it is .GE. THRESH. */
@@ -420,9 +431,9 @@ static doublereal c_b64 = 0.;
 
 		if (! trfcon) {
 
-/*                 Use DGTTRS to solve for one column at a time of inv(A)   
-                   or inv(A^T), computing the maximum column sum as we   
-                   go. */
+/*                 Use DGTTRS to solve for one column at a time of inv(A) */
+/*                 or inv(A^T), computing the maximum column sum as we */
+/*                 go. */
 
 		    ainvnm = 0.;
 		    i__3 = n;
@@ -458,9 +469,9 @@ static doublereal c_b64 = 0.;
 		    rcondc = 0.;
 		}
 
-/* +    TEST 7   
-                Estimate the reciprocal of the condition number of the   
-                matrix. */
+/* +    TEST 7 */
+/*              Estimate the reciprocal of the condition number of the */
+/*              matrix. */
 
 		s_copy(srnamc_1.srnamt, "DGTCON", (ftnlen)6, (ftnlen)6);
 		dgtcon_(norm, &n, &af[1], &af[m + 1], &af[n + m + 1], &af[n + 
@@ -470,7 +481,7 @@ static doublereal c_b64 = 0.;
 /*              Check error code from DGTCON. */
 
 		if (info != 0) {
-		    alaerh_(path, "DGTCON", &info, &c__0, norm, &n, &n, &c_n1,
+		    alaerh_(path, "DGTCON", &info, &c__0, norm, &n, &n, &c_n1, 
 			     &c_n1, &c_n1, &imat, &nfail, &nerrs, nout);
 		}
 
@@ -531,13 +542,13 @@ static doublereal c_b64 = 0.;
 		    dlagtm_(trans, &n, &nrhs, &c_b63, &a[1], &a[m + 1], &a[n 
 			    + m + 1], &xact[1], &lda, &c_b64, &b[1], &lda);
 
-/* +    TEST 2   
-                   Solve op(A) * X = B and compute the residual. */
+/* +    TEST 2 */
+/*                 Solve op(A) * X = B and compute the residual. */
 
 		    dlacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &lda);
 		    s_copy(srnamc_1.srnamt, "DGTTRS", (ftnlen)6, (ftnlen)6);
 		    dgttrs_(trans, &n, &nrhs, &af[1], &af[m + 1], &af[n + m + 
-			    1], &af[n + (m << 1) + 1], &iwork[1], &x[1], &lda,
+			    1], &af[n + (m << 1) + 1], &iwork[1], &x[1], &lda, 
 			     &info);
 
 /*                 Check error code from DGTTRS. */
@@ -549,21 +560,21 @@ static doublereal c_b64 = 0.;
 		    }
 
 		    dlacpy_("Full", &n, &nrhs, &b[1], &lda, &work[1], &lda);
-		    dgtt02_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1],
+		    dgtt02_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1], 
 			     &x[1], &lda, &work[1], &lda, &rwork[1], &result[
 			    1]);
 
-/* +    TEST 3   
-                   Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*                 Check solution from generated exact solution. */
 
 		    dget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &rcondc, &
 			    result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                   Use iterative refinement to improve the solution. */
+/* +    TESTS 4, 5, and 6 */
+/*                 Use iterative refinement to improve the solution. */
 
 		    s_copy(srnamc_1.srnamt, "DGTRFS", (ftnlen)6, (ftnlen)6);
-		    dgtrfs_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1],
+		    dgtrfs_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1], 
 			     &af[1], &af[m + 1], &af[n + m + 1], &af[n + (m <<
 			     1) + 1], &iwork[1], &b[1], &lda, &x[1], &lda, &
 			    rwork[1], &rwork[nrhs + 1], &work[1], &iwork[n + 
@@ -579,12 +590,12 @@ static doublereal c_b64 = 0.;
 
 		    dget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &rcondc, &
 			    result[3]);
-		    dgtt05_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1],
+		    dgtt05_(trans, &n, &nrhs, &a[1], &a[m + 1], &a[n + m + 1], 
 			     &b[1], &lda, &x[1], &lda, &xact[1], &lda, &rwork[
 			    1], &rwork[nrhs + 1], &result[4]);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    for (k = 2; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
