@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dchkpb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -42,7 +30,7 @@ static integer c__7 = 7;
 	integer *nnb, integer *nbval, integer *nns, integer *nsval, 
 	doublereal *thresh, logical *tsterr, integer *nmax, doublereal *a, 
 	doublereal *afac, doublereal *ainv, doublereal *b, doublereal *x, 
-	doublereal *xact, doublereal *work, doublereal *rwork, integer *iwork,
+	doublereal *xact, doublereal *work, doublereal *rwork, integer *iwork, 
 	 integer *nout)
 {
     /* Initialized data */
@@ -63,21 +51,21 @@ static integer c__7 = 7;
     /* System generated locals */
     integer i__1, i__2, i__3, i__4, i__5, i__6;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, k, n, i1, i2, kd, nb, in, kl, iw, ku, lda, ikd, inb, 
-	    nkd, ldab, ioff, mode, koff, imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char uplo[1], type__[1];
-    static integer nrun;
+    integer i__, k, n, i1, i2, kd, nb, in, kl, iw, ku, lda, ikd, inb, nkd, 
+	    ldab, ioff, mode, koff, imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char uplo[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *), dget04_(
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern doublereal dget06_(doublereal *, doublereal *);
     extern /* Subroutine */ int dpbt01_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
@@ -87,16 +75,16 @@ static integer c__7 = 7;
 	    dpbt05_(char *, integer *, integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, doublereal *);
-    static integer kdval[4];
-    static doublereal rcond;
-    static integer nimat;
-    static doublereal anorm;
+    integer kdval[4];
+    doublereal rcond;
+    integer nimat;
+    doublereal anorm;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *), dswap_(integer *, doublereal *, integer 
 	    *, doublereal *, integer *);
-    static integer iuplo, izero, nerrs;
-    static logical zerot;
-    static char xtype[1];
+    integer iuplo, izero, nerrs;
+    logical zerot;
+    char xtype[1];
     extern /* Subroutine */ int dlatb4_(char *, integer *, integer *, integer 
 	    *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, char *);
@@ -108,10 +96,10 @@ static integer c__7 = 7;
     extern doublereal dlansb_(char *, char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *);
     extern /* Subroutine */ int dpbcon_(char *, integer *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     integer *, integer *);
-    static doublereal rcondc;
-    static char packit[1];
+    doublereal rcondc;
+    char packit[1];
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *), 
 	    dlarhs_(char *, char *, char *, char *, integer *, integer *, 
@@ -120,22 +108,22 @@ static integer c__7 = 7;
 	    integer *), dlaset_(char *, 
 	    integer *, integer *, doublereal *, doublereal *, doublereal *, 
 	    integer *), dpbrfs_(char *, integer *, integer *, integer 
-	    *, doublereal *, integer *, doublereal *, integer *, doublereal *,
+	    *, doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *, integer *), dpbtrf_(char *, 
 	    integer *, integer *, doublereal *, integer *, integer *),
 	     alasum_(char *, integer *, integer *, integer *, integer *);
-    static doublereal cndnum;
+    doublereal cndnum;
     extern /* Subroutine */ int dlatms_(integer *, integer *, char *, integer 
 	    *, char *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, char *, doublereal *, integer *, doublereal 
 	    *, integer *);
-    static doublereal ainvnm;
+    doublereal ainvnm;
     extern /* Subroutine */ int derrpo_(char *, integer *), dpbtrs_(
 	    char *, integer *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, integer *), xlaenv_(integer *, 
 	    integer *);
-    static doublereal result[7];
+    doublereal result[7];
 
     /* Fortran I/O blocks */
     static cilist io___40 = { 0, 0, 0, fmt_9999, 0 };
@@ -144,81 +132,102 @@ static integer c__7 = 7;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DCHKPB tests DPBTRF, -TRS, -RFS, and -CON.   
+/*  DCHKPB tests DPBTRF, -TRS, -RFS, and -CON. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB contained in the vector NBVAL.   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB contained in the vector NBVAL. */
 
-    NBVAL   (input) INTEGER array, dimension (NBVAL)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NBVAL) */
+/*          The values of the blocksize NB. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX)   
+/*  A       (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX) */
 
-    B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -233,9 +242,11 @@ static integer c__7 = 7;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Double precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "PB", (ftnlen)2, (ftnlen)2);
@@ -264,9 +275,9 @@ static integer c__7 = 7;
 	lda = max(n,1);
 	*(unsigned char *)xtype = 'N';
 
-/*        Set limits on the number of loop iterations.   
+/*        Set limits on the number of loop iterations. */
 
-   Computing MAX */
+/* Computing MAX */
 	i__2 = 1, i__3 = min(n,4);
 	nkd = max(i__2,i__3);
 	nimat = 8;
@@ -281,9 +292,9 @@ static integer c__7 = 7;
 	i__2 = nkd;
 	for (ikd = 1; ikd <= i__2; ++ikd) {
 
-/*           Do for KD = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This order   
-             makes it easier to skip redundant values for small values   
-             of N. */
+/*           Do for KD = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This order */
+/*           makes it easier to skip redundant values for small values */
+/*           of N. */
 
 	    kd = kdval[ikd - 1];
 	    ldab = kd + 1;
@@ -321,15 +332,15 @@ static integer c__7 = 7;
 
 		    if (! zerot || ! dotype[1]) {
 
-/*                    Set up parameters with DLATB4 and generate a test   
-                      matrix with DLATMS. */
+/*                    Set up parameters with DLATB4 and generate a test */
+/*                    matrix with DLATMS. */
 
-			dlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm,
+			dlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, 
 				 &mode, &cndnum, dist);
 
 			s_copy(srnamc_1.srnamt, "DLATMS", (ftnlen)6, (ftnlen)
 				6);
-			dlatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode,
+			dlatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode, 
 				 &cndnum, &anorm, &kd, &kd, packit, &a[koff], 
 				&ldab, &work[1], &info);
 
@@ -337,14 +348,14 @@ static integer c__7 = 7;
 
 			if (info != 0) {
 			    alaerh_(path, "DLATMS", &info, &c__0, uplo, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			    goto L60;
 			}
 		    } else if (izero > 0) {
 
-/*                    Use the same matrix for types 3 and 4 as for type   
-                      2 by copying back the zeroed out column, */
+/*                    Use the same matrix for types 3 and 4 as for type */
+/*                    2 by copying back the zeroed out column, */
 
 			iw = (lda << 1) + 1;
 			if (iuplo == 1) {
@@ -373,8 +384,8 @@ static integer c__7 = 7;
 			}
 		    }
 
-/*                 For types 2-4, zero one row and column of the matrix   
-                   to test that INFO is returned correctly. */
+/*                 For types 2-4, zero one row and column of the matrix */
+/*                 to test that INFO is returned correctly. */
 
 		    izero = 0;
 		    if (zerot) {
@@ -437,8 +448,8 @@ static integer c__7 = 7;
 			nb = nbval[inb];
 			xlaenv_(&c__1, &nb);
 
-/*                    Compute the L*L' or U'*U factorization of the band   
-                      matrix. */
+/*                    Compute the L*L' or U'*U factorization of the band */
+/*                    matrix. */
 
 			i__5 = kd + 1;
 			dlacpy_("Full", &i__5, &n, &a[1], &ldab, &afac[1], &
@@ -462,9 +473,9 @@ static integer c__7 = 7;
 			    goto L50;
 			}
 
-/* +    TEST 1   
-                      Reconstruct matrix from factors and compute   
-                      residual. */
+/* +    TEST 1 */
+/*                    Reconstruct matrix from factors and compute */
+/*                    residual. */
 
 			i__5 = kd + 1;
 			dlacpy_("Full", &i__5, &n, &afac[1], &ldab, &ainv[1], 
@@ -483,8 +494,10 @@ static integer c__7 = 7;
 			    do_fio(&c__1, uplo, (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
-			    do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
+			    do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(
@@ -502,8 +515,8 @@ static integer c__7 = 7;
 			    goto L50;
 			}
 
-/*                    Form the inverse of A so we can get a good estimate   
-                      of RCONDC = 1/(norm(A) * norm(inv(A))). */
+/*                    Form the inverse of A so we can get a good estimate */
+/*                    of RCONDC = 1/(norm(A) * norm(inv(A))). */
 
 			dlaset_("Full", &n, &n, &c_b50, &c_b51, &ainv[1], &
 				lda);
@@ -528,14 +541,14 @@ static integer c__7 = 7;
 			for (irhs = 1; irhs <= i__5; ++irhs) {
 			    nrhs = nsval[irhs];
 
-/* +    TEST 2   
-                      Solve and compute residual for A * X = B. */
+/* +    TEST 2 */
+/*                    Solve and compute residual for A * X = B. */
 
 			    s_copy(srnamc_1.srnamt, "DLARHS", (ftnlen)6, (
 				    ftnlen)6);
 			    dlarhs_(path, xtype, uplo, " ", &n, &n, &kd, &kd, 
 				    &nrhs, &a[1], &ldab, &xact[1], &lda, &b[1]
-				    , &lda, iseed, &info);
+, &lda, iseed, &info);
 			    dlacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &
 				    lda);
 
@@ -548,24 +561,24 @@ static integer c__7 = 7;
 
 			    if (info != 0) {
 				alaerh_(path, "DPBTRS", &info, &c__0, uplo, &
-					n, &n, &kd, &kd, &nrhs, &imat, &nfail,
+					n, &n, &kd, &kd, &nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 			    }
 
 			    dlacpy_("Full", &n, &nrhs, &b[1], &lda, &work[1], 
 				    &lda);
-			    dpbt02_(uplo, &n, &kd, &nrhs, &a[1], &ldab, &x[1],
+			    dpbt02_(uplo, &n, &kd, &nrhs, &a[1], &ldab, &x[1], 
 				     &lda, &work[1], &lda, &rwork[1], &result[
 				    1]);
 
-/* +    TEST 3   
-                      Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*                    Check solution from generated exact solution. */
 
 			    dget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                      Use iterative refinement to improve the solution. */
+/* +    TESTS 4, 5, and 6 */
+/*                    Use iterative refinement to improve the solution. */
 
 			    s_copy(srnamc_1.srnamt, "DPBRFS", (ftnlen)6, (
 				    ftnlen)6);
@@ -578,18 +591,18 @@ static integer c__7 = 7;
 
 			    if (info != 0) {
 				alaerh_(path, "DPBRFS", &info, &c__0, uplo, &
-					n, &n, &kd, &kd, &nrhs, &imat, &nfail,
+					n, &n, &kd, &kd, &nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 			    }
 
 			    dget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[3]);
-			    dpbt05_(uplo, &n, &kd, &nrhs, &a[1], &ldab, &b[1],
+			    dpbt05_(uplo, &n, &kd, &nrhs, &a[1], &ldab, &b[1], 
 				     &lda, &x[1], &lda, &xact[1], &lda, &
 				    rwork[1], &rwork[nrhs + 1], &result[4]);
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 2; k <= 6; ++k) {
 				if (result[k - 1] >= *thresh) {
@@ -620,8 +633,8 @@ static integer c__7 = 7;
 /* L40: */
 			}
 
-/* +    TEST 7   
-                      Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 7 */
+/*                    Get an estimate of RCOND = 1/CNDNUM. */
 
 			s_copy(srnamc_1.srnamt, "DPBCON", (ftnlen)6, (ftnlen)
 				6);
@@ -632,7 +645,7 @@ static integer c__7 = 7;
 
 			if (info != 0) {
 			    alaerh_(path, "DPBCON", &info, &c__0, uplo, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
@@ -649,7 +662,8 @@ static integer c__7 = 7;
 			    do_fio(&c__1, uplo, (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__7, (ftnlen)sizeof(
