@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dchktp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -72,73 +60,73 @@ static integer c__9 = 9;
     integer i__1, i__2[2], i__3, i__4[3], i__5[4];
     char ch__1[2], ch__2[3], ch__3[4];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, k, n, in, lda, lap;
-    static char diag[1];
-    static integer imat, info;
-    static char path[3];
-    static integer irhs, nrhs;
-    static char norm[1], uplo[1];
-    static integer nrun;
+    integer i__, k, n, in, lda, lap;
+    char diag[1];
+    integer imat, info;
+    char path[3];
+    integer irhs, nrhs;
+    char norm[1], uplo[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer idiag;
-    static doublereal scale;
+    integer idiag;
+    doublereal scale;
     extern /* Subroutine */ int dget04_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern logical lsame_(char *, char *);
-    static doublereal rcond, anorm;
-    static integer itran;
+    doublereal rcond, anorm;
+    integer itran;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *), dtpt01_(char *, char *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *), dtpt02_(char *, char *, char *, 
 	    integer *, integer *, doublereal *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *), dtpt03_(char *, char *, char *, integer *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *), dtpt05_(char *, char *, 
 	    char *, integer *, integer *, doublereal *, doublereal *, integer 
-	    *, doublereal *, integer *, doublereal *, integer *, doublereal *,
+	    *, doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	     doublereal *, doublereal *), dtpt06_(
 	    doublereal *, doublereal *, char *, char *, integer *, doublereal 
 	    *, doublereal *, doublereal *);
-    static char trans[1];
-    static integer iuplo, nerrs;
-    static char xtype[1];
+    char trans[1];
+    integer iuplo, nerrs;
+    char xtype[1];
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static doublereal rcondc;
+    doublereal rcondc;
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *);
-    static doublereal rcondi;
+    doublereal rcondi;
     extern /* Subroutine */ int dlarhs_(char *, char *, char *, char *, 
 	    integer *, integer *, integer *, integer *, integer *, doublereal 
 	    *, integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *, integer *);
-    extern doublereal dlantp_(char *, char *, char *, integer *, doublereal *,
+    extern doublereal dlantp_(char *, char *, char *, integer *, doublereal *, 
 	     doublereal *);
-    static doublereal rcondo;
+    doublereal rcondo;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *), dlatps_(char *, char *, char *, char *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     integer *);
-    static doublereal ainvnm;
+    doublereal ainvnm;
     extern /* Subroutine */ int dlattp_(integer *, char *, char *, char *, 
 	    integer *, integer *, doublereal *, doublereal *, doublereal *, 
 	    integer *), dtpcon_(char *, char *, char *
-	    , integer *, doublereal *, doublereal *, doublereal *, integer *, 
+, integer *, doublereal *, doublereal *, doublereal *, integer *, 
 	    integer *), derrtr_(char *, integer *), dtprfs_(char *, char *, char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *), dtptri_(char *, char *, integer *, 
 	    doublereal *, integer *);
-    static doublereal result[9];
+    doublereal result[9];
     extern /* Subroutine */ int dtptrs_(char *, char *, char *, integer *, 
 	    integer *, doublereal *, doublereal *, integer *, integer *);
 
@@ -151,75 +139,96 @@ static integer c__9 = 9;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DCHKTP tests DTPTRI, -TRS, -RFS, and -CON, and DLATPS   
+/*  DCHKTP tests DTPTRI, -TRS, -RFS, and -CON, and DLATPS */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The leading dimension of the work arrays.  NMAX >= the   
-            maximumm value of N in NVAL.   
+/*  NMAX    (input) INTEGER */
+/*          The leading dimension of the work arrays.  NMAX >= the */
+/*          maximumm value of N in NVAL. */
 
-    AP      (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AP      (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AINVP   (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AINVP   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -232,9 +241,11 @@ static integer c__9 = 9;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Double precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "TP", (ftnlen)2, (ftnlen)2);
@@ -291,8 +302,8 @@ static integer c__9 = 9;
 		    idiag = 2;
 		}
 
-/* +    TEST 1   
-                Form the inverse of A. */
+/* +    TEST 1 */
+/*              Form the inverse of A. */
 
 		if (n > 0) {
 		    dcopy_(&lap, &ap[1], &c__1, &ainvp[1], &c__1);
@@ -321,10 +332,10 @@ static integer c__9 = 9;
 		    rcondi = 1. / anorm / ainvnm;
 		}
 
-/*              Compute the residual for the triangular matrix times its   
-                inverse.  Also compute the 1-norm condition number of A. */
+/*              Compute the residual for the triangular matrix times its */
+/*              inverse.  Also compute the 1-norm condition number of A. */
 
-		dtpt01_(uplo, diag, &n, &ap[1], &ainvp[1], &rcondo, &rwork[1],
+		dtpt01_(uplo, diag, &n, &ap[1], &ainvp[1], &rcondo, &rwork[1], 
 			 result);
 
 /*              Print the test ratio if it is .GE. THRESH. */
@@ -366,8 +377,8 @@ static integer c__9 = 9;
 			    rcondc = rcondi;
 			}
 
-/* +    TEST 2   
-                   Solve and compute residual for op(A)*x = b. */
+/* +    TEST 2 */
+/*                 Solve and compute residual for op(A)*x = b. */
 
 			s_copy(srnamc_1.srnamt, "DLARHS", (ftnlen)6, (ftnlen)
 				6);
@@ -398,20 +409,20 @@ static integer c__9 = 9;
 			dtpt02_(uplo, trans, diag, &n, &nrhs, &ap[1], &x[1], &
 				lda, &b[1], &lda, &work[1], &result[1]);
 
-/* +    TEST 3   
-                   Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*                 Check solution from generated exact solution. */
 
 			dget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				rcondc, &result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                   Use iterative refinement to improve the solution and   
-                   compute error bounds. */
+/* +    TESTS 4, 5, and 6 */
+/*                 Use iterative refinement to improve the solution and */
+/*                 compute error bounds. */
 
 			s_copy(srnamc_1.srnamt, "DTPRFS", (ftnlen)6, (ftnlen)
 				6);
 			dtprfs_(uplo, trans, diag, &n, &nrhs, &ap[1], &b[1], &
-				lda, &x[1], &lda, &rwork[1], &rwork[nrhs + 1],
+				lda, &x[1], &lda, &rwork[1], &rwork[nrhs + 1], 
 				 &work[1], &iwork[1], &info);
 
 /*                 Check error code from DTPRFS. */
@@ -433,8 +444,8 @@ static integer c__9 = 9;
 				lda, &x[1], &lda, &xact[1], &lda, &rwork[1], &
 				rwork[nrhs + 1], &result[4]);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			for (k = 2; k <= 6; ++k) {
 			    if (result[k - 1] >= *thresh) {
@@ -467,8 +478,8 @@ static integer c__9 = 9;
 /* L40: */
 		}
 
-/* +    TEST 7   
-                   Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 7 */
+/*                 Get an estimate of RCOND = 1/CNDNUM. */
 
 		for (itran = 1; itran <= 2; ++itran) {
 		    if (itran == 1) {
@@ -497,7 +508,7 @@ static integer c__9 = 9;
 		    }
 
 		    dtpt06_(&rcond, &rcondc, uplo, diag, &n, &ap[1], &rwork[1]
-			    , &result[6]);
+, &result[6]);
 
 /*                 Print the test ratio if it is .GE. THRESH. */
 
@@ -554,14 +565,14 @@ L70:
 
 		    s_copy(srnamc_1.srnamt, "DLATTP", (ftnlen)6, (ftnlen)6);
 		    dlattp_(&imat, uplo, trans, diag, iseed, &n, &ap[1], &x[1]
-			    , &work[1], &info);
+, &work[1], &info);
 
-/* +    TEST 8   
-                   Solve the system op(A)*x = b. */
+/* +    TEST 8 */
+/*                 Solve the system op(A)*x = b. */
 
 		    s_copy(srnamc_1.srnamt, "DLATPS", (ftnlen)6, (ftnlen)6);
 		    dcopy_(&n, &x[1], &c__1, &b[1], &c__1);
-		    dlatps_(uplo, trans, diag, "N", &n, &ap[1], &b[1], &scale,
+		    dlatps_(uplo, trans, diag, "N", &n, &ap[1], &b[1], &scale, 
 			     &rwork[1], &info);
 
 /*                 Check error code from DLATPS. */
@@ -582,8 +593,8 @@ L70:
 			    rwork[1], &c_b103, &b[1], &lda, &x[1], &lda, &
 			    work[1], &result[7]);
 
-/* +    TEST 9   
-                   Solve op(A)*x = b again with NORMIN = 'Y'. */
+/* +    TEST 9 */
+/*                 Solve op(A)*x = b again with NORMIN = 'Y'. */
 
 		    dcopy_(&n, &x[1], &c__1, &b[n + 1], &c__1);
 		    dlatps_(uplo, trans, diag, "Y", &n, &ap[1], &b[n + 1], &
@@ -607,8 +618,8 @@ L70:
 			    rwork[1], &c_b103, &b[n + 1], &lda, &x[1], &lda, &
 			    work[1], &result[8]);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    if (result[7] >= *thresh) {
 			if (nfail == 0 && nerrs == 0) {
