@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* ddrvge.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -67,50 +55,50 @@ static integer c__7 = 7;
     doublereal d__1;
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, k, n, k1, nb, in, kl, ku, nt, lda;
-    static char fact[1];
-    static integer ioff, mode;
-    static doublereal amax;
-    static char path[3];
-    static integer imat, info;
-    static char dist[1], type__[1];
-    static integer nrun;
+    integer i__, k, n, k1, nb, in, kl, ku, nt, lda;
+    char fact[1];
+    integer ioff, mode;
+    doublereal amax;
+    char path[3];
+    integer imat, info;
+    char dist[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int dget01_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *, doublereal *, 
 	    doublereal *), dget02_(char *, integer *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *);
-    static integer ifact;
+    integer ifact;
     extern /* Subroutine */ int dget04_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *);
-    static integer nfail, iseed[4], nfact;
+    integer nfail, iseed[4], nfact;
     extern doublereal dget06_(doublereal *, doublereal *);
     extern /* Subroutine */ int dget07_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *);
     extern logical lsame_(char *, char *);
-    static char equed[1];
-    static integer nbmin;
-    static doublereal rcond, roldc;
-    static integer nimat;
-    static doublereal roldi;
+    char equed[1];
+    integer nbmin;
+    doublereal rcond, roldc;
+    integer nimat;
+    doublereal roldi;
     extern /* Subroutine */ int dgesv_(integer *, integer *, doublereal *, 
 	    integer *, integer *, doublereal *, integer *, integer *);
-    static doublereal anorm;
-    static integer itran;
-    static logical equil;
-    static doublereal roldo;
-    static char trans[1];
-    static integer izero, nerrs, lwork;
-    static logical zerot;
-    static char xtype[1];
+    doublereal anorm;
+    integer itran;
+    logical equil;
+    doublereal roldo;
+    char trans[1];
+    integer izero, nerrs, lwork;
+    logical zerot;
+    char xtype[1];
     extern /* Subroutine */ int dlatb4_(char *, integer *, integer *, integer 
 	    *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, char *), aladhd_(integer *, 
@@ -122,41 +110,41 @@ static integer c__7 = 7;
 	    integer *, integer *, integer *, integer *), dlaqge_(integer *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, char *);
-    static logical prefac;
-    static doublereal colcnd, rcondc;
-    static logical nofact;
-    static integer iequed;
+    logical prefac;
+    doublereal colcnd, rcondc;
+    logical nofact;
+    integer iequed;
     extern /* Subroutine */ int dgeequ_(integer *, integer *, doublereal *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *);
-    static doublereal rcondi;
+    doublereal rcondi;
     extern /* Subroutine */ int dgetrf_(integer *, integer *, doublereal *, 
-	    integer *, integer *, integer *), dgetri_(integer *, doublereal *,
+	    integer *, integer *, integer *), dgetri_(integer *, doublereal *, 
 	     integer *, integer *, doublereal *, integer *, integer *), 
 	    dlacpy_(char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *), alasvm_(char *, integer *, 
 	    integer *, integer *, integer *);
-    static doublereal cndnum, anormi, rcondo, ainvnm;
+    doublereal cndnum, anormi, rcondo, ainvnm;
     extern doublereal dlantr_(char *, char *, char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *);
     extern /* Subroutine */ int dlarhs_(char *, char *, char *, char *, 
 	    integer *, integer *, integer *, integer *, integer *, doublereal 
 	    *, integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *, integer *);
-    static logical trfcon;
-    static doublereal anormo, rowcnd;
+    logical trfcon;
+    doublereal anormo, rowcnd;
     extern /* Subroutine */ int dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *), 
 	    dgesvx_(char *, char *, integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *, char *, doublereal 
-	    *, doublereal *, doublereal *, integer *, doublereal *, integer *,
+	    *, doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	     doublereal *, doublereal *, doublereal *, doublereal *, integer *
-	    , integer *), dlatms_(integer *, integer *
-	    , char *, integer *, char *, doublereal *, integer *, doublereal *
-	    , doublereal *, integer *, integer *, char *, doublereal *, 
+, integer *), dlatms_(integer *, integer *
+, char *, integer *, char *, doublereal *, integer *, doublereal *
+, doublereal *, integer *, integer *, char *, doublereal *, 
 	    integer *, doublereal *, integer *), 
 	    xlaenv_(integer *, integer *), derrvx_(char *, integer *);
-    static doublereal result[7], rpvgrw;
+    doublereal result[7], rpvgrw;
 
     /* Fortran I/O blocks */
     static cilist io___55 = { 0, 0, 0, fmt_9999, 0 };
@@ -171,75 +159,96 @@ static integer c__7 = 7;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DDRVGE tests the driver routines DGESV and -SVX.   
+/*  DDRVGE tests the driver routines DGESV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX)   
+/*  A       (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX) */
 
-    ASAV    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX)   
+/*  ASAV    (workspace) DOUBLE PRECISION array, dimension (NMAX*NMAX) */
 
-    B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    BSAV    (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  BSAV    (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    S       (workspace) DOUBLE PRECISION array, dimension (2*NMAX)   
+/*  S       (workspace) DOUBLE PRECISION array, dimension (2*NMAX) */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*max(3,NRHS))   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*max(3,NRHS)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (2*NRHS+NMAX)   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (2*NRHS+NMAX) */
 
-    IWORK   (workspace) INTEGER array, dimension (2*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (2*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -254,9 +263,11 @@ static integer c__7 = 7;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Double precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "GE", (ftnlen)2, (ftnlen)2);
@@ -310,8 +321,8 @@ static integer c__7 = 7;
 		goto L80;
 	    }
 
-/*           Set up parameters with DLATB4 and generate a test matrix   
-             with DLATMS. */
+/*           Set up parameters with DLATB4 and generate a test matrix */
+/*           with DLATMS. */
 
 	    dlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, &
 		    cndnum, dist);
@@ -330,8 +341,8 @@ static integer c__7 = 7;
 		goto L80;
 	    }
 
-/*           For types 5-7, zero one or more columns of the matrix to   
-             test that INFO is returned correctly. */
+/*           For types 5-7, zero one or more columns of the matrix to */
+/*           test that INFO is returned correctly. */
 
 	    if (zerot) {
 		if (imat == 5) {
@@ -387,17 +398,17 @@ static integer c__7 = 7;
 
 		    } else if (! nofact) {
 
-/*                    Compute the condition number for comparison with   
-                      the value returned by DGESVX (FACT = 'N' reuses   
-                      the condition number from the previous iteration   
-                      with FACT = 'F'). */
+/*                    Compute the condition number for comparison with */
+/*                    the value returned by DGESVX (FACT = 'N' reuses */
+/*                    the condition number from the previous iteration */
+/*                    with FACT = 'F'). */
 
 			dlacpy_("Full", &n, &n, &asav[1], &lda, &afac[1], &
 				lda);
 			if (equil || iequed > 1) {
 
-/*                       Compute row and column scale factors to   
-                         equilibrate the matrix A. */
+/*                       Compute row and column scale factors to */
+/*                       equilibrate the matrix A. */
 
 			    dgeequ_(&n, &n, &afac[1], &lda, &s[1], &s[n + 1], 
 				    &rowcnd, &colcnd, &amax, &info);
@@ -421,8 +432,8 @@ static integer c__7 = 7;
 			    }
 			}
 
-/*                    Save the condition number of the non-equilibrated   
-                      system for use in DGET04. */
+/*                    Save the condition number of the non-equilibrated */
+/*                    system for use in DGET04. */
 
 			if (equil) {
 			    roldo = rcondo;
@@ -494,10 +505,10 @@ static integer c__7 = 7;
 
 			if (nofact && itran == 1) {
 
-/*                       --- Test DGESV  ---   
+/*                       --- Test DGESV  --- */
 
-                         Compute the LU factorization of the matrix and   
-                         solve the system. */
+/*                       Compute the LU factorization of the matrix and */
+/*                       solve the system. */
 
 			    dlacpy_("Full", &n, &n, &a[1], &lda, &afac[1], &
 				    lda);
@@ -506,7 +517,7 @@ static integer c__7 = 7;
 
 			    s_copy(srnamc_1.srnamt, "DGESV ", (ftnlen)6, (
 				    ftnlen)6);
-			    dgesv_(&n, nrhs, &afac[1], &lda, &iwork[1], &x[1],
+			    dgesv_(&n, nrhs, &afac[1], &lda, &iwork[1], &x[1], 
 				     &lda, &info);
 
 /*                       Check error code from DGESV . */
@@ -517,8 +528,8 @@ static integer c__7 = 7;
 					nfail, &nerrs, nout);
 			    }
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    dget01_(&n, &n, &a[1], &lda, &afac[1], &lda, &
 				    iwork[1], &rwork[1], result);
@@ -535,13 +546,13 @@ static integer c__7 = 7;
 
 /*                          Check solution from generated exact solution. */
 
-				dget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				dget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &rcondc, &result[2]);
 				nt = 3;
 			    }
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    i__4 = nt;
 			    for (k = 1; k <= i__4; ++k) {
@@ -577,15 +588,15 @@ static integer c__7 = 7;
 			dlaset_("Full", &n, nrhs, &c_b20, &c_b20, &x[1], &lda);
 			if (iequed > 1 && n > 0) {
 
-/*                       Equilibrate the matrix if FACT = 'F' and   
-                         EQUED = 'R', 'C', or 'B'. */
+/*                       Equilibrate the matrix if FACT = 'F' and */
+/*                       EQUED = 'R', 'C', or 'B'. */
 
 			    dlaqge_(&n, &n, &a[1], &lda, &s[1], &s[n + 1], &
 				    rowcnd, &colcnd, &amax, equed);
 			}
 
-/*                    Solve the system and compute the condition number   
-                      and error bounds using DGESVX. */
+/*                    Solve the system and compute the condition number */
+/*                    and error bounds using DGESVX. */
 
 			s_copy(srnamc_1.srnamt, "DGESVX", (ftnlen)6, (ftnlen)
 				6);
@@ -607,8 +618,8 @@ static integer c__7 = 7;
 				    nerrs, nout);
 			}
 
-/*                    Compare WORK(1) from DGESVX with the computed   
-                      reciprocal pivot growth factor RPVGRW */
+/*                    Compare WORK(1) from DGESVX with the computed */
+/*                    reciprocal pivot growth factor RPVGRW */
 
 			if (info != 0) {
 			    rpvgrw = dlantr_("M", "U", "N", &info, &info, &
@@ -634,8 +645,8 @@ static integer c__7 = 7;
 
 			if (! prefac) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    dget01_(&n, &n, &a[1], &lda, &afac[1], &lda, &
 				    iwork[1], &rwork[(*nrhs << 1) + 1], 
@@ -651,15 +662,15 @@ static integer c__7 = 7;
 /*                       Compute residual of the computed solution. */
 
 			    dlacpy_("Full", &n, nrhs, &bsav[1], &lda, &work[1]
-				    , &lda);
+, &lda);
 			    dget02_(trans, &n, &n, nrhs, &asav[1], &lda, &x[1]
-				    , &lda, &work[1], &lda, &rwork[(*nrhs << 
+, &lda, &work[1], &lda, &rwork[(*nrhs << 
 				    1) + 1], &result[1]);
 
 /*                       Check solution from generated exact solution. */
 
 			    if (nofact || prefac && lsame_(equed, "N")) {
-				dget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				dget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &rcondc, &result[2]);
 			    } else {
 				if (itran == 1) {
@@ -667,12 +678,12 @@ static integer c__7 = 7;
 				} else {
 				    roldc = roldi;
 				}
-				dget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				dget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &roldc, &result[2]);
 			    }
 
-/*                       Check the error bounds from iterative   
-                         refinement. */
+/*                       Check the error bounds from iterative */
+/*                       refinement. */
 
 			    dget07_(trans, &n, nrhs, &asav[1], &lda, &b[1], &
 				    lda, &x[1], &lda, &xact[1], &lda, &rwork[
@@ -681,13 +692,13 @@ static integer c__7 = 7;
 			    trfcon = TRUE_;
 			}
 
-/*                    Compare RCOND from DGESVX with the computed value   
-                      in RCONDC. */
+/*                    Compare RCOND from DGESVX with the computed value */
+/*                    in RCONDC. */
 
 			result[5] = dget06_(&rcond, &rcondc);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			if (! trfcon) {
 			    for (k = k1; k <= 7; ++k) {
