@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* ddrvsp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -59,46 +47,46 @@ static integer c__2 = 2;
     integer i__1, i__2, i__3, i__4, i__5[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, k1, in, kl, ku, nt, lda, npp;
-    static char fact[1];
-    static integer ioff, mode, imat, info;
-    static char path[3], dist[1], uplo[1], type__[1];
-    static integer nrun, ifact;
+    integer i__, j, k, n, i1, i2, k1, in, kl, ku, nt, lda, npp;
+    char fact[1];
+    integer ioff, mode, imat, info;
+    char path[3], dist[1], uplo[1], type__[1];
+    integer nrun, ifact;
     extern /* Subroutine */ int dget04_(integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern doublereal dget06_(doublereal *, doublereal *);
-    static doublereal rcond;
-    static integer nimat;
+    doublereal rcond;
+    integer nimat;
     extern /* Subroutine */ int dppt02_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *), dspt01_(char *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *);
-    static doublereal anorm;
+    doublereal anorm;
     extern /* Subroutine */ int dppt05_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, doublereal *), dcopy_(integer *, doublereal *, integer *, doublereal *, 
 	     integer *);
-    static integer iuplo, izero, nerrs, lwork;
+    integer iuplo, izero, nerrs, lwork;
     extern /* Subroutine */ int dspsv_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, integer *);
-    static logical zerot;
-    static char xtype[1];
+    logical zerot;
+    char xtype[1];
     extern /* Subroutine */ int dlatb4_(char *, integer *, integer *, integer 
 	    *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, char *), aladhd_(integer *, 
 	    char *), alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static doublereal rcondc;
-    static char packit[1];
+    doublereal rcondc;
+    char packit[1];
     extern /* Subroutine */ int dlacpy_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *), 
 	    dlarhs_(char *, char *, char *, char *, integer *, integer *, 
@@ -111,20 +99,20 @@ static integer c__2 = 2;
 	    doublereal *);
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static doublereal cndnum;
+    doublereal cndnum;
     extern /* Subroutine */ int dlatms_(integer *, integer *, char *, integer 
 	    *, char *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, char *, doublereal *, integer *, doublereal 
 	    *, integer *);
-    static doublereal ainvnm;
+    doublereal ainvnm;
     extern /* Subroutine */ int dsptrf_(char *, integer *, doublereal *, 
 	    integer *, integer *), dsptri_(char *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *), 
 	    derrvx_(char *, integer *);
-    static doublereal result[6];
+    doublereal result[6];
     extern /* Subroutine */ int dspsvx_(char *, char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *, integer *);
 
     /* Fortran I/O blocks */
@@ -133,74 +121,95 @@ static integer c__2 = 2;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DDRVSP tests the driver routines DSPSV and -SVX.   
+/*  DDRVSP tests the driver routines DSPSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  A       (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AFAC    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AFAC    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AINV    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AINV    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  B       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  X       (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) DOUBLE PRECISION array, dimension (NMAX*NRHS) */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension   
-                        (NMAX*max(2,NRHS))   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension */
+/*                      (NMAX*max(2,NRHS)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX+2*NRHS) */
 
-    IWORK   (workspace) INTEGER array, dimension (2*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (2*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -213,9 +222,11 @@ static integer c__2 = 2;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Double precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "SP", (ftnlen)2, (ftnlen)2);
@@ -277,8 +288,8 @@ static integer c__2 = 2;
 		    *(unsigned char *)packit = 'R';
 		}
 
-/*              Set up parameters with DLATB4 and generate a test matrix   
-                with DLATMS. */
+/*              Set up parameters with DLATB4 and generate a test matrix */
+/*              with DLATMS. */
 
 		dlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, 
 			&cndnum, dist);
@@ -291,13 +302,13 @@ static integer c__2 = 2;
 /*              Check error code from DLATMS. */
 
 		if (info != 0) {
-		    alaerh_(path, "DLATMS", &info, &c__0, uplo, &n, &n, &c_n1,
+		    alaerh_(path, "DLATMS", &info, &c__0, uplo, &n, &n, &c_n1, 
 			     &c_n1, &c_n1, &imat, &nfail, &nerrs, nout);
 		    goto L160;
 		}
 
-/*              For types 3-6, zero one or more rows and columns of the   
-                matrix to test that INFO is returned correctly. */
+/*              For types 3-6, zero one or more rows and columns of the */
+/*              matrix to test that INFO is returned correctly. */
 
 		if (zerot) {
 		    if (imat == 3) {
@@ -386,8 +397,8 @@ static integer c__2 = 2;
 		    *(unsigned char *)fact = *(unsigned char *)&facts[ifact - 
 			    1];
 
-/*                 Compute the condition number for comparison with   
-                   the value returned by DSPSVX. */
+/*                 Compute the condition number for comparison with */
+/*                 the value returned by DSPSVX. */
 
 		    if (zerot) {
 			if (ifact == 1) {
@@ -443,8 +454,8 @@ static integer c__2 = 2;
 			dspsv_(uplo, &n, nrhs, &afac[1], &iwork[1], &x[1], &
 				lda, &info);
 
-/*                    Adjust the expected value of INFO to account for   
-                      pivoting. */
+/*                    Adjust the expected value of INFO to account for */
+/*                    pivoting. */
 
 			k = izero;
 			if (k > 0) {
@@ -471,11 +482,11 @@ L100:
 			    goto L120;
 			}
 
-/*                    Reconstruct matrix from factors and compute   
-                      residual. */
+/*                    Reconstruct matrix from factors and compute */
+/*                    residual. */
 
 			dspt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &ainv[1]
-				, &lda, &rwork[1], result);
+, &lda, &rwork[1], result);
 
 /*                    Compute residual of the computed solution. */
 
@@ -489,8 +500,8 @@ L100:
 				rcondc, &result[2]);
 			nt = 3;
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			i__3 = nt;
 			for (k = 1; k <= i__3; ++k) {
@@ -523,21 +534,21 @@ L120:
 /*                 --- Test DSPSVX --- */
 
 		    if (ifact == 2 && npp > 0) {
-			dlaset_("Full", &npp, &c__1, &c_b59, &c_b59, &afac[1],
+			dlaset_("Full", &npp, &c__1, &c_b59, &c_b59, &afac[1], 
 				 &npp);
 		    }
 		    dlaset_("Full", &n, nrhs, &c_b59, &c_b59, &x[1], &lda);
 
-/*                 Solve the system and compute the condition number and   
-                   error bounds using DSPSVX. */
+/*                 Solve the system and compute the condition number and */
+/*                 error bounds using DSPSVX. */
 
 		    s_copy(srnamc_1.srnamt, "DSPSVX", (ftnlen)6, (ftnlen)6);
 		    dspsvx_(fact, uplo, &n, nrhs, &a[1], &afac[1], &iwork[1], 
 			    &b[1], &lda, &x[1], &lda, &rcond, &rwork[1], &
 			    rwork[*nrhs + 1], &work[1], &iwork[n + 1], &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -569,8 +580,8 @@ L130:
 		    if (info == 0) {
 			if (ifact >= 2) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    dspt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &
 				    ainv[1], &lda, &rwork[(*nrhs << 1) + 1], 
@@ -600,13 +611,13 @@ L130:
 			k1 = 6;
 		    }
 
-/*                 Compare RCOND from DSPSVX with the computed value   
-                   in RCONDC. */
+/*                 Compare RCOND from DSPSVX with the computed value */
+/*                 in RCONDC. */
 
 		    result[5] = dget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    for (k = k1; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
