@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* derrge.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -45,13 +33,13 @@ static integer c__4 = 4;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static doublereal a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static doublereal w[12], x[4];
-    static char c2[2];
-    static doublereal r1[4], r2[4], af[16]	/* was [4][4] */;
-    static integer ip[4], iw[4], info;
-    static doublereal anrm, ccond, rcond;
+    doublereal a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    doublereal w[12], x[4];
+    char c2[2];
+    doublereal r1[4], r2[4], af[16]	/* was [4][4] */;
+    integer ip[4], iw[4], info;
+    doublereal anrm, ccond, rcond;
     extern /* Subroutine */ int dgbtf2_(integer *, integer *, integer *, 
 	    integer *, doublereal *, integer *, integer *, integer *), 
 	    dgetf2_(integer *, integer *, doublereal *, integer *, integer *, 
@@ -69,12 +57,12 @@ static integer c__4 = 4;
 	    doublereal *, doublereal *, integer *, integer *), 
 	    dgbtrf_(integer *, integer *, integer *, integer *, doublereal *, 
 	    integer *, integer *, integer *), dgeequ_(integer *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, integer *), dgerfs_(char *, integer *
-	    , integer *, doublereal *, integer *, doublereal *, integer *, 
+, integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *, integer *), dgetrf_(integer *, integer *, doublereal *, integer *, 
-	    integer *, integer *), dgetri_(integer *, doublereal *, integer *,
+	    integer *, integer *), dgetri_(integer *, doublereal *, integer *, 
 	     integer *, doublereal *, integer *, integer *);
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int chkxer_(char *, integer *, integer *, logical 
@@ -89,28 +77,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DERRGE tests the error exits for the DOUBLE PRECISION routines   
-    for general matrices.   
+/*  DERRGE tests the error exits for the DOUBLE PRECISION routines */
+/*  for general matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -139,10 +146,10 @@ static integer c__4 = 4;
 
     if (lsamen_(&c__2, c2, "GE")) {
 
-/*        Test error exits of the routines that use the LU decomposition   
-          of a general matrix.   
+/*        Test error exits of the routines that use the LU decomposition */
+/*        of a general matrix. */
 
-          DGETRF */
+/*        DGETRF */
 
 	s_copy(srnamc_1.srnamt, "DGETRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -283,10 +290,10 @@ static integer c__4 = 4;
 
     } else if (lsamen_(&c__2, c2, "GB")) {
 
-/*        Test error exits of the routines that use the LU decomposition   
-          of a general band matrix.   
+/*        Test error exits of the routines that use the LU decomposition */
+/*        of a general band matrix. */
 
-          DGBTRF */
+/*        DGBTRF */
 
 	s_copy(srnamc_1.srnamt, "DGBTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
