@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* derrpo.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -42,13 +30,13 @@ static integer c_n1 = -1;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static doublereal a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static doublereal w[12], x[4];
-    static char c2[2];
-    static doublereal r1[4], r2[4], af[16]	/* was [4][4] */;
-    static integer iw[4], info;
-    static doublereal anrm, rcond;
+    doublereal a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    doublereal w[12], x[4];
+    char c2[2];
+    doublereal r1[4], r2[4], af[16]	/* was [4][4] */;
+    integer iw[4], info;
+    doublereal anrm, rcond;
     extern /* Subroutine */ int dpbtf2_(char *, integer *, integer *, 
 	    doublereal *, integer *, integer *), dpotf2_(char *, 
 	    integer *, doublereal *, integer *, integer *), alaesm_(
@@ -57,7 +45,7 @@ static integer c_n1 = -1;
 	    doublereal *, integer *, integer *);
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int dpbequ_(char *, integer *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     integer *), dpbrfs_(char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
@@ -67,11 +55,11 @@ static integer c_n1 = -1;
 	    integer *, doublereal *, doublereal *, doublereal *, integer *, 
 	    integer *), chkxer_(char *, integer *, integer *, logical 
 	    *, logical *), dppcon_(char *, integer *, doublereal *, 
-	    doublereal *, doublereal *, doublereal *, integer *, integer *), dpoequ_(integer *, doublereal *, integer *, doublereal *,
+	    doublereal *, doublereal *, doublereal *, integer *, integer *), dpoequ_(integer *, doublereal *, integer *, doublereal *, 
 	     doublereal *, doublereal *, integer *), dpbtrs_(char *, integer *
-	    , integer *, integer *, doublereal *, integer *, doublereal *, 
+, integer *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, integer *), dporfs_(char *, integer *, integer 
-	    *, doublereal *, integer *, doublereal *, integer *, doublereal *,
+	    *, doublereal *, integer *, doublereal *, integer *, doublereal *, 
 	     integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *, integer *), dpotrf_(char *, 
 	    integer *, doublereal *, integer *, integer *), dpotri_(
@@ -79,7 +67,7 @@ static integer c_n1 = -1;
 	    dppequ_(char *, integer *, doublereal *, doublereal *, doublereal 
 	    *, doublereal *, integer *), dpprfs_(char *, integer *, 
 	    integer *, doublereal *, doublereal *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     integer *, integer *), dpptrf_(char *, integer *, 
 	    doublereal *, integer *), dpptri_(char *, integer *, 
 	    doublereal *, integer *), dpotrs_(char *, integer *, 
@@ -92,28 +80,47 @@ static integer c_n1 = -1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DERRPO tests the error exits for the DOUBLE PRECISION routines   
-    for symmetric positive definite matrices.   
+/*  DERRPO tests the error exits for the DOUBLE PRECISION routines */
+/*  for symmetric positive definite matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -141,10 +148,10 @@ static integer c_n1 = -1;
 
     if (lsamen_(&c__2, c2, "PO")) {
 
-/*        Test error exits of the routines that use the Cholesky   
-          decomposition of a symmetric positive definite matrix.   
+/*        Test error exits of the routines that use the Cholesky */
+/*        decomposition of a symmetric positive definite matrix. */
 
-          DPOTRF */
+/*        DPOTRF */
 
 	s_copy(srnamc_1.srnamt, "DPOTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -285,10 +292,10 @@ static integer c_n1 = -1;
 
     } else if (lsamen_(&c__2, c2, "PP")) {
 
-/*        Test error exits of the routines that use the Cholesky   
-          decomposition of a symmetric positive definite packed matrix.   
+/*        Test error exits of the routines that use the Cholesky */
+/*        decomposition of a symmetric positive definite packed matrix. */
 
-          DPPTRF */
+/*        DPPTRF */
 
 	s_copy(srnamc_1.srnamt, "DPPTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -387,10 +394,10 @@ static integer c_n1 = -1;
 
     } else if (lsamen_(&c__2, c2, "PB")) {
 
-/*        Test error exits of the routines that use the Cholesky   
-          decomposition of a symmetric positive definite band matrix.   
+/*        Test error exits of the routines that use the Cholesky */
+/*        decomposition of a symmetric positive definite band matrix. */
 
-          DPBTRF */
+/*        DPBTRF */
 
 	s_copy(srnamc_1.srnamt, "DPBTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
