@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* derrtr.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -42,11 +30,11 @@ static integer c_n1 = -1;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static doublereal a[4]	/* was [2][2] */, b[2], w[2], x[2];
-    static char c2[2];
-    static doublereal r1[2], r2[2];
-    static integer iw[2], info;
-    static doublereal scale, rcond;
+    doublereal a[4]	/* was [2][2] */, b[2], w[2], x[2];
+    char c2[2];
+    doublereal r1[2], r2[2];
+    integer iw[2], info;
+    doublereal scale, rcond;
     extern /* Subroutine */ int dtrti2_(char *, char *, integer *, doublereal 
 	    *, integer *, integer *), alaesm_(char *, logical 
 	    *, integer *), dlatbs_(char *, char *, char *, char *, 
@@ -62,15 +50,15 @@ static integer c_n1 = -1;
 	    doublereal *, integer *, integer *), 
 	    dlatps_(char *, char *, char *, char *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, integer *), dtpcon_(char *, char *, char *, integer *
-	    , doublereal *, doublereal *, doublereal *, integer *, integer *), dlatrs_(char *, char *, char *, char *, 
+, doublereal *, doublereal *, doublereal *, integer *, integer *), dlatrs_(char *, char *, char *, char *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    doublereal *, integer *), dtrcon_(
 	    char *, char *, char *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, integer *, integer *), dtbtrs_(char *, char *, char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, integer *, 
 	    integer *), dtprfs_(char *, char *, char *
-	    , integer *, integer *, doublereal *, doublereal *, integer *, 
-	    doublereal *, integer *, doublereal *, doublereal *, doublereal *,
+, integer *, integer *, doublereal *, doublereal *, integer *, 
+	    doublereal *, integer *, doublereal *, doublereal *, doublereal *, 
 	     integer *, integer *), dtrrfs_(char *, 
 	    char *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, integer *, doublereal *, 
@@ -87,28 +75,45 @@ static integer c_n1 = -1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DERRTR tests the error exits for the DOUBLE PRECISION triangular   
-    routines.   
+/*  DERRTR tests the error exits for the DOUBLE PRECISION triangular */
+/*  routines. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -123,9 +128,9 @@ static integer c_n1 = -1;
 
     if (lsamen_(&c__2, c2, "TR")) {
 
-/*        Test error exits for the general triangular routines.   
+/*        Test error exits for the general triangular routines. */
 
-          DTRTRI */
+/*        DTRTRI */
 
 	s_copy(srnamc_1.srnamt, "DTRTRI", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -201,42 +206,42 @@ static integer c_n1 = -1;
 
 	s_copy(srnamc_1.srnamt, "DTRRFS", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	dtrrfs_("/", "N", "N", &c__0, &c__0, a, &c__1, b, &c__1, x, &c__1, r1,
+	dtrrfs_("/", "N", "N", &c__0, &c__0, a, &c__1, b, &c__1, x, &c__1, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	dtrrfs_("U", "/", "N", &c__0, &c__0, a, &c__1, b, &c__1, x, &c__1, r1,
+	dtrrfs_("U", "/", "N", &c__0, &c__0, a, &c__1, b, &c__1, x, &c__1, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	dtrrfs_("U", "N", "/", &c__0, &c__0, a, &c__1, b, &c__1, x, &c__1, r1,
+	dtrrfs_("U", "N", "/", &c__0, &c__0, a, &c__1, b, &c__1, x, &c__1, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	dtrrfs_("U", "N", "N", &c_n1, &c__0, a, &c__1, b, &c__1, x, &c__1, r1,
+	dtrrfs_("U", "N", "N", &c_n1, &c__0, a, &c__1, b, &c__1, x, &c__1, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	dtrrfs_("U", "N", "N", &c__0, &c_n1, a, &c__1, b, &c__1, x, &c__1, r1,
+	dtrrfs_("U", "N", "N", &c__0, &c_n1, a, &c__1, b, &c__1, x, &c__1, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 7;
-	dtrrfs_("U", "N", "N", &c__2, &c__1, a, &c__1, b, &c__2, x, &c__2, r1,
+	dtrrfs_("U", "N", "N", &c__2, &c__1, a, &c__1, b, &c__2, x, &c__2, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 9;
-	dtrrfs_("U", "N", "N", &c__2, &c__1, a, &c__2, b, &c__1, x, &c__2, r1,
+	dtrrfs_("U", "N", "N", &c__2, &c__1, a, &c__2, b, &c__1, x, &c__2, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 11;
-	dtrrfs_("U", "N", "N", &c__2, &c__1, a, &c__2, b, &c__2, x, &c__1, r1,
+	dtrrfs_("U", "N", "N", &c__2, &c__1, a, &c__2, b, &c__2, x, &c__1, r1, 
 		 r2, w, iw, &info);
 	chkxer_("DTRRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -295,9 +300,9 @@ static integer c_n1 = -1;
 
     } else if (lsamen_(&c__2, c2, "TP")) {
 
-/*        Test error exits for the packed triangular routines.   
+/*        Test error exits for the packed triangular routines. */
 
-          DTPTRI */
+/*        DTPTRI */
 
 	s_copy(srnamc_1.srnamt, "DTPTRI", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -345,37 +350,37 @@ static integer c_n1 = -1;
 
 	s_copy(srnamc_1.srnamt, "DTPRFS", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	dtprfs_("/", "N", "N", &c__0, &c__0, a, b, &c__1, x, &c__1, r1, r2, w,
+	dtprfs_("/", "N", "N", &c__0, &c__0, a, b, &c__1, x, &c__1, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	dtprfs_("U", "/", "N", &c__0, &c__0, a, b, &c__1, x, &c__1, r1, r2, w,
+	dtprfs_("U", "/", "N", &c__0, &c__0, a, b, &c__1, x, &c__1, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	dtprfs_("U", "N", "/", &c__0, &c__0, a, b, &c__1, x, &c__1, r1, r2, w,
+	dtprfs_("U", "N", "/", &c__0, &c__0, a, b, &c__1, x, &c__1, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	dtprfs_("U", "N", "N", &c_n1, &c__0, a, b, &c__1, x, &c__1, r1, r2, w,
+	dtprfs_("U", "N", "N", &c_n1, &c__0, a, b, &c__1, x, &c__1, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 5;
-	dtprfs_("U", "N", "N", &c__0, &c_n1, a, b, &c__1, x, &c__1, r1, r2, w,
+	dtprfs_("U", "N", "N", &c__0, &c_n1, a, b, &c__1, x, &c__1, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 8;
-	dtprfs_("U", "N", "N", &c__2, &c__1, a, b, &c__1, x, &c__2, r1, r2, w,
+	dtprfs_("U", "N", "N", &c__2, &c__1, a, b, &c__1, x, &c__2, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 10;
-	dtprfs_("U", "N", "N", &c__2, &c__1, a, b, &c__2, x, &c__1, r1, r2, w,
+	dtprfs_("U", "N", "N", &c__2, &c__1, a, b, &c__2, x, &c__1, r1, r2, w, 
 		 iw, &info);
 	chkxer_("DTPRFS", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
@@ -426,9 +431,9 @@ static integer c_n1 = -1;
 
     } else if (lsamen_(&c__2, c2, "TB")) {
 
-/*        Test error exits for the banded triangular routines.   
+/*        Test error exits for the banded triangular routines. */
 
-          DTBTRS */
+/*        DTBTRS */
 
 	s_copy(srnamc_1.srnamt, "DTBTRS", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
