@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dlattp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -28,37 +16,37 @@ static doublereal c_b48 = 1.;
     integer i__1, i__2;
     doublereal d__1, d__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double pow_dd(doublereal *, doublereal *), sqrt(doublereal), d_sign(
 	    doublereal *, doublereal *);
 
     /* Local variables */
-    static doublereal c__;
-    static integer i__, j;
-    static doublereal s, t, x, y, z__;
-    static integer jc;
-    static doublereal ra;
-    static integer jj;
-    static doublereal rb;
-    static integer jl, kl, jr, ku, iy, jx;
-    static doublereal ulp, sfac;
-    static integer mode;
-    static char path[3], dist[1];
-    static doublereal unfl;
+    doublereal c__;
+    integer i__, j;
+    doublereal s, t, x, y, z__;
+    integer jc;
+    doublereal ra;
+    integer jj;
+    doublereal rb;
+    integer jl, kl, jr, ku, iy, jx;
+    doublereal ulp, sfac;
+    integer mode;
+    char path[3], dist[1];
+    doublereal unfl;
     extern /* Subroutine */ int drot_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *);
-    static doublereal rexp;
-    static char type__[1];
-    static doublereal texp, star1, plus1, plus2, bscal;
+    doublereal rexp;
+    char type__[1];
+    doublereal texp, star1, plus1, plus2, bscal;
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
     extern logical lsame_(char *, char *);
-    static doublereal tscal, anorm, bnorm, tleft;
+    doublereal tscal, anorm, bnorm, tleft;
     extern /* Subroutine */ int drotg_(doublereal *, doublereal *, doublereal 
 	    *, doublereal *);
-    static doublereal stemp;
-    static logical upper;
+    doublereal stemp;
+    logical upper;
     extern /* Subroutine */ int dlatb4_(char *, integer *, integer *, integer 
 	    *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, char *), dlabad_(doublereal 
@@ -66,81 +54,96 @@ static doublereal c_b48 = 1.;
     extern doublereal dlamch_(char *);
     extern integer idamax_(integer *, doublereal *, integer *);
     extern doublereal dlarnd_(integer *, integer *);
-    static char packit[1];
-    static doublereal bignum, cndnum;
+    char packit[1];
+    doublereal bignum, cndnum;
     extern /* Subroutine */ int dlatms_(integer *, integer *, char *, integer 
 	    *, char *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, char *, doublereal *, integer *, doublereal 
 	    *, integer *), dlarnv_(integer *, integer 
 	    *, integer *, doublereal *);
-    static integer jcnext, jcount;
-    static doublereal smlnum;
+    integer jcnext, jcount;
+    doublereal smlnum;
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    DLATTP generates a triangular test matrix in packed storage.   
-    IMAT and UPLO uniquely specify the properties of the test   
-    matrix, which is returned in the array AP.   
+/*  DLATTP generates a triangular test matrix in packed storage. */
+/*  IMAT and UPLO uniquely specify the properties of the test */
+/*  matrix, which is returned in the array AP. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    IMAT    (input) INTEGER   
-            An integer key describing which matrix to generate for this   
-            path.   
+/*  IMAT    (input) INTEGER */
+/*          An integer key describing which matrix to generate for this */
+/*          path. */
 
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A will be upper or lower   
-            triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A will be upper or lower */
+/*          triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
 
-    TRANS   (input) CHARACTER*1   
-            Specifies whether the matrix or its transpose will be used.   
-            = 'N':  No transpose   
-            = 'T':  Transpose   
-            = 'C':  Conjugate transpose (= Transpose)   
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies whether the matrix or its transpose will be used. */
+/*          = 'N':  No transpose */
+/*          = 'T':  Transpose */
+/*          = 'C':  Conjugate transpose (= Transpose) */
 
-    DIAG    (output) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
+/*  DIAG    (output) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
 
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            The seed vector for the random number generator (used in   
-            DLATMS).  Modified on exit.   
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          The seed vector for the random number generator (used in */
+/*          DLATMS).  Modified on exit. */
 
-    N       (input) INTEGER   
-            The order of the matrix to be generated.   
+/*  N       (input) INTEGER */
+/*          The order of the matrix to be generated. */
 
-    A       (output) DOUBLE PRECISION array, dimension (N*(N+1)/2)   
-            The upper or lower triangular matrix A, packed columnwise in   
-            a linear array.  The j-th column of A is stored in the array   
-            AP as follows:   
-            if UPLO = 'U', AP((j-1)*j/2 + i) = A(i,j) for 1<=i<=j;   
-            if UPLO = 'L',   
-               AP((j-1)*(n-j) + j*(j+1)/2 + i-j) = A(i,j) for j<=i<=n.   
+/*  A       (output) DOUBLE PRECISION array, dimension (N*(N+1)/2) */
+/*          The upper or lower triangular matrix A, packed columnwise in */
+/*          a linear array.  The j-th column of A is stored in the array */
+/*          AP as follows: */
+/*          if UPLO = 'U', AP((j-1)*j/2 + i) = A(i,j) for 1<=i<=j; */
+/*          if UPLO = 'L', */
+/*             AP((j-1)*(n-j) + j*(j+1)/2 + i-j) = A(i,j) for j<=i<=n. */
 
-    B       (output) DOUBLE PRECISION array, dimension (N)   
-            The right hand side vector, if IMAT > 10.   
+/*  B       (output) DOUBLE PRECISION array, dimension (N) */
+/*          The right hand side vector, if IMAT > 10. */
 
-    WORK    (workspace) DOUBLE PRECISION array, dimension (3*N)   
+/*  WORK    (workspace) DOUBLE PRECISION array, dimension (3*N) */
 
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0: if INFO = -k, the k-th argument had an illegal value   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0: if INFO = -k, the k-th argument had an illegal value */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --work;
     --b;
     --a;
@@ -187,10 +190,10 @@ static doublereal c_b48 = 1.;
 	dlatms_(n, n, dist, &iseed[1], type__, &b[1], &mode, &cndnum, &anorm, 
 		&kl, &ku, packit, &a[1], n, &work[1], info);
 
-/*     IMAT > 6:  Unit triangular matrix   
-       The diagonal is deliberately set to something other than 1.   
+/*     IMAT > 6:  Unit triangular matrix */
+/*     The diagonal is deliberately set to something other than 1. */
 
-       IMAT = 7:  Matrix is the identity */
+/*     IMAT = 7:  Matrix is the identity */
 
     } else if (*imat == 7) {
 	if (upper) {
@@ -221,11 +224,11 @@ static doublereal c_b48 = 1.;
 	    }
 	}
 
-/*     IMAT > 7:  Non-trivial unit triangular matrix   
+/*     IMAT > 7:  Non-trivial unit triangular matrix */
 
-       Generate a unit triangular matrix T with condition CNDNUM by   
-       forming a triangular matrix with known singular values and   
-       filling in the zero entries with Givens rotations. */
+/*     Generate a unit triangular matrix T with condition CNDNUM by */
+/*     forming a triangular matrix with known singular values and */
+/*     filling in the zero entries with Givens rotations. */
 
     } else if (*imat <= 10) {
 	if (upper) {
@@ -256,63 +259,63 @@ static doublereal c_b48 = 1.;
 	    }
 	}
 
-/*        Since the trace of a unit triangular matrix is 1, the product   
-          of its singular values must be 1.  Let s = sqrt(CNDNUM),   
-          x = sqrt(s) - 1/sqrt(s), y = sqrt(2/(n-2))*x, and z = x**2.   
-          The following triangular matrix has singular values s, 1, 1,   
-          ..., 1, 1/s:   
+/*        Since the trace of a unit triangular matrix is 1, the product */
+/*        of its singular values must be 1.  Let s = sqrt(CNDNUM), */
+/*        x = sqrt(s) - 1/sqrt(s), y = sqrt(2/(n-2))*x, and z = x**2. */
+/*        The following triangular matrix has singular values s, 1, 1, */
+/*        ..., 1, 1/s: */
 
-          1  y  y  y  ...  y  y  z   
-             1  0  0  ...  0  0  y   
-                1  0  ...  0  0  y   
-                   .  ...  .  .  .   
-                       .   .  .  .   
-                           1  0  y   
-                              1  y   
-                                 1   
+/*        1  y  y  y  ...  y  y  z */
+/*           1  0  0  ...  0  0  y */
+/*              1  0  ...  0  0  y */
+/*                 .  ...  .  .  . */
+/*                     .   .  .  . */
+/*                         1  0  y */
+/*                            1  y */
+/*                               1 */
 
-          To fill in the zeros, we first multiply by a matrix with small   
-          condition number of the form   
+/*        To fill in the zeros, we first multiply by a matrix with small */
+/*        condition number of the form */
 
-          1  0  0  0  0  ...   
-             1  +  *  0  0  ...   
-                1  +  0  0  0   
-                   1  +  *  0  0   
-                      1  +  0  0   
-                         ...   
-                            1  +  0   
-                               1  0   
-                                  1   
+/*        1  0  0  0  0  ... */
+/*           1  +  *  0  0  ... */
+/*              1  +  0  0  0 */
+/*                 1  +  *  0  0 */
+/*                    1  +  0  0 */
+/*                       ... */
+/*                          1  +  0 */
+/*                             1  0 */
+/*                                1 */
 
-          Each element marked with a '*' is formed by taking the product   
-          of the adjacent elements marked with '+'.  The '*'s can be   
-          chosen freely, and the '+'s are chosen so that the inverse of   
-          T will have elements of the same magnitude as T.  If the *'s in   
-          both T and inv(T) have small magnitude, T is well conditioned.   
-          The two offdiagonals of T are stored in WORK.   
+/*        Each element marked with a '*' is formed by taking the product */
+/*        of the adjacent elements marked with '+'.  The '*'s can be */
+/*        chosen freely, and the '+'s are chosen so that the inverse of */
+/*        T will have elements of the same magnitude as T.  If the *'s in */
+/*        both T and inv(T) have small magnitude, T is well conditioned. */
+/*        The two offdiagonals of T are stored in WORK. */
 
-          The product of these two matrices has the form   
+/*        The product of these two matrices has the form */
 
-          1  y  y  y  y  y  .  y  y  z   
-             1  +  *  0  0  .  0  0  y   
-                1  +  0  0  .  0  0  y   
-                   1  +  *  .  .  .  .   
-                      1  +  .  .  .  .   
-                         .  .  .  .  .   
-                            .  .  .  .   
-                               1  +  y   
-                                  1  y   
-                                     1   
+/*        1  y  y  y  y  y  .  y  y  z */
+/*           1  +  *  0  0  .  0  0  y */
+/*              1  +  0  0  .  0  0  y */
+/*                 1  +  *  .  .  .  . */
+/*                    1  +  .  .  .  . */
+/*                       .  .  .  .  . */
+/*                          .  .  .  . */
+/*                             1  +  y */
+/*                                1  y */
+/*                                   1 */
 
-          Now we multiply by Givens rotations, using the fact that   
+/*        Now we multiply by Givens rotations, using the fact that */
 
-                [  c   s ] [  1   w ] [ -c  -s ] =  [  1  -w ]   
-                [ -s   c ] [  0   1 ] [  s  -c ]    [  0   1 ]   
-          and   
-                [ -c  -s ] [  1   0 ] [  c   s ] =  [  1   0 ]   
-                [  s  -c ] [  w   1 ] [ -s   c ]    [ -w   1 ]   
+/*              [  c   s ] [  1   w ] [ -c  -s ] =  [  1  -w ] */
+/*              [ -s   c ] [  0   1 ] [  s  -c ]    [  0   1 ] */
+/*        and */
+/*              [ -c  -s ] [  1   0 ] [  c   s ] =  [  1   0 ] */
+/*              [  s  -c ] [  w   1 ] [ -s   c ]    [ -w   1 ] */
 
-          where c = w / sqrt(w**2+4) and s = 2 / sqrt(w**2+4). */
+/*        where c = w / sqrt(w**2+4) and s = 2 / sqrt(w**2+4). */
 
 	star1 = .25;
 	sfac = .5;
@@ -349,8 +352,8 @@ static doublereal c_b48 = 1.;
 
 	if (upper) {
 
-/*           Set the upper triangle of A with a unit triangular matrix   
-             of known condition number. */
+/*           Set the upper triangle of A with a unit triangular matrix */
+/*           of known condition number. */
 
 	    jc = 1;
 	    i__1 = *n;
@@ -374,8 +377,8 @@ static doublereal c_b48 = 1.;
 	    }
 	} else {
 
-/*           Set the lower triangle of A with a unit triangular matrix   
-             of known condition number. */
+/*           Set the lower triangle of A with a unit triangular matrix */
+/*           of known condition number. */
 
 	    i__1 = *n - 1;
 	    for (i__ = 2; i__ <= i__1; ++i__) {
@@ -479,15 +482,15 @@ static doublereal c_b48 = 1.;
 	    }
 	}
 
-/*     IMAT > 10:  Pathological test cases.  These triangular matrices   
-       are badly scaled or badly conditioned, so when used in solving a   
-       triangular system they may cause overflow in the solution vector. */
+/*     IMAT > 10:  Pathological test cases.  These triangular matrices */
+/*     are badly scaled or badly conditioned, so when used in solving a */
+/*     triangular system they may cause overflow in the solution vector. */
 
     } else if (*imat == 11) {
 
-/*        Type 11:  Generate a triangular matrix with elements between   
-          -1 and 1. Give the diagonal norm 2 to make it well-conditioned.   
-          Make the right hand side large so that it requires scaling. */
+/*        Type 11:  Generate a triangular matrix with elements between */
+/*        -1 and 1. Give the diagonal norm 2 to make it well-conditioned. */
+/*        Make the right hand side large so that it requires scaling. */
 
 	if (upper) {
 	    jc = 1;
@@ -520,9 +523,9 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 12) {
 
-/*        Type 12:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 12, the offdiagonal elements are small (CNORM(j) < 1). */
+/*        Type 12:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 12, the offdiagonal elements are small (CNORM(j) < 1). */
 
 	dlarnv_(&c__2, &iseed[1], n, &b[1]);
 /* Computing MAX */
@@ -560,9 +563,9 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 13) {
 
-/*        Type 13:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 13, the offdiagonal elements are O(1) (CNORM(j) > 1). */
+/*        Type 13:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 13, the offdiagonal elements are O(1) (CNORM(j) > 1). */
 
 	dlarnv_(&c__2, &iseed[1], n, &b[1]);
 	if (upper) {
@@ -593,9 +596,9 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 14) {
 
-/*        Type 14:  T is diagonal with small numbers on the diagonal to   
-          make the growth factor underflow, but a small right hand side   
-          chosen so that the solution does not overflow. */
+/*        Type 14:  T is diagonal with small numbers on the diagonal to */
+/*        make the growth factor underflow, but a small right hand side */
+/*        chosen so that the solution does not overflow. */
 
 	if (upper) {
 	    jcount = 1;
@@ -663,11 +666,11 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 15) {
 
-/*        Type 15:  Make the diagonal elements small to cause gradual   
-          overflow when dividing by T(j,j).  To control the amount of   
-          scaling needed, the matrix is bidiagonal.   
+/*        Type 15:  Make the diagonal elements small to cause gradual */
+/*        overflow when dividing by T(j,j).  To control the amount of */
+/*        scaling needed, the matrix is bidiagonal. */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = 1., d__2 = (doublereal) (*n - 1);
 	texp = 1. / max(d__1,d__2);
 	tscal = pow_dd(&smlnum, &texp);
@@ -746,10 +749,10 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 17) {
 
-/*        Type 17:  Make the offdiagonal elements large to cause overflow   
-          when adding a column of T.  In the non-transposed case, the   
-          matrix is constructed to cause overflow when adding a column in   
-          every other step. */
+/*        Type 17:  Make the offdiagonal elements large to cause overflow */
+/*        when adding a column of T.  In the non-transposed case, the */
+/*        matrix is constructed to cause overflow when adding a column in */
+/*        every other step. */
 
 	tscal = unfl / ulp;
 	tscal = (1. - ulp) / tscal;
@@ -766,7 +769,8 @@ static doublereal c_b48 = 1.;
 		a[jc + j - 1] = 1.;
 		b[j] = texp * (1. - ulp);
 		jc = jc - j + 1;
-		a[jc] = -(tscal / (doublereal) (*n + 1)) / (doublereal) (*n + 2);
+		a[jc] = -(tscal / (doublereal) (*n + 1)) / (doublereal) (*n + 
+			2);
 		a[jc + j - 2] = 1.;
 		b[j - 1] = texp * (doublereal) (*n * *n + *n - 1);
 		texp *= 2.;
@@ -795,9 +799,9 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 18) {
 
-/*        Type 18:  Generate a unit triangular matrix with elements   
-          between -1 and 1, and make the right hand side large so that it   
-          requires scaling. */
+/*        Type 18:  Generate a unit triangular matrix with elements */
+/*        between -1 and 1, and make the right hand side large so that it */
+/*        requires scaling. */
 
 	if (upper) {
 	    jc = 1;
@@ -833,11 +837,11 @@ static doublereal c_b48 = 1.;
 
     } else if (*imat == 19) {
 
-/*        Type 19:  Generate a triangular matrix with elements between   
-          BIGNUM/(n-1) and BIGNUM so that at least one of the column   
-          norms will exceed BIGNUM.   
+/*        Type 19:  Generate a triangular matrix with elements between */
+/*        BIGNUM/(n-1) and BIGNUM so that at least one of the column */
+/*        norms will exceed BIGNUM. */
 
-   Computing MAX */
+/* Computing MAX */
 	d__1 = 1., d__2 = (doublereal) (*n - 1);
 	tleft = bignum / max(d__1,d__2);
 /* Computing MAX */
@@ -877,8 +881,8 @@ static doublereal c_b48 = 1.;
 	dscal_(n, &c_b36, &b[1], &c__1);
     }
 
-/*     Flip the matrix across its counter-diagonal if the transpose will   
-       be used. */
+/*     Flip the matrix across its counter-diagonal if the transpose will */
+/*     be used. */
 
     if (! lsame_(trans, "N")) {
 	if (upper) {
