@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* schkaa.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -81,6 +69,7 @@ static integer c__6 = 6;
     /* System generated locals */
     integer i__1, i__2;
     real r__1;
+    cilist ci__1;
     cllist cl__1;
 
     /* Builtin functions */
@@ -93,26 +82,25 @@ static integer c__6 = 6;
     integer f_clos(cllist *);
 
     /* Local variables */
-    static real a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][
-	    4] */;
-    static integer i__, j, k;
-    static real s[264];
-    static char c1[1], c2[2];
-    static real s1, s2;
-    static integer ic, la, nb, nm, nn, vers_patch__, vers_major__, 
-	    vers_minor__, lda, nnb;
-    static real eps;
-    static integer nns, nnb2;
-    static char path[3];
-    static integer mval[12], nval[12], nrhs;
-    static real work[23496]	/* was [132][178] */;
-    static integer lafac;
-    static logical fatal;
-    static char aline[72];
+    real a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][4] */;
+    integer i__, j, k;
+    real s[264];
+    char c1[1], c2[2];
+    real s1, s2;
+    integer ic, la, nb, nm, nn, vers_patch__, vers_major__, vers_minor__, lda,
+	     nnb;
+    real eps;
+    integer nns, nnb2;
+    char path[3];
+    integer mval[12], nval[12], nrhs;
+    real work[23496]	/* was [132][178] */;
+    integer lafac;
+    logical fatal;
+    char aline[72];
     extern logical lsame_(char *, char *);
-    static integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
-    static real rwork[692];
-    static integer nbval2[12];
+    integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
+    real rwork[692];
+    integer nbval2[12];
     extern /* Subroutine */ int schkq3_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, real *, 
 	    real *, real *, real *, real *, real *, real *, integer *, 
@@ -122,23 +110,23 @@ static integer c__6 = 6;
 	    real *, real *, real *, integer *, integer *), schkge_(logical *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, real *, logical *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, real *, integer *, 
+, real *, real *, real *, real *, real *, real *, integer *, 
 	    integer *), alareq_(char *, integer *, logical *, integer *, 
 	    integer *, integer *);
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int schkpb_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, real *, logical *, 
-	    integer *, real *, real *, real *, real *, real *, real *, real *,
+	    integer *, real *, real *, real *, real *, real *, real *, real *, 
 	     real *, integer *, integer *);
     extern doublereal second_(void);
     extern /* Subroutine */ int schkeq_(real *, integer *);
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int schktb_(logical *, integer *, integer *, 
 	    integer *, integer *, real *, logical *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, integer *, integer *), 
+, real *, real *, real *, real *, real *, integer *, integer *), 
 	    ilaver_(integer *, integer *, integer *), schkgt_(logical *, 
 	    integer *, integer *, integer *, integer *, real *, logical *, 
-	    real *, real *, real *, real *, real *, real *, real *, integer *,
+	    real *, real *, real *, real *, real *, real *, real *, integer *, 
 	     integer *), schklq_(logical *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, real *, 
 	    logical *, integer *, real *, real *, real *, real *, real *, 
@@ -152,44 +140,44 @@ static integer c__6 = 6;
 	    real *, real *, real *, real *, real *, real *, real *, real *, 
 	    integer *, integer *), schkpp_(logical *, integer *, integer *, 
 	    integer *, integer *, real *, logical *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, real *, integer *, 
+, real *, real *, real *, real *, real *, real *, integer *, 
 	    integer *), schkqp_(logical *, integer *, integer *, integer *, 
 	    integer *, real *, logical *, real *, real *, real *, real *, 
 	    real *, real *, integer *, integer *), schkqr_(logical *, integer 
 	    *, integer *, integer *, integer *, integer *, integer *, integer 
 	    *, integer *, real *, logical *, integer *, real *, real *, real *
-	    , real *, real *, real *, real *, real *, real *, real *, real *, 
+, real *, real *, real *, real *, real *, real *, real *, real *, 
 	    integer *, integer *), schkpt_(logical *, integer *, integer *, 
 	    integer *, integer *, real *, logical *, real *, real *, real *, 
 	    real *, real *, real *, real *, real *, integer *);
-    static real thresh;
+    real thresh;
     extern /* Subroutine */ int schkrq_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    real *, logical *, integer *, real *, real *, real *, real *, 
-	    real *, real *, real *, real *, real *, real *, real *, integer *,
+	    real *, real *, real *, real *, real *, real *, real *, integer *, 
 	     integer *), schksp_(logical *, integer *, integer *, integer *, 
 	    integer *, real *, logical *, integer *, real *, real *, real *, 
 	    real *, real *, real *, real *, real *, integer *, integer *);
-    static logical tstchk;
+    logical tstchk;
     extern /* Subroutine */ int schktp_(logical *, integer *, integer *, 
 	    integer *, integer *, real *, logical *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, integer *, integer *), 
+, real *, real *, real *, real *, real *, integer *, integer *), 
 	    schktr_(logical *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, real *, logical *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, integer *, integer *);
-    static logical dotype[30];
+, real *, real *, real *, real *, real *, integer *, integer *);
+    logical dotype[30];
     extern /* Subroutine */ int schksy_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, real *, logical *, 
-	    integer *, real *, real *, real *, real *, real *, real *, real *,
+	    integer *, real *, real *, real *, real *, real *, real *, real *, 
 	     real *, integer *, integer *), schktz_(logical *, integer *, 
 	    integer *, integer *, integer *, real *, logical *, real *, real *
-	    , real *, real *, real *, real *, integer *), sdrvgb_(logical *, 
+, real *, real *, real *, real *, integer *), sdrvgb_(logical *, 
 	    integer *, integer *, integer *, real *, logical *, real *, 
 	    integer *, real *, integer *, real *, real *, real *, real *, 
 	    real *, real *, real *, real *, integer *, integer *), sdrvge_(
 	    logical *, integer *, integer *, integer *, real *, logical *, 
-	    integer *, real *, real *, real *, real *, real *, real *, real *,
-	     real *, real *, real *, integer *, integer *), sdrvgt_(logical *,
+	    integer *, real *, real *, real *, real *, real *, real *, real *, 
+	     real *, real *, real *, integer *, integer *), sdrvgt_(logical *, 
 	     integer *, integer *, integer *, real *, logical *, real *, real 
 	    *, real *, real *, real *, real *, real *, integer *, integer *), 
 	    sdrvpb_(logical *, integer *, integer *, integer *, real *, 
@@ -197,22 +185,22 @@ static integer c__6 = 6;
 	    real *, real *, real *, real *, real *, integer *, integer *), 
 	    sdrvls_(logical *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, real *, 
-	    logical *, real *, real *, real *, real *, real *, real *, real *,
+	    logical *, real *, real *, real *, real *, real *, real *, real *, 
 	     real *, integer *, integer *), sdrvpo_(logical *, integer *, 
 	    integer *, integer *, real *, logical *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, real *, real *, real *, 
+, real *, real *, real *, real *, real *, real *, real *, real *, 
 	    integer *, integer *), sdrvpp_(logical *, integer *, integer *, 
 	    integer *, real *, logical *, integer *, real *, real *, real *, 
-	    real *, real *, real *, real *, real *, real *, real *, integer *,
+	    real *, real *, real *, real *, real *, real *, real *, integer *, 
 	     integer *), sdrvsp_(logical *, integer *, integer *, integer *, 
 	    real *, logical *, integer *, real *, real *, real *, real *, 
 	    real *, real *, real *, real *, integer *, integer *);
-    static integer ntypes;
-    static logical tsterr;
+    integer ntypes;
+    logical tsterr;
     extern /* Subroutine */ int sdrvpt_(logical *, integer *, integer *, 
 	    integer *, real *, logical *, real *, real *, real *, real *, 
 	    real *, real *, real *, real *, integer *);
-    static logical tstdrv;
+    logical tstdrv;
     extern /* Subroutine */ int sdrvsy_(logical *, integer *, integer *, 
 	    integer *, real *, logical *, integer *, real *, real *, real *, 
 	    real *, real *, real *, real *, real *, integer *, integer *);
@@ -260,27 +248,27 @@ static integer c__6 = 6;
     static cilist io___67 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___68 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___69 = { 0, 6, 0, 0, 0 };
-    static cilist io___70 = { 0, 5, 1, "(A72)", 0 };
-    static cilist io___79 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___80 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___88 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___90 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___93 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___94 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___95 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___96 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___97 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___98 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___99 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___100 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___101 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___102 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___103 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___104 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___105 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___106 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___107 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___108 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___78 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___79 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___87 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___89 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___92 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___93 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___94 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___95 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___96 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___97 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___98 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___99 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___100 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___101 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___102 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___103 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___104 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___105 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___106 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___107 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___108 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___109 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___110 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___111 = { 0, 6, 0, fmt_9989, 0 };
@@ -289,87 +277,105 @@ static integer c__6 = 6;
     static cilist io___114 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___115 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___116 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___117 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___118 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___119 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___120 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___122 = { 0, 6, 0, fmt_9998, 0 };
-    static cilist io___123 = { 0, 6, 0, fmt_9997, 0 };
+    static cilist io___117 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___118 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___119 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___121 = { 0, 6, 0, fmt_9998, 0 };
+    static cilist io___122 = { 0, 6, 0, fmt_9997, 0 };
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SCHKAA is the main test program for the REAL LAPACK   
-    linear equation routines   
+/*  SCHKAA is the main test program for the REAL LAPACK */
+/*  linear equation routines */
 
-    The program must be driven by a short data file. The first 14 records   
-    specify problem dimensions and program options using list-directed   
-    input.  The remaining lines specify the LAPACK test paths and the   
-    number of matrix types to use in testing.  An annotated example of a   
-    data file can be obtained by deleting the first 3 characters from the   
-    following 36 lines:   
-    Data file for testing REAL LAPACK linear eqn. routines   
-    7                      Number of values of M   
-    0 1 2 3 5 10 16        Values of M (row dimension)   
-    7                      Number of values of N   
-    0 1 2 3 5 10 16        Values of N (column dimension)   
-    1                      Number of values of NRHS   
-    2                      Values of NRHS (number of right hand sides)   
-    5                      Number of values of NB   
-    1 3 3 3 20             Values of NB (the blocksize)   
-    1 0 5 9 1              Values of NX (crossover point)   
-    20.0                   Threshold value of test ratio   
-    T                      Put T to test the LAPACK routines   
-    T                      Put T to test the driver routines   
-    T                      Put T to test the error exits   
-    SGE   11               List types on next line if 0 < NTYPES < 11   
-    SGB    8               List types on next line if 0 < NTYPES <  8   
-    SGT   12               List types on next line if 0 < NTYPES < 12   
-    SPO    9               List types on next line if 0 < NTYPES <  9   
-    SPP    9               List types on next line if 0 < NTYPES <  9   
-    SPB    8               List types on next line if 0 < NTYPES <  8   
-    SPT   12               List types on next line if 0 < NTYPES < 12   
-    SSY   10               List types on next line if 0 < NTYPES < 10   
-    SSP   10               List types on next line if 0 < NTYPES < 10   
-    STR   18               List types on next line if 0 < NTYPES < 18   
-    STP   18               List types on next line if 0 < NTYPES < 18   
-    STB   17               List types on next line if 0 < NTYPES < 17   
-    SQR    8               List types on next line if 0 < NTYPES <  8   
-    SRQ    8               List types on next line if 0 < NTYPES <  8   
-    SLQ    8               List types on next line if 0 < NTYPES <  8   
-    SQL    8               List types on next line if 0 < NTYPES <  8   
-    SQP    6               List types on next line if 0 < NTYPES <  6   
-    STZ    3               List types on next line if 0 < NTYPES <  3   
-    SLS    6               List types on next line if 0 < NTYPES <  6   
-    SEQ   
+/*  The program must be driven by a short data file. The first 14 records */
+/*  specify problem dimensions and program options using list-directed */
+/*  input.  The remaining lines specify the LAPACK test paths and the */
+/*  number of matrix types to use in testing.  An annotated example of a */
+/*  data file can be obtained by deleting the first 3 characters from the */
+/*  following 36 lines: */
+/*  Data file for testing REAL LAPACK linear eqn. routines */
+/*  7                      Number of values of M */
+/*  0 1 2 3 5 10 16        Values of M (row dimension) */
+/*  7                      Number of values of N */
+/*  0 1 2 3 5 10 16        Values of N (column dimension) */
+/*  1                      Number of values of NRHS */
+/*  2                      Values of NRHS (number of right hand sides) */
+/*  5                      Number of values of NB */
+/*  1 3 3 3 20             Values of NB (the blocksize) */
+/*  1 0 5 9 1              Values of NX (crossover point) */
+/*  20.0                   Threshold value of test ratio */
+/*  T                      Put T to test the LAPACK routines */
+/*  T                      Put T to test the driver routines */
+/*  T                      Put T to test the error exits */
+/*  SGE   11               List types on next line if 0 < NTYPES < 11 */
+/*  SGB    8               List types on next line if 0 < NTYPES <  8 */
+/*  SGT   12               List types on next line if 0 < NTYPES < 12 */
+/*  SPO    9               List types on next line if 0 < NTYPES <  9 */
+/*  SPP    9               List types on next line if 0 < NTYPES <  9 */
+/*  SPB    8               List types on next line if 0 < NTYPES <  8 */
+/*  SPT   12               List types on next line if 0 < NTYPES < 12 */
+/*  SSY   10               List types on next line if 0 < NTYPES < 10 */
+/*  SSP   10               List types on next line if 0 < NTYPES < 10 */
+/*  STR   18               List types on next line if 0 < NTYPES < 18 */
+/*  STP   18               List types on next line if 0 < NTYPES < 18 */
+/*  STB   17               List types on next line if 0 < NTYPES < 17 */
+/*  SQR    8               List types on next line if 0 < NTYPES <  8 */
+/*  SRQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  SLQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  SQL    8               List types on next line if 0 < NTYPES <  8 */
+/*  SQP    6               List types on next line if 0 < NTYPES <  6 */
+/*  STZ    3               List types on next line if 0 < NTYPES <  3 */
+/*  SLS    6               List types on next line if 0 < NTYPES <  6 */
+/*  SEQ */
 
-    Internal Parameters   
-    ===================   
+/*  Internal Parameters */
+/*  =================== */
 
-    NMAX    INTEGER   
-            The maximum allowable value for N   
+/*  NMAX    INTEGER */
+/*          The maximum allowable value for N */
 
-    MAXIN   INTEGER   
-            The number of different values that can be used for each of   
-            M, N, NRHS, NB, and NX   
+/*  MAXIN   INTEGER */
+/*          The number of different values that can be used for each of */
+/*          M, N, NRHS, NB, and NX */
 
-    MAXRHS  INTEGER   
-            The maximum number of right hand sides   
+/*  MAXRHS  INTEGER */
+/*          The maximum number of right hand sides */
 
-    NIN     INTEGER   
-            The unit number for input   
+/*  NIN     INTEGER */
+/*          The unit number for input */
 
-    NOUT    INTEGER   
-            The unit number for output   
+/*  NOUT    INTEGER */
+/*          The unit number for output */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Arrays in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s1 = second_();
     lda = 132;
@@ -719,7 +725,11 @@ L80:
 
 /*     Read a test path and the number of matrix types to use. */
 
-    i__1 = s_rsfe(&io___70);
+    ci__1.cierr = 0;
+    ci__1.ciend = 1;
+    ci__1.ciunit = 5;
+    ci__1.cifmt = "(A72)";
+    i__1 = s_rsfe(&ci__1);
     if (i__1 != 0) {
 	goto L140;
     }
@@ -769,7 +779,7 @@ L130:
 /*     Check first character for correct precision. */
 
     if (! lsame_(c1, "Single precision")) {
-	s_wsfe(&io___79);
+	s_wsfe(&io___78);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -777,7 +787,7 @@ L130:
 
 /*        Check for a positive number of tests requested. */
 
-	s_wsfe(&io___80);
+	s_wsfe(&io___79);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -793,7 +803,7 @@ L130:
 		    &thresh, &tsterr, &lda, a, &a[21912], &a[43824], b, &b[
 		    2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___88);
+	    s_wsfe(&io___87);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -803,7 +813,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___90);
+	    s_wsfe(&io___89);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -822,7 +832,7 @@ L130:
 		    &thresh, &tsterr, a, &la, &a[43824], &lafac, b, &b[2112], 
 		    &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___93);
+	    s_wsfe(&io___92);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -832,7 +842,7 @@ L130:
 		    43824], &lafac, &a[109560], b, &b[2112], &b[4224], &b[
 		    6336], s, work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___94);
+	    s_wsfe(&io___93);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -848,7 +858,7 @@ L130:
 	    schkgt_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___95);
+	    s_wsfe(&io___94);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -857,7 +867,7 @@ L130:
 	    sdrvgt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, &a[21912], 
 		    b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___96);
+	    s_wsfe(&io___95);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -874,7 +884,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___97);
+	    s_wsfe(&io___96);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -884,7 +894,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___98);
+	    s_wsfe(&io___97);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -897,11 +907,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    schkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    schkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___99);
+	    s_wsfe(&io___98);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -911,7 +921,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___100);
+	    s_wsfe(&io___99);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -928,7 +938,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___101);
+	    s_wsfe(&io___100);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -938,7 +948,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___102);
+	    s_wsfe(&io___101);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -955,7 +965,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, &
 		    c__6);
 	} else {
-	    s_wsfe(&io___103);
+	    s_wsfe(&io___102);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -964,7 +974,7 @@ L130:
 	    sdrvpt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, &a[21912], 
 		    &a[43824], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___104);
+	    s_wsfe(&io___103);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -981,7 +991,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___105);
+	    s_wsfe(&io___104);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -991,7 +1001,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___106);
+	    s_wsfe(&io___105);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1004,11 +1014,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    schksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    schksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___107);
+	    s_wsfe(&io___106);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1018,7 +1028,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___108);
+	    s_wsfe(&io___107);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1035,7 +1045,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], b, &b[2112], &b[4224], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___109);
+	    s_wsfe(&io___108);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1048,11 +1058,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    schktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    schktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, iwork, &
 		    c__6);
 	} else {
-	    s_wsfe(&io___110);
+	    s_wsfe(&io___109);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1065,11 +1075,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    schktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    schktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, iwork, &
 		    c__6);
 	} else {
-	    s_wsfe(&io___111);
+	    s_wsfe(&io___110);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1087,7 +1097,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___112);
+	    s_wsfe(&io___111);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1105,7 +1115,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___113);
+	    s_wsfe(&io___112);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1123,7 +1133,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___114);
+	    s_wsfe(&io___113);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1141,7 +1151,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___115);
+	    s_wsfe(&io___114);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1156,10 +1166,10 @@ L130:
 	if (tstchk) {
 	    schkqp_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, iwork, &c__6);
-	    schkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh,
+	    schkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh, 
 		     a, &a[21912], b, &b[2112], &b[4224], work, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___116);
+	    s_wsfe(&io___115);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1175,7 +1185,7 @@ L130:
 	    schktz_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, &c__6);
 	} else {
-	    s_wsfe(&io___117);
+	    s_wsfe(&io___116);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1192,27 +1202,27 @@ L130:
 		    nxval, &thresh, &tsterr, a, &a[21912], b, &b[2112], &b[
 		    4224], rwork, &rwork[132], work, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___118);
+	    s_wsfe(&io___117);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else if (lsamen_(&c__2, c2, "EQ")) {
 
-/*        EQ:  Equilibration routines for general and positive definite   
-               matrices (THREQ should be between 2 and 10) */
+/*        EQ:  Equilibration routines for general and positive definite */
+/*             matrices (THREQ should be between 2 and 10) */
 
 	if (tstchk) {
 	    schkeq_(&threq, &c__6);
 	} else {
-	    s_wsfe(&io___119);
+	    s_wsfe(&io___118);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else {
 
-	s_wsfe(&io___120);
+	s_wsfe(&io___119);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
     }
@@ -1229,9 +1239,9 @@ L140:
     cl__1.csta = 0;
     f_clos(&cl__1);
     s2 = second_();
-    s_wsfe(&io___122);
+    s_wsfe(&io___121);
     e_wsfe();
-    s_wsfe(&io___123);
+    s_wsfe(&io___122);
     r__1 = s2 - s1;
     do_fio(&c__1, (char *)&r__1, (ftnlen)sizeof(real));
     e_wsfe();
@@ -1240,6 +1250,6 @@ L140:
 /*     End of SCHKAA */
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Main program alias */ int schkaa_ () { MAIN__ (); return 0; }
+/* Main program alias */ int schkaa_ () { MAIN__ (); return 0; }
