@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* schktb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -69,58 +57,58 @@ static integer c__8 = 8;
     integer i__1, i__2, i__3, i__4, i__5, i__6[3], i__7[4];
     char ch__1[3], ch__2[4];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n, kd, ik, in, nk, lda, ldab;
-    static char diag[1];
-    static integer imat, info;
-    static char path[3];
-    static integer irhs, nrhs;
-    static char norm[1], uplo[1];
-    static integer nrun;
+    integer i__, j, k, n, kd, ik, in, nk, lda, ldab;
+    char diag[1];
+    integer imat, info;
+    char path[3];
+    integer irhs, nrhs;
+    char norm[1], uplo[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer idiag;
-    static real scale;
-    static integer nfail, iseed[4];
+    integer idiag;
+    real scale;
+    integer nfail, iseed[4];
     extern logical lsame_(char *, char *);
-    static real rcond;
+    real rcond;
     extern /* Subroutine */ int sget04_(integer *, integer *, real *, integer 
 	    *, real *, integer *, real *, real *);
-    static integer nimat;
-    static real anorm;
-    static integer itran;
+    integer nimat;
+    real anorm;
+    integer itran;
     extern /* Subroutine */ int stbt02_(char *, char *, char *, integer *, 
 	    integer *, integer *, real *, integer *, real *, integer *, real *
-	    , integer *, real *, real *), stbt03_(
+, integer *, real *, real *), stbt03_(
 	    char *, char *, char *, integer *, integer *, integer *, real *, 
 	    integer *, real *, real *, real *, real *, integer *, real *, 
 	    integer *, real *, real *), stbt05_(char *
-	    , char *, char *, integer *, integer *, integer *, real *, 
+, char *, char *, integer *, integer *, integer *, real *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , real *, real *, real *), stbt06_(real *,
+, real *, real *, real *), stbt06_(real *, 
 	     real *, char *, char *, integer *, integer *, real *, integer *, 
 	    real *, real *);
-    static char trans[1];
-    static integer iuplo, nerrs;
+    char trans[1];
+    integer iuplo, nerrs;
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *), stbsv_(char *, char *, char *, integer *, integer *, 
 	    real *, integer *, real *, integer *);
-    static char xtype[1];
-    static integer nimat2;
+    char xtype[1];
+    integer nimat2;
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static real rcondc, rcondi;
+    real rcondc, rcondi;
     extern doublereal slantb_(char *, char *, char *, integer *, integer *, 
 	    real *, integer *, real *);
-    static real rcondo;
+    real rcondo;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real ainvnm;
+    real ainvnm;
     extern /* Subroutine */ int slatbs_(char *, char *, char *, char *, 
 	    integer *, integer *, real *, integer *, real *, real *, real *, 
 	    integer *), slattb_(integer *, 
@@ -138,8 +126,8 @@ static integer c__8 = 8;
 	    real *, integer *, real *);
     extern /* Subroutine */ int stbrfs_(char *, char *, char *, integer *, 
 	    integer *, integer *, real *, integer *, real *, integer *, real *
-	    , integer *, real *, real *, real *, integer *, integer *);
-    static real result[8];
+, integer *, real *, real *, real *, integer *, integer *);
+    real result[8];
     extern /* Subroutine */ int serrtr_(char *, integer *), stbtrs_(
 	    char *, char *, char *, integer *, integer *, integer *, real *, 
 	    integer *, real *, integer *, integer *);
@@ -152,73 +140,94 @@ static integer c__8 = 8;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SCHKTB tests STBTRS, -RFS, and -CON, and SLATBS.   
+/*  SCHKTB tests STBTRS, -RFS, and -CON, and SLATBS. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The leading dimension of the work arrays.   
-            NMAX >= the maximum value of N in NVAL.   
+/*  NMAX    (input) INTEGER */
+/*          The leading dimension of the work arrays. */
+/*          NMAX >= the maximum value of N in NVAL. */
 
-    AB      (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  AB      (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    B       (workspace) REAL array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) REAL array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) REAL array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) REAL array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) REAL array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) REAL array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) REAL array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) REAL array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) REAL array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -231,9 +240,11 @@ static integer c__8 = 8;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Single precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "TB", (ftnlen)2, (ftnlen)2);
@@ -273,8 +284,8 @@ static integer c__8 = 8;
 	i__2 = nk;
 	for (ik = 1; ik <= i__2; ++ik) {
 
-/*           Do for KD = 0, N, (3N-1)/4, and (N+1)/4. This order makes   
-             it easier to skip redundant values for small values of N. */
+/*           Do for KD = 0, N, (3N-1)/4, and (N+1)/4. This order makes */
+/*           it easier to skip redundant values for small values of N. */
 
 	    if (ik == 1) {
 		kd = 0;
@@ -306,7 +317,7 @@ static integer c__8 = 8;
 /*                 Call SLATTB to generate a triangular test matrix. */
 
 		    s_copy(srnamc_1.srnamt, "SLATTB", (ftnlen)6, (ftnlen)6);
-		    slattb_(&imat, uplo, "No transpose", diag, iseed, &n, &kd,
+		    slattb_(&imat, uplo, "No transpose", diag, iseed, &n, &kd, 
 			     &ab[1], &ldab, &x[1], &work[1], &info);
 
 /*                 Set IDIAG = 1 for non-unit matrices, 2 for unit. */
@@ -317,8 +328,8 @@ static integer c__8 = 8;
 			idiag = 2;
 		    }
 
-/*                 Form the inverse of A so we can get a good estimate   
-                   of RCONDC = 1/(norm(A) * norm(inv(A))). */
+/*                 Form the inverse of A so we can get a good estimate */
+/*                 of RCONDC = 1/(norm(A) * norm(inv(A))). */
 
 		    slaset_("Full", &n, &n, &c_b14, &c_b15, &ainv[1], &lda);
 		    if (lsame_(uplo, "U")) {
@@ -382,8 +393,8 @@ static integer c__8 = 8;
 				rcondc = rcondi;
 			    }
 
-/* +    TEST 1   
-                      Solve and compute residual for op(A)*x = b. */
+/* +    TEST 1 */
+/*                    Solve and compute residual for op(A)*x = b. */
 
 			    s_copy(srnamc_1.srnamt, "SLARHS", (ftnlen)6, (
 				    ftnlen)6);
@@ -396,7 +407,7 @@ static integer c__8 = 8;
 
 			    s_copy(srnamc_1.srnamt, "STBTRS", (ftnlen)6, (
 				    ftnlen)6);
-			    stbtrs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    stbtrs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &x[1], &lda, &info);
 
 /*                    Check error code from STBTRS. */
@@ -408,30 +419,30 @@ static integer c__8 = 8;
 				i__6[2] = 1, a__1[2] = diag;
 				s_cat(ch__1, a__1, i__6, &c__3, (ftnlen)3);
 				alaerh_(path, "STBTRS", &info, &c__0, ch__1, &
-					n, &n, &kd, &kd, &nrhs, &imat, &nfail,
+					n, &n, &kd, &kd, &nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 			    }
 
-			    stbt02_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    stbt02_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &x[1], &lda, &b[1], &lda, &work[1]
-				    , result)
+, result)
 				    ;
 
-/* +    TEST 2   
-                      Check solution from generated exact solution. */
+/* +    TEST 2 */
+/*                    Check solution from generated exact solution. */
 
 			    sget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[1]);
 
-/* +    TESTS 3, 4, and 5   
-                      Use iterative refinement to improve the solution   
-                      and compute error bounds. */
+/* +    TESTS 3, 4, and 5 */
+/*                    Use iterative refinement to improve the solution */
+/*                    and compute error bounds. */
 
 			    s_copy(srnamc_1.srnamt, "STBRFS", (ftnlen)6, (
 				    ftnlen)6);
-			    stbrfs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    stbrfs_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &b[1], &lda, &x[1], &lda, &rwork[
-				    1], &rwork[nrhs + 1], &work[1], &iwork[1],
+				    1], &rwork[nrhs + 1], &work[1], &iwork[1], 
 				     &info);
 
 /*                    Check error code from STBRFS. */
@@ -443,19 +454,19 @@ static integer c__8 = 8;
 				i__6[2] = 1, a__1[2] = diag;
 				s_cat(ch__1, a__1, i__6, &c__3, (ftnlen)3);
 				alaerh_(path, "STBRFS", &info, &c__0, ch__1, &
-					n, &n, &kd, &kd, &nrhs, &imat, &nfail,
+					n, &n, &kd, &kd, &nrhs, &imat, &nfail, 
 					 &nerrs, nout);
 			    }
 
 			    sget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[2]);
-			    stbt05_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1],
+			    stbt05_(uplo, trans, diag, &n, &kd, &nrhs, &ab[1], 
 				     &ldab, &b[1], &lda, &x[1], &lda, &xact[1]
-				    , &lda, &rwork[1], &rwork[nrhs + 1], &
+, &lda, &rwork[1], &rwork[nrhs + 1], &
 				    result[3]);
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 1; k <= 5; ++k) {
 				if (result[k - 1] >= *thresh) {
@@ -490,8 +501,8 @@ static integer c__8 = 8;
 /* L60: */
 		    }
 
-/* +    TEST 6   
-                      Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 6 */
+/*                    Get an estimate of RCOND = 1/CNDNUM. */
 
 		    for (itran = 1; itran <= 2; ++itran) {
 			if (itran == 1) {
@@ -515,15 +526,15 @@ static integer c__8 = 8;
 			    i__6[2] = 1, a__1[2] = diag;
 			    s_cat(ch__1, a__1, i__6, &c__3, (ftnlen)3);
 			    alaerh_(path, "STBCON", &info, &c__0, ch__1, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
 			stbt06_(&rcond, &rcondc, uplo, diag, &n, &kd, &ab[1], 
 				&ldab, &rwork[1], &result[5]);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			if (result[5] >= *thresh) {
 			    if (nfail == 0 && nerrs == 0) {
@@ -537,7 +548,8 @@ static integer c__8 = 8;
 			    do_fio(&c__1, diag, (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__6, (ftnlen)sizeof(
@@ -587,8 +599,8 @@ L90:
 			slattb_(&imat, uplo, trans, diag, iseed, &n, &kd, &ab[
 				1], &ldab, &x[1], &work[1], &info);
 
-/* +    TEST 7   
-                      Solve the system op(A)*x = b */
+/* +    TEST 7 */
+/*                    Solve the system op(A)*x = b */
 
 			s_copy(srnamc_1.srnamt, "SLATBS", (ftnlen)6, (ftnlen)
 				6);
@@ -606,7 +618,7 @@ L90:
 			    i__7[3] = 1, a__2[3] = "N";
 			    s_cat(ch__2, a__2, i__7, &c__4, (ftnlen)4);
 			    alaerh_(path, "SLATBS", &info, &c__0, ch__2, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
@@ -614,8 +626,8 @@ L90:
 				ldab, &scale, &rwork[1], &c_b15, &b[1], &lda, 
 				&x[1], &lda, &work[1], &result[6]);
 
-/* +    TEST 8   
-                      Solve op(A)*x = b again with NORMIN = 'Y'. */
+/* +    TEST 8 */
+/*                    Solve op(A)*x = b again with NORMIN = 'Y'. */
 
 			scopy_(&n, &x[1], &c__1, &b[1], &c__1);
 			slatbs_(uplo, trans, diag, "Y", &n, &kd, &ab[1], &
@@ -631,7 +643,7 @@ L90:
 			    i__7[3] = 1, a__2[3] = "Y";
 			    s_cat(ch__2, a__2, i__7, &c__4, (ftnlen)4);
 			    alaerh_(path, "SLATBS", &info, &c__0, ch__2, &n, &
-				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs,
+				    n, &kd, &kd, &c_n1, &imat, &nfail, &nerrs, 
 				     nout);
 			}
 
@@ -639,8 +651,8 @@ L90:
 				ldab, &scale, &rwork[1], &c_b15, &b[1], &lda, 
 				&x[1], &lda, &work[1], &result[7]);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			if (result[6] >= *thresh) {
 			    if (nfail == 0 && nerrs == 0) {
@@ -655,7 +667,8 @@ L90:
 			    do_fio(&c__1, "N", (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__7, (ftnlen)sizeof(
@@ -678,7 +691,8 @@ L90:
 			    do_fio(&c__1, "Y", (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&kd, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&c__8, (ftnlen)sizeof(
