@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* schktr.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -73,66 +61,66 @@ static integer c__9 = 9;
     integer i__1, i__2, i__3[2], i__4, i__5[3], i__6[4];
     char ch__1[2], ch__2[3], ch__3[4];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, k, n, nb, in, lda, inb;
-    static char diag[1];
-    static integer imat, info;
-    static char path[3];
-    static integer irhs, nrhs;
-    static char norm[1], uplo[1];
-    static integer nrun;
+    integer i__, k, n, nb, in, lda, inb;
+    char diag[1];
+    integer imat, info;
+    char path[3];
+    integer irhs, nrhs;
+    char norm[1], uplo[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer idiag;
-    static real scale;
-    static integer nfail, iseed[4];
+    integer idiag;
+    real scale;
+    integer nfail, iseed[4];
     extern logical lsame_(char *, char *);
-    static real rcond;
+    real rcond;
     extern /* Subroutine */ int sget04_(integer *, integer *, real *, integer 
 	    *, real *, integer *, real *, real *);
-    static real anorm;
-    static integer itran;
-    static char trans[1];
-    static integer iuplo, nerrs;
-    static real dummy;
+    real anorm;
+    integer itran;
+    char trans[1];
+    integer iuplo, nerrs;
+    real dummy;
     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
 	    integer *), strt01_(char *, char *, integer *, real *, integer *, 
 	    real *, integer *, real *, real *, real *), 
 	    strt02_(char *, char *, char *, integer *, integer *, real *, 
 	    integer *, real *, integer *, real *, integer *, real *, real *), strt03_(char *, char *, char *, integer *
-	    , integer *, real *, integer *, real *, real *, real *, real *, 
+, integer *, real *, integer *, real *, real *, real *, real *, 
 	    integer *, real *, integer *, real *, real *), strt05_(char *, char *, char *, integer *, integer *, 
 	    real *, integer *, real *, integer *, real *, integer *, real *, 
 	    integer *, real *, real *, real *), 
 	    strt06_(real *, real *, char *, char *, integer *, real *, 
 	    integer *, real *, real *);
-    static char xtype[1];
+    char xtype[1];
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static real rcondc, rcondi;
+    real rcondc, rcondi;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real rcondo, ainvnm;
+    real rcondo, ainvnm;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), slarhs_(char *, char *, 
 	    char *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , integer *, integer *), xlaenv_(
+, integer *, integer *), xlaenv_(
 	    integer *, integer *);
     extern doublereal slantr_(char *, char *, char *, integer *, integer *, 
 	    real *, integer *, real *);
     extern /* Subroutine */ int slatrs_(char *, char *, char *, char *, 
 	    integer *, real *, integer *, real *, real *, real *, integer *), slattr_(integer *, char *, char *
-	    , char *, integer *, integer *, real *, integer *, real *, real *,
+, char *, integer *, integer *, real *, integer *, real *, real *, 
 	     integer *), strcon_(char *, char *, char 
 	    *, integer *, real *, integer *, real *, real *, integer *, 
 	    integer *);
-    static real result[9];
+    real result[9];
     extern /* Subroutine */ int serrtr_(char *, integer *), strrfs_(
 	    char *, char *, char *, integer *, integer *, real *, integer *, 
 	    real *, integer *, real *, integer *, real *, real *, real *, 
@@ -150,79 +138,100 @@ static integer c__9 = 9;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SCHKTR tests STRTRI, -TRS, -RFS, and -CON, and SLATRS   
+/*  SCHKTR tests STRTRI, -TRS, -RFS, and -CON, and SLATRS */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB contained in the vector NBVAL.   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB contained in the vector NBVAL. */
 
-    NBVAL   (input) INTEGER array, dimension (NNB)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NNB) */
+/*          The values of the blocksize NB. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The leading dimension of the work arrays.   
-            NMAX >= the maximum value of N in NVAL.   
+/*  NMAX    (input) INTEGER */
+/*          The leading dimension of the work arrays. */
+/*          NMAX >= the maximum value of N in NVAL. */
 
-    A       (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  A       (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    B       (workspace) REAL array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) REAL array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) REAL array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) REAL array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) REAL array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) REAL array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) REAL array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) REAL array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) REAL array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) REAL array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -236,9 +245,11 @@ static integer c__9 = 9;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Single precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "TR", (ftnlen)2, (ftnlen)2);
@@ -303,8 +314,8 @@ static integer c__9 = 9;
 		    nb = nbval[inb];
 		    xlaenv_(&c__1, &nb);
 
-/* +    TEST 1   
-                   Form the inverse of A. */
+/* +    TEST 1 */
+/*                 Form the inverse of A. */
 
 		    slacpy_(uplo, &n, &n, &a[1], &lda, &ainv[1], &lda);
 		    s_copy(srnamc_1.srnamt, "STRTRI", (ftnlen)6, (ftnlen)6);
@@ -333,9 +344,9 @@ static integer c__9 = 9;
 			rcondi = 1.f / anorm / ainvnm;
 		    }
 
-/*                 Compute the residual for the triangular matrix times   
-                   its inverse.  Also compute the 1-norm condition number   
-                   of A. */
+/*                 Compute the residual for the triangular matrix times */
+/*                 its inverse.  Also compute the 1-norm condition number */
+/*                 of A. */
 
 		    strt01_(uplo, diag, &n, &a[1], &lda, &ainv[1], &lda, &
 			    rcondo, &rwork[1], result);
@@ -354,7 +365,8 @@ static integer c__9 = 9;
 			do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__1, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[0], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[0], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
@@ -385,13 +397,13 @@ static integer c__9 = 9;
 				rcondc = rcondi;
 			    }
 
-/* +    TEST 2   
-                         Solve and compute residual for op(A)*x = b. */
+/* +    TEST 2 */
+/*                       Solve and compute residual for op(A)*x = b. */
 
 			    s_copy(srnamc_1.srnamt, "SLARHS", (ftnlen)6, (
 				    ftnlen)6);
 			    slarhs_(path, xtype, uplo, trans, &n, &n, &c__0, &
-				    idiag, &nrhs, &a[1], &lda, &xact[1], &lda,
+				    idiag, &nrhs, &a[1], &lda, &xact[1], &lda, 
 				     &b[1], &lda, iseed, &info);
 			    *(unsigned char *)xtype = 'C';
 			    slacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &
@@ -399,7 +411,7 @@ static integer c__9 = 9;
 
 			    s_copy(srnamc_1.srnamt, "STRTRS", (ftnlen)6, (
 				    ftnlen)6);
-			    strtrs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
+			    strtrs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
 				     &x[1], &lda, &info);
 
 /*                       Check error code from STRTRS. */
@@ -421,23 +433,23 @@ static integer c__9 = 9;
 				dummy = a[1];
 			    }
 
-			    strt02_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
+			    strt02_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
 				     &x[1], &lda, &b[1], &lda, &work[1], &
 				    result[1]);
 
-/* +    TEST 3   
-                         Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*                       Check solution from generated exact solution. */
 
 			    sget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                         Use iterative refinement to improve the solution   
-                         and compute error bounds. */
+/* +    TESTS 4, 5, and 6 */
+/*                       Use iterative refinement to improve the solution */
+/*                       and compute error bounds. */
 
 			    s_copy(srnamc_1.srnamt, "STRRFS", (ftnlen)6, (
 				    ftnlen)6);
-			    strrfs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
+			    strrfs_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
 				     &b[1], &lda, &x[1], &lda, &rwork[1], &
 				    rwork[nrhs + 1], &work[1], &iwork[1], &
 				    info);
@@ -457,12 +469,12 @@ static integer c__9 = 9;
 
 			    sget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				    rcondc, &result[3]);
-			    strt05_(uplo, trans, diag, &n, &nrhs, &a[1], &lda,
-				     &b[1], &lda, &x[1], &lda, &xact[1], &lda,
+			    strt05_(uplo, trans, diag, &n, &nrhs, &a[1], &lda, 
+				     &b[1], &lda, &x[1], &lda, &xact[1], &lda, 
 				     &rwork[1], &rwork[nrhs + 1], &result[4]);
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 2; k <= 6; ++k) {
 				if (result[k - 1] >= *thresh) {
@@ -495,8 +507,8 @@ static integer c__9 = 9;
 /* L40: */
 		    }
 
-/* +    TEST 7   
-                         Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 7 */
+/*                       Get an estimate of RCOND = 1/CNDNUM. */
 
 		    for (itran = 1; itran <= 2; ++itran) {
 			if (itran == 1) {
@@ -588,8 +600,8 @@ L80:
 		    slattr_(&imat, uplo, trans, diag, iseed, &n, &a[1], &lda, 
 			    &x[1], &work[1], &info);
 
-/* +    TEST 8   
-                   Solve the system op(A)*x = b. */
+/* +    TEST 8 */
+/*                 Solve the system op(A)*x = b. */
 
 		    s_copy(srnamc_1.srnamt, "SLATRS", (ftnlen)6, (ftnlen)6);
 		    scopy_(&n, &x[1], &c__1, &b[1], &c__1);
@@ -610,16 +622,16 @@ L80:
 				nout);
 		    }
 
-		    strt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale,
+		    strt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale, 
 			     &rwork[1], &c_b101, &b[1], &lda, &x[1], &lda, &
 			    work[1], &result[7]);
 
-/* +    TEST 9   
-                   Solve op(A)*X = b again with NORMIN = 'Y'. */
+/* +    TEST 9 */
+/*                 Solve op(A)*X = b again with NORMIN = 'Y'. */
 
 		    scopy_(&n, &x[1], &c__1, &b[n + 1], &c__1);
 		    slatrs_(uplo, trans, diag, "Y", &n, &a[1], &lda, &b[n + 1]
-			    , &scale, &rwork[1], &info);
+, &scale, &rwork[1], &info);
 
 /*                 Check error code from SLATRS. */
 
@@ -635,12 +647,12 @@ L80:
 				nout);
 		    }
 
-		    strt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale,
-			     &rwork[1], &c_b101, &b[n + 1], &lda, &x[1], &lda,
+		    strt03_(uplo, trans, diag, &n, &c__1, &a[1], &lda, &scale, 
+			     &rwork[1], &c_b101, &b[n + 1], &lda, &x[1], &lda, 
 			     &work[1], &result[8]);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    if (result[7] >= *thresh) {
 			if (nfail == 0 && nerrs == 0) {
@@ -656,7 +668,8 @@ L80:
 			do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__8, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[7], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[7], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
@@ -674,7 +687,8 @@ L80:
 			do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer));
 			do_fio(&c__1, (char *)&c__9, (ftnlen)sizeof(integer));
-			do_fio(&c__1, (char *)&result[8], (ftnlen)sizeof(real) );
+			do_fio(&c__1, (char *)&result[8], (ftnlen)sizeof(real)
+				);
 			e_wsfe();
 			++nfail;
 		    }
