@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* sdrvge.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -66,76 +54,92 @@ static integer c__7 = 7;
     real r__1;
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, k, n, k1, nb, in, kl, ku, nt, lda;
-    static char fact[1];
-    static integer ioff, mode;
-    static real amax;
-    static char path[3];
-    static integer imat, info;
-    static char dist[1], type__[1];
-    static integer nrun, ifact, nfail, iseed[4], nfact;
+    integer i__, k, n, k1, nb, in, kl, ku, nt, lda;
+    char fact[1];
+    integer ioff, mode;
+    real amax;
+    char path[3];
+    integer imat, info;
+    char dist[1], type__[1];
+    integer nrun, ifact, nfail, iseed[4], nfact;
     extern logical lsame_(char *, char *);
-    static char equed[1];
-    static integer nbmin;
-    static real rcond, roldc;
+    char equed[1];
+    integer nbmin;
+    real rcond, roldc;
     extern /* Subroutine */ int sget01_(integer *, integer *, real *, integer 
 	    *, real *, integer *, integer *, real *, real *);
-    static integer nimat;
-    static real roldi;
+    integer nimat;
+    real roldi;
     extern doublereal sget06_(real *, real *);
     extern /* Subroutine */ int sget02_(char *, integer *, integer *, integer 
 	    *, real *, integer *, real *, integer *, real *, integer *, real *
-	    , real *);
-    static real anorm;
-    static integer itran;
+, real *);
+    real anorm;
+    integer itran;
     extern /* Subroutine */ int sget04_(integer *, integer *, real *, integer 
 	    *, real *, integer *, real *, real *);
-    static logical equil;
-    static real roldo;
+    logical equil;
+    real roldo;
     extern /* Subroutine */ int sget07_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , real *, real *, real *);
-    static char trans[1];
-    static integer izero, nerrs;     extern /* Subroutine */ int sgesv_(integer *, integer *, real *, integer * 	    , integer *, real *, integer *, integer *);     static integer lwork;     static logical zerot;     static char xtype[1];     extern /* Subroutine */ int slatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), aladhd_(integer *, char *), 
+, real *, real *, real *);
+    char trans[1];
+    integer izero, nerrs;
+    extern /* Subroutine */ int sgesv_(integer *, integer *, real *, integer *
+, integer *, real *, integer *, integer *);
+    integer lwork;
+    logical zerot;
+    char xtype[1];
+    extern /* Subroutine */ int slatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), aladhd_(integer *, char *), 
 	    alaerh_(char *, char *, integer *, integer *, char *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *);
-    static logical prefac;
-    static real colcnd;
+    logical prefac;
+    real colcnd;
     extern doublereal slamch_(char *);
-    static real rcondc;
-    extern doublereal slange_(char *, integer *, integer *, real *, integer *,
+    real rcondc;
+    extern doublereal slange_(char *, integer *, integer *, real *, integer *, 
 	     real *);
-    static logical nofact;
-    static integer iequed;
+    logical nofact;
+    integer iequed;
     extern /* Subroutine */ int slaqge_(integer *, integer *, real *, integer 
 	    *, real *, real *, real *, real *, real *, char *);
-    static real rcondi;
+    real rcondi;
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real cndnum, anormi, rcondo, ainvnm;
+    real cndnum, anormi, rcondo, ainvnm;
     extern /* Subroutine */ int sgeequ_(integer *, integer *, real *, integer 
 	    *, real *, real *, real *, real *, real *, integer *);
-    static logical trfcon;
-    static real anormo, rowcnd;
+    logical trfcon;
+    real anormo, rowcnd;
     extern /* Subroutine */ int sgetrf_(integer *, integer *, real *, integer 
 	    *, integer *, integer *), sgetri_(integer *, real *, integer *, 
 	    integer *, real *, integer *, integer *), slacpy_(char *, integer 
 	    *, integer *, real *, integer *, real *, integer *), 
 	    slarhs_(char *, char *, char *, char *, integer *, integer *, 
-	    integer *, integer *, integer *, real *, integer *, real *,  	    integer *, real *, integer *, integer *, integer *);     extern doublereal slantr_(char *, char *, char *, integer *, integer *,  	    real *, integer *, real *);     extern /* Subroutine */ int slaset_(char *, integer *, integer *, real *,  	    real *, real *, integer *), slatms_(integer *, integer *,  	    char *, integer *, char *, real *, integer *, real *, real *,  	    integer *, integer *, char *, real *, integer *, real *, integer * 	    ), xlaenv_(integer *, integer *);
-    static real result[7];
+	    integer *, integer *, integer *, real *, integer *, real *, 
+	    integer *, real *, integer *, integer *, integer *);
+    extern doublereal slantr_(char *, char *, char *, integer *, integer *, 
+	    real *, integer *, real *);
+    extern /* Subroutine */ int slaset_(char *, integer *, integer *, real *, 
+	    real *, real *, integer *), slatms_(integer *, integer *, 
+	    char *, integer *, char *, real *, integer *, real *, real *, 
+	    integer *, integer *, char *, real *, integer *, real *, integer *
+), xlaenv_(integer *, integer *);
+    real result[7];
     extern /* Subroutine */ int sgesvx_(char *, char *, integer *, integer *, 
 	    real *, integer *, real *, integer *, integer *, char *, real *, 
 	    real *, real *, integer *, real *, integer *, real *, real *, 
 	    real *, real *, integer *, integer *);
-    static real rpvgrw;
+    real rpvgrw;
     extern /* Subroutine */ int serrvx_(char *, integer *);
 
     /* Fortran I/O blocks */
@@ -151,75 +155,96 @@ static integer c__7 = 7;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SDRVGE tests the driver routines SGESV and -SVX.   
+/*  SDRVGE tests the driver routines SGESV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  A       (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    ASAV    (workspace) REAL array, dimension (NMAX*NMAX)   
+/*  ASAV    (workspace) REAL array, dimension (NMAX*NMAX) */
 
-    B       (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  B       (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    BSAV    (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  BSAV    (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    X       (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  X       (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    S       (workspace) REAL array, dimension (2*NMAX)   
+/*  S       (workspace) REAL array, dimension (2*NMAX) */
 
-    WORK    (workspace) REAL array, dimension   
-                        (NMAX*max(3,NRHS))   
+/*  WORK    (workspace) REAL array, dimension */
+/*                      (NMAX*max(3,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (2*NRHS+NMAX)   
+/*  RWORK   (workspace) REAL array, dimension (2*NRHS+NMAX) */
 
-    IWORK   (workspace) INTEGER array, dimension (2*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (2*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -234,9 +259,11 @@ static integer c__7 = 7;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Single precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "GE", (ftnlen)2, (ftnlen)2);
@@ -290,8 +317,8 @@ static integer c__7 = 7;
 		goto L80;
 	    }
 
-/*           Set up parameters with SLATB4 and generate a test matrix   
-             with SLATMS. */
+/*           Set up parameters with SLATB4 and generate a test matrix */
+/*           with SLATMS. */
 
 	    slatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, &
 		    cndnum, dist);
@@ -310,8 +337,8 @@ static integer c__7 = 7;
 		goto L80;
 	    }
 
-/*           For types 5-7, zero one or more columns of the matrix to   
-             test that INFO is returned correctly. */
+/*           For types 5-7, zero one or more columns of the matrix to */
+/*           test that INFO is returned correctly. */
 
 	    if (zerot) {
 		if (imat == 5) {
@@ -367,17 +394,17 @@ static integer c__7 = 7;
 
 		    } else if (! nofact) {
 
-/*                    Compute the condition number for comparison with   
-                      the value returned by SGESVX (FACT = 'N' reuses   
-                      the condition number from the previous iteration   
-                      with FACT = 'F'). */
+/*                    Compute the condition number for comparison with */
+/*                    the value returned by SGESVX (FACT = 'N' reuses */
+/*                    the condition number from the previous iteration */
+/*                    with FACT = 'F'). */
 
 			slacpy_("Full", &n, &n, &asav[1], &lda, &afac[1], &
 				lda);
 			if (equil || iequed > 1) {
 
-/*                       Compute row and column scale factors to   
-                         equilibrate the matrix A. */
+/*                       Compute row and column scale factors to */
+/*                       equilibrate the matrix A. */
 
 			    sgeequ_(&n, &n, &afac[1], &lda, &s[1], &s[n + 1], 
 				    &rowcnd, &colcnd, &amax, &info);
@@ -401,8 +428,8 @@ static integer c__7 = 7;
 			    }
 			}
 
-/*                    Save the condition number of the non-equilibrated   
-                      system for use in SGET04. */
+/*                    Save the condition number of the non-equilibrated */
+/*                    system for use in SGET04. */
 
 			if (equil) {
 			    roldo = rcondo;
@@ -474,10 +501,10 @@ static integer c__7 = 7;
 
 			if (nofact && itran == 1) {
 
-/*                       --- Test SGESV  ---   
+/*                       --- Test SGESV  --- */
 
-                         Compute the LU factorization of the matrix and   
-                         solve the system. */
+/*                       Compute the LU factorization of the matrix and */
+/*                       solve the system. */
 
 			    slacpy_("Full", &n, &n, &a[1], &lda, &afac[1], &
 				    lda);
@@ -486,7 +513,7 @@ static integer c__7 = 7;
 
 			    s_copy(srnamc_1.srnamt, "SGESV ", (ftnlen)6, (
 				    ftnlen)6);
-			    sgesv_(&n, nrhs, &afac[1], &lda, &iwork[1], &x[1],
+			    sgesv_(&n, nrhs, &afac[1], &lda, &iwork[1], &x[1], 
 				     &lda, &info);
 
 /*                       Check error code from SGESV . */
@@ -497,8 +524,8 @@ static integer c__7 = 7;
 					nfail, &nerrs, nout);
 			    }
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    sget01_(&n, &n, &a[1], &lda, &afac[1], &lda, &
 				    iwork[1], &rwork[1], result);
@@ -515,13 +542,13 @@ static integer c__7 = 7;
 
 /*                          Check solution from generated exact solution. */
 
-				sget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				sget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &rcondc, &result[2]);
 				nt = 3;
 			    }
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    i__4 = nt;
 			    for (k = 1; k <= i__4; ++k) {
@@ -557,15 +584,15 @@ static integer c__7 = 7;
 			slaset_("Full", &n, nrhs, &c_b20, &c_b20, &x[1], &lda);
 			if (iequed > 1 && n > 0) {
 
-/*                       Equilibrate the matrix if FACT = 'F' and   
-                         EQUED = 'R', 'C', or 'B'. */
+/*                       Equilibrate the matrix if FACT = 'F' and */
+/*                       EQUED = 'R', 'C', or 'B'. */
 
 			    slaqge_(&n, &n, &a[1], &lda, &s[1], &s[n + 1], &
 				    rowcnd, &colcnd, &amax, equed);
 			}
 
-/*                    Solve the system and compute the condition number   
-                      and error bounds using SGESVX. */
+/*                    Solve the system and compute the condition number */
+/*                    and error bounds using SGESVX. */
 
 			s_copy(srnamc_1.srnamt, "SGESVX", (ftnlen)6, (ftnlen)
 				6);
@@ -587,8 +614,8 @@ static integer c__7 = 7;
 				    nerrs, nout);
 			}
 
-/*                    Compare WORK(1) from SGESVX with the computed   
-                      reciprocal pivot growth factor RPVGRW */
+/*                    Compare WORK(1) from SGESVX with the computed */
+/*                    reciprocal pivot growth factor RPVGRW */
 
 			if (info != 0) {
 			    rpvgrw = slantr_("M", "U", "N", &info, &info, &
@@ -615,8 +642,8 @@ static integer c__7 = 7;
 
 			if (! prefac) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    sget01_(&n, &n, &a[1], &lda, &afac[1], &lda, &
 				    iwork[1], &rwork[(*nrhs << 1) + 1], 
@@ -632,15 +659,15 @@ static integer c__7 = 7;
 /*                       Compute residual of the computed solution. */
 
 			    slacpy_("Full", &n, nrhs, &bsav[1], &lda, &work[1]
-				    , &lda);
+, &lda);
 			    sget02_(trans, &n, &n, nrhs, &asav[1], &lda, &x[1]
-				    , &lda, &work[1], &lda, &rwork[(*nrhs << 
+, &lda, &work[1], &lda, &rwork[(*nrhs << 
 				    1) + 1], &result[1]);
 
 /*                       Check solution from generated exact solution. */
 
 			    if (nofact || prefac && lsame_(equed, "N")) {
-				sget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				sget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &rcondc, &result[2]);
 			    } else {
 				if (itran == 1) {
@@ -648,12 +675,12 @@ static integer c__7 = 7;
 				} else {
 				    roldc = roldi;
 				}
-				sget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda,
+				sget04_(&n, nrhs, &x[1], &lda, &xact[1], &lda, 
 					 &roldc, &result[2]);
 			    }
 
-/*                       Check the error bounds from iterative   
-                         refinement. */
+/*                       Check the error bounds from iterative */
+/*                       refinement. */
 
 			    sget07_(trans, &n, nrhs, &asav[1], &lda, &b[1], &
 				    lda, &x[1], &lda, &xact[1], &lda, &rwork[
@@ -662,13 +689,13 @@ static integer c__7 = 7;
 			    trfcon = TRUE_;
 			}
 
-/*                    Compare RCOND from SGESVX with the computed value   
-                      in RCONDC. */
+/*                    Compare RCOND from SGESVX with the computed value */
+/*                    in RCONDC. */
 
 			result[5] = sget06_(&rcond, &rcondc);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			if (! trfcon) {
 			    for (k = k1; k <= 7; ++k) {
