@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* sdrvls.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -63,59 +51,68 @@ static real c_b92 = -1.f;
     integer i__1, i__2, i__3, i__4, i__5, i__6;
     real r__1, r__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal), log(doublereal);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, m, n, nb, im, in, lda, ldb, inb;
-    static real eps;
-    static integer ins, info;
-    static char path[3];
-    static integer rank, nrhs, nlvl, nrun;
+    integer i__, j, k, m, n, nb, im, in, lda, ldb, inb;
+    real eps;
+    integer ins, info;
+    char path[3];
+    integer rank, nrhs, nlvl, nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer nfail, iseed[4], crank, irank;
-    static real rcond;
+    integer nfail, iseed[4], crank, irank;
+    real rcond;
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *), 
 	    sgemm_(char *, char *, integer *, integer *, integer *, real *, 
 	    real *, integer *, real *, integer *, real *, real *, integer *);
-    static integer itran, mnmin, ncols;
-    static real norma, normb;
+    integer itran, mnmin, ncols;
+    real norma, normb;
     extern /* Subroutine */ int sgels_(char *, integer *, integer *, integer *
-	    , real *, integer *, real *, integer *, real *, integer *, 
-	    integer *);     static char trans[1];     static integer nerrs, itype;     extern doublereal sasum_(integer *, real *, integer *);     static integer lwork;     extern doublereal sqrt12_(integer *, integer *, real *, integer *, real *, 	     real *, integer *), sqrt14_(char *, integer *, integer *,  	    integer *, real *, integer *, real *, integer *, real *, integer * 	    ), sqrt17_(char *, integer *, integer *, integer *, 
+, real *, integer *, real *, integer *, real *, integer *, 
+	    integer *);
+    char trans[1];
+    integer nerrs, itype;
+    extern doublereal sasum_(integer *, real *, integer *);
+    integer lwork;
+    extern doublereal sqrt12_(integer *, integer *, real *, integer *, real *, 
+	     real *, integer *), sqrt14_(char *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , real *, real *, integer *);
+), sqrt17_(char *, integer *, integer *, integer *, 
+	    integer *, real *, integer *, real *, integer *, real *, integer *
+, real *, real *, integer *);
     extern /* Subroutine */ int sqrt13_(integer *, integer *, integer *, real 
 	    *, integer *, real *, integer *), sqrt15_(integer *, integer *, 
 	    integer *, integer *, integer *, real *, integer *, real *, 
 	    integer *, real *, integer *, real *, real *, integer *, real *, 
 	    integer *), saxpy_(integer *, real *, real *, integer *, real *, 
 	    integer *), sqrt16_(char *, integer *, integer *, integer *, real 
-	    *, integer *, real *, integer *, real *, integer *, real *, real * );
-    static integer nrows, lwlsy;
+	    *, integer *, real *, integer *, real *, integer *, real *, real *
+);
+    integer nrows, lwlsy;
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static integer iscale;
+    integer iscale;
     extern doublereal slamch_(char *);
     extern /* Subroutine */ int sgelsd_(integer *, integer *, integer *, real 
 	    *, integer *, real *, integer *, real *, real *, integer *, real *
-	    , integer *, integer *, integer *), alasvm_(char *, integer *, 
+, integer *, integer *, integer *), alasvm_(char *, integer *, 
 	    integer *, integer *, integer *), slacpy_(char *, integer 
 	    *, integer *, real *, integer *, real *, integer *), 
 	    xlaenv_(integer *, integer *), sgelss_(integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, real *, real *, 
 	    integer *, real *, integer *, integer *);
-    static integer ldwork;
+    integer ldwork;
     extern /* Subroutine */ int sgelsx_(integer *, integer *, integer *, real 
 	    *, integer *, real *, integer *, integer *, real *, integer *, 
 	    real *, integer *), sgelsy_(integer *, integer *, integer *, real 
 	    *, integer *, real *, integer *, integer *, real *, integer *, 
 	    real *, integer *, integer *), slarnv_(integer *, integer *, 
 	    integer *, real *), serrls_(char *, integer *);
-    static real result[18];
+    real result[18];
 
     /* Fortran I/O blocks */
     static cilist io___35 = { 0, 0, 0, fmt_9999, 0 };
@@ -124,105 +121,126 @@ static real c_b92 = -1.f;
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SDRVLS tests the least squares driver routines SGELS, SGELSS, SGELSX,   
-    SGELSY and SGELSD.   
+/*  SDRVLS tests the least squares driver routines SGELS, SGELSS, SGELSX, */
+/*  SGELSY and SGELSD. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
-            The matrix of type j is generated as follows:   
-            j=1: A = U*D*V where U and V are random orthogonal matrices   
-                 and D has random entries (> 0.1) taken from a uniform   
-                 distribution (0,1). A is full rank.   
-            j=2: The same of 1, but A is scaled up.   
-            j=3: The same of 1, but A is scaled down.   
-            j=4: A = U*D*V where U and V are random orthogonal matrices   
-                 and D has 3*min(M,N)/4 random entries (> 0.1) taken   
-                 from a uniform distribution (0,1) and the remaining   
-                 entries set to 0. A is rank-deficient.   
-            j=5: The same of 4, but A is scaled up.   
-            j=6: The same of 5, but A is scaled down.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
+/*          The matrix of type j is generated as follows: */
+/*          j=1: A = U*D*V where U and V are random orthogonal matrices */
+/*               and D has random entries (> 0.1) taken from a uniform */
+/*               distribution (0,1). A is full rank. */
+/*          j=2: The same of 1, but A is scaled up. */
+/*          j=3: The same of 1, but A is scaled down. */
+/*          j=4: A = U*D*V where U and V are random orthogonal matrices */
+/*               and D has 3*min(M,N)/4 random entries (> 0.1) taken */
+/*               from a uniform distribution (0,1) and the remaining */
+/*               entries set to 0. A is rank-deficient. */
+/*          j=5: The same of 4, but A is scaled up. */
+/*          j=6: The same of 5, but A is scaled down. */
 
-    NM      (input) INTEGER   
-            The number of values of M contained in the vector MVAL.   
+/*  NM      (input) INTEGER */
+/*          The number of values of M contained in the vector MVAL. */
 
-    MVAL    (input) INTEGER array, dimension (NM)   
-            The values of the matrix row dimension M.   
+/*  MVAL    (input) INTEGER array, dimension (NM) */
+/*          The values of the matrix row dimension M. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB and NX contained in the   
-            vectors NBVAL and NXVAL.  The blocking parameters are used   
-            in pairs (NB,NX).   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB and NX contained in the */
+/*          vectors NBVAL and NXVAL.  The blocking parameters are used */
+/*          in pairs (NB,NX). */
 
-    NBVAL   (input) INTEGER array, dimension (NNB)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NNB) */
+/*          The values of the blocksize NB. */
 
-    NXVAL   (input) INTEGER array, dimension (NNB)   
-            The values of the crossover point NX.   
+/*  NXVAL   (input) INTEGER array, dimension (NNB) */
+/*          The values of the crossover point NX. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) REAL array, dimension (MMAX*NMAX)   
-            where MMAX is the maximum value of M in MVAL and NMAX is the   
-            maximum value of N in NVAL.   
+/*  A       (workspace) REAL array, dimension (MMAX*NMAX) */
+/*          where MMAX is the maximum value of M in MVAL and NMAX is the */
+/*          maximum value of N in NVAL. */
 
-    COPYA   (workspace) REAL array, dimension (MMAX*NMAX)   
+/*  COPYA   (workspace) REAL array, dimension (MMAX*NMAX) */
 
-    B       (workspace) REAL array, dimension (MMAX*NSMAX)   
-            where MMAX is the maximum value of M in MVAL and NSMAX is the   
-            maximum value of NRHS in NSVAL.   
+/*  B       (workspace) REAL array, dimension (MMAX*NSMAX) */
+/*          where MMAX is the maximum value of M in MVAL and NSMAX is the */
+/*          maximum value of NRHS in NSVAL. */
 
-    COPYB   (workspace) REAL array, dimension (MMAX*NSMAX)   
+/*  COPYB   (workspace) REAL array, dimension (MMAX*NSMAX) */
 
-    C       (workspace) REAL array, dimension (MMAX*NSMAX)   
+/*  C       (workspace) REAL array, dimension (MMAX*NSMAX) */
 
-    S       (workspace) REAL array, dimension   
-                        (min(MMAX,NMAX))   
+/*  S       (workspace) REAL array, dimension */
+/*                      (min(MMAX,NMAX)) */
 
-    COPYS   (workspace) REAL array, dimension   
-                        (min(MMAX,NMAX))   
+/*  COPYS   (workspace) REAL array, dimension */
+/*                      (min(MMAX,NMAX)) */
 
-    WORK    (workspace) REAL array,   
-                        dimension (MMAX*NMAX + 4*NMAX + MMAX).   
+/*  WORK    (workspace) REAL array, */
+/*                      dimension (MMAX*NMAX + 4*NMAX + MMAX). */
 
-    IWORK   (workspace) INTEGER array, dimension (15*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (15*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --work;
     --copys;
@@ -239,9 +257,11 @@ static real c_b92 = -1.f;
     --mval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Single precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "LS", (ftnlen)2, (ftnlen)2);
@@ -289,8 +309,8 @@ static real c_b92 = -1.f;
 	    i__3 = *nns;
 	    for (ins = 1; ins <= i__3; ++ins) {
 		nrhs = nsval[ins];
-/* Computing MAX   
-   Computing MAX */
+/* Computing MAX */
+/* Computing MAX */
 		r__1 = 1.f, r__2 = (real) mnmin;
 		i__4 = (integer) (log(dmax(r__1,r__2) / 26.f) / log(2.f)) + 1;
 		nlvl = max(i__4,0);
@@ -311,9 +331,9 @@ static real c_b92 = -1.f;
 
 			if (irank == 1) {
 
-/*                       Test SGELS   
+/*                       Test SGELS */
 
-                         Generate a matrix of scaling type ISCALE */
+/*                       Generate a matrix of scaling type ISCALE */
 
 			    sqrt13_(&iscale, &m, &n, &copya[1], &lda, &norma, 
 				    iseed);
@@ -402,8 +422,8 @@ static real c_b92 = -1.f;
 						&ldb, &work[1], &lwork);
 				    }
 
-/*                             Print information about the tests that   
-                               did not pass the threshold. */
+/*                             Print information about the tests that */
+/*                             did not pass the threshold. */
 
 				    for (k = 1; k <= 2; ++k) {
 					if (result[k - 1] >= *thresh) {
@@ -439,16 +459,16 @@ static real c_b92 = -1.f;
 			    }
 			}
 
-/*                    Generate a matrix of scaling type ISCALE and rank   
-                      type IRANK. */
+/*                    Generate a matrix of scaling type ISCALE and rank */
+/*                    type IRANK. */
 
 			sqrt15_(&iscale, &irank, &m, &n, &nrhs, &copya[1], &
 				lda, &copyb[1], &ldb, &copys[1], &rank, &
 				norma, &normb, iseed, &work[1], &lwork);
 
-/*                    workspace used: MAX(M+MIN(M,N),NRHS*MIN(M,N),2*N+M)   
+/*                    workspace used: MAX(M+MIN(M,N),NRHS*MIN(M,N),2*N+M) */
 
-                      Initialize vector IWORK. */
+/*                    Initialize vector IWORK. */
 
 			i__4 = n;
 			for (j = 1; j <= i__4; ++j) {
@@ -457,11 +477,11 @@ static real c_b92 = -1.f;
 			}
 			ldwork = max(1,m);
 
-/*                    Test SGELSX   
+/*                    Test SGELSX */
 
-                      SGELSX:  Compute the minimum-norm solution X   
-                      to min( norm( A * X - B ) ) using a complete   
-                      orthogonal factorization. */
+/*                    SGELSX:  Compute the minimum-norm solution X */
+/*                    to min( norm( A * X - B ) ) using a complete */
+/*                    orthogonal factorization. */
 
 			slacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &lda);
 			slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], &
@@ -472,21 +492,21 @@ static real c_b92 = -1.f;
 			sgelsx_(&m, &n, &nrhs, &a[1], &lda, &b[1], &ldb, &
 				iwork[1], &rcond, &crank, &work[1], &info);
 			if (info != 0) {
-			    alaerh_(path, "SGELSX", &info, &c__0, " ", &m, &n,
+			    alaerh_(path, "SGELSX", &info, &c__0, " ", &m, &n, 
 				     &nrhs, &c_n1, &nb, &itype, &nfail, &
 				    nerrs, nout);
 			}
 
-/*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )   
+/*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS ) */
 
-                      Test 3:  Compute relative error in svd   
-                               workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
+/*                    Test 3:  Compute relative error in svd */
+/*                             workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
 
 			result[2] = sqrt12_(&crank, &crank, &a[1], &lda, &
 				copys[1], &work[1], &lwork);
 
-/*                    Test 4:  Compute error in solution   
-                               workspace:  M*NRHS + M */
+/*                    Test 4:  Compute error in solution */
+/*                             workspace:  M*NRHS + M */
 
 			slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &work[1], 
 				&ldwork);
@@ -494,29 +514,29 @@ static real c_b92 = -1.f;
 				lda, &b[1], &ldb, &work[1], &ldwork, &work[m *
 				 nrhs + 1], &result[3]);
 
-/*                    Test 5:  Check norm of r'*A   
-                               workspace: NRHS*(M+N) */
+/*                    Test 5:  Check norm of r'*A */
+/*                             workspace: NRHS*(M+N) */
 
 			result[4] = 0.f;
 			if (m > crank) {
-			    result[4] = sqrt17_("No transpose", &c__1, &m, &n,
+			    result[4] = sqrt17_("No transpose", &c__1, &m, &n, 
 				     &nrhs, &copya[1], &lda, &b[1], &ldb, &
 				    copyb[1], &ldb, &c__[1], &work[1], &lwork);
 			}
 
-/*                    Test 6:  Check if x is in the rowspace of A   
-                               workspace: (M+NRHS)*(N+2) */
+/*                    Test 6:  Check if x is in the rowspace of A */
+/*                             workspace: (M+NRHS)*(N+2) */
 
 			result[5] = 0.f;
 
 			if (n > crank) {
-			    result[5] = sqrt14_("No transpose", &m, &n, &nrhs,
+			    result[5] = sqrt14_("No transpose", &m, &n, &nrhs, 
 				     &copya[1], &lda, &b[1], &ldb, &work[1], &
 				    lwork);
 			}
 
-/*                    Print information about the tests that did not   
-                      pass the threshold. */
+/*                    Print information about the tests that did not */
+/*                    pass the threshold. */
 
 			for (k = 3; k <= 6; ++k) {
 			    if (result[k - 1] >= *thresh) {
@@ -554,14 +574,14 @@ static real c_b92 = -1.f;
 			    xlaenv_(&c__1, &nb);
 			    xlaenv_(&c__3, &nxval[inb]);
 
-/*                       Test SGELSY   
+/*                       Test SGELSY */
 
-                         SGELSY:  Compute the minimum-norm solution X   
-                         to min( norm( A * X - B ) )   
-                         using the rank-revealing orthogonal   
-                         factorization.   
+/*                       SGELSY:  Compute the minimum-norm solution X */
+/*                       to min( norm( A * X - B ) ) */
+/*                       using the rank-revealing orthogonal */
+/*                       factorization. */
 
-                         Initialize vector IWORK. */
+/*                       Initialize vector IWORK. */
 
 			    i__5 = n;
 			    for (j = 1; j <= i__5; ++j) {
@@ -569,9 +589,9 @@ static real c_b92 = -1.f;
 /* L70: */
 			    }
 
-/*                       Set LWLSY to the adequate value.   
+/*                       Set LWLSY to the adequate value. */
 
-   Computing MAX */
+/* Computing MAX */
 			    i__5 = 1, i__6 = mnmin + (n << 1) + nb * (n + 1), 
 				    i__5 = max(i__5,i__6), i__6 = (mnmin << 1)
 				     + nb * nrhs;
@@ -579,7 +599,7 @@ static real c_b92 = -1.f;
 
 			    slacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &
 				    lda);
-			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1],
+			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], 
 				     &ldb);
 
 			    s_copy(srnamc_1.srnamt, "SGELSY", (ftnlen)6, (
@@ -588,19 +608,19 @@ static real c_b92 = -1.f;
 				    iwork[1], &rcond, &crank, &work[1], &
 				    lwlsy, &info);
 			    if (info != 0) {
-				alaerh_(path, "SGELSY", &info, &c__0, " ", &m,
+				alaerh_(path, "SGELSY", &info, &c__0, " ", &m, 
 					 &n, &nrhs, &c_n1, &nb, &itype, &
 					nfail, &nerrs, nout);
 			    }
 
-/*                       Test 7:  Compute relative error in svd   
-                                  workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
+/*                       Test 7:  Compute relative error in svd */
+/*                                workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
 
 			    result[6] = sqrt12_(&crank, &crank, &a[1], &lda, &
 				    copys[1], &work[1], &lwork);
 
-/*                       Test 8:  Compute error in solution   
-                                  workspace:  M*NRHS + M */
+/*                       Test 8:  Compute error in solution */
+/*                                workspace:  M*NRHS + M */
 
 			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &work[
 				    1], &ldwork);
@@ -608,19 +628,19 @@ static real c_b92 = -1.f;
 				    &lda, &b[1], &ldb, &work[1], &ldwork, &
 				    work[m * nrhs + 1], &result[7]);
 
-/*                       Test 9:  Check norm of r'*A   
-                                  workspace: NRHS*(M+N) */
+/*                       Test 9:  Check norm of r'*A */
+/*                                workspace: NRHS*(M+N) */
 
 			    result[8] = 0.f;
 			    if (m > crank) {
-				result[8] = sqrt17_("No transpose", &c__1, &m,
+				result[8] = sqrt17_("No transpose", &c__1, &m, 
 					 &n, &nrhs, &copya[1], &lda, &b[1], &
 					ldb, &copyb[1], &ldb, &c__[1], &work[
 					1], &lwork);
 			    }
 
-/*                       Test 10:  Check if x is in the rowspace of A   
-                                  workspace: (M+NRHS)*(N+2) */
+/*                       Test 10:  Check if x is in the rowspace of A */
+/*                                workspace: (M+NRHS)*(N+2) */
 
 			    result[9] = 0.f;
 
@@ -630,15 +650,15 @@ static real c_b92 = -1.f;
 					work[1], &lwork);
 			    }
 
-/*                       Test SGELSS   
+/*                       Test SGELSS */
 
-                         SGELSS:  Compute the minimum-norm solution X   
-                         to min( norm( A * X - B ) )   
-                         using the SVD. */
+/*                       SGELSS:  Compute the minimum-norm solution X */
+/*                       to min( norm( A * X - B ) ) */
+/*                       using the SVD. */
 
 			    slacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &
 				    lda);
-			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1],
+			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], 
 				     &ldb);
 			    s_copy(srnamc_1.srnamt, "SGELSS", (ftnlen)6, (
 				    ftnlen)6);
@@ -646,15 +666,15 @@ static real c_b92 = -1.f;
 				    s[1], &rcond, &crank, &work[1], &lwork, &
 				    info);
 			    if (info != 0) {
-				alaerh_(path, "SGELSS", &info, &c__0, " ", &m,
+				alaerh_(path, "SGELSS", &info, &c__0, " ", &m, 
 					 &n, &nrhs, &c_n1, &nb, &itype, &
 					nfail, &nerrs, nout);
 			    }
 
-/*                       workspace used: 3*min(m,n) +   
-                                         max(2*min(m,n),nrhs,max(m,n))   
+/*                       workspace used: 3*min(m,n) + */
+/*                                       max(2*min(m,n),nrhs,max(m,n)) */
 
-                         Test 11:  Compute relative error in svd */
+/*                       Test 11:  Compute relative error in svd */
 
 			    if (rank > 0) {
 				saxpy_(&mnmin, &c_b92, &copys[1], &c__1, &s[1]
@@ -693,13 +713,13 @@ static real c_b92 = -1.f;
 					work[1], &lwork);
 			    }
 
-/*                       Test SGELSD   
+/*                       Test SGELSD */
 
-                         SGELSD:  Compute the minimum-norm solution X   
-                         to min( norm( A * X - B ) ) using a   
-                         divide and conquer SVD.   
+/*                       SGELSD:  Compute the minimum-norm solution X */
+/*                       to min( norm( A * X - B ) ) using a */
+/*                       divide and conquer SVD. */
 
-                         Initialize vector IWORK. */
+/*                       Initialize vector IWORK. */
 
 			    i__5 = n;
 			    for (j = 1; j <= i__5; ++j) {
@@ -709,7 +729,7 @@ static real c_b92 = -1.f;
 
 			    slacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &
 				    lda);
-			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1],
+			    slacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], 
 				     &ldb);
 
 			    s_copy(srnamc_1.srnamt, "SGELSD", (ftnlen)6, (
@@ -718,7 +738,7 @@ static real c_b92 = -1.f;
 				    s[1], &rcond, &crank, &work[1], &lwork, &
 				    iwork[1], &info);
 			    if (info != 0) {
-				alaerh_(path, "SGELSD", &info, &c__0, " ", &m,
+				alaerh_(path, "SGELSD", &info, &c__0, " ", &m, 
 					 &n, &nrhs, &c_n1, &nb, &itype, &
 					nfail, &nerrs, nout);
 			    }
@@ -762,8 +782,8 @@ static real c_b92 = -1.f;
 					work[1], &lwork);
 			    }
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 7; k <= 18; ++k) {
 				if (result[k - 1] >= *thresh) {
