@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* sdrvsp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -58,34 +46,34 @@ static integer c__2 = 2;
     integer i__1, i__2, i__3, i__4, i__5[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, k1, in, kl, ku, nt, lda, npp;
-    static char fact[1];
-    static integer ioff, mode, imat, info;
-    static char path[3], dist[1], uplo[1], type__[1];
-    static integer nrun, ifact, nfail, iseed[4];
-    static real rcond;
+    integer i__, j, k, n, i1, i2, k1, in, kl, ku, nt, lda, npp;
+    char fact[1];
+    integer ioff, mode, imat, info;
+    char path[3], dist[1], uplo[1], type__[1];
+    integer nrun, ifact, nfail, iseed[4];
+    real rcond;
     extern /* Subroutine */ int sget04_(integer *, integer *, real *, integer 
 	    *, real *, integer *, real *, real *);
-    static integer nimat;
+    integer nimat;
     extern doublereal sget06_(real *, real *);
-    static real anorm;
-    static integer iuplo, izero, nerrs;
+    real anorm;
+    integer iuplo, izero, nerrs;
     extern /* Subroutine */ int sppt02_(char *, integer *, integer *, real *, 
 	    real *, integer *, real *, integer *, real *, real *), 
 	    scopy_(integer *, real *, integer *, real *, integer *);
-    static integer lwork;
+    integer lwork;
     extern /* Subroutine */ int sppt05_(char *, integer *, integer *, real *, 
 	    real *, integer *, real *, integer *, real *, integer *, real *, 
 	    real *, real *), sspt01_(char *, integer *, real *, real *
-	    , integer *, real *, integer *, real *, real *);
-    static logical zerot;
-    static char xtype[1];
+, integer *, real *, integer *, real *, real *);
+    logical zerot;
+    char xtype[1];
     extern /* Subroutine */ int sspsv_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *, integer *), slatb4_(char *, 
 	    integer *, integer *, integer *, char *, integer *, integer *, 
@@ -93,22 +81,22 @@ static integer c__2 = 2;
 	    aladhd_(integer *, char *), alaerh_(char *, char *, 
 	    integer *, integer *, char *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *);
-    static real rcondc;
-    static char packit[1];
+    real rcondc;
+    char packit[1];
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static real cndnum, ainvnm;
+    real cndnum, ainvnm;
     extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *), slarhs_(char *, char *, 
 	    char *, char *, integer *, integer *, integer *, integer *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , integer *, integer *), slaset_(
+, integer *, integer *), slaset_(
 	    char *, integer *, integer *, real *, real *, real *, integer *);
     extern doublereal slansp_(char *, char *, integer *, real *, real *);
     extern /* Subroutine */ int slatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, real *, integer *, real *, integer *);
-    static real result[6];
+, char *, real *, integer *, real *, integer *);
+    real result[6];
     extern /* Subroutine */ int ssptrf_(char *, integer *, real *, integer *, 
 	    integer *), ssptri_(char *, integer *, real *, integer *, 
 	    real *, integer *), serrvx_(char *, integer *), 
@@ -122,74 +110,95 @@ static integer c__2 = 2;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SDRVSP tests the driver routines SSPSV and -SVX.   
+/*  SDRVSP tests the driver routines SSPSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) REAL   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) REAL */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) REAL array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  A       (workspace) REAL array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AFAC    (workspace) REAL array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AFAC    (workspace) REAL array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AINV    (workspace) REAL array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AINV    (workspace) REAL array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    B       (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  B       (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    X       (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  X       (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) REAL array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) REAL array, dimension (NMAX*NRHS) */
 
-    WORK    (workspace) REAL array, dimension   
-                        (NMAX*max(2,NRHS))   
+/*  WORK    (workspace) REAL array, dimension */
+/*                      (NMAX*max(2,NRHS)) */
 
-    RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS) */
 
-    IWORK   (workspace) INTEGER array, dimension (2*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (2*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -202,9 +211,11 @@ static integer c__2 = 2;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Single precision", (ftnlen)1, (ftnlen)16);
     s_copy(path + 1, "SP", (ftnlen)2, (ftnlen)2);
@@ -266,8 +277,8 @@ static integer c__2 = 2;
 		    *(unsigned char *)packit = 'R';
 		}
 
-/*              Set up parameters with SLATB4 and generate a test matrix   
-                with SLATMS. */
+/*              Set up parameters with SLATB4 and generate a test matrix */
+/*              with SLATMS. */
 
 		slatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, 
 			&cndnum, dist);
@@ -280,13 +291,13 @@ static integer c__2 = 2;
 /*              Check error code from SLATMS. */
 
 		if (info != 0) {
-		    alaerh_(path, "SLATMS", &info, &c__0, uplo, &n, &n, &c_n1,
+		    alaerh_(path, "SLATMS", &info, &c__0, uplo, &n, &n, &c_n1, 
 			     &c_n1, &c_n1, &imat, &nfail, &nerrs, nout);
 		    goto L160;
 		}
 
-/*              For types 3-6, zero one or more rows and columns of the   
-                matrix to test that INFO is returned correctly. */
+/*              For types 3-6, zero one or more rows and columns of the */
+/*              matrix to test that INFO is returned correctly. */
 
 		if (zerot) {
 		    if (imat == 3) {
@@ -375,8 +386,8 @@ static integer c__2 = 2;
 		    *(unsigned char *)fact = *(unsigned char *)&facts[ifact - 
 			    1];
 
-/*                 Compute the condition number for comparison with   
-                   the value returned by SSPSVX. */
+/*                 Compute the condition number for comparison with */
+/*                 the value returned by SSPSVX. */
 
 		    if (zerot) {
 			if (ifact == 1) {
@@ -432,8 +443,8 @@ static integer c__2 = 2;
 			sspsv_(uplo, &n, nrhs, &afac[1], &iwork[1], &x[1], &
 				lda, &info);
 
-/*                    Adjust the expected value of INFO to account for   
-                      pivoting. */
+/*                    Adjust the expected value of INFO to account for */
+/*                    pivoting. */
 
 			k = izero;
 			if (k > 0) {
@@ -460,11 +471,11 @@ L100:
 			    goto L120;
 			}
 
-/*                    Reconstruct matrix from factors and compute   
-                      residual. */
+/*                    Reconstruct matrix from factors and compute */
+/*                    residual. */
 
 			sspt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &ainv[1]
-				, &lda, &rwork[1], result);
+, &lda, &rwork[1], result);
 
 /*                    Compute residual of the computed solution. */
 
@@ -478,8 +489,8 @@ L100:
 				rcondc, &result[2]);
 			nt = 3;
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			i__3 = nt;
 			for (k = 1; k <= i__3; ++k) {
@@ -512,21 +523,21 @@ L120:
 /*                 --- Test SSPSVX --- */
 
 		    if (ifact == 2 && npp > 0) {
-			slaset_("Full", &npp, &c__1, &c_b59, &c_b59, &afac[1],
+			slaset_("Full", &npp, &c__1, &c_b59, &c_b59, &afac[1], 
 				 &npp);
 		    }
 		    slaset_("Full", &n, nrhs, &c_b59, &c_b59, &x[1], &lda);
 
-/*                 Solve the system and compute the condition number and   
-                   error bounds using SSPSVX. */
+/*                 Solve the system and compute the condition number and */
+/*                 error bounds using SSPSVX. */
 
 		    s_copy(srnamc_1.srnamt, "SSPSVX", (ftnlen)6, (ftnlen)6);
 		    sspsvx_(fact, uplo, &n, nrhs, &a[1], &afac[1], &iwork[1], 
 			    &b[1], &lda, &x[1], &lda, &rcond, &rwork[1], &
 			    rwork[*nrhs + 1], &work[1], &iwork[n + 1], &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -558,8 +569,8 @@ L130:
 		    if (info == 0) {
 			if (ifact >= 2) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    sspt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &
 				    ainv[1], &lda, &rwork[(*nrhs << 1) + 1], 
@@ -589,13 +600,13 @@ L130:
 			k1 = 6;
 		    }
 
-/*                 Compare RCOND from SSPSVX with the computed value   
-                   in RCONDC. */
+/*                 Compare RCOND from SSPSVX with the computed value */
+/*                 in RCONDC. */
 
 		    result[5] = sget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    for (k = k1; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
