@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* serrpo.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -42,13 +30,13 @@ static integer c_n1 = -1;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static real a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static real w[12], x[4];
-    static char c2[2];
-    static real r1[4], r2[4], af[16]	/* was [4][4] */;
-    static integer iw[4], info;
-    static real anrm, rcond;
+    real a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    real w[12], x[4];
+    char c2[2];
+    real r1[4], r2[4], af[16]	/* was [4][4] */;
+    integer iw[4], info;
+    real anrm, rcond;
     extern /* Subroutine */ int spbtf2_(char *, integer *, integer *, real *, 
 	    integer *, integer *), spotf2_(char *, integer *, real *, 
 	    integer *, integer *), alaesm_(char *, logical *, integer 
@@ -67,9 +55,9 @@ static integer c_n1 = -1;
 	    real *, real *, integer *, integer *), spoequ_(integer *, 
 	    real *, integer *, real *, real *, real *, integer *), spbtrs_(
 	    char *, integer *, integer *, integer *, real *, integer *, real *
-	    , integer *, integer *), sporfs_(char *, integer *, 
+, integer *, integer *), sporfs_(char *, integer *, 
 	    integer *, real *, integer *, real *, integer *, real *, integer *
-	    , real *, integer *, real *, real *, real *, integer *, integer *), spotrf_(char *, integer *, real *, integer *, integer *), spotri_(char *, integer *, real *, integer *, integer *), sppequ_(char *, integer *, real *, real *, real *, real 
+, real *, integer *, real *, real *, real *, integer *, integer *), spotrf_(char *, integer *, real *, integer *, integer *), spotri_(char *, integer *, real *, integer *, integer *), sppequ_(char *, integer *, real *, real *, real *, real 
 	    *, integer *), spprfs_(char *, integer *, integer *, real 
 	    *, real *, real *, integer *, real *, integer *, real *, real *, 
 	    real *, integer *, integer *), spptrf_(char *, integer *, 
@@ -83,28 +71,47 @@ static integer c_n1 = -1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SERRPO tests the error exits for the REAL routines   
-    for symmetric positive definite matrices.   
+/*  SERRPO tests the error exits for the REAL routines */
+/*  for symmetric positive definite matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -132,10 +139,10 @@ static integer c_n1 = -1;
 
     if (lsamen_(&c__2, c2, "PO")) {
 
-/*        Test error exits of the routines that use the Cholesky   
-          decomposition of a symmetric positive definite matrix.   
+/*        Test error exits of the routines that use the Cholesky */
+/*        decomposition of a symmetric positive definite matrix. */
 
-          SPOTRF */
+/*        SPOTRF */
 
 	s_copy(srnamc_1.srnamt, "SPOTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -276,10 +283,10 @@ static integer c_n1 = -1;
 
     } else if (lsamen_(&c__2, c2, "PP")) {
 
-/*        Test error exits of the routines that use the Cholesky   
-          decomposition of a symmetric positive definite packed matrix.   
+/*        Test error exits of the routines that use the Cholesky */
+/*        decomposition of a symmetric positive definite packed matrix. */
 
-          SPPTRF */
+/*        SPPTRF */
 
 	s_copy(srnamc_1.srnamt, "SPPTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
@@ -378,10 +385,10 @@ static integer c_n1 = -1;
 
     } else if (lsamen_(&c__2, c2, "PB")) {
 
-/*        Test error exits of the routines that use the Cholesky   
-          decomposition of a symmetric positive definite band matrix.   
+/*        Test error exits of the routines that use the Cholesky */
+/*        decomposition of a symmetric positive definite band matrix. */
 
-          SPBTRF */
+/*        SPBTRF */
 
 	s_copy(srnamc_1.srnamt, "SPBTRF", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
