@@ -1,125 +1,143 @@
-#include "blaswrap.h"
-/* slattb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
 static integer c__2 = 2;
-static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; static integer c_n1 = -1;  /* Subroutine */ int slattb_(integer *imat, char *uplo, char *trans, char * 	diag, integer *iseed, integer *n, integer *kd, real *ab, integer * 	ldab, real *b, real *work, integer *info  	)
+static integer c__1 = 1;
+static real c_b36 = 2.f;
+static real c_b47 = 1.f;
+static integer c_n1 = -1;
+
+/* Subroutine */ int slattb_(integer *imat, char *uplo, char *trans, char *
+	diag, integer *iseed, integer *n, integer *kd, real *ab, integer *
+	ldab, real *b, real *work, integer *info)
 {
     /* System generated locals */
     integer ab_dim1, ab_offset, i__1, i__2, i__3, i__4, i__5;
     real r__1, r__2;
     doublereal d__1, d__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal), r_sign(real *, real *), pow_dd(doublereal *, 
 	    doublereal *);
 
     /* Local variables */
-    static integer i__, j, kl, ku, iy;
-    static real ulp, sfac;
-    static integer ioff, mode, lenj;
-    static char path[3], dist[1];
-    static real unfl, rexp;
-    static char type__[1];
-    static real texp, star1, plus1, plus2, bscal;
+    integer i__, j, kl, ku, iy;
+    real ulp, sfac;
+    integer ioff, mode, lenj;
+    char path[3], dist[1];
+    real unfl, rexp;
+    char type__[1];
+    real texp, star1, plus1, plus2, bscal;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static real tscal, anorm, bnorm, tleft;     static logical upper;     extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *,  	    integer *), sswap_(integer *, real *, integer *, real *, integer * );     static real tnorm;     extern /* Subroutine */ int slatb4_(char *, integer *, integer *, integer  	    *, char *, integer *, integer *, real *, integer *, real *, char * 	    ), slabad_(real *, real *);
+    real tscal, anorm, bnorm, tleft;
+    logical upper;
+    extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
+	    integer *), sswap_(integer *, real *, integer *, real *, integer *
+);
+    real tnorm;
+    extern /* Subroutine */ int slatb4_(char *, integer *, integer *, integer 
+	    *, char *, integer *, integer *, real *, integer *, real *, char *
+), slabad_(real *, real *);
     extern doublereal slamch_(char *);
-    static char packit[1];
-    static real bignum;
+    char packit[1];
+    real bignum;
     extern integer isamax_(integer *, real *, integer *);
     extern doublereal slarnd_(integer *, integer *);
-    static real cndnum;
-    static integer jcount;
+    real cndnum;
+    integer jcount;
     extern /* Subroutine */ int slatms_(integer *, integer *, char *, integer 
 	    *, char *, real *, integer *, real *, real *, integer *, integer *
-	    , char *, real *, integer *, real *, integer *), slarnv_(integer *, integer *, integer *, real *);
-    static real smlnum;
+, char *, real *, integer *, real *, integer *), slarnv_(integer *, integer *, integer *, real *);
+    real smlnum;
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    SLATTB generates a triangular test matrix in 2-dimensional storage.   
-    IMAT and UPLO uniquely specify the properties of the test matrix,   
-    which is returned in the array A.   
+/*  SLATTB generates a triangular test matrix in 2-dimensional storage. */
+/*  IMAT and UPLO uniquely specify the properties of the test matrix, */
+/*  which is returned in the array A. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    IMAT    (input) INTEGER   
-            An integer key describing which matrix to generate for this   
-            path.   
+/*  IMAT    (input) INTEGER */
+/*          An integer key describing which matrix to generate for this */
+/*          path. */
 
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A will be upper or lower   
-            triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A will be upper or lower */
+/*          triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
 
-    TRANS   (input) CHARACTER*1   
-            Specifies whether the matrix or its transpose will be used.   
-            = 'N':  No transpose   
-            = 'T':  Transpose   
-            = 'C':  Conjugate transpose (= transpose)   
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies whether the matrix or its transpose will be used. */
+/*          = 'N':  No transpose */
+/*          = 'T':  Transpose */
+/*          = 'C':  Conjugate transpose (= transpose) */
 
-    DIAG    (output) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
+/*  DIAG    (output) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
 
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            The seed vector for the random number generator (used in   
-            SLATMS).  Modified on exit.   
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          The seed vector for the random number generator (used in */
+/*          SLATMS).  Modified on exit. */
 
-    N       (input) INTEGER   
-            The order of the matrix to be generated.   
+/*  N       (input) INTEGER */
+/*          The order of the matrix to be generated. */
 
-    KD      (input) INTEGER   
-            The number of superdiagonals or subdiagonals of the banded   
-            triangular matrix A.  KD >= 0.   
+/*  KD      (input) INTEGER */
+/*          The number of superdiagonals or subdiagonals of the banded */
+/*          triangular matrix A.  KD >= 0. */
 
-    AB      (output) REAL array, dimension (LDAB,N)   
-            The upper or lower triangular banded matrix A, stored in the   
-            first KD+1 rows of AB.  Let j be a column of A, 1<=j<=n.   
-            If UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j.   
-            If UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd).   
+/*  AB      (output) REAL array, dimension (LDAB,N) */
+/*          The upper or lower triangular banded matrix A, stored in the */
+/*          first KD+1 rows of AB.  Let j be a column of A, 1<=j<=n. */
+/*          If UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j. */
+/*          If UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd). */
 
-    LDAB    (input) INTEGER   
-            The leading dimension of the array AB.  LDAB >= KD+1.   
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array AB.  LDAB >= KD+1. */
 
-    B       (workspace) REAL array, dimension (N)   
+/*  B       (workspace) REAL array, dimension (N) */
 
-    WORK    (workspace) REAL array, dimension (2*N)   
+/*  WORK    (workspace) REAL array, dimension (2*N) */
 
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0: if INFO = -k, the k-th argument had an illegal value   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0: if INFO = -k, the k-th argument had an illegal value */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --iseed;
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
@@ -176,10 +194,10 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 	slatms_(n, n, dist, &iseed[1], type__, &b[1], &mode, &cndnum, &anorm, 
 		&kl, &ku, packit, &ab[ioff + ab_dim1], ldab, &work[1], info);
 
-/*     IMAT > 5:  Unit triangular matrix   
-       The diagonal is deliberately set to something other than 1.   
+/*     IMAT > 5:  Unit triangular matrix */
+/*     The diagonal is deliberately set to something other than 1. */
 
-       IMAT = 6:  Matrix is the identity */
+/*     IMAT = 6:  Matrix is the identity */
 
     } else if (*imat == 6) {
 	if (upper) {
@@ -210,10 +228,10 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 	    }
 	}
 
-/*     IMAT > 6:  Non-trivial unit triangular matrix   
+/*     IMAT > 6:  Non-trivial unit triangular matrix */
 
-       A unit triangular matrix T with condition CNDNUM is formed.   
-       In this version, T only has bandwidth 2, the rest of it is zero. */
+/*     A unit triangular matrix T with condition CNDNUM is formed. */
+/*     In this version, T only has bandwidth 2, the rest of it is zero. */
 
     } else if (*imat <= 9) {
 	tnorm = sqrt(cndnum);
@@ -248,8 +266,8 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 	    }
 	}
 
-/*        Special case:  T is tridiagonal.  Set every other offdiagonal   
-          so that the matrix has norm TNORM+1. */
+/*        Special case:  T is tridiagonal.  Set every other offdiagonal */
+/*        so that the matrix has norm TNORM+1. */
 
 	if (*kd == 1) {
 	    if (upper) {
@@ -275,21 +293,21 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 	    }
 	} else if (*kd > 1) {
 
-/*           Form a unit triangular matrix T with condition CNDNUM.  T is   
-             given by   
-                     | 1   +   *                      |   
-                     |     1   +                      |   
-                 T = |         1   +   *              |   
-                     |             1   +              |   
-                     |                 1   +   *      |   
-                     |                     1   +      |   
-                     |                          . . . |   
-          Each element marked with a '*' is formed by taking the product   
-          of the adjacent elements marked with '+'.  The '*'s can be   
-          chosen freely, and the '+'s are chosen so that the inverse of   
-          T will have elements of the same magnitude as T.   
+/*           Form a unit triangular matrix T with condition CNDNUM.  T is */
+/*           given by */
+/*                   | 1   +   *                      | */
+/*                   |     1   +                      | */
+/*               T = |         1   +   *              | */
+/*                   |             1   +              | */
+/*                   |                 1   +   *      | */
+/*                   |                     1   +      | */
+/*                   |                          . . . | */
+/*        Each element marked with a '*' is formed by taking the product */
+/*        of the adjacent elements marked with '+'.  The '*'s can be */
+/*        chosen freely, and the '+'s are chosen so that the inverse of */
+/*        T will have elements of the same magnitude as T. */
 
-          The two offdiagonals of T are stored in WORK. */
+/*        The two offdiagonals of T are stored in WORK. */
 
 	    r__1 = slarnd_(&c__2, &iseed[1]);
 	    star1 = r_sign(&tnorm, &r__1);
@@ -306,8 +324,8 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 		    work[*n + j + 1] = 0.f;
 		    plus1 = star1 / plus2;
 
-/*                 Generate a new *-value with norm between sqrt(TNORM)   
-                   and TNORM. */
+/*                 Generate a new *-value with norm between sqrt(TNORM) */
+/*                 and TNORM. */
 
 		    rexp = slarnd_(&c__2, &iseed[1]);
 		    if (rexp < 0.f) {
@@ -340,15 +358,15 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 	    }
 	}
 
-/*     IMAT > 9:  Pathological test cases.  These triangular matrices   
-       are badly scaled or badly conditioned, so when used in solving a   
-       triangular system they may cause overflow in the solution vector. */
+/*     IMAT > 9:  Pathological test cases.  These triangular matrices */
+/*     are badly scaled or badly conditioned, so when used in solving a */
+/*     triangular system they may cause overflow in the solution vector. */
 
     } else if (*imat == 10) {
 
-/*        Type 10:  Generate a triangular matrix with elements between   
-          -1 and 1. Give the diagonal norm 2 to make it well-conditioned.   
-          Make the right hand side large so that it requires scaling. */
+/*        Type 10:  Generate a triangular matrix with elements between */
+/*        -1 and 1. Give the diagonal norm 2 to make it well-conditioned. */
+/*        Make the right hand side large so that it requires scaling. */
 
 	if (upper) {
 	    i__1 = *n;
@@ -386,9 +404,9 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 11) {
 
-/*        Type 11:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 11, the offdiagonal elements are small (CNORM(j) < 1). */
+/*        Type 11:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 11, the offdiagonal elements are small (CNORM(j) < 1). */
 
 	slarnv_(&c__2, &iseed[1], n, &b[1]);
 	tscal = 1.f / (real) (*kd + 1);
@@ -427,9 +445,9 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 12) {
 
-/*        Type 12:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 12, the offdiagonal elements are O(1) (CNORM(j) > 1). */
+/*        Type 12:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 12, the offdiagonal elements are O(1) (CNORM(j) > 1). */
 
 	slarnv_(&c__2, &iseed[1], n, &b[1]);
 	if (upper) {
@@ -460,9 +478,9 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 13) {
 
-/*        Type 13:  T is diagonal with small numbers on the diagonal to   
-          make the growth factor underflow, but a small right hand side   
-          chosen so that the solution does not overflow. */
+/*        Type 13:  T is diagonal with small numbers on the diagonal to */
+/*        make the growth factor underflow, but a small right hand side */
+/*        chosen so that the solution does not overflow. */
 
 	if (upper) {
 	    jcount = 1;
@@ -530,9 +548,9 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 14) {
 
-/*        Type 14:  Make the diagonal elements small to cause gradual   
-          overflow when dividing by T(j,j).  To control the amount of   
-          scaling needed, the matrix is bidiagonal. */
+/*        Type 14:  Make the diagonal elements small to cause gradual */
+/*        overflow when dividing by T(j,j).  To control the amount of */
+/*        scaling needed, the matrix is bidiagonal. */
 
 	texp = 1.f / (real) (*kd + 1);
 	d__1 = (doublereal) smlnum;
@@ -617,10 +635,10 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 16) {
 
-/*        Type 16:  Make the offdiagonal elements large to cause overflow   
-          when adding a column of T.  In the non-transposed case, the   
-          matrix is constructed to cause overflow when adding a column in   
-          every other step. */
+/*        Type 16:  Make the offdiagonal elements large to cause overflow */
+/*        when adding a column of T.  In the non-transposed case, the */
+/*        matrix is constructed to cause overflow when adding a column in */
+/*        every other step. */
 
 	tscal = unfl / ulp;
 	tscal = (1.f - ulp) / tscal;
@@ -711,9 +729,9 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 17) {
 
-/*        Type 17:  Generate a unit triangular matrix with elements   
-          between -1 and 1, and make the right hand side large so that it   
-          requires scaling. */
+/*        Type 17:  Generate a unit triangular matrix with elements */
+/*        between -1 and 1, and make the right hand side large so that it */
+/*        requires scaling. */
 
 	if (upper) {
 	    i__2 = *n;
@@ -750,11 +768,11 @@ static integer c__1 = 1; static real c_b36 = 2.f; static real c_b47 = 1.f; stati
 
     } else if (*imat == 18) {
 
-/*        Type 18:  Generate a triangular matrix with elements between   
-          BIGNUM/KD and BIGNUM so that at least one of the column   
-          norms will exceed BIGNUM.   
+/*        Type 18:  Generate a triangular matrix with elements between */
+/*        BIGNUM/KD and BIGNUM so that at least one of the column */
+/*        norms will exceed BIGNUM. */
 
-   Computing MAX */
+/* Computing MAX */
 	r__1 = 1.f, r__2 = (real) (*kd);
 	tleft = bignum / dmax(r__1,r__2);
 	tscal = bignum * ((real) (*kd) / (real) (*kd + 1));
