@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zchkaa.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -80,6 +68,7 @@ static integer c__6 = 6;
     /* System generated locals */
     integer i__1, i__2;
     doublereal d__1;
+    cilist ci__1;
     cllist cl__1;
 
     /* Builtin functions */
@@ -92,26 +81,26 @@ static integer c__6 = 6;
     integer f_clos(cllist *);
 
     /* Local variables */
-    static doublecomplex a[153384]	/* was [21912][7] */, b[8448]	/* 
-	    was [2112][4] */;
-    static integer i__, j, k;
-    static doublereal s[264];
-    static char c1[1], c2[2];
-    static doublereal s1, s2;
-    static integer ic, la, nb, nm, nn, vers_patch__, vers_major__, 
-	    vers_minor__, lda, nnb;
-    static doublereal eps;
-    static integer nns, nnb2;
-    static char path[3];
-    static integer mval[12], nval[12], nrhs;
-    static doublecomplex work[20856]	/* was [132][158] */;
-    static integer lafac;
-    static logical fatal;
-    static char aline[72];
+    doublecomplex a[153384]	/* was [21912][7] */, b[8448]	/* was [2112][
+	    4] */;
+    integer i__, j, k;
+    doublereal s[264];
+    char c1[1], c2[2];
+    doublereal s1, s2;
+    integer ic, la, nb, nm, nn, vers_patch__, vers_major__, vers_minor__, lda,
+	     nnb;
+    doublereal eps;
+    integer nns, nnb2;
+    char path[3];
+    integer mval[12], nval[12], nrhs;
+    doublecomplex work[20856]	/* was [132][158] */;
+    integer lafac;
+    logical fatal;
+    char aline[72];
     extern logical lsame_(char *, char *);
-    static integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
-    static doublereal rwork[19832];
-    static integer nbval2[12];
+    integer nbval[12], nmats, nsval[12], nxval[12], iwork[3300];
+    doublereal rwork[19832];
+    integer nbval2[12];
     extern /* Subroutine */ int zchkq3_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, doublereal 
 	    *, doublecomplex *, doublecomplex *, doublereal *, doublereal *, 
@@ -128,58 +117,58 @@ static integer c__6 = 6;
 	    integer *, integer *, integer *, integer *, integer *, doublereal 
 	    *, logical *, integer *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublereal *, integer *, integer *), zchkhe_(
+, doublecomplex *, doublereal *, integer *, integer *), zchkhe_(
 	    logical *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, integer *, 
+, doublecomplex *, doublecomplex *, doublereal *, integer *, 
 	    integer *);
     extern logical lsamen_(integer *, char *, char *);
     extern /* Subroutine */ int zchkpb_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, doublereal *, logical 
 	    *, integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublereal *, integer *), ilaver_(integer *, integer *, integer 
+, doublereal *, integer *), ilaver_(integer *, integer *, integer 
 	    *), zchkeq_(doublereal *, integer *), zchktb_(logical *, integer *
-	    , integer *, integer *, integer *, doublereal *, logical *, 
+, integer *, integer *, integer *, doublereal *, logical *, 
 	    integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublereal *, 
 	    integer *), zchkhp_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, integer *, 
+, doublecomplex *, doublecomplex *, doublereal *, integer *, 
 	    integer *), zchkgt_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublereal *, integer *, integer *), zchklq_(
+, doublecomplex *, doublereal *, integer *, integer *), zchklq_(
 	    logical *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, doublereal *, logical *, integer 
 	    *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublecomplex *, doublereal *,
+, doublecomplex *, doublecomplex *, doublecomplex *, doublereal *, 
 	     integer *, integer *);
-    static doublereal thresh;
+    doublereal thresh;
     extern /* Subroutine */ int zchkpo_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, doublereal *, logical 
 	    *, integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublereal *, integer *), zchkpp_(logical *, integer *, integer 
+, doublereal *, integer *), zchkpp_(logical *, integer *, integer 
 	    *, integer *, integer *, doublereal *, logical *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublecomplex *, doublereal *,
+, doublecomplex *, doublecomplex *, doublecomplex *, doublereal *, 
 	     integer *);
-    static logical tstchk;
+    logical tstchk;
     extern /* Subroutine */ int zchkql_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublecomplex *, 
+, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublereal *, integer *, 
 	    integer *), zchkpt_(logical *, integer *, integer *, integer *, 
-	    integer *, doublereal *, logical *, doublecomplex *, doublereal *,
+	    integer *, doublereal *, logical *, doublecomplex *, doublereal *, 
 	     doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex 
 	    *, doublecomplex *, doublereal *, integer *);
-    static logical dotype[30];
+    logical dotype[30];
     extern /* Subroutine */ int zchkqp_(logical *, integer *, integer *, 
 	    integer *, integer *, doublereal *, logical *, doublecomplex *, 
 	    doublecomplex *, doublereal *, doublereal *, doublecomplex *, 
@@ -188,29 +177,29 @@ static integer c__6 = 6;
 	    integer *, integer *, integer *, doublereal *, logical *, integer 
 	    *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublecomplex *, doublereal *,
+, doublecomplex *, doublecomplex *, doublecomplex *, doublereal *, 
 	     integer *, integer *), zchkrq_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublecomplex *, 
+, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublereal *, integer *, 
 	    integer *), zchksp_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, integer *, 
+, doublecomplex *, doublecomplex *, doublereal *, integer *, 
 	    integer *), zchktp_(logical *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublereal *, integer *), zchktr_(logical *, 
+, doublecomplex *, doublereal *, integer *), zchktr_(logical *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublereal *, integer *), zchksy_(logical *, 
+, doublecomplex *, doublereal *, integer *), zchksy_(logical *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, integer *, 
+, doublecomplex *, doublecomplex *, doublereal *, integer *, 
 	    integer *), zdrvgb_(logical *, integer *, integer *, integer *, 
 	    doublereal *, logical *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
@@ -222,52 +211,52 @@ static integer c__6 = 6;
 	    integer *), zdrvge_(logical *, integer *, integer *, integer *, 
 	    doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, doublecomplex *,
+, doublecomplex *, doublecomplex *, doublereal *, doublecomplex *, 
 	     doublereal *, integer *, integer *), zdrvhe_(logical *, integer *
-	    , integer *, integer *, doublereal *, logical *, integer *, 
+, integer *, integer *, doublereal *, logical *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublecomplex *, doublereal *,
+, doublecomplex *, doublecomplex *, doublecomplex *, doublereal *, 
 	     integer *, integer *), zdrvgt_(logical *, integer *, integer *, 
 	    integer *, doublereal *, logical *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublereal *, integer *, integer *), zdrvhp_(
+, doublecomplex *, doublereal *, integer *, integer *), zdrvhp_(
 	    logical *, integer *, integer *, integer *, doublereal *, logical 
 	    *, integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublereal *, integer *, integer *);
-    static integer ntypes;
-    static logical tsterr;
+, doublereal *, integer *, integer *);
+    integer ntypes;
+    logical tsterr;
     extern /* Subroutine */ int zdrvls_(logical *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, doublereal *, logical *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublereal *, doublereal *, doublecomplex *, doublereal *, 
+, doublereal *, doublereal *, doublecomplex *, doublereal *, 
 	    integer *, integer *);
-    static logical tstdrv;
+    logical tstdrv;
     extern /* Subroutine */ int zdrvpb_(logical *, integer *, integer *, 
 	    integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, doublecomplex *,
+, doublecomplex *, doublecomplex *, doublereal *, doublecomplex *, 
 	     doublereal *, integer *), zdrvpo_(logical *, integer *, integer *
-	    , integer *, doublereal *, logical *, integer *, doublecomplex *, 
+, integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, doublecomplex *,
+, doublecomplex *, doublecomplex *, doublereal *, doublecomplex *, 
 	     doublereal *, integer *), zdrvpp_(logical *, integer *, integer *
-	    , integer *, doublereal *, logical *, integer *, doublecomplex *, 
+, integer *, doublereal *, logical *, integer *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublecomplex *, doublereal *, doublecomplex *,
+, doublecomplex *, doublecomplex *, doublereal *, doublecomplex *, 
 	     doublereal *, integer *), zdrvpt_(logical *, integer *, integer *
-	    , integer *, doublereal *, logical *, doublecomplex *, doublereal 
+, integer *, doublereal *, logical *, doublecomplex *, doublereal 
 	    *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublereal *, integer *), 
 	    zdrvsp_(logical *, integer *, integer *, integer *, doublereal *, 
 	    logical *, integer *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublecomplex *, doublereal *, integer *, integer *), zdrvsy_(
+, doublecomplex *, doublereal *, integer *, integer *), zdrvsy_(
 	    logical *, integer *, integer *, integer *, doublereal *, logical 
 	    *, integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, doublecomplex *
-	    , doublereal *, integer *, integer *);
+, doublereal *, integer *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___6 = { 0, 5, 0, 0, 0 };
@@ -312,31 +301,31 @@ static integer c__6 = 6;
     static cilist io___67 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___68 = { 0, 6, 0, fmt_9991, 0 };
     static cilist io___69 = { 0, 6, 0, 0, 0 };
-    static cilist io___71 = { 0, 5, 1, "(A72)", 0 };
-    static cilist io___79 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___80 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___88 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___90 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___93 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___94 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___95 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___96 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___97 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___98 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___99 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___100 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___101 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___102 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___103 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___104 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___105 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___106 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___107 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___108 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___109 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___110 = { 0, 6, 0, fmt_9988, 0 };
-    static cilist io___111 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___112 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___78 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___79 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___87 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___89 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___92 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___93 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___94 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___95 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___96 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___97 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___98 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___99 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___100 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___101 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___102 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___103 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___104 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___105 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___106 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___107 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___108 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___109 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___110 = { 0, 6, 0, fmt_9989, 0 };
+    static cilist io___111 = { 0, 6, 0, fmt_9988, 0 };
+    static cilist io___112 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___113 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___114 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___115 = { 0, 6, 0, fmt_9989, 0 };
@@ -347,87 +336,105 @@ static integer c__6 = 6;
     static cilist io___120 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___121 = { 0, 6, 0, fmt_9989, 0 };
     static cilist io___122 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___123 = { 0, 6, 0, fmt_9989, 0 };
-    static cilist io___124 = { 0, 6, 0, fmt_9990, 0 };
-    static cilist io___126 = { 0, 6, 0, fmt_9998, 0 };
-    static cilist io___127 = { 0, 6, 0, fmt_9997, 0 };
+    static cilist io___123 = { 0, 6, 0, fmt_9990, 0 };
+    static cilist io___125 = { 0, 6, 0, fmt_9998, 0 };
+    static cilist io___126 = { 0, 6, 0, fmt_9997, 0 };
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZCHKAA is the main test program for the COMPLEX*16 linear equation   
-    routines.   
+/*  ZCHKAA is the main test program for the COMPLEX*16 linear equation */
+/*  routines. */
 
-    The program must be driven by a short data file. The first 14 records   
-    specify problem dimensions and program options using list-directed   
-    input.  The remaining lines specify the LAPACK test paths and the   
-    number of matrix types to use in testing.  An annotated example of a   
-    data file can be obtained by deleting the first 3 characters from the   
-    following 38 lines:   
-    Data file for testing COMPLEX*16 LAPACK linear equation routines   
-    7                      Number of values of M   
-    0 1 2 3 5 10 16        Values of M (row dimension)   
-    7                      Number of values of N   
-    0 1 2 3 5 10 16        Values of N (column dimension)   
-    1                      Number of values of NRHS   
-    2                      Values of NRHS (number of right hand sides)   
-    5                      Number of values of NB   
-    1 3 3 3 20             Values of NB (the blocksize)   
-    1 0 5 9 1              Values of NX (crossover point)   
-    30.0                   Threshold value of test ratio   
-    T                      Put T to test the LAPACK routines   
-    T                      Put T to test the driver routines   
-    T                      Put T to test the error exits   
-    ZGE   11               List types on next line if 0 < NTYPES < 11   
-    ZGB    8               List types on next line if 0 < NTYPES <  8   
-    ZGT   12               List types on next line if 0 < NTYPES < 12   
-    ZPO    9               List types on next line if 0 < NTYPES <  9   
-    ZPP    9               List types on next line if 0 < NTYPES <  9   
-    ZPB    8               List types on next line if 0 < NTYPES <  8   
-    ZPT   12               List types on next line if 0 < NTYPES < 12   
-    ZHE   10               List types on next line if 0 < NTYPES < 10   
-    ZHP   10               List types on next line if 0 < NTYPES < 10   
-    ZSY   11               List types on next line if 0 < NTYPES < 11   
-    ZSP   11               List types on next line if 0 < NTYPES < 11   
-    ZTR   18               List types on next line if 0 < NTYPES < 18   
-    ZTP   18               List types on next line if 0 < NTYPES < 18   
-    ZTB   17               List types on next line if 0 < NTYPES < 17   
-    ZQR    8               List types on next line if 0 < NTYPES <  8   
-    ZRQ    8               List types on next line if 0 < NTYPES <  8   
-    ZLQ    8               List types on next line if 0 < NTYPES <  8   
-    ZQL    8               List types on next line if 0 < NTYPES <  8   
-    ZQP    6               List types on next line if 0 < NTYPES <  6   
-    ZTZ    3               List types on next line if 0 < NTYPES <  3   
-    ZLS    6               List types on next line if 0 < NTYPES <  6   
-    ZEQ   
+/*  The program must be driven by a short data file. The first 14 records */
+/*  specify problem dimensions and program options using list-directed */
+/*  input.  The remaining lines specify the LAPACK test paths and the */
+/*  number of matrix types to use in testing.  An annotated example of a */
+/*  data file can be obtained by deleting the first 3 characters from the */
+/*  following 38 lines: */
+/*  Data file for testing COMPLEX*16 LAPACK linear equation routines */
+/*  7                      Number of values of M */
+/*  0 1 2 3 5 10 16        Values of M (row dimension) */
+/*  7                      Number of values of N */
+/*  0 1 2 3 5 10 16        Values of N (column dimension) */
+/*  1                      Number of values of NRHS */
+/*  2                      Values of NRHS (number of right hand sides) */
+/*  5                      Number of values of NB */
+/*  1 3 3 3 20             Values of NB (the blocksize) */
+/*  1 0 5 9 1              Values of NX (crossover point) */
+/*  30.0                   Threshold value of test ratio */
+/*  T                      Put T to test the LAPACK routines */
+/*  T                      Put T to test the driver routines */
+/*  T                      Put T to test the error exits */
+/*  ZGE   11               List types on next line if 0 < NTYPES < 11 */
+/*  ZGB    8               List types on next line if 0 < NTYPES <  8 */
+/*  ZGT   12               List types on next line if 0 < NTYPES < 12 */
+/*  ZPO    9               List types on next line if 0 < NTYPES <  9 */
+/*  ZPP    9               List types on next line if 0 < NTYPES <  9 */
+/*  ZPB    8               List types on next line if 0 < NTYPES <  8 */
+/*  ZPT   12               List types on next line if 0 < NTYPES < 12 */
+/*  ZHE   10               List types on next line if 0 < NTYPES < 10 */
+/*  ZHP   10               List types on next line if 0 < NTYPES < 10 */
+/*  ZSY   11               List types on next line if 0 < NTYPES < 11 */
+/*  ZSP   11               List types on next line if 0 < NTYPES < 11 */
+/*  ZTR   18               List types on next line if 0 < NTYPES < 18 */
+/*  ZTP   18               List types on next line if 0 < NTYPES < 18 */
+/*  ZTB   17               List types on next line if 0 < NTYPES < 17 */
+/*  ZQR    8               List types on next line if 0 < NTYPES <  8 */
+/*  ZRQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  ZLQ    8               List types on next line if 0 < NTYPES <  8 */
+/*  ZQL    8               List types on next line if 0 < NTYPES <  8 */
+/*  ZQP    6               List types on next line if 0 < NTYPES <  6 */
+/*  ZTZ    3               List types on next line if 0 < NTYPES <  3 */
+/*  ZLS    6               List types on next line if 0 < NTYPES <  6 */
+/*  ZEQ */
 
-    Internal Parameters   
-    ===================   
+/*  Internal Parameters */
+/*  =================== */
 
-    NMAX    INTEGER   
-            The maximum allowable value for N.   
+/*  NMAX    INTEGER */
+/*          The maximum allowable value for N. */
 
-    MAXIN   INTEGER   
-            The number of different values that can be used for each of   
-            M, N, or NB   
+/*  MAXIN   INTEGER */
+/*          The number of different values that can be used for each of */
+/*          M, N, or NB */
 
-    MAXRHS  INTEGER   
-            The maximum number of right hand sides   
+/*  MAXRHS  INTEGER */
+/*          The maximum number of right hand sides */
 
-    NIN     INTEGER   
-            The unit number for input   
+/*  NIN     INTEGER */
+/*          The unit number for input */
 
-    NOUT    INTEGER   
-            The unit number for output   
+/*  NOUT    INTEGER */
+/*          The unit number for output */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Arrays in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s1 = dsecnd_();
     lda = 132;
@@ -778,7 +785,11 @@ L80:
 
 /*     Read a test path and the number of matrix types to use. */
 
-    i__1 = s_rsfe(&io___71);
+    ci__1.cierr = 0;
+    ci__1.ciend = 1;
+    ci__1.ciunit = 5;
+    ci__1.cifmt = "(A72)";
+    i__1 = s_rsfe(&ci__1);
     if (i__1 != 0) {
 	goto L140;
     }
@@ -826,7 +837,7 @@ L130:
 /*     Check first character for correct precision. */
 
     if (! lsame_(c1, "Zomplex precision")) {
-	s_wsfe(&io___79);
+	s_wsfe(&io___78);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -834,7 +845,7 @@ L130:
 
 /*        Check for a positive number of tests requested. */
 
-	s_wsfe(&io___80);
+	s_wsfe(&io___79);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
 
@@ -850,7 +861,7 @@ L130:
 		    &thresh, &tsterr, &lda, a, &a[21912], &a[43824], b, &b[
 		    2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___88);
+	    s_wsfe(&io___87);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -860,7 +871,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___90);
+	    s_wsfe(&io___89);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -879,7 +890,7 @@ L130:
 		    &thresh, &tsterr, a, &la, &a[43824], &lafac, b, &b[2112], 
 		    &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___93);
+	    s_wsfe(&io___92);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -889,7 +900,7 @@ L130:
 		    43824], &lafac, &a[109560], b, &b[2112], &b[4224], &b[
 		    6336], s, work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___94);
+	    s_wsfe(&io___93);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -905,7 +916,7 @@ L130:
 	    zchkgt_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, a, &a[
 		    21912], b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___95);
+	    s_wsfe(&io___94);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -914,7 +925,7 @@ L130:
 	    zdrvgt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, &a[21912], 
 		    b, &b[2112], &b[4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___96);
+	    s_wsfe(&io___95);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -931,7 +942,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___97);
+	    s_wsfe(&io___96);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -941,7 +952,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___98);
+	    s_wsfe(&io___97);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -954,11 +965,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    zchkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    zchkpp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     &c__6);
 	} else {
-	    s_wsfe(&io___99);
+	    s_wsfe(&io___98);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -968,7 +979,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___100);
+	    s_wsfe(&io___99);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -985,7 +996,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___101);
+	    s_wsfe(&io___100);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -995,7 +1006,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], &b[6336], s, 
 		    work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___102);
+	    s_wsfe(&io___101);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1011,7 +1022,7 @@ L130:
 	    zchkpt_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, a, s, &
 		    a[21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___103);
+	    s_wsfe(&io___102);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1020,7 +1031,7 @@ L130:
 	    zdrvpt_(dotype, &nn, nval, &nrhs, &thresh, &tsterr, a, s, &a[
 		    21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___104);
+	    s_wsfe(&io___103);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1037,7 +1048,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___105);
+	    s_wsfe(&io___104);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1047,7 +1058,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___106);
+	    s_wsfe(&io___105);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1060,11 +1071,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    zchkhp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    zchkhp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___107);
+	    s_wsfe(&io___106);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1074,7 +1085,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___108);
+	    s_wsfe(&io___107);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1091,7 +1102,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], &a[43824], b, &b[2112], &b[
 		    4224], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___109);
+	    s_wsfe(&io___108);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1101,7 +1112,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___110);
+	    s_wsfe(&io___109);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1114,11 +1125,11 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    zchksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
-		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork,
+	    zchksp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
+		     &a[21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		     iwork, &c__6);
 	} else {
-	    s_wsfe(&io___111);
+	    s_wsfe(&io___110);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1128,7 +1139,7 @@ L130:
 		    21912], &a[43824], b, &b[2112], &b[4224], work, rwork, 
 		    iwork, &c__6);
 	} else {
-	    s_wsfe(&io___112);
+	    s_wsfe(&io___111);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1145,7 +1156,7 @@ L130:
 		    tsterr, &lda, a, &a[21912], b, &b[2112], &b[4224], work, 
 		    rwork, &c__6);
 	} else {
-	    s_wsfe(&io___113);
+	    s_wsfe(&io___112);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1158,10 +1169,10 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    zchktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    zchktp_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___114);
+	    s_wsfe(&io___113);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1174,10 +1185,10 @@ L130:
 	alareq_(path, &nmats, dotype, &ntypes, &c__5, &c__6);
 
 	if (tstchk) {
-	    zchktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a,
+	    zchktb_(dotype, &nn, nval, &nns, nsval, &thresh, &tsterr, &lda, a, 
 		     &a[21912], b, &b[2112], &b[4224], work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___115);
+	    s_wsfe(&io___114);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1195,7 +1206,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___116);
+	    s_wsfe(&io___115);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1213,7 +1224,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___117);
+	    s_wsfe(&io___116);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1231,7 +1242,7 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___118);
+	    s_wsfe(&io___117);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1249,20 +1260,20 @@ L130:
 		    65736], &a[87648], b, &b[2112], &b[4224], &b[6336], work, 
 		    rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___119);
+	    s_wsfe(&io___118);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else if (lsamen_(&c__2, c2, "EQ")) {
 
-/*        EQ:  Equilibration routines for general and positive definite   
-               matrices (THREQ should be between 2 and 10) */
+/*        EQ:  Equilibration routines for general and positive definite */
+/*             matrices (THREQ should be between 2 and 10) */
 
 	if (tstchk) {
 	    zchkeq_(&threq, &c__6);
 	} else {
-	    s_wsfe(&io___120);
+	    s_wsfe(&io___119);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1278,7 +1289,7 @@ L130:
 	    zchktz_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], s, &s[132], b, work, rwork, &c__6);
 	} else {
-	    s_wsfe(&io___121);
+	    s_wsfe(&io___120);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1293,10 +1304,10 @@ L130:
 	if (tstchk) {
 	    zchkqp_(dotype, &nm, mval, &nn, nval, &thresh, &tsterr, a, &a[
 		    21912], s, &s[132], b, work, rwork, iwork, &c__6);
-	    zchkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh,
+	    zchkq3_(dotype, &nm, mval, &nn, nval, &nnb, nbval, nxval, &thresh, 
 		     a, &a[21912], s, &s[132], b, work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___122);
+	    s_wsfe(&io___121);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
@@ -1313,14 +1324,14 @@ L130:
 		    nxval, &thresh, &tsterr, a, &a[21912], &a[43824], &a[
 		    65736], &a[87648], s, &s[132], work, rwork, iwork, &c__6);
 	} else {
-	    s_wsfe(&io___123);
+	    s_wsfe(&io___122);
 	    do_fio(&c__1, path, (ftnlen)3);
 	    e_wsfe();
 	}
 
     } else {
 
-	s_wsfe(&io___124);
+	s_wsfe(&io___123);
 	do_fio(&c__1, path, (ftnlen)3);
 	e_wsfe();
     }
@@ -1337,9 +1348,9 @@ L140:
     cl__1.csta = 0;
     f_clos(&cl__1);
     s2 = dsecnd_();
-    s_wsfe(&io___126);
+    s_wsfe(&io___125);
     e_wsfe();
-    s_wsfe(&io___127);
+    s_wsfe(&io___126);
     d__1 = s2 - s1;
     do_fio(&c__1, (char *)&d__1, (ftnlen)sizeof(doublereal));
     e_wsfe();
@@ -1348,6 +1359,6 @@ L140:
 /*     End of ZCHKAA */
 
     return 0;
-} /* MAIN__   
+} /* MAIN__ */
 
-   Main program alias */ int zchkaa_ () { MAIN__ (); return 0; }
+/* Main program alias */ int zchkaa_ () { MAIN__ (); return 0; }
