@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zchkeq.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -42,35 +30,35 @@ static integer c__1 = 1;
     doublereal d__1, d__2, d__3;
     doublecomplex z__1;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double pow_di(doublereal *, integer *);
     integer pow_ii(integer *, integer *), s_wsle(cilist *), e_wsle(void), 
 	    s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublecomplex a[25]	/* was [5][5] */;
-    static doublereal c__[5];
-    static integer i__, j, m, n;
-    static doublereal r__[5];
-    static doublecomplex ab[65]	/* was [13][5] */, ap[15];
-    static integer kl;
-    static logical ok;
-    static integer ku;
-    static doublereal eps, pow[11];
-    static integer info;
-    static char path[3];
-    static doublereal norm, rpow[11], ccond, rcond, rcmin, rcmax, ratio;
+    doublecomplex a[25]	/* was [5][5] */;
+    doublereal c__[5];
+    integer i__, j, m, n;
+    doublereal r__[5];
+    doublecomplex ab[65]	/* was [13][5] */, ap[15];
+    integer kl;
+    logical ok;
+    integer ku;
+    doublereal eps, pow[11];
+    integer info;
+    char path[3];
+    doublereal norm, rpow[11], ccond, rcond, rcmin, rcmax, ratio;
     extern doublereal dlamch_(char *);
     extern /* Subroutine */ int zgbequ_(integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, integer *), zgeequ_(
 	    integer *, integer *, doublecomplex *, integer *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, integer *)
 	    , zpbequ_(char *, integer *, integer *, doublecomplex *, integer *
-	    , doublereal *, doublereal *, doublereal *, integer *);
-    static doublereal reslts[5];
-    extern /* Subroutine */ int zpoequ_(integer *, doublecomplex *, integer *,
+, doublereal *, doublereal *, doublereal *, integer *);
+    doublereal reslts[5];
+    extern /* Subroutine */ int zpoequ_(integer *, doublecomplex *, integer *, 
 	     doublereal *, doublereal *, doublereal *, integer *), zppequ_(
 	    char *, integer *, doublecomplex *, doublereal *, doublereal *, 
 	    doublereal *, integer *);
@@ -86,27 +74,42 @@ static integer c__1 = 1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZCHKEQ tests ZGEEQU, ZGBEQU, ZPOEQU, ZPPEQU and ZPBEQU   
+/*  ZCHKEQ tests ZGEEQU, ZGBEQU, ZPOEQU, ZPPEQU and ZPBEQU */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    THRESH  (input) DOUBLE PRECISION   
-            Threshold for testing routines. Should be between 2 and 10.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          Threshold for testing routines. Should be between 2 and 10. */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Zomplex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "EQ", (ftnlen)2, (ftnlen)2);
@@ -392,7 +395,11 @@ static integer c__1 = 1;
 		d__2 = reslts[2], d__3 = (d__1 = (norm - pow[n * 2]) / pow[n *
 			 2], abs(d__1));
 		reslts[2] = max(d__2,d__3);
-		i__1 = n; 		for (i__ = 1; i__ <= i__1; ++i__) { /* Computing MAX */ 		    d__2 = reslts[2], d__3 = (d__1 = (r__[i__ - 1] - rpow[i__] 			    ) / rpow[i__], abs(d__1));
+		i__1 = n;
+		for (i__ = 1; i__ <= i__1; ++i__) {
+/* Computing MAX */
+		    d__2 = reslts[2], d__3 = (d__1 = (r__[i__ - 1] - rpow[i__]
+			    ) / rpow[i__], abs(d__1));
 		    reslts[2] = max(d__2,d__3);
 /* L280: */
 		}
@@ -442,7 +449,11 @@ static integer c__1 = 1;
 		d__2 = reslts[3], d__3 = (d__1 = (norm - pow[n * 2]) / pow[n *
 			 2], abs(d__1));
 		reslts[3] = max(d__2,d__3);
-		i__1 = n; 		for (i__ = 1; i__ <= i__1; ++i__) { /* Computing MAX */ 		    d__2 = reslts[3], d__3 = (d__1 = (r__[i__ - 1] - rpow[i__] 			    ) / rpow[i__], abs(d__1));
+		i__1 = n;
+		for (i__ = 1; i__ <= i__1; ++i__) {
+/* Computing MAX */
+		    d__2 = reslts[3], d__3 = (d__1 = (r__[i__ - 1] - rpow[i__]
+			    ) / rpow[i__], abs(d__1));
 		    reslts[3] = max(d__2,d__3);
 /* L320: */
 		}
@@ -481,7 +492,11 @@ static integer c__1 = 1;
 		d__2 = reslts[3], d__3 = (d__1 = (norm - pow[n * 2]) / pow[n *
 			 2], abs(d__1));
 		reslts[3] = max(d__2,d__3);
-		i__1 = n; 		for (i__ = 1; i__ <= i__1; ++i__) { /* Computing MAX */ 		    d__2 = reslts[3], d__3 = (d__1 = (r__[i__ - 1] - rpow[i__] 			    ) / rpow[i__], abs(d__1));
+		i__1 = n;
+		for (i__ = 1; i__ <= i__1; ++i__) {
+/* Computing MAX */
+		    d__2 = reslts[3], d__3 = (d__1 = (r__[i__ - 1] - rpow[i__]
+			    ) / rpow[i__], abs(d__1));
 		    reslts[3] = max(d__2,d__3);
 /* L350: */
 		}
