@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zchkpt.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -40,7 +28,7 @@ static integer c__7 = 7;
 
 /* Subroutine */ int zchkpt_(logical *dotype, integer *nn, integer *nval, 
 	integer *nns, integer *nsval, doublereal *thresh, logical *tsterr, 
-	doublecomplex *a, doublereal *d__, doublecomplex *e, doublecomplex *b,
+	doublecomplex *a, doublereal *d__, doublecomplex *e, doublecomplex *b, 
 	 doublecomplex *x, doublecomplex *xact, doublecomplex *work, 
 	doublereal *rwork, integer *nout)
 {
@@ -60,36 +48,40 @@ static integer c__7 = 7;
     integer i__1, i__2, i__3, i__4, i__5;
     doublereal d__1, d__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double z_abs(doublecomplex *);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n;
-    static doublecomplex z__[3];
-    static integer ia, in, kl, ku, ix, lda;
-    static doublereal cond;
-    static integer mode;
-    static doublereal dmax__;
-    static integer imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char uplo[1], type__[1];
-    static integer nrun;
+    integer i__, j, k, n;
+    doublecomplex z__[3];
+    integer ia, in, kl, ku, ix, lda;
+    doublereal cond;
+    integer mode;
+    doublereal dmax__;
+    integer imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char uplo[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *), dscal_(
 	    integer *, doublereal *, doublereal *, integer *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern doublereal dget06_(doublereal *, doublereal *);
-    static doublereal rcond;
-    static integer nimat;     static doublereal anorm;     extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *, 	     integer *, doublecomplex *, integer *, doublereal *, doublereal * 	    ), dcopy_(integer *, doublereal *, integer *, doublereal *, 
+    doublereal rcond;
+    integer nimat;
+    doublereal anorm;
+    extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *, 
+	     integer *, doublecomplex *, integer *, doublereal *, doublereal *
+), dcopy_(integer *, doublereal *, integer *, doublereal *, 
 	    integer *);
-    static integer iuplo, izero, nerrs;
-    static logical zerot;
+    integer iuplo, izero, nerrs;
+    logical zerot;
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), zptt01_(integer *, doublereal *, 
 	    doublecomplex *, doublereal *, doublecomplex *, doublecomplex *, 
-	    doublereal *), zptt02_(char *, integer *, integer *, doublereal *,
+	    doublereal *), zptt02_(char *, integer *, integer *, doublereal *, 
 	     doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublereal *), zptt05_(integer *, integer *, 
 	    doublereal *, doublecomplex *, doublecomplex *, integer *, 
@@ -100,13 +92,14 @@ static integer c__7 = 7;
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *);
     extern integer idamax_(integer *, doublereal *, integer *);
-    static doublereal rcondc;
+    doublereal rcondc;
     extern /* Subroutine */ int zdscal_(integer *, doublereal *, 
-	    doublecomplex *, integer *), alasum_(char *, integer *, integer *,
+	    doublecomplex *, integer *), alasum_(char *, integer *, integer *, 
 	     integer *, integer *), dlarnv_(integer *, integer *, 
 	    integer *, doublereal *);
-    static doublereal ainvnm;
-    extern doublereal zlanht_(char *, integer *, doublereal *, doublecomplex * );
+    doublereal ainvnm;
+    extern doublereal zlanht_(char *, integer *, doublereal *, doublecomplex *
+);
     extern /* Subroutine */ int zlacpy_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
     extern doublereal dzasum_(integer *, doublecomplex *, integer *);
@@ -118,12 +111,12 @@ static integer c__7 = 7;
 	    integer *, char *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *), zlarnv_(integer *, integer *, 
 	    integer *, doublecomplex *), zerrgt_(char *, integer *);
-    static doublereal result[7];
+    doublereal result[7];
     extern /* Subroutine */ int zptcon_(integer *, doublereal *, 
 	    doublecomplex *, doublereal *, doublereal *, doublereal *, 
 	    integer *), zptrfs_(char *, integer *, integer *, doublereal *, 
 	    doublecomplex *, doublereal *, doublecomplex *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublecomplex *, doublereal *, integer *), zpttrf_(
 	    integer *, doublereal *, doublecomplex *, integer *), zpttrs_(
 	    char *, integer *, integer *, doublereal *, doublecomplex *, 
@@ -136,69 +129,90 @@ static integer c__7 = 7;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZCHKPT tests ZPTTRF, -TRS, -RFS, and -CON   
+/*  ZCHKPT tests ZPTTRF, -TRS, -RFS, and -CON */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) COMPLEX*16 array, dimension (NMAX*2)   
+/*  A       (workspace) COMPLEX*16 array, dimension (NMAX*2) */
 
-    D       (workspace) DOUBLE PRECISION array, dimension (NMAX*2)   
+/*  D       (workspace) DOUBLE PRECISION array, dimension (NMAX*2) */
 
-    E       (workspace) COMPLEX*16 array, dimension (NMAX*2)   
+/*  E       (workspace) COMPLEX*16 array, dimension (NMAX*2) */
 
-    B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*max(3,NSMAX))   
+/*  WORK    (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*max(3,NSMAX)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension   
-                        (max(NMAX,2*NSMAX))   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (max(NMAX,2*NSMAX)) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --rwork;
     --work;
     --xact;
@@ -212,6 +226,8 @@ static integer c__7 = 7;
     --dotype;
 
     /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
     s_copy(path, "Zomplex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "PT", (ftnlen)2, (ftnlen)2);
@@ -259,8 +275,8 @@ static integer c__7 = 7;
 	    zerot = imat >= 8 && imat <= 10;
 	    if (imat <= 6) {
 
-/*              Type 1-6:  generate a Hermitian tridiagonal matrix of   
-                known condition number in lower triangular band storage. */
+/*              Type 1-6:  generate a Hermitian tridiagonal matrix of */
+/*              known condition number in lower triangular band storage. */
 
 		s_copy(srnamc_1.srnamt, "ZLATMS", (ftnlen)6, (ftnlen)6);
 		zlatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode, &cond, 
@@ -294,8 +310,8 @@ static integer c__7 = 7;
 		}
 	    } else {
 
-/*              Type 7-12:  generate a diagonally dominant matrix with   
-                unknown condition number in the vectors D and E. */
+/*              Type 7-12:  generate a diagonally dominant matrix with */
+/*              unknown condition number in the vectors D and E. */
 
 		if (! zerot || ! dotype[7]) {
 
@@ -333,8 +349,8 @@ static integer c__7 = 7;
 
 		} else if (izero > 0) {
 
-/*                 Reuse the last matrix by copying back the zeroed out   
-                   elements. */
+/*                 Reuse the last matrix by copying back the zeroed out */
+/*                 elements. */
 
 		    if (izero == 1) {
 			d__[1] = z__[1].r;
@@ -356,8 +372,8 @@ static integer c__7 = 7;
 		    }
 		}
 
-/*              For types 8-10, set one row and column of the matrix to   
-                zero. */
+/*              For types 8-10, set one row and column of the matrix to */
+/*              zero. */
 
 		izero = 0;
 		if (imat == 8) {
@@ -403,9 +419,9 @@ static integer c__7 = 7;
 		zcopy_(&i__3, &e[1], &c__1, &e[n + 1], &c__1);
 	    }
 
-/* +    TEST 1   
-             Factor A as L*D*L' and compute the ratio   
-                norm(L*D*L' - A) / (n * norm(A) * EPS ) */
+/* +    TEST 1 */
+/*           Factor A as L*D*L' and compute the ratio */
+/*              norm(L*D*L' - A) / (n * norm(A) * EPS ) */
 
 	    zpttrf_(&n, &d__[n + 1], &e[n + 1], &info);
 
@@ -442,14 +458,14 @@ static integer c__7 = 7;
 	    }
 	    ++nrun;
 
-/*           Compute RCONDC = 1 / (norm(A) * norm(inv(A))   
+/*           Compute RCONDC = 1 / (norm(A) * norm(inv(A)) */
 
-             Compute norm(A). */
+/*           Compute norm(A). */
 
 	    anorm = zlanht_("1", &n, &d__[1], &e[1]);
 
-/*           Use ZPTTRS to solve for one column at a time of inv(A),   
-             computing the maximum column sum as we go. */
+/*           Use ZPTTRS to solve for one column at a time of inv(A), */
+/*           computing the maximum column sum as we go. */
 
 	    ainvnm = 0.;
 	    i__3 = n;
@@ -496,11 +512,11 @@ static integer c__7 = 7;
 
 /*              Set the right hand side. */
 
-		    zlaptm_(uplo, &n, &nrhs, &c_b48, &d__[1], &e[1], &xact[1],
+		    zlaptm_(uplo, &n, &nrhs, &c_b48, &d__[1], &e[1], &xact[1], 
 			     &lda, &c_b49, &b[1], &lda);
 
-/* +    TEST 2   
-                Solve A*x = b and compute the residual. */
+/* +    TEST 2 */
+/*              Solve A*x = b and compute the residual. */
 
 		    zlacpy_("Full", &n, &nrhs, &b[1], &lda, &x[1], &lda);
 		    zpttrs_(uplo, &n, &nrhs, &d__[n + 1], &e[n + 1], &x[1], &
@@ -518,20 +534,20 @@ static integer c__7 = 7;
 		    zptt02_(uplo, &n, &nrhs, &d__[1], &e[1], &x[1], &lda, &
 			    work[1], &lda, &result[1]);
 
-/* +    TEST 3   
-                Check solution from generated exact solution. */
+/* +    TEST 3 */
+/*              Check solution from generated exact solution. */
 
 		    zget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &rcondc, &
 			    result[2]);
 
-/* +    TESTS 4, 5, and 6   
-                Use iterative refinement to improve the solution. */
+/* +    TESTS 4, 5, and 6 */
+/*              Use iterative refinement to improve the solution. */
 
 		    s_copy(srnamc_1.srnamt, "ZPTRFS", (ftnlen)6, (ftnlen)6);
 		    zptrfs_(uplo, &n, &nrhs, &d__[1], &e[1], &d__[n + 1], &e[
 			    n + 1], &b[1], &lda, &x[1], &lda, &rwork[1], &
 			    rwork[nrhs + 1], &work[1], &rwork[(nrhs << 1) + 1]
-			    , &info);
+, &info);
 
 /*              Check error code from ZPTRFS. */
 
@@ -547,8 +563,8 @@ static integer c__7 = 7;
 			    lda, &xact[1], &lda, &rwork[1], &rwork[nrhs + 1], 
 			    &result[4]);
 
-/*              Print information about the tests that did not pass the   
-                threshold. */
+/*              Print information about the tests that did not pass the */
+/*              threshold. */
 
 		    for (k = 2; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
@@ -580,9 +596,9 @@ static integer c__7 = 7;
 /* L90: */
 	    }
 
-/* +    TEST 7   
-             Estimate the reciprocal of the condition number of the   
-             matrix. */
+/* +    TEST 7 */
+/*           Estimate the reciprocal of the condition number of the */
+/*           matrix. */
 
 L100:
 	    s_copy(srnamc_1.srnamt, "ZPTCON", (ftnlen)6, (ftnlen)6);
