@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zchksy.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -61,67 +49,72 @@ static integer c__8 = 8;
     /* System generated locals */
     integer i__1, i__2, i__3, i__4, i__5;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, nb, in, kl, ku, nt, lda, inb, ioff, 
-	    mode, imat, info;
-    static char path[3], dist[1];
-    static integer irhs, nrhs;
-    static char uplo[1], type__[1];
-    static integer nrun;
+    integer i__, j, k, n, i1, i2, nb, in, kl, ku, nt, lda, inb, ioff, mode, 
+	    imat, info;
+    char path[3], dist[1];
+    integer irhs, nrhs;
+    char uplo[1], type__[1];
+    integer nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer nfail, iseed[4];
+    integer nfail, iseed[4];
     extern doublereal dget06_(doublereal *, doublereal *);
-    static doublereal rcond;
-    static integer nimat;
-    static doublereal anorm;
-    extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *,
-	     integer *, doublecomplex *, integer *, doublereal *, doublereal * );
-    static integer iuplo, izero, nerrs, lwork;
+    doublereal rcond;
+    integer nimat;
+    doublereal anorm;
+    extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *, 
+	     integer *, doublecomplex *, integer *, doublereal *, doublereal *
+);
+    integer iuplo, izero, nerrs, lwork;
     extern /* Subroutine */ int zpot05_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublereal *);
-    static logical zerot;
-    static char xtype[1];
+    logical zerot;
+    char xtype[1];
     extern /* Subroutine */ int zsyt01_(char *, integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, integer *, doublecomplex *, 	     integer *, doublereal *, doublereal *), zsyt02_(char *,  	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 	     integer *, doublecomplex *, integer *, doublereal *, doublereal * 	    ), zsyt03_(char *, integer *, doublecomplex *, integer *, 
+	    integer *, doublecomplex *, integer *, integer *, doublecomplex *, 
+	     integer *, doublereal *, doublereal *), zsyt02_(char *, 
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
+	     integer *, doublecomplex *, integer *, doublereal *, doublereal *
+), zsyt03_(char *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
-	    doublereal *, doublereal *, doublereal *), zlatb4_(char *,
+	    doublereal *, doublereal *, doublereal *), zlatb4_(char *, 
 	     integer *, integer *, integer *, char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, char *), alaerh_(char *, char *, integer *, integer *, char *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *);
-    static doublereal rcondc;
+    doublereal rcondc;
     extern /* Subroutine */ int alasum_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static doublereal cndnum;
-    static logical trfcon;
-    extern /* Subroutine */ int xlaenv_(integer *, integer *), zlacpy_(char *,
+    doublereal cndnum;
+    logical trfcon;
+    extern /* Subroutine */ int xlaenv_(integer *, integer *), zlacpy_(char *, 
 	     integer *, integer *, doublecomplex *, integer *, doublecomplex *
-	    , integer *), zlarhs_(char *, char *, char *, char *, 
+, integer *), zlarhs_(char *, char *, char *, char *, 
 	    integer *, integer *, integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, integer *, integer *), zlatms_(integer *, integer *, char *, integer *, 
 	    char *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, char *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
-    static doublereal result[8];
+    doublereal result[8];
     extern doublereal zlansy_(char *, char *, integer *, doublecomplex *, 
 	    integer *, doublereal *);
     extern /* Subroutine */ int zsycon_(char *, integer *, doublecomplex *, 
-	    integer *, integer *, doublereal *, doublereal *, doublecomplex *,
+	    integer *, integer *, doublereal *, doublereal *, doublecomplex *, 
 	     integer *), zlatsy_(char *, integer *, doublecomplex *, 
 	    integer *, integer *), zerrsy_(char *, integer *),
-	     zsyrfs_(char *, integer *, integer *, doublecomplex *, integer *,
+	     zsyrfs_(char *, integer *, integer *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, integer *, doublecomplex *, integer *
-	    , doublecomplex *, integer *, doublereal *, doublereal *, 
-	    doublecomplex *, doublereal *, integer *), zsytrf_(char *,
+, doublecomplex *, integer *, doublereal *, doublereal *, 
+	    doublecomplex *, doublereal *, integer *), zsytrf_(char *, 
 	     integer *, doublecomplex *, integer *, integer *, doublecomplex *
-	    , integer *, integer *), zsytri_(char *, integer *, 
+, integer *, integer *), zsytri_(char *, integer *, 
 	    doublecomplex *, integer *, integer *, doublecomplex *, integer *), zsytrs_(char *, integer *, integer *, doublecomplex *, 
 	    integer *, integer *, doublecomplex *, integer *, integer *);
 
@@ -132,81 +125,102 @@ static integer c__8 = 8;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZCHKSY tests ZSYTRF, -TRI, -TRS, -RFS, and -CON.   
+/*  ZCHKSY tests ZSYTRF, -TRI, -TRS, -RFS, and -CON. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB contained in the vector NBVAL.   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB contained in the vector NBVAL. */
 
-    NBVAL   (input) INTEGER array, dimension (NBVAL)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NBVAL) */
+/*          The values of the blocksize NB. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)   
+/*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX) */
 
-    AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)   
+/*  AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX) */
 
-    AINV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)   
+/*  AINV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX) */
 
-    B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)   
-            where NSMAX is the largest entry in NSVAL.   
+/*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX) */
+/*          where NSMAX is the largest entry in NSVAL. */
 
-    X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)   
+/*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX) */
 
-    XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)   
+/*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX) */
 
-    WORK    (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*max(2,NSMAX))   
+/*  WORK    (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*max(2,NSMAX)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array,   
-                                   dimension (NMAX+2*NSMAX)   
+/*  RWORK   (workspace) DOUBLE PRECISION array, */
+/*                                 dimension (NMAX+2*NSMAX) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -221,9 +235,11 @@ static integer c__8 = 8;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Zomplex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "SY", (ftnlen)2, (ftnlen)2);
@@ -278,8 +294,8 @@ static integer c__8 = 8;
 
 		if (imat != 11) {
 
-/*                 Set up parameters with ZLATB4 and generate a test   
-                   matrix with ZLATMS. */
+/*                 Set up parameters with ZLATB4 and generate a test */
+/*                 matrix with ZLATMS. */
 
 		    zlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &
 			    mode, &cndnum, dist);
@@ -298,8 +314,8 @@ static integer c__8 = 8;
 			goto L160;
 		    }
 
-/*                 For types 3-6, zero one or more rows and columns of   
-                   the matrix to test that INFO is returned correctly. */
+/*                 For types 3-6, zero one or more rows and columns of */
+/*                 the matrix to test that INFO is returned correctly. */
 
 		    if (zerot) {
 			if (imat == 3) {
@@ -389,8 +405,8 @@ static integer c__8 = 8;
 		    }
 		} else {
 
-/*                 Use a special block diagonal matrix to test alternate   
-                   code for the 2 x 2 blocks. */
+/*                 Use a special block diagonal matrix to test alternate */
+/*                 code for the 2 x 2 blocks. */
 
 		    zlatsy_(uplo, &n, &a[1], &lda, iseed);
 		}
@@ -402,8 +418,8 @@ static integer c__8 = 8;
 		    nb = nbval[inb];
 		    xlaenv_(&c__1, &nb);
 
-/*                 Compute the L*D*L' or U*D*U' factorization of the   
-                   matrix. */
+/*                 Compute the L*D*L' or U*D*U' factorization of the */
+/*                 matrix. */
 
 		    zlacpy_(uplo, &n, &n, &a[1], &lda, &afac[1], &lda);
 		    lwork = max(2,nb) * lda;
@@ -411,8 +427,8 @@ static integer c__8 = 8;
 		    zsytrf_(uplo, &n, &afac[1], &lda, &iwork[1], &ainv[1], &
 			    lwork, &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -440,21 +456,21 @@ L100:
 			trfcon = FALSE_;
 		    }
 
-/* +    TEST 1   
-                   Reconstruct matrix from factors and compute residual. */
+/* +    TEST 1 */
+/*                 Reconstruct matrix from factors and compute residual. */
 
 		    zsyt01_(uplo, &n, &a[1], &lda, &afac[1], &lda, &iwork[1], 
 			    &ainv[1], &lda, &rwork[1], result);
 		    nt = 1;
 
-/* +    TEST 2   
-                   Form the inverse and compute the residual. */
+/* +    TEST 2 */
+/*                 Form the inverse and compute the residual. */
 
 		    if (inb == 1 && ! trfcon) {
 			zlacpy_(uplo, &n, &n, &afac[1], &lda, &ainv[1], &lda);
 			s_copy(srnamc_1.srnamt, "ZSYTRI", (ftnlen)6, (ftnlen)
 				6);
-			zsytri_(uplo, &n, &ainv[1], &lda, &iwork[1], &work[1],
+			zsytri_(uplo, &n, &ainv[1], &lda, &iwork[1], &work[1], 
 				 &info);
 
 /*                 Check error code from ZSYTRI. */
@@ -470,8 +486,8 @@ L100:
 			nt = 2;
 		    }
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    i__4 = nt;
 		    for (k = 1; k <= i__4; ++k) {
@@ -484,7 +500,8 @@ L100:
 			    do_fio(&c__1, uplo, (ftnlen)1);
 			    do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer))
 				    ;
-			    do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer) );
+			    do_fio(&c__1, (char *)&nb, (ftnlen)sizeof(integer)
+				    );
 			    do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(
 				    integer));
 			    do_fio(&c__1, (char *)&k, (ftnlen)sizeof(integer))
@@ -498,8 +515,8 @@ L100:
 		    }
 		    nrun += nt;
 
-/*                 Skip the other tests if this is not the first block   
-                   size. */
+/*                 Skip the other tests if this is not the first block */
+/*                 size. */
 
 		    if (inb > 1) {
 			goto L150;
@@ -516,8 +533,8 @@ L100:
 		    for (irhs = 1; irhs <= i__4; ++irhs) {
 			nrhs = nsval[irhs];
 
-/* +    TEST 3   
-                   Solve and compute residual for  A * X = B. */
+/* +    TEST 3 */
+/*                 Solve and compute residual for  A * X = B. */
 
 			s_copy(srnamc_1.srnamt, "ZLARHS", (ftnlen)6, (ftnlen)
 				6);
@@ -544,20 +561,20 @@ L100:
 			zsyt02_(uplo, &n, &nrhs, &a[1], &lda, &x[1], &lda, &
 				work[1], &lda, &rwork[1], &result[2]);
 
-/* +    TEST 4   
-                   Check solution from generated exact solution. */
+/* +    TEST 4 */
+/*                 Check solution from generated exact solution. */
 
 			zget04_(&n, &nrhs, &x[1], &lda, &xact[1], &lda, &
 				rcondc, &result[3]);
 
-/* +    TESTS 5, 6, and 7   
-                   Use iterative refinement to improve the solution. */
+/* +    TESTS 5, 6, and 7 */
+/*                 Use iterative refinement to improve the solution. */
 
 			s_copy(srnamc_1.srnamt, "ZSYRFS", (ftnlen)6, (ftnlen)
 				6);
 			zsyrfs_(uplo, &n, &nrhs, &a[1], &lda, &afac[1], &lda, 
 				&iwork[1], &b[1], &lda, &x[1], &lda, &rwork[1]
-				, &rwork[nrhs + 1], &work[1], &rwork[(nrhs << 
+, &rwork[nrhs + 1], &work[1], &rwork[(nrhs << 
 				1) + 1], &info);
 
 /*                 Check error code from ZSYRFS. */
@@ -574,8 +591,8 @@ L100:
 				1], &lda, &xact[1], &lda, &rwork[1], &rwork[
 				nrhs + 1], &result[5]);
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			for (k = 3; k <= 7; ++k) {
 			    if (result[k - 1] >= *thresh) {
@@ -604,8 +621,8 @@ L100:
 /* L130: */
 		    }
 
-/* +    TEST 8   
-                   Get an estimate of RCOND = 1/CNDNUM. */
+/* +    TEST 8 */
+/*                 Get an estimate of RCOND = 1/CNDNUM. */
 
 L140:
 		    anorm = zlansy_("1", uplo, &n, &a[1], &lda, &rwork[1]);
@@ -623,8 +640,8 @@ L140:
 
 		    result[7] = dget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    if (result[7] >= *thresh) {
 			if (nfail == 0 && nerrs == 0) {
