@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zdrvgb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -77,54 +65,55 @@ static integer c__7 = 7;
     doublereal d__1, d__2;
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
     double z_abs(doublecomplex *);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda, ldb, 
-	    ikl, nkl, iku, nku;
-    static char fact[1];
-    static integer ioff, mode;
-    static doublereal amax;
-    static char path[3];
-    static integer imat, info;
-    static char dist[1];
-    static doublereal rdum[1];
-    static char type__[1];
-    static integer nrun, ldafb, ifact, nfail, iseed[4], nfact;
+    integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda, ldb, ikl, nkl, 
+	    iku, nku;
+    char fact[1];
+    integer ioff, mode;
+    doublereal amax;
+    char path[3];
+    integer imat, info;
+    char dist[1];
+    doublereal rdum[1];
+    char type__[1];
+    integer nrun, ldafb, ifact, nfail, iseed[4], nfact;
     extern doublereal dget06_(doublereal *, doublereal *);
     extern logical lsame_(char *, char *);
-    static char equed[1];
-    static integer nbmin;
-    static doublereal rcond, roldc;
+    char equed[1];
+    integer nbmin;
+    doublereal rcond, roldc;
     extern /* Subroutine */ int zgbt01_(integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     integer *, doublecomplex *, doublereal *);
-    static integer nimat;
-    static doublereal roldi;
+    integer nimat;
+    doublereal roldi;
     extern /* Subroutine */ int zgbt02_(char *, integer *, integer *, integer 
 	    *, integer *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *), zgbt05_(char *, integer *, integer *, 
-	    integer *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, doublecomplex *, integer *, doublecomplex *, integer *
-	    , doublereal *, doublereal *, doublereal *);
-    static doublereal anorm;
-    static integer itran;
-    extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *,
-	     integer *, doublecomplex *, integer *, doublereal *, doublereal * );
-    static logical equil;
-    static doublereal roldo;
-    static char trans[1];
-    static integer izero, nerrs;
+, doublereal *, doublereal *, doublereal *);
+    doublereal anorm;
+    integer itran;
+    extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *, 
+	     integer *, doublecomplex *, integer *, doublereal *, doublereal *
+);
+    logical equil;
+    doublereal roldo;
+    char trans[1];
+    integer izero, nerrs;
     extern /* Subroutine */ int zgbsv_(integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, integer *, doublecomplex *,
+	    integer *, doublecomplex *, integer *, integer *, doublecomplex *, 
 	     integer *, integer *);
-    static logical zerot;
-    static char xtype[1];
+    logical zerot;
+    char xtype[1];
     extern /* Subroutine */ int zlatb4_(char *, integer *, integer *, integer 
 	    *, char *, integer *, integer *, doublereal *, integer *, 
 	    doublereal *, char *), aladhd_(integer *, 
@@ -133,35 +122,35 @@ static integer c__7 = 7;
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static logical prefac;
-    static doublereal colcnd, rcondc;
-    static logical nofact;
-    static integer iequed;
+    logical prefac;
+    doublereal colcnd, rcondc;
+    logical nofact;
+    integer iequed;
     extern doublereal zlangb_(char *, integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublereal *);
-    static doublereal rcondi;
+    doublereal rcondi;
     extern doublereal zlange_(char *, integer *, integer *, doublecomplex *, 
 	    integer *, doublereal *);
     extern /* Subroutine */ int zlaqgb_(integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, char *), 
 	    alasvm_(char *, integer *, integer *, integer *, integer *);
-    static doublereal cndnum, anormi, rcondo, ainvnm;
+    doublereal cndnum, anormi, rcondo, ainvnm;
     extern doublereal zlantb_(char *, char *, char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublereal *);
-    static logical trfcon;
-    static doublereal anormo, rowcnd;
+    logical trfcon;
+    doublereal anormo, rowcnd;
     extern /* Subroutine */ int xlaenv_(integer *, integer *), zgbequ_(
 	    integer *, integer *, integer *, integer *, doublecomplex *, 
-	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
+	    integer *, doublereal *, doublereal *, doublereal *, doublereal *, 
 	     doublereal *, integer *), zgbtrf_(integer *, integer *, integer *
-	    , integer *, doublecomplex *, integer *, integer *, integer *);
-    static doublereal anrmpv;
+, integer *, doublecomplex *, integer *, integer *, integer *);
+    doublereal anrmpv;
     extern /* Subroutine */ int zlacpy_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), 
 	    zlarhs_(char *, char *, char *, char *, integer *, integer *, 
 	    integer *, integer *, integer *, doublecomplex *, integer *, 
-	    doublecomplex *, integer *, doublecomplex *, integer *, integer *,
+	    doublecomplex *, integer *, doublecomplex *, integer *, integer *, 
 	     integer *), zlaset_(char *, 
 	    integer *, integer *, doublecomplex *, doublecomplex *, 
 	    doublecomplex *, integer *), zgbtrs_(char *, integer *, 
@@ -171,14 +160,14 @@ static integer c__7 = 7;
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    integer *, char *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *);
-    static doublereal result[7];
+    doublereal result[7];
     extern /* Subroutine */ int zgbsvx_(char *, char *, integer *, integer *, 
-	    integer *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, integer *, char *, doublereal *, doublereal *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublecomplex *, 
 	    doublereal *, integer *);
-    static doublereal rpvgrw;
+    doublereal rpvgrw;
     extern /* Subroutine */ int zerrvx_(char *, integer *);
 
     /* Fortran I/O blocks */
@@ -196,80 +185,101 @@ static integer c__7 = 7;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZDRVGB tests the driver routines ZGBSV and -SVX.   
+/*  ZDRVGB tests the driver routines ZGBSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) COMPLEX*16 array, dimension (LA)   
+/*  A       (workspace) COMPLEX*16 array, dimension (LA) */
 
-    LA      (input) INTEGER   
-            The length of the array A.  LA >= (2*NMAX-1)*NMAX   
-            where NMAX is the largest entry in NVAL.   
+/*  LA      (input) INTEGER */
+/*          The length of the array A.  LA >= (2*NMAX-1)*NMAX */
+/*          where NMAX is the largest entry in NVAL. */
 
-    AFB     (workspace) COMPLEX*16 array, dimension (LAFB)   
+/*  AFB     (workspace) COMPLEX*16 array, dimension (LAFB) */
 
-    LAFB    (input) INTEGER   
-            The length of the array AFB.  LAFB >= (3*NMAX-2)*NMAX   
-            where NMAX is the largest entry in NVAL.   
+/*  LAFB    (input) INTEGER */
+/*          The length of the array AFB.  LAFB >= (3*NMAX-2)*NMAX */
+/*          where NMAX is the largest entry in NVAL. */
 
-    ASAV    (workspace) COMPLEX*16 array, dimension (LA)   
+/*  ASAV    (workspace) COMPLEX*16 array, dimension (LA) */
 
-    B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    BSAV    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  BSAV    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    S       (workspace) DOUBLE PRECISION array, dimension (2*NMAX)   
+/*  S       (workspace) DOUBLE PRECISION array, dimension (2*NMAX) */
 
-    WORK    (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*max(3,NRHS,NMAX))   
+/*  WORK    (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*max(3,NRHS,NMAX)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension   
-                        (max(NMAX,2*NRHS))   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (max(NMAX,2*NRHS)) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -284,9 +294,11 @@ static integer c__7 = 7;
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Zomplex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "GB", (ftnlen)2, (ftnlen)2);
@@ -320,9 +332,9 @@ static integer c__7 = 7;
 	ldb = max(n,1);
 	*(unsigned char *)xtype = 'N';
 
-/*        Set limits on the number of loop iterations.   
+/*        Set limits on the number of loop iterations. */
 
-   Computing MAX */
+/* Computing MAX */
 	i__2 = 1, i__3 = min(n,4);
 	nkl = max(i__2,i__3);
 	if (n == 0) {
@@ -337,8 +349,8 @@ static integer c__7 = 7;
 	i__2 = nkl;
 	for (ikl = 1; ikl <= i__2; ++ikl) {
 
-/*           Do for KL = 0, N-1, (3N-1)/4, and (N+1)/4. This order makes   
-             it easier to skip redundant values for small values of N. */
+/*           Do for KL = 0, N-1, (3N-1)/4, and (N+1)/4. This order makes */
+/*           it easier to skip redundant values for small values of N. */
 
 	    if (ikl == 1) {
 		kl = 0;
@@ -354,9 +366,9 @@ static integer c__7 = 7;
 	    i__3 = nku;
 	    for (iku = 1; iku <= i__3; ++iku) {
 
-/*              Do for KU = 0, N-1, (3N-1)/4, and (N+1)/4. This order   
-                makes it easier to skip redundant values for small   
-                values of N. */
+/*              Do for KU = 0, N-1, (3N-1)/4, and (N+1)/4. This order */
+/*              makes it easier to skip redundant values for small */
+/*              values of N. */
 
 		if (iku == 1) {
 		    ku = 0;
@@ -370,8 +382,8 @@ static integer c__7 = 7;
 		    ku = (n + 1) / 4;
 		}
 
-/*              Check that A and AFB are big enough to generate this   
-                matrix. */
+/*              Check that A and AFB are big enough to generate this */
+/*              matrix. */
 
 		lda = kl + ku + 1;
 		ldafb = (kl << 1) + ku + 1;
@@ -424,8 +436,8 @@ static integer c__7 = 7;
 			goto L120;
 		    }
 
-/*                 Set up parameters with ZLATB4 and generate a   
-                   test matrix with ZLATMS. */
+/*                 Set up parameters with ZLATB4 and generate a */
+/*                 test matrix with ZLATMS. */
 
 		    zlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &
 			    mode, &cndnum, dist);
@@ -444,8 +456,8 @@ static integer c__7 = 7;
 			goto L120;
 		    }
 
-/*                 For types 2, 3, and 4, zero one or more columns of   
-                   the matrix to test that INFO is returned correctly. */
+/*                 For types 2, 3, and 4, zero one or more columns of */
+/*                 the matrix to test that INFO is returned correctly. */
 
 		    izero = 0;
 		    if (zerot) {
@@ -521,18 +533,18 @@ static integer c__7 = 7;
 
 			    } else if (! nofact) {
 
-/*                          Compute the condition number for comparison   
-                            with the value returned by DGESVX (FACT =   
-                            'N' reuses the condition number from the   
-                            previous iteration with FACT = 'F'). */
+/*                          Compute the condition number for comparison */
+/*                          with the value returned by DGESVX (FACT = */
+/*                          'N' reuses the condition number from the */
+/*                          previous iteration with FACT = 'F'). */
 
 				i__8 = kl + ku + 1;
 				zlacpy_("Full", &i__8, &n, &asav[1], &lda, &
 					afb[kl + 1], &ldafb);
 				if (equil || iequed > 1) {
 
-/*                             Compute row and column scale factors to   
-                               equilibrate the matrix A. */
+/*                             Compute row and column scale factors to */
+/*                             equilibrate the matrix A. */
 
 				    zgbequ_(&n, &n, &kl, &ku, &afb[kl + 1], &
 					    ldafb, &s[1], &s[n + 1], &rowcnd, 
@@ -552,13 +564,13 @@ static integer c__7 = 7;
 /*                                Equilibrate the matrix. */
 
 					zlaqgb_(&n, &n, &kl, &ku, &afb[kl + 1]
-						, &ldafb, &s[1], &s[n + 1], &
+, &ldafb, &s[1], &s[n + 1], &
 						rowcnd, &colcnd, &amax, equed);
 				    }
 				}
 
-/*                          Save the condition number of the   
-                            non-equilibrated system for use in ZGET04. */
+/*                          Save the condition number of the */
+/*                          non-equilibrated system for use in ZGET04. */
 
 				if (equil) {
 				    roldo = rcondo;
@@ -597,8 +609,8 @@ static integer c__7 = 7;
 				    rcondo = 1. / anormo / ainvnm;
 				}
 
-/*                          Compute the infinity-norm condition number   
-                            of A. */
+/*                          Compute the infinity-norm condition number */
+/*                          of A. */
 
 				ainvnm = zlange_("I", &n, &n, &work[1], &ldb, 
 					&rwork[1]);
@@ -627,8 +639,8 @@ static integer c__7 = 7;
 				zlacpy_("Full", &i__8, &n, &asav[1], &lda, &a[
 					1], &lda);
 
-/*                          Form an exact solution and set the right hand   
-                            side. */
+/*                          Form an exact solution and set the right hand */
+/*                          side. */
 
 				s_copy(srnamc_1.srnamt, "ZLARHS", (ftnlen)6, (
 					ftnlen)6);
@@ -641,10 +653,10 @@ static integer c__7 = 7;
 
 				if (nofact && itran == 1) {
 
-/*                             --- Test ZGBSV  ---   
+/*                             --- Test ZGBSV  --- */
 
-                               Compute the LU factorization of the matrix   
-                               and solve the system. */
+/*                             Compute the LU factorization of the matrix */
+/*                             and solve the system. */
 
 				    i__8 = kl + ku + 1;
 				    zlacpy_("Full", &i__8, &n, &a[1], &lda, &
@@ -661,13 +673,13 @@ static integer c__7 = 7;
 /*                             Check error code from ZGBSV . */
 
 				    if (info != izero) {
-					alaerh_(path, "ZGBSV ", &info, &izero,
+					alaerh_(path, "ZGBSV ", &info, &izero, 
 						 " ", &n, &n, &kl, &ku, nrhs, 
 						&imat, &nfail, &nerrs, nout);
 				    }
 
-/*                             Reconstruct matrix from factors and   
-                               compute residual. */
+/*                             Reconstruct matrix from factors and */
+/*                             compute residual. */
 
 				    zgbt01_(&n, &n, &kl, &ku, &a[1], &lda, &
 					    afb[1], &ldafb, &iwork[1], &work[
@@ -675,18 +687,18 @@ static integer c__7 = 7;
 				    nt = 1;
 				    if (izero == 0) {
 
-/*                                Compute residual of the computed   
-                                  solution. */
+/*                                Compute residual of the computed */
+/*                                solution. */
 
-					zlacpy_("Full", &n, nrhs, &b[1], &ldb,
+					zlacpy_("Full", &n, nrhs, &b[1], &ldb, 
 						 &work[1], &ldb);
 					zgbt02_("No transpose", &n, &n, &kl, &
 						ku, nrhs, &a[1], &lda, &x[1], 
 						&ldb, &work[1], &ldb, &result[
 						1]);
 
-/*                                Check solution from generated exact   
-                                  solution. */
+/*                                Check solution from generated exact */
+/*                                solution. */
 
 					zget04_(&n, nrhs, &x[1], &ldb, &xact[
 						1], &ldb, &rcondc, &result[2])
@@ -694,8 +706,8 @@ static integer c__7 = 7;
 					nt = 3;
 				    }
 
-/*                             Print information about the tests that did   
-                               not pass the threshold. */
+/*                             Print information about the tests that did */
+/*                             not pass the threshold. */
 
 				    i__8 = nt;
 				    for (k = 1; k <= i__8; ++k) {
@@ -732,28 +744,28 @@ static integer c__7 = 7;
 
 				if (! prefac) {
 				    i__8 = (kl << 1) + ku + 1;
-				    zlaset_("Full", &i__8, &n, &c_b48, &c_b48,
+				    zlaset_("Full", &i__8, &n, &c_b48, &c_b48, 
 					     &afb[1], &ldafb);
 				}
 				zlaset_("Full", &n, nrhs, &c_b48, &c_b48, &x[
 					1], &ldb);
 				if (iequed > 1 && n > 0) {
 
-/*                             Equilibrate the matrix if FACT = 'F' and   
-                               EQUED = 'R', 'C', or 'B'. */
+/*                             Equilibrate the matrix if FACT = 'F' and */
+/*                             EQUED = 'R', 'C', or 'B'. */
 
 				    zlaqgb_(&n, &n, &kl, &ku, &a[1], &lda, &s[
 					    1], &s[n + 1], &rowcnd, &colcnd, &
 					    amax, equed);
 				}
 
-/*                          Solve the system and compute the condition   
-                            number and error bounds using ZGBSVX. */
+/*                          Solve the system and compute the condition */
+/*                          number and error bounds using ZGBSVX. */
 
 				s_copy(srnamc_1.srnamt, "ZGBSVX", (ftnlen)6, (
 					ftnlen)6);
 				zgbsvx_(fact, trans, &n, &kl, &ku, nrhs, &a[1]
-					, &lda, &afb[1], &ldafb, &iwork[1], 
+, &lda, &afb[1], &ldafb, &iwork[1], 
 					equed, &s[1], &s[ldb + 1], &b[1], &
 					ldb, &x[1], &ldb, &rcond, &rwork[1], &
 					rwork[*nrhs + 1], &work[1], &rwork[(*
@@ -765,13 +777,14 @@ static integer c__7 = 7;
 /* Writing concatenation */
 				    i__11[0] = 1, a__1[0] = fact;
 				    i__11[1] = 1, a__1[1] = trans;
-				    s_cat(ch__1, a__1, i__11, &c__2, (ftnlen) 2);
+				    s_cat(ch__1, a__1, i__11, &c__2, (ftnlen)
+					    2);
 				    alaerh_(path, "ZGBSVX", &info, &izero, 
 					    ch__1, &n, &n, &kl, &ku, nrhs, &
 					    imat, &nfail, &nerrs, nout);
 				}
-/*                          Compare RWORK(2*NRHS+1) from ZGBSVX with the   
-                            computed reciprocal pivot growth RPVGRW */
+/*                          Compare RWORK(2*NRHS+1) from ZGBSVX with the */
+/*                          computed reciprocal pivot growth RPVGRW */
 
 				if (info != 0) {
 				    anrmpv = 0.;
@@ -799,7 +812,7 @@ static integer c__7 = 7;
 /* Computing MAX */
 				    i__9 = 1, i__10 = kl + ku + 2 - info;
 				    rpvgrw = zlantb_("M", "U", "N", &info, &
-					    i__8, &afb[max(i__9,i__10)], &
+					    i__8, &afb[max(i__9, i__10)], &
 					    ldafb, rdum);
 				    if (rpvgrw == 0.) {
 					rpvgrw = 1.;
@@ -808,7 +821,7 @@ static integer c__7 = 7;
 				    }
 				} else {
 				    i__8 = kl + ku;
-				    rpvgrw = zlantb_("M", "U", "N", &n, &i__8,
+				    rpvgrw = zlantb_("M", "U", "N", &n, &i__8, 
 					     &afb[1], &ldafb, rdum);
 				    if (rpvgrw == 0.) {
 					rpvgrw = 1.;
@@ -826,8 +839,8 @@ static integer c__7 = 7;
 
 				if (! prefac) {
 
-/*                             Reconstruct matrix from factors and   
-                               compute residual. */
+/*                             Reconstruct matrix from factors and */
+/*                             compute residual. */
 
 				    zgbt01_(&n, &n, &kl, &ku, &a[1], &lda, &
 					    afb[1], &ldafb, &iwork[1], &work[
@@ -848,8 +861,8 @@ static integer c__7 = 7;
 					    asav[1], &lda, &x[1], &ldb, &work[
 					    1], &ldb, &result[1]);
 
-/*                             Check solution from generated exact   
-                               solution. */
+/*                             Check solution from generated exact */
+/*                             solution. */
 
 				    if (nofact || prefac && lsame_(equed, 
 					    "N")) {
@@ -866,8 +879,8 @@ static integer c__7 = 7;
 						1], &ldb, &roldc, &result[2]);
 				    }
 
-/*                             Check the error bounds from iterative   
-                               refinement. */
+/*                             Check the error bounds from iterative */
+/*                             refinement. */
 
 				    zgbt05_(trans, &n, &kl, &ku, nrhs, &asav[
 					    1], &lda, &bsav[1], &ldb, &x[1], &
@@ -877,13 +890,13 @@ static integer c__7 = 7;
 				    trfcon = TRUE_;
 				}
 
-/*                          Compare RCOND from ZGBSVX with the computed   
-                            value in RCONDC. */
+/*                          Compare RCOND from ZGBSVX with the computed */
+/*                          value in RCONDC. */
 
 				result[5] = dget06_(&rcond, &rcondc);
 
-/*                          Print information about the tests that did   
-                            not pass the threshold. */
+/*                          Print information about the tests that did */
+/*                          not pass the threshold. */
 
 				if (! trfcon) {
 				    for (k = k1; k <= 7; ++k) {
@@ -901,7 +914,8 @@ static integer c__7 = 7;
 			  do_fio(&c__1, (char *)&kl, (ftnlen)sizeof(integer));
 			  do_fio(&c__1, (char *)&ku, (ftnlen)sizeof(integer));
 			  do_fio(&c__1, equed, (ftnlen)1);
-			  do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer) );
+			  do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer)
+				  );
 			  do_fio(&c__1, (char *)&k, (ftnlen)sizeof(integer));
 			  do_fio(&c__1, (char *)&result[k - 1], (ftnlen)
 				  sizeof(doublereal));
@@ -915,7 +929,8 @@ static integer c__7 = 7;
 			  do_fio(&c__1, (char *)&n, (ftnlen)sizeof(integer));
 			  do_fio(&c__1, (char *)&kl, (ftnlen)sizeof(integer));
 			  do_fio(&c__1, (char *)&ku, (ftnlen)sizeof(integer));
-			  do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer) );
+			  do_fio(&c__1, (char *)&imat, (ftnlen)sizeof(integer)
+				  );
 			  do_fio(&c__1, (char *)&k, (ftnlen)sizeof(integer));
 			  do_fio(&c__1, (char *)&result[k - 1], (ftnlen)
 				  sizeof(doublereal));
@@ -950,7 +965,8 @@ static integer c__7 = 7;
 					    do_fio(&c__1, (char *)&c__1, (
 						    ftnlen)sizeof(integer));
 					    do_fio(&c__1, (char *)&result[0], 
-						    (ftnlen)sizeof(doublereal) );
+						    (ftnlen)sizeof(doublereal)
+						    );
 					    e_wsfe();
 					} else {
 					    io___76.ciunit = *nout;
@@ -970,7 +986,8 @@ static integer c__7 = 7;
 					    do_fio(&c__1, (char *)&c__1, (
 						    ftnlen)sizeof(integer));
 					    do_fio(&c__1, (char *)&result[0], 
-						    (ftnlen)sizeof(doublereal) );
+						    (ftnlen)sizeof(doublereal)
+						    );
 					    e_wsfe();
 					}
 					++nfail;
@@ -999,7 +1016,8 @@ static integer c__7 = 7;
 					    do_fio(&c__1, (char *)&c__6, (
 						    ftnlen)sizeof(integer));
 					    do_fio(&c__1, (char *)&result[5], 
-						    (ftnlen)sizeof(doublereal) );
+						    (ftnlen)sizeof(doublereal)
+						    );
 					    e_wsfe();
 					} else {
 					    io___78.ciunit = *nout;
@@ -1019,7 +1037,8 @@ static integer c__7 = 7;
 					    do_fio(&c__1, (char *)&c__6, (
 						    ftnlen)sizeof(integer));
 					    do_fio(&c__1, (char *)&result[5], 
-						    (ftnlen)sizeof(doublereal) );
+						    (ftnlen)sizeof(doublereal)
+						    );
 					    e_wsfe();
 					}
 					++nfail;
@@ -1048,7 +1067,8 @@ static integer c__7 = 7;
 					    do_fio(&c__1, (char *)&c__7, (
 						    ftnlen)sizeof(integer));
 					    do_fio(&c__1, (char *)&result[6], 
-						    (ftnlen)sizeof(doublereal) );
+						    (ftnlen)sizeof(doublereal)
+						    );
 					    e_wsfe();
 					} else {
 					    io___80.ciunit = *nout;
@@ -1068,7 +1088,8 @@ static integer c__7 = 7;
 					    do_fio(&c__1, (char *)&c__7, (
 						    ftnlen)sizeof(integer));
 					    do_fio(&c__1, (char *)&result[6], 
-						    (ftnlen)sizeof(doublereal) );
+						    (ftnlen)sizeof(doublereal)
+						    );
 					    e_wsfe();
 					}
 					++nfail;
