@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zdrvhp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -59,52 +47,56 @@ static doublecomplex c_b64 = {0.,0.};
     integer i__1, i__2, i__3, i__4, i__5, i__6[2];
     char ch__1[2];
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda, npp;
-    static char fact[1];
-    static integer ioff, mode, imat, info;
-    static char path[3], dist[1], uplo[1], type__[1];
-    static integer nrun, ifact, nfail, iseed[4];
+    integer i__, j, k, n, i1, i2, k1, nb, in, kl, ku, nt, lda, npp;
+    char fact[1];
+    integer ioff, mode, imat, info;
+    char path[3], dist[1], uplo[1], type__[1];
+    integer nrun, ifact, nfail, iseed[4];
     extern doublereal dget06_(doublereal *, doublereal *);
-    static integer nbmin;
-    static doublereal rcond;
-    static integer nimat;     static doublereal anorm;     extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *, 	     integer *, doublecomplex *, integer *, doublereal *, doublereal * 	    ), zhpt01_(char *, integer *, doublecomplex *, doublecomplex *, 
+    integer nbmin;
+    doublereal rcond;
+    integer nimat;
+    doublereal anorm;
+    extern /* Subroutine */ int zget04_(integer *, integer *, doublecomplex *, 
+	     integer *, doublecomplex *, integer *, doublereal *, doublereal *
+), zhpt01_(char *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublereal *, doublereal *);
-    static integer iuplo, izero, nerrs;
+    integer iuplo, izero, nerrs;
     extern /* Subroutine */ int zppt02_(char *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublereal *, doublereal *), zppt05_(char *, 
-	    integer *, integer *, doublecomplex *, doublecomplex *, integer *,
+	    integer *, integer *, doublecomplex *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublereal *);
-    static logical zerot;
+    logical zerot;
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
-    static char xtype[1];
+    char xtype[1];
     extern /* Subroutine */ int zhpsv_(char *, integer *, integer *, 
-	    doublecomplex *, integer *, doublecomplex *, integer *, integer *), zlatb4_(char *, integer *, integer *, integer *, char *,
+	    doublecomplex *, integer *, doublecomplex *, integer *, integer *), zlatb4_(char *, integer *, integer *, integer *, char *, 
 	     integer *, integer *, doublereal *, integer *, doublereal *, 
 	    char *), aladhd_(integer *, char *), alaerh_(char *, char *, integer *, integer *, char *, 
 	    integer *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *);
-    static doublereal rcondc;
-    static char packit[1];
+    doublereal rcondc;
+    char packit[1];
     extern /* Subroutine */ int alasvm_(char *, integer *, integer *, integer 
 	    *, integer *);
-    static doublereal cndnum;
-    extern /* Subroutine */ int zlaipd_(integer *, doublecomplex *, integer *,
+    doublereal cndnum;
+    extern /* Subroutine */ int zlaipd_(integer *, doublecomplex *, integer *, 
 	     integer *);
-    static doublereal ainvnm;
+    doublereal ainvnm;
     extern doublereal zlanhp_(char *, char *, integer *, doublecomplex *, 
 	    doublereal *);
-    extern /* Subroutine */ int xlaenv_(integer *, integer *), zlacpy_(char *,
+    extern /* Subroutine */ int xlaenv_(integer *, integer *), zlacpy_(char *, 
 	     integer *, integer *, doublecomplex *, integer *, doublecomplex *
-	    , integer *), zlarhs_(char *, char *, char *, char *, 
+, integer *), zlarhs_(char *, char *, char *, char *, 
 	    integer *, integer *, integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, integer *, integer *), zlaset_(char *, integer *, integer *, 
@@ -112,12 +104,12 @@ static doublecomplex c_b64 = {0.,0.};
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    integer *, char *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *);
-    static doublereal result[6];
+    doublereal result[6];
     extern /* Subroutine */ int zhptrf_(char *, integer *, doublecomplex *, 
 	    integer *, integer *), zhptri_(char *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), 
 	    zerrvx_(char *, integer *), zhpsvx_(char *, char *, 
-	    integer *, integer *, doublecomplex *, doublecomplex *, integer *,
+	    integer *, integer *, doublecomplex *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublecomplex *, 
 	    doublereal *, integer *);
@@ -128,74 +120,95 @@ static doublecomplex c_b64 = {0.,0.};
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZDRVHP tests the driver routines ZHPSV and -SVX.   
+/*  ZDRVHP tests the driver routines ZHPSV and -SVX. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix dimension N. */
 
-    NRHS    (input) INTEGER   
-            The number of right hand side vectors to be generated for   
-            each linear system.   
+/*  NRHS    (input) INTEGER */
+/*          The number of right hand side vectors to be generated for */
+/*          each linear system. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    NMAX    (input) INTEGER   
-            The maximum value permitted for N, used in dimensioning the   
-            work arrays.   
+/*  NMAX    (input) INTEGER */
+/*          The maximum value permitted for N, used in dimensioning the */
+/*          work arrays. */
 
-    A       (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  A       (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AFAC    (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AFAC    (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    AINV    (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*(NMAX+1)/2)   
+/*  AINV    (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*(NMAX+1)/2) */
 
-    B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)   
+/*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS) */
 
-    WORK    (workspace) COMPLEX*16 array, dimension   
-                        (NMAX*max(2,NRHS))   
+/*  WORK    (workspace) COMPLEX*16 array, dimension */
+/*                      (NMAX*max(2,NRHS)) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX+2*NRHS)   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX+2*NRHS) */
 
-    IWORK   (workspace) INTEGER array, dimension (NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -208,9 +221,11 @@ static doublecomplex c_b64 = {0.,0.};
     --nval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     *(unsigned char *)path = 'Z';
     s_copy(path + 1, "HP", (ftnlen)2, (ftnlen)2);
@@ -276,8 +291,8 @@ static doublecomplex c_b64 = {0.,0.};
 		    *(unsigned char *)packit = 'R';
 		}
 
-/*              Set up parameters with ZLATB4 and generate a test matrix   
-                with ZLATMS. */
+/*              Set up parameters with ZLATB4 and generate a test matrix */
+/*              with ZLATMS. */
 
 		zlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, 
 			&cndnum, dist);
@@ -290,13 +305,13 @@ static doublecomplex c_b64 = {0.,0.};
 /*              Check error code from ZLATMS. */
 
 		if (info != 0) {
-		    alaerh_(path, "ZLATMS", &info, &c__0, uplo, &n, &n, &c_n1,
+		    alaerh_(path, "ZLATMS", &info, &c__0, uplo, &n, &n, &c_n1, 
 			     &c_n1, &c_n1, &imat, &nfail, &nerrs, nout);
 		    goto L160;
 		}
 
-/*              For types 3-6, zero one or more rows and columns of the   
-                matrix to test that INFO is returned correctly. */
+/*              For types 3-6, zero one or more rows and columns of the */
+/*              matrix to test that INFO is returned correctly. */
 
 		if (zerot) {
 		    if (imat == 3) {
@@ -399,8 +414,8 @@ static doublecomplex c_b64 = {0.,0.};
 		    *(unsigned char *)fact = *(unsigned char *)&facts[ifact - 
 			    1];
 
-/*                 Compute the condition number for comparison with   
-                   the value returned by ZHPSVX. */
+/*                 Compute the condition number for comparison with */
+/*                 the value returned by ZHPSVX. */
 
 		    if (zerot) {
 			if (ifact == 1) {
@@ -456,8 +471,8 @@ static doublecomplex c_b64 = {0.,0.};
 			zhpsv_(uplo, &n, nrhs, &afac[1], &iwork[1], &x[1], &
 				lda, &info);
 
-/*                    Adjust the expected value of INFO to account for   
-                      pivoting. */
+/*                    Adjust the expected value of INFO to account for */
+/*                    pivoting. */
 
 			k = izero;
 			if (k > 0) {
@@ -484,11 +499,11 @@ L100:
 			    goto L120;
 			}
 
-/*                    Reconstruct matrix from factors and compute   
-                      residual. */
+/*                    Reconstruct matrix from factors and compute */
+/*                    residual. */
 
 			zhpt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &ainv[1]
-				, &lda, &rwork[1], result);
+, &lda, &rwork[1], result);
 
 /*                    Compute residual of the computed solution. */
 
@@ -502,8 +517,8 @@ L100:
 				rcondc, &result[2]);
 			nt = 3;
 
-/*                    Print information about the tests that did not pass   
-                      the threshold. */
+/*                    Print information about the tests that did not pass */
+/*                    the threshold. */
 
 			i__3 = nt;
 			for (k = 1; k <= i__3; ++k) {
@@ -536,13 +551,13 @@ L120:
 /*                 --- Test ZHPSVX --- */
 
 		    if (ifact == 2 && npp > 0) {
-			zlaset_("Full", &npp, &c__1, &c_b64, &c_b64, &afac[1],
+			zlaset_("Full", &npp, &c__1, &c_b64, &c_b64, &afac[1], 
 				 &npp);
 		    }
 		    zlaset_("Full", &n, nrhs, &c_b64, &c_b64, &x[1], &lda);
 
-/*                 Solve the system and compute the condition number and   
-                   error bounds using ZHPSVX. */
+/*                 Solve the system and compute the condition number and */
+/*                 error bounds using ZHPSVX. */
 
 		    s_copy(srnamc_1.srnamt, "ZHPSVX", (ftnlen)6, (ftnlen)6);
 		    zhpsvx_(fact, uplo, &n, nrhs, &a[1], &afac[1], &iwork[1], 
@@ -550,8 +565,8 @@ L120:
 			    rwork[*nrhs + 1], &work[1], &rwork[(*nrhs << 1) + 
 			    1], &info);
 
-/*                 Adjust the expected value of INFO to account for   
-                   pivoting. */
+/*                 Adjust the expected value of INFO to account for */
+/*                 pivoting. */
 
 		    k = izero;
 		    if (k > 0) {
@@ -583,8 +598,8 @@ L130:
 		    if (info == 0) {
 			if (ifact >= 2) {
 
-/*                       Reconstruct matrix from factors and compute   
-                         residual. */
+/*                       Reconstruct matrix from factors and compute */
+/*                       residual. */
 
 			    zhpt01_(uplo, &n, &a[1], &afac[1], &iwork[1], &
 				    ainv[1], &lda, &rwork[(*nrhs << 1) + 1], 
@@ -614,13 +629,13 @@ L130:
 			k1 = 6;
 		    }
 
-/*                 Compare RCOND from ZHPSVX with the computed value   
-                   in RCONDC. */
+/*                 Compare RCOND from ZHPSVX with the computed value */
+/*                 in RCONDC. */
 
 		    result[5] = dget06_(&rcond, &rcondc);
 
-/*                 Print information about the tests that did not pass   
-                   the threshold. */
+/*                 Print information about the tests that did not pass */
+/*                 the threshold. */
 
 		    for (k = k1; k <= 6; ++k) {
 			if (result[k - 1] >= *thresh) {
