@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zdrvls.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -65,34 +53,34 @@ static doublereal c_b91 = -1.;
     integer i__1, i__2, i__3, i__4, i__5, i__6;
     doublereal d__1;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal);
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j, k, m, n, nb, im, in, lda, ldb, inb;
-    static doublereal eps;
-    static integer ins, info;
-    static char path[3];
-    static integer rank, nrhs, nrun;
+    integer i__, j, k, m, n, nb, im, in, lda, ldb, inb;
+    doublereal eps;
+    integer ins, info;
+    char path[3];
+    integer rank, nrhs, nrun;
     extern /* Subroutine */ int alahd_(integer *, char *);
-    static integer nfail, iseed[4], crank, irank;
-    static doublereal rcond;
+    integer nfail, iseed[4], crank, irank;
+    doublereal rcond;
     extern doublereal dasum_(integer *, doublereal *, integer *);
-    static integer itran, mnmin, ncols;
-    static doublereal norma, normb;
+    integer itran, mnmin, ncols;
+    doublereal norma, normb;
     extern /* Subroutine */ int zgels_(char *, integer *, integer *, integer *
-	    , doublecomplex *, integer *, doublecomplex *, integer *, 
+, doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, integer *), daxpy_(integer *, 
 	    doublereal *, doublereal *, integer *, doublereal *, integer *), 
 	    zgemm_(char *, char *, integer *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *);
-    static char trans[1];
-    static integer nerrs, itype, lwork;
+    char trans[1];
+    integer nerrs, itype, lwork;
     extern doublereal zqrt12_(integer *, integer *, doublecomplex *, integer *
-	    , doublereal *, doublecomplex *, integer *, doublereal *), 
+, doublereal *, doublecomplex *, integer *, doublereal *), 
 	    zqrt14_(char *, integer *, integer *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublecomplex *, integer *);
     extern /* Subroutine */ int zqrt13_(integer *, integer *, integer *, 
@@ -101,12 +89,12 @@ static doublereal c_b91 = -1.;
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    doublecomplex *, integer *);
-    static integer nrows;
+    integer nrows;
     extern doublereal zqrt17_(char *, integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *);
-    static integer lwlsy;
+    integer lwlsy;
     extern /* Subroutine */ int zqrt16_(char *, integer *, integer *, integer 
 	    *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublereal *);
@@ -114,27 +102,27 @@ static doublereal c_b91 = -1.;
     extern /* Subroutine */ int alaerh_(char *, char *, integer *, integer *, 
 	    char *, integer *, integer *, integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
-    static integer iscale;
+    integer iscale;
     extern /* Subroutine */ int zdscal_(integer *, doublereal *, 
-	    doublecomplex *, integer *), alasvm_(char *, integer *, integer *,
+	    doublecomplex *, integer *), alasvm_(char *, integer *, integer *, 
 	     integer *, integer *), zgelsd_(integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublecomplex *, integer *,
+	    integer *, doublecomplex *, integer *, doublecomplex *, integer *, 
 	     doublereal *, doublereal *, integer *, doublecomplex *, integer *
-	    , doublereal *, integer *, integer *), xlaenv_(integer *, integer 
+, doublereal *, integer *, integer *), xlaenv_(integer *, integer 
 	    *);
-    static integer ldwork;
+    integer ldwork;
     extern /* Subroutine */ int zlacpy_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), 
 	    zgelss_(integer *, integer *, integer *, doublecomplex *, integer 
 	    *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	    integer *, doublecomplex *, integer *, doublereal *, integer *), 
 	    zgelsx_(integer *, integer *, integer *, doublecomplex *, integer 
-	    *, doublecomplex *, integer *, integer *, doublereal *, integer *,
+	    *, doublecomplex *, integer *, integer *, doublereal *, integer *, 
 	     doublecomplex *, doublereal *, integer *), zgelsy_(integer *, 
-	    integer *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, integer *, doublereal *, integer *, doublecomplex *, 
 	    integer *, doublereal *, integer *);
-    static doublereal result[18];
+    doublereal result[18];
     extern /* Subroutine */ int zlarnv_(integer *, integer *, integer *, 
 	    doublecomplex *), zerrls_(char *, integer *);
 
@@ -145,107 +133,128 @@ static doublereal c_b91 = -1.;
 
 
 
-/*  -- LAPACK test routine (version 3.1.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       January 2007   
+/*  -- LAPACK test routine (version 3.1.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     January 2007 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZDRVLS tests the least squares driver routines ZGELS, CGELSX, CGELSS,   
-    ZGELSY and CGELSD.   
+/*  ZDRVLS tests the least squares driver routines ZGELS, CGELSX, CGELSS, */
+/*  ZGELSY and CGELSD. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    DOTYPE  (input) LOGICAL array, dimension (NTYPES)   
-            The matrix types to be used for testing.  Matrices of type j   
-            (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =   
-            .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.   
-            The matrix of type j is generated as follows:   
-            j=1: A = U*D*V where U and V are random unitary matrices   
-                 and D has random entries (> 0.1) taken from a uniform   
-                 distribution (0,1). A is full rank.   
-            j=2: The same of 1, but A is scaled up.   
-            j=3: The same of 1, but A is scaled down.   
-            j=4: A = U*D*V where U and V are random unitary matrices   
-                 and D has 3*min(M,N)/4 random entries (> 0.1) taken   
-                 from a uniform distribution (0,1) and the remaining   
-                 entries set to 0. A is rank-deficient.   
-            j=5: The same of 4, but A is scaled up.   
-            j=6: The same of 5, but A is scaled down.   
+/*  DOTYPE  (input) LOGICAL array, dimension (NTYPES) */
+/*          The matrix types to be used for testing.  Matrices of type j */
+/*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) = */
+/*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used. */
+/*          The matrix of type j is generated as follows: */
+/*          j=1: A = U*D*V where U and V are random unitary matrices */
+/*               and D has random entries (> 0.1) taken from a uniform */
+/*               distribution (0,1). A is full rank. */
+/*          j=2: The same of 1, but A is scaled up. */
+/*          j=3: The same of 1, but A is scaled down. */
+/*          j=4: A = U*D*V where U and V are random unitary matrices */
+/*               and D has 3*min(M,N)/4 random entries (> 0.1) taken */
+/*               from a uniform distribution (0,1) and the remaining */
+/*               entries set to 0. A is rank-deficient. */
+/*          j=5: The same of 4, but A is scaled up. */
+/*          j=6: The same of 5, but A is scaled down. */
 
-    NM      (input) INTEGER   
-            The number of values of M contained in the vector MVAL.   
+/*  NM      (input) INTEGER */
+/*          The number of values of M contained in the vector MVAL. */
 
-    MVAL    (input) INTEGER array, dimension (NM)   
-            The values of the matrix row dimension M.   
+/*  MVAL    (input) INTEGER array, dimension (NM) */
+/*          The values of the matrix row dimension M. */
 
-    NN      (input) INTEGER   
-            The number of values of N contained in the vector NVAL.   
+/*  NN      (input) INTEGER */
+/*          The number of values of N contained in the vector NVAL. */
 
-    NVAL    (input) INTEGER array, dimension (NN)   
-            The values of the matrix column dimension N.   
+/*  NVAL    (input) INTEGER array, dimension (NN) */
+/*          The values of the matrix column dimension N. */
 
-    NNB     (input) INTEGER   
-            The number of values of NB and NX contained in the   
-            vectors NBVAL and NXVAL.  The blocking parameters are used   
-            in pairs (NB,NX).   
+/*  NNB     (input) INTEGER */
+/*          The number of values of NB and NX contained in the */
+/*          vectors NBVAL and NXVAL.  The blocking parameters are used */
+/*          in pairs (NB,NX). */
 
-    NBVAL   (input) INTEGER array, dimension (NNB)   
-            The values of the blocksize NB.   
+/*  NBVAL   (input) INTEGER array, dimension (NNB) */
+/*          The values of the blocksize NB. */
 
-    NXVAL   (input) INTEGER array, dimension (NNB)   
-            The values of the crossover point NX.   
+/*  NXVAL   (input) INTEGER array, dimension (NNB) */
+/*          The values of the crossover point NX. */
 
-    NNS     (input) INTEGER   
-            The number of values of NRHS contained in the vector NSVAL.   
+/*  NNS     (input) INTEGER */
+/*          The number of values of NRHS contained in the vector NSVAL. */
 
-    NSVAL   (input) INTEGER array, dimension (NNS)   
-            The values of the number of right hand sides NRHS.   
+/*  NSVAL   (input) INTEGER array, dimension (NNS) */
+/*          The values of the number of right hand sides NRHS. */
 
-    THRESH  (input) DOUBLE PRECISION   
-            The threshold value for the test ratios.  A result is   
-            included in the output file if RESULT >= THRESH.  To have   
-            every test ratio printed, use THRESH = 0.   
+/*  THRESH  (input) DOUBLE PRECISION */
+/*          The threshold value for the test ratios.  A result is */
+/*          included in the output file if RESULT >= THRESH.  To have */
+/*          every test ratio printed, use THRESH = 0. */
 
-    TSTERR  (input) LOGICAL   
-            Flag that indicates whether error exits are to be tested.   
+/*  TSTERR  (input) LOGICAL */
+/*          Flag that indicates whether error exits are to be tested. */
 
-    A       (workspace) COMPLEX*16 array, dimension (MMAX*NMAX)   
-            where MMAX is the maximum value of M in MVAL and NMAX is the   
-            maximum value of N in NVAL.   
+/*  A       (workspace) COMPLEX*16 array, dimension (MMAX*NMAX) */
+/*          where MMAX is the maximum value of M in MVAL and NMAX is the */
+/*          maximum value of N in NVAL. */
 
-    COPYA   (workspace) COMPLEX*16 array, dimension (MMAX*NMAX)   
+/*  COPYA   (workspace) COMPLEX*16 array, dimension (MMAX*NMAX) */
 
-    B       (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX)   
-            where MMAX is the maximum value of M in MVAL and NSMAX is the   
-            maximum value of NRHS in NSVAL.   
+/*  B       (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX) */
+/*          where MMAX is the maximum value of M in MVAL and NSMAX is the */
+/*          maximum value of NRHS in NSVAL. */
 
-    COPYB   (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX)   
+/*  COPYB   (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX) */
 
-    C       (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX)   
+/*  C       (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX) */
 
-    S       (workspace) DOUBLE PRECISION array, dimension   
-                        (min(MMAX,NMAX))   
+/*  S       (workspace) DOUBLE PRECISION array, dimension */
+/*                      (min(MMAX,NMAX)) */
 
-    COPYS   (workspace) DOUBLE PRECISION array, dimension   
-                        (min(MMAX,NMAX))   
+/*  COPYS   (workspace) DOUBLE PRECISION array, dimension */
+/*                      (min(MMAX,NMAX)) */
 
-    WORK    (workspace) COMPLEX*16 array, dimension   
-                        (MMAX*NMAX + 4*NMAX + MMAX).   
+/*  WORK    (workspace) COMPLEX*16 array, dimension */
+/*                      (MMAX*NMAX + 4*NMAX + MMAX). */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (5*NMAX-1)   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (5*NMAX-1) */
 
-    IWORK   (workspace) INTEGER array, dimension (15*NMAX)   
+/*  IWORK   (workspace) INTEGER array, dimension (15*NMAX) */
 
-    NOUT    (input) INTEGER   
-            The unit number for output.   
+/*  NOUT    (input) INTEGER */
+/*          The unit number for output. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
-       Parameter adjustments */
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Data statements .. */
+    /* Parameter adjustments */
     --iwork;
     --rwork;
     --work;
@@ -263,9 +272,11 @@ static doublereal c_b91 = -1.;
     --mval;
     --dotype;
 
-    /* Function Body   
+    /* Function Body */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Initialize constants and the random number seed. */
+/*     Initialize constants and the random number seed. */
 
     s_copy(path, "Zomplex precision", (ftnlen)1, (ftnlen)17);
     s_copy(path + 1, "LS", (ftnlen)2, (ftnlen)2);
@@ -328,9 +339,9 @@ static doublereal c_b91 = -1.;
 
 			if (irank == 1) {
 
-/*                       Test ZGELS   
+/*                       Test ZGELS */
 
-                         Generate a matrix of scaling type ISCALE */
+/*                       Generate a matrix of scaling type ISCALE */
 
 			    zqrt13_(&iscale, &m, &n, &copya[1], &lda, &norma, 
 				    iseed);
@@ -420,8 +431,8 @@ static doublereal c_b91 = -1.;
 						&ldb, &work[1], &lwork);
 				    }
 
-/*                             Print information about the tests that   
-                               did not pass the threshold. */
+/*                             Print information about the tests that */
+/*                             did not pass the threshold. */
 
 				    for (k = 1; k <= 2; ++k) {
 					if (result[k - 1] >= *thresh) {
@@ -458,8 +469,8 @@ static doublereal c_b91 = -1.;
 			    }
 			}
 
-/*                    Generate a matrix of scaling type ISCALE and rank   
-                      type IRANK. */
+/*                    Generate a matrix of scaling type ISCALE and rank */
+/*                    type IRANK. */
 
 			zqrt15_(&iscale, &irank, &m, &n, &nrhs, &copya[1], &
 				lda, &copyb[1], &ldb, &copys[1], &rank, &
@@ -474,11 +485,11 @@ static doublereal c_b91 = -1.;
 			}
 			ldwork = max(1,m);
 
-/*                    Test ZGELSX   
+/*                    Test ZGELSX */
 
-                      ZGELSX:  Compute the minimum-norm solution X   
-                      to min( norm( A * X - B ) )   
-                      using a complete orthogonal factorization. */
+/*                    ZGELSX:  Compute the minimum-norm solution X */
+/*                    to min( norm( A * X - B ) ) */
+/*                    using a complete orthogonal factorization. */
 
 			zlacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &lda);
 			zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], &
@@ -487,55 +498,55 @@ static doublereal c_b91 = -1.;
 			s_copy(srnamc_1.srnamt, "ZGELSX", (ftnlen)6, (ftnlen)
 				6);
 			zgelsx_(&m, &n, &nrhs, &a[1], &lda, &b[1], &ldb, &
-				iwork[1], &rcond, &crank, &work[1], &rwork[1],
+				iwork[1], &rcond, &crank, &work[1], &rwork[1], 
 				 &info);
 
 			if (info != 0) {
-			    alaerh_(path, "ZGELSX", &info, &c__0, " ", &m, &n,
+			    alaerh_(path, "ZGELSX", &info, &c__0, " ", &m, &n, 
 				     &nrhs, &c_n1, &nb, &itype, &nfail, &
 				    nerrs, nout);
 			}
 
-/*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )   
+/*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS ) */
 
-                      Test 3:  Compute relative error in svd   
-                               workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
+/*                    Test 3:  Compute relative error in svd */
+/*                             workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
 
 			result[2] = zqrt12_(&crank, &crank, &a[1], &lda, &
 				copys[1], &work[1], &lwork, &rwork[1]);
 
-/*                    Test 4:  Compute error in solution   
-                               workspace:  M*NRHS + M */
+/*                    Test 4:  Compute error in solution */
+/*                             workspace:  M*NRHS + M */
 
 			zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &work[1], 
 				&ldwork);
 			zqrt16_("No transpose", &m, &n, &nrhs, &copya[1], &
 				lda, &b[1], &ldb, &work[1], &ldwork, &rwork[1]
-				, &result[3]);
+, &result[3]);
 
-/*                    Test 5:  Check norm of r'*A   
-                               workspace: NRHS*(M+N) */
+/*                    Test 5:  Check norm of r'*A */
+/*                             workspace: NRHS*(M+N) */
 
 			result[4] = 0.;
 			if (m > crank) {
-			    result[4] = zqrt17_("No transpose", &c__1, &m, &n,
+			    result[4] = zqrt17_("No transpose", &c__1, &m, &n, 
 				     &nrhs, &copya[1], &lda, &b[1], &ldb, &
 				    copyb[1], &ldb, &c__[1], &work[1], &lwork);
 			}
 
-/*                    Test 6:  Check if x is in the rowspace of A   
-                               workspace: (M+NRHS)*(N+2) */
+/*                    Test 6:  Check if x is in the rowspace of A */
+/*                             workspace: (M+NRHS)*(N+2) */
 
 			result[5] = 0.;
 
 			if (n > crank) {
-			    result[5] = zqrt14_("No transpose", &m, &n, &nrhs,
+			    result[5] = zqrt14_("No transpose", &m, &n, &nrhs, 
 				     &copya[1], &lda, &b[1], &ldb, &work[1], &
 				    lwork);
 			}
 
-/*                    Print information about the tests that did not   
-                      pass the threshold. */
+/*                    Print information about the tests that did not */
+/*                    pass the threshold. */
 
 			for (k = 3; k <= 6; ++k) {
 			    if (result[k - 1] >= *thresh) {
@@ -573,16 +584,16 @@ static doublereal c_b91 = -1.;
 			    xlaenv_(&c__1, &nb);
 			    xlaenv_(&c__3, &nxval[inb]);
 
-/*                       Test ZGELSY   
+/*                       Test ZGELSY */
 
-                         ZGELSY:  Compute the minimum-norm solution   
-                         X to min( norm( A * X - B ) )   
-                         using the rank-revealing orthogonal   
-                         factorization. */
+/*                       ZGELSY:  Compute the minimum-norm solution */
+/*                       X to min( norm( A * X - B ) ) */
+/*                       using the rank-revealing orthogonal */
+/*                       factorization. */
 
 			    zlacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &
 				    lda);
-			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1],
+			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], 
 				     &ldb);
 
 /*                       Initialize vector IWORK. */
@@ -593,9 +604,9 @@ static doublereal c_b91 = -1.;
 /* L70: */
 			    }
 
-/*                       Set LWLSY to the adequate value.   
+/*                       Set LWLSY to the adequate value. */
 
-   Computing MAX */
+/* Computing MAX */
 			    i__5 = mnmin << 1, i__6 = nb * (n + 1), i__5 = 
 				    max(i__5,i__6), i__6 = mnmin + nb * nrhs;
 			    lwlsy = mnmin + max(i__5,i__6);
@@ -607,21 +618,21 @@ static doublereal c_b91 = -1.;
 				    iwork[1], &rcond, &crank, &work[1], &
 				    lwlsy, &rwork[1], &info);
 			    if (info != 0) {
-				alaerh_(path, "ZGELSY", &info, &c__0, " ", &m,
+				alaerh_(path, "ZGELSY", &info, &c__0, " ", &m, 
 					 &n, &nrhs, &c_n1, &nb, &itype, &
 					nfail, &nerrs, nout);
 			    }
 
-/*                       workspace used: 2*MNMIN+NB*NB+NB*MAX(N,NRHS)   
+/*                       workspace used: 2*MNMIN+NB*NB+NB*MAX(N,NRHS) */
 
-                         Test 7:  Compute relative error in svd   
-                                  workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
+/*                       Test 7:  Compute relative error in svd */
+/*                                workspace: M*N + 4*MIN(M,N) + MAX(M,N) */
 
 			    result[6] = zqrt12_(&crank, &crank, &a[1], &lda, &
 				    copys[1], &work[1], &lwork, &rwork[1]);
 
-/*                       Test 8:  Compute error in solution   
-                                  workspace:  M*NRHS + M */
+/*                       Test 8:  Compute error in solution */
+/*                                workspace:  M*NRHS + M */
 
 			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &work[
 				    1], &ldwork);
@@ -629,19 +640,19 @@ static doublereal c_b91 = -1.;
 				    &lda, &b[1], &ldb, &work[1], &ldwork, &
 				    rwork[1], &result[7]);
 
-/*                       Test 9:  Check norm of r'*A   
-                                  workspace: NRHS*(M+N) */
+/*                       Test 9:  Check norm of r'*A */
+/*                                workspace: NRHS*(M+N) */
 
 			    result[8] = 0.;
 			    if (m > crank) {
-				result[8] = zqrt17_("No transpose", &c__1, &m,
+				result[8] = zqrt17_("No transpose", &c__1, &m, 
 					 &n, &nrhs, &copya[1], &lda, &b[1], &
 					ldb, &copyb[1], &ldb, &c__[1], &work[
 					1], &lwork);
 			    }
 
-/*                       Test 10:  Check if x is in the rowspace of A   
-                                  workspace: (M+NRHS)*(N+2) */
+/*                       Test 10:  Check if x is in the rowspace of A */
+/*                                workspace: (M+NRHS)*(N+2) */
 
 			    result[9] = 0.;
 
@@ -651,15 +662,15 @@ static doublereal c_b91 = -1.;
 					work[1], &lwork);
 			    }
 
-/*                       Test ZGELSS   
+/*                       Test ZGELSS */
 
-                         ZGELSS:  Compute the minimum-norm solution   
-                         X to min( norm( A * X - B ) )   
-                         using the SVD. */
+/*                       ZGELSS:  Compute the minimum-norm solution */
+/*                       X to min( norm( A * X - B ) ) */
+/*                       using the SVD. */
 
 			    zlacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &
 				    lda);
-			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1],
+			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], 
 				     &ldb);
 			    s_copy(srnamc_1.srnamt, "ZGELSS", (ftnlen)6, (
 				    ftnlen)6);
@@ -668,15 +679,15 @@ static doublereal c_b91 = -1.;
 				    rwork[1], &info);
 
 			    if (info != 0) {
-				alaerh_(path, "ZGELSS", &info, &c__0, " ", &m,
+				alaerh_(path, "ZGELSS", &info, &c__0, " ", &m, 
 					 &n, &nrhs, &c_n1, &nb, &itype, &
 					nfail, &nerrs, nout);
 			    }
 
-/*                       workspace used: 3*min(m,n) +   
-                                         max(2*min(m,n),nrhs,max(m,n))   
+/*                       workspace used: 3*min(m,n) + */
+/*                                       max(2*min(m,n),nrhs,max(m,n)) */
 
-                         Test 11:  Compute relative error in svd */
+/*                       Test 11:  Compute relative error in svd */
 
 			    if (rank > 0) {
 				daxpy_(&mnmin, &c_b91, &copys[1], &c__1, &s[1]
@@ -715,17 +726,17 @@ static doublereal c_b91 = -1.;
 					work[1], &lwork);
 			    }
 
-/*                       Test ZGELSD   
+/*                       Test ZGELSD */
 
-                         ZGELSD:  Compute the minimum-norm solution X   
-                         to min( norm( A * X - B ) ) using a   
-                         divide and conquer SVD. */
+/*                       ZGELSD:  Compute the minimum-norm solution X */
+/*                       to min( norm( A * X - B ) ) using a */
+/*                       divide and conquer SVD. */
 
 			    xlaenv_(&c__9, &c__25);
 
 			    zlacpy_("Full", &m, &n, &copya[1], &lda, &a[1], &
 				    lda);
-			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1],
+			    zlacpy_("Full", &m, &nrhs, &copyb[1], &ldb, &b[1], 
 				     &ldb);
 
 			    s_copy(srnamc_1.srnamt, "ZGELSD", (ftnlen)6, (
@@ -734,7 +745,7 @@ static doublereal c_b91 = -1.;
 				    s[1], &rcond, &crank, &work[1], &lwork, &
 				    rwork[1], &iwork[1], &info);
 			    if (info != 0) {
-				alaerh_(path, "ZGELSD", &info, &c__0, " ", &m,
+				alaerh_(path, "ZGELSD", &info, &c__0, " ", &m, 
 					 &n, &nrhs, &c_n1, &nb, &itype, &
 					nfail, &nerrs, nout);
 			    }
@@ -778,8 +789,8 @@ static doublereal c_b91 = -1.;
 					work[1], &lwork);
 			    }
 
-/*                       Print information about the tests that did not   
-                         pass the threshold. */
+/*                       Print information about the tests that did not */
+/*                       pass the threshold. */
 
 			    for (k = 7; k <= 18; ++k) {
 				if (result[k - 1] >= *thresh) {
