@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zerrge.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -49,15 +37,15 @@ static integer c__4 = 4;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static doublecomplex a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static doublereal r__[4];
-    static doublecomplex w[8], x[4];
-    static char c2[2];
-    static doublereal r1[4], r2[4];
-    static doublecomplex af[16]	/* was [4][4] */;
-    static integer ip[4], info;
-    static doublereal anrm, ccond, rcond;
+    doublecomplex a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    doublereal r__[4];
+    doublecomplex w[8], x[4];
+    char c2[2];
+    doublereal r1[4], r2[4];
+    doublecomplex af[16]	/* was [4][4] */;
+    integer ip[4], info;
+    doublereal anrm, ccond, rcond;
     extern /* Subroutine */ int zgbtf2_(integer *, integer *, integer *, 
 	    integer *, doublecomplex *, integer *, integer *, integer *), 
 	    zgetf2_(integer *, integer *, doublecomplex *, integer *, integer 
@@ -66,8 +54,10 @@ static integer c__4 = 4;
     extern /* Subroutine */ int zgbcon_(char *, integer *, integer *, integer 
 	    *, doublecomplex *, integer *, integer *, doublereal *, 
 	    doublereal *, doublecomplex *, doublereal *, integer *), 
-	    chkxer_(char *, integer *, integer *, logical *, logical *), zgecon_(char *, integer *, doublecomplex *, integer *,	    doublereal *, doublereal *, doublecomplex *, doublereal *,	    integer *), zgbequ_(integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    chkxer_(char *, integer *, integer *, logical *, logical *), zgecon_(char *, integer *, doublecomplex *, integer *, 
+	    doublereal *, doublereal *, doublecomplex *, doublereal *, 
+	    integer *), zgbequ_(integer *, integer *, integer *, 
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublereal *, doublereal *, doublereal *, integer *), zgbrfs_(
 	    char *, integer *, integer *, integer *, integer *, doublecomplex 
 	    *, integer *, doublecomplex *, integer *, integer *, 
@@ -78,16 +68,16 @@ static integer c__4 = 4;
 	    zgeequ_(integer *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, integer *), zgerfs_(char *, integer *, integer *, 
-	    doublecomplex *, integer *, doublecomplex *, integer *, integer *,
+	    doublecomplex *, integer *, doublecomplex *, integer *, integer *, 
 	     doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublecomplex *, doublereal *, 
-	    integer *), zgetrf_(integer *, integer *, doublecomplex *,
+	    integer *), zgetrf_(integer *, integer *, doublecomplex *, 
 	     integer *, integer *, integer *), zgetri_(integer *, 
-	    doublecomplex *, integer *, integer *, doublecomplex *, integer *,
+	    doublecomplex *, integer *, integer *, doublecomplex *, integer *, 
 	     integer *), zgbtrs_(char *, integer *, integer *, integer *, 
-	    integer *, doublecomplex *, integer *, integer *, doublecomplex *,
+	    integer *, doublecomplex *, integer *, integer *, doublecomplex *, 
 	     integer *, integer *), zgetrs_(char *, integer *, 
-	    integer *, doublecomplex *, integer *, integer *, doublecomplex *,
+	    integer *, doublecomplex *, integer *, integer *, doublecomplex *, 
 	     integer *, integer *);
 
     /* Fortran I/O blocks */
@@ -95,28 +85,47 @@ static integer c__4 = 4;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZERRGE tests the error exits for the COMPLEX*16 routines   
-    for general matrices.   
+/*  ZERRGE tests the error exits for the COMPLEX*16 routines */
+/*  for general matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -153,8 +162,8 @@ static integer c__4 = 4;
     }
     infoc_1.ok = TRUE_;
 
-/*     Test error exits of the routines that use the LU decomposition   
-       of a general matrix. */
+/*     Test error exits of the routines that use the LU decomposition */
+/*     of a general matrix. */
 
     if (lsamen_(&c__2, c2, "GE")) {
 
@@ -304,8 +313,8 @@ static integer c__4 = 4;
 	chkxer_("ZGEEQU", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 
-/*     Test error exits of the routines that use the LU decomposition   
-       of a general band matrix. */
+/*     Test error exits of the routines that use the LU decomposition */
+/*     of a general band matrix. */
 
     } else if (lsamen_(&c__2, c2, "GB")) {
 
@@ -449,27 +458,27 @@ static integer c__4 = 4;
 
 	s_copy(srnamc_1.srnamt, "ZGBCON", (ftnlen)6, (ftnlen)6);
 	infoc_1.infot = 1;
-	zgbcon_("/", &c__0, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__,
+	zgbcon_("/", &c__0, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("ZGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 2;
-	zgbcon_("1", &c_n1, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__,
+	zgbcon_("1", &c_n1, &c__0, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("ZGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 3;
-	zgbcon_("1", &c__1, &c_n1, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__,
+	zgbcon_("1", &c__1, &c_n1, &c__0, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("ZGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 4;
-	zgbcon_("1", &c__1, &c__0, &c_n1, a, &c__1, ip, &anrm, &rcond, w, r__,
+	zgbcon_("1", &c__1, &c__0, &c_n1, a, &c__1, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("ZGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 	infoc_1.infot = 6;
-	zgbcon_("1", &c__2, &c__1, &c__1, a, &c__3, ip, &anrm, &rcond, w, r__,
+	zgbcon_("1", &c__2, &c__1, &c__1, a, &c__3, ip, &anrm, &rcond, w, r__, 
 		 &info);
 	chkxer_("ZGBCON", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
