@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zerrpo.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Common Block Declarations */
 
@@ -47,15 +35,15 @@ static integer c_n1 = -1;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static doublecomplex a[16]	/* was [4][4] */, b[4];
-    static integer i__, j;
-    static doublereal r__[4];
-    static doublecomplex w[8], x[4];
-    static char c2[2];
-    static doublereal r1[4], r2[4];
-    static doublecomplex af[16]	/* was [4][4] */;
-    static integer info;
-    static doublereal anrm, rcond;
+    doublecomplex a[16]	/* was [4][4] */, b[4];
+    integer i__, j;
+    doublereal r__[4];
+    doublecomplex w[8], x[4];
+    char c2[2];
+    doublereal r1[4], r2[4];
+    doublecomplex af[16]	/* was [4][4] */;
+    integer info;
+    doublereal anrm, rcond;
     extern /* Subroutine */ int zpbtf2_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, integer *), zpotf2_(char *, 
 	    integer *, doublecomplex *, integer *, integer *), 
@@ -64,23 +52,23 @@ static integer c_n1 = -1;
     extern /* Subroutine */ int chkxer_(char *, integer *, integer *, logical 
 	    *, logical *), zpbcon_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublereal *, 
-	    doublecomplex *, doublereal *, integer *), zpbequ_(char *,
+	    doublecomplex *, doublereal *, integer *), zpbequ_(char *, 
 	     integer *, integer *, doublecomplex *, integer *, doublereal *, 
 	    doublereal *, doublereal *, integer *), zpbrfs_(char *, 
 	    integer *, integer *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublereal *, doublereal *, 
-	    doublecomplex *, doublereal *, integer *), zpbtrf_(char *,
+	    doublecomplex *, doublereal *, integer *), zpbtrf_(char *, 
 	     integer *, integer *, doublecomplex *, integer *, integer *), zpocon_(char *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *, doublecomplex *, doublereal *, 
 	    integer *), zppcon_(char *, integer *, doublecomplex *, 
 	    doublereal *, doublereal *, doublecomplex *, doublereal *, 
-	    integer *), zpoequ_(integer *, doublecomplex *, integer *,
+	    integer *), zpoequ_(integer *, doublecomplex *, integer *, 
 	     doublereal *, doublereal *, doublereal *, integer *), zpbtrs_(
 	    char *, integer *, integer *, integer *, doublecomplex *, integer 
-	    *, doublecomplex *, integer *, integer *), zporfs_(char *,
+	    *, doublecomplex *, integer *, integer *), zporfs_(char *, 
 	     integer *, integer *, doublecomplex *, integer *, doublecomplex *
-	    , integer *, doublecomplex *, integer *, doublecomplex *, integer 
+, integer *, doublecomplex *, integer *, doublecomplex *, integer 
 	    *, doublereal *, doublereal *, doublecomplex *, doublereal *, 
 	    integer *), zpotrf_(char *, integer *, doublecomplex *, 
 	    integer *, integer *), zpotri_(char *, integer *, 
@@ -88,11 +76,11 @@ static integer c_n1 = -1;
 	    integer *, doublecomplex *, doublereal *, doublereal *, 
 	    doublereal *, integer *), zpprfs_(char *, integer *, 
 	    integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *, doublereal *, doublereal *,
+	    integer *, doublecomplex *, integer *, doublereal *, doublereal *, 
 	     doublecomplex *, doublereal *, integer *), zpptrf_(char *
-	    , integer *, doublecomplex *, integer *), zpptri_(char *, 
+, integer *, doublecomplex *, integer *), zpptri_(char *, 
 	    integer *, doublecomplex *, integer *), zpotrs_(char *, 
-	    integer *, integer *, doublecomplex *, integer *, doublecomplex *,
+	    integer *, integer *, doublecomplex *, integer *, doublecomplex *, 
 	     integer *, integer *), zpptrs_(char *, integer *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *, integer *);
 
@@ -101,28 +89,47 @@ static integer c_n1 = -1;
 
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZERRPO tests the error exits for the COMPLEX*16 routines   
-    for Hermitian positive definite matrices.   
+/*  ZERRPO tests the error exits for the COMPLEX*16 routines */
+/*  for Hermitian positive definite matrices. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    PATH    (input) CHARACTER*3   
-            The LAPACK path name for the routines to be tested.   
+/*  PATH    (input) CHARACTER*3 */
+/*          The LAPACK path name for the routines to be tested. */
 
-    NUNIT   (input) INTEGER   
-            The unit number for output.   
+/*  NUNIT   (input) INTEGER */
+/*          The unit number for output. */
 
-    ===================================================================== */
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Local Arrays .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Scalars in Common .. */
+/*     .. */
+/*     .. Common blocks .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
     infoc_1.nout = *nunit;
     io___1.ciunit = infoc_1.nout;
@@ -159,8 +166,8 @@ static integer c_n1 = -1;
     anrm = 1.;
     infoc_1.ok = TRUE_;
 
-/*     Test error exits of the routines that use the Cholesky   
-       decomposition of a Hermitian positive definite matrix. */
+/*     Test error exits of the routines that use the Cholesky */
+/*     decomposition of a Hermitian positive definite matrix. */
 
     if (lsamen_(&c__2, c2, "PO")) {
 
@@ -312,8 +319,8 @@ static integer c_n1 = -1;
 	chkxer_("ZPOEQU", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 
-/*     Test error exits of the routines that use the Cholesky   
-       decomposition of a Hermitian positive definite packed matrix. */
+/*     Test error exits of the routines that use the Cholesky */
+/*     decomposition of a Hermitian positive definite packed matrix. */
 
     } else if (lsamen_(&c__2, c2, "PP")) {
 
@@ -419,8 +426,8 @@ static integer c_n1 = -1;
 	chkxer_("ZPPEQU", &infoc_1.infot, &infoc_1.nout, &infoc_1.lerr, &
 		infoc_1.ok);
 
-/*     Test error exits of the routines that use the Cholesky   
-       decomposition of a Hermitian positive definite band matrix. */
+/*     Test error exits of the routines that use the Cholesky */
+/*     decomposition of a Hermitian positive definite band matrix. */
 
     } else if (lsamen_(&c__2, c2, "PB")) {
 
