@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zlattb.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -22,129 +10,147 @@ static integer c__4 = 4;
 static doublereal c_b91 = 2.;
 static integer c_n1 = -1;
 
-/* Subroutine */ int zlattb_(integer *imat, char *uplo, char *trans, char * 	diag, integer *iseed, integer *n, integer *kd, doublecomplex *ab,  	integer *ldab, doublecomplex *b, doublecomplex *work, doublereal * 	rwork, integer *info  	)
+/* Subroutine */ int zlattb_(integer *imat, char *uplo, char *trans, char *
+	diag, integer *iseed, integer *n, integer *kd, doublecomplex *ab, 
+	integer *ldab, doublecomplex *b, doublecomplex *work, doublereal *
+	rwork, integer *info)
 {
     /* System generated locals */
     integer ab_dim1, ab_offset, i__1, i__2, i__3, i__4, i__5;
     doublereal d__1, d__2;
     doublecomplex z__1, z__2;
 
-    /* Builtin functions   
-       Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double sqrt(doublereal);
     void z_div(doublecomplex *, doublecomplex *, doublecomplex *);
     double pow_dd(doublereal *, doublereal *), z_abs(doublecomplex *);
 
     /* Local variables */
-    static integer i__, j, kl, ku, iy;
-    static doublereal ulp, sfac;
-    static integer ioff, mode, lenj;
-    static char path[3], dist[1];
-    static doublereal unfl, rexp;
-    static char type__[1];
-    static doublereal texp;
-    static doublecomplex star1, plus1, plus2;
-    static doublereal bscal;
+    integer i__, j, kl, ku, iy;
+    doublereal ulp, sfac;
+    integer ioff, mode, lenj;
+    char path[3], dist[1];
+    doublereal unfl, rexp;
+    char type__[1];
+    doublereal texp;
+    doublecomplex star1, plus1, plus2;
+    doublereal bscal;
     extern logical lsame_(char *, char *);
-    static doublereal tscal, anorm, bnorm, tleft;
-    static logical upper;
-    static doublereal tnorm;
+    doublereal tscal, anorm, bnorm, tleft;
+    logical upper;
+    doublereal tnorm;
     extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), zswap_(integer *, doublecomplex *, 
-	    integer *, doublecomplex *, integer *), zlatb4_(char *, integer *,
-	     integer *, integer *, char *, integer *, integer *, doublereal *,
+	    integer *, doublecomplex *, integer *), zlatb4_(char *, integer *, 
+	     integer *, integer *, char *, integer *, integer *, doublereal *, 
 	     integer *, doublereal *, char *), 
 	    dlabad_(doublereal *, doublereal *);
     extern doublereal dlamch_(char *), dlarnd_(integer *, integer *);
-    static char packit[1];
+    char packit[1];
     extern /* Subroutine */ int zdscal_(integer *, doublereal *, 
 	    doublecomplex *, integer *);
-    static doublereal bignum, cndnum;
+    doublereal bignum, cndnum;
     extern /* Subroutine */ int dlarnv_(integer *, integer *, integer *, 
 	    doublereal *);
     extern integer izamax_(integer *, doublecomplex *, integer *);
     extern /* Double Complex */ VOID zlarnd_(doublecomplex *, integer *, 
 	    integer *);
-    static integer jcount;
+    integer jcount;
     extern /* Subroutine */ int zlatms_(integer *, integer *, char *, integer 
 	    *, char *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, integer *, char *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
-    static doublereal smlnum;
+    doublereal smlnum;
     extern /* Subroutine */ int zlarnv_(integer *, integer *, integer *, 
 	    doublecomplex *);
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-    ZLATTB generates a triangular test matrix in 2-dimensional storage.   
-    IMAT and UPLO uniquely specify the properties of the test matrix,   
-    which is returned in the array A.   
+/*  ZLATTB generates a triangular test matrix in 2-dimensional storage. */
+/*  IMAT and UPLO uniquely specify the properties of the test matrix, */
+/*  which is returned in the array A. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    IMAT    (input) INTEGER   
-            An integer key describing which matrix to generate for this   
-            path.   
+/*  IMAT    (input) INTEGER */
+/*          An integer key describing which matrix to generate for this */
+/*          path. */
 
-    UPLO    (input) CHARACTER*1   
-            Specifies whether the matrix A will be upper or lower   
-            triangular.   
-            = 'U':  Upper triangular   
-            = 'L':  Lower triangular   
+/*  UPLO    (input) CHARACTER*1 */
+/*          Specifies whether the matrix A will be upper or lower */
+/*          triangular. */
+/*          = 'U':  Upper triangular */
+/*          = 'L':  Lower triangular */
 
-    TRANS   (input) CHARACTER*1   
-            Specifies whether the matrix or its transpose will be used.   
-            = 'N':  No transpose   
-            = 'T':  Transpose   
-            = 'C':  Conjugate transpose (= transpose)   
+/*  TRANS   (input) CHARACTER*1 */
+/*          Specifies whether the matrix or its transpose will be used. */
+/*          = 'N':  No transpose */
+/*          = 'T':  Transpose */
+/*          = 'C':  Conjugate transpose (= transpose) */
 
-    DIAG    (output) CHARACTER*1   
-            Specifies whether or not the matrix A is unit triangular.   
-            = 'N':  Non-unit triangular   
-            = 'U':  Unit triangular   
+/*  DIAG    (output) CHARACTER*1 */
+/*          Specifies whether or not the matrix A is unit triangular. */
+/*          = 'N':  Non-unit triangular */
+/*          = 'U':  Unit triangular */
 
-    ISEED   (input/output) INTEGER array, dimension (4)   
-            The seed vector for the random number generator (used in   
-            ZLATMS).  Modified on exit.   
+/*  ISEED   (input/output) INTEGER array, dimension (4) */
+/*          The seed vector for the random number generator (used in */
+/*          ZLATMS).  Modified on exit. */
 
-    N       (input) INTEGER   
-            The order of the matrix to be generated.   
+/*  N       (input) INTEGER */
+/*          The order of the matrix to be generated. */
 
-    KD      (input) INTEGER   
-            The number of superdiagonals or subdiagonals of the banded   
-            triangular matrix A.  KD >= 0.   
+/*  KD      (input) INTEGER */
+/*          The number of superdiagonals or subdiagonals of the banded */
+/*          triangular matrix A.  KD >= 0. */
 
-    AB      (output) COMPLEX*16 array, dimension (LDAB,N)   
-            The upper or lower triangular banded matrix A, stored in the   
-            first KD+1 rows of AB.  Let j be a column of A, 1<=j<=n.   
-            If UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j.   
-            If UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd).   
+/*  AB      (output) COMPLEX*16 array, dimension (LDAB,N) */
+/*          The upper or lower triangular banded matrix A, stored in the */
+/*          first KD+1 rows of AB.  Let j be a column of A, 1<=j<=n. */
+/*          If UPLO = 'U', AB(kd+1+i-j,j) = A(i,j) for max(1,j-kd)<=i<=j. */
+/*          If UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+kd). */
 
-    LDAB    (input) INTEGER   
-            The leading dimension of the array AB.  LDAB >= KD+1.   
+/*  LDAB    (input) INTEGER */
+/*          The leading dimension of the array AB.  LDAB >= KD+1. */
 
-    B       (workspace) COMPLEX*16 array, dimension (N)   
+/*  B       (workspace) COMPLEX*16 array, dimension (N) */
 
-    WORK    (workspace) COMPLEX*16 array, dimension (2*N)   
+/*  WORK    (workspace) COMPLEX*16 array, dimension (2*N) */
 
-    RWORK   (workspace) DOUBLE PRECISION array, dimension (N)   
+/*  RWORK   (workspace) DOUBLE PRECISION array, dimension (N) */
 
-    INFO    (output) INTEGER   
-            = 0:  successful exit   
-            < 0:  if INFO = -i, the i-th argument had an illegal value   
+/*  INFO    (output) INTEGER */
+/*          = 0:  successful exit */
+/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --iseed;
     ab_dim1 = *ldab;
     ab_offset = 1 + ab_dim1;
@@ -203,10 +209,10 @@ static integer c_n1 = -1;
 		anorm, &kl, &ku, packit, &ab[ioff + ab_dim1], ldab, &work[1], 
 		info);
 
-/*     IMAT > 5:  Unit triangular matrix   
-       The diagonal is deliberately set to something other than 1.   
+/*     IMAT > 5:  Unit triangular matrix */
+/*     The diagonal is deliberately set to something other than 1. */
 
-       IMAT = 6:  Matrix is the identity */
+/*     IMAT = 6:  Matrix is the identity */
 
     } else if (*imat == 6) {
 	if (upper) {
@@ -241,10 +247,10 @@ static integer c_n1 = -1;
 	    }
 	}
 
-/*     IMAT > 6:  Non-trivial unit triangular matrix   
+/*     IMAT > 6:  Non-trivial unit triangular matrix */
 
-       A unit triangular matrix T with condition CNDNUM is formed.   
-       In this version, T only has bandwidth 2, the rest of it is zero. */
+/*     A unit triangular matrix T with condition CNDNUM is formed. */
+/*     In this version, T only has bandwidth 2, the rest of it is zero. */
 
     } else if (*imat <= 9) {
 	tnorm = sqrt(cndnum);
@@ -285,8 +291,8 @@ static integer c_n1 = -1;
 	    }
 	}
 
-/*        Special case:  T is tridiagonal.  Set every other offdiagonal   
-          so that the matrix has norm TNORM+1. */
+/*        Special case:  T is tridiagonal.  Set every other offdiagonal */
+/*        so that the matrix has norm TNORM+1. */
 
 	if (*kd == 1) {
 	    if (upper) {
@@ -324,21 +330,21 @@ static integer c_n1 = -1;
 	    }
 	} else if (*kd > 1) {
 
-/*           Form a unit triangular matrix T with condition CNDNUM.  T is   
-             given by   
-                     | 1   +   *                      |   
-                     |     1   +                      |   
-                 T = |         1   +   *              |   
-                     |             1   +              |   
-                     |                 1   +   *      |   
-                     |                     1   +      |   
-                     |                          . . . |   
-          Each element marked with a '*' is formed by taking the product   
-          of the adjacent elements marked with '+'.  The '*'s can be   
-          chosen freely, and the '+'s are chosen so that the inverse of   
-          T will have elements of the same magnitude as T.   
+/*           Form a unit triangular matrix T with condition CNDNUM.  T is */
+/*           given by */
+/*                   | 1   +   *                      | */
+/*                   |     1   +                      | */
+/*               T = |         1   +   *              | */
+/*                   |             1   +              | */
+/*                   |                 1   +   *      | */
+/*                   |                     1   +      | */
+/*                   |                          . . . | */
+/*        Each element marked with a '*' is formed by taking the product */
+/*        of the adjacent elements marked with '+'.  The '*'s can be */
+/*        chosen freely, and the '+'s are chosen so that the inverse of */
+/*        T will have elements of the same magnitude as T. */
 
-          The two offdiagonals of T are stored in WORK. */
+/*        The two offdiagonals of T are stored in WORK. */
 
 	    zlarnd_(&z__2, &c__5, &iseed[1]);
 	    z__1.r = tnorm * z__2.r, z__1.i = tnorm * z__2.i;
@@ -363,8 +369,8 @@ static integer c_n1 = -1;
 		    z_div(&z__1, &star1, &plus2);
 		    plus1.r = z__1.r, plus1.i = z__1.i;
 
-/*                 Generate a new *-value with norm between sqrt(TNORM)   
-                   and TNORM. */
+/*                 Generate a new *-value with norm between sqrt(TNORM) */
+/*                 and TNORM. */
 
 		    rexp = dlarnd_(&c__2, &iseed[1]);
 		    if (rexp < 0.) {
@@ -401,15 +407,15 @@ static integer c_n1 = -1;
 	    }
 	}
 
-/*     IMAT > 9:  Pathological test cases.  These triangular matrices   
-       are badly scaled or badly conditioned, so when used in solving a   
-       triangular system they may cause overflow in the solution vector. */
+/*     IMAT > 9:  Pathological test cases.  These triangular matrices */
+/*     are badly scaled or badly conditioned, so when used in solving a */
+/*     triangular system they may cause overflow in the solution vector. */
 
     } else if (*imat == 10) {
 
-/*        Type 10:  Generate a triangular matrix with elements between   
-          -1 and 1. Give the diagonal norm 2 to make it well-conditioned.   
-          Make the right hand side large so that it requires scaling. */
+/*        Type 10:  Generate a triangular matrix with elements between */
+/*        -1 and 1. Give the diagonal norm 2 to make it well-conditioned. */
+/*        Make the right hand side large so that it requires scaling. */
 
 	if (upper) {
 	    i__1 = *n;
@@ -452,9 +458,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 11) {
 
-/*        Type 11:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 11, the offdiagonal elements are small (CNORM(j) < 1). */
+/*        Type 11:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 11, the offdiagonal elements are small (CNORM(j) < 1). */
 
 	zlarnv_(&c__2, &iseed[1], n, &b[1]);
 	tscal = 1. / (doublereal) (*kd + 1);
@@ -502,9 +508,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 12) {
 
-/*        Type 12:  Make the first diagonal element in the solve small to   
-          cause immediate overflow when dividing by T(j,j).   
-          In type 12, the offdiagonal elements are O(1) (CNORM(j) > 1). */
+/*        Type 12:  Make the first diagonal element in the solve small to */
+/*        cause immediate overflow when dividing by T(j,j). */
+/*        In type 12, the offdiagonal elements are O(1) (CNORM(j) > 1). */
 
 	zlarnv_(&c__2, &iseed[1], n, &b[1]);
 	if (upper) {
@@ -548,9 +554,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 13) {
 
-/*        Type 13:  T is diagonal with small numbers on the diagonal to   
-          make the growth factor underflow, but a small right hand side   
-          chosen so that the solution does not overflow. */
+/*        Type 13:  T is diagonal with small numbers on the diagonal to */
+/*        make the growth factor underflow, but a small right hand side */
+/*        chosen so that the solution does not overflow. */
 
 	if (upper) {
 	    jcount = 1;
@@ -639,9 +645,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 14) {
 
-/*        Type 14:  Make the diagonal elements small to cause gradual   
-          overflow when dividing by T(j,j).  To control the amount of   
-          scaling needed, the matrix is bidiagonal. */
+/*        Type 14:  Make the diagonal elements small to cause gradual */
+/*        overflow when dividing by T(j,j).  To control the amount of */
+/*        scaling needed, the matrix is bidiagonal. */
 
 	texp = 1. / (doublereal) (*kd + 1);
 	tscal = pow_dd(&smlnum, &texp);
@@ -741,10 +747,10 @@ static integer c_n1 = -1;
 
     } else if (*imat == 16) {
 
-/*        Type 16:  Make the offdiagonal elements large to cause overflow   
-          when adding a column of T.  In the non-transposed case, the   
-          matrix is constructed to cause overflow when adding a column in   
-          every other step. */
+/*        Type 16:  Make the offdiagonal elements large to cause overflow */
+/*        when adding a column of T.  In the non-transposed case, the */
+/*        matrix is constructed to cause overflow when adding a column in */
+/*        every other step. */
 
 	tscal = unfl / ulp;
 	tscal = (1. - ulp) / tscal;
@@ -850,9 +856,9 @@ static integer c_n1 = -1;
 
     } else if (*imat == 17) {
 
-/*        Type 17:  Generate a unit triangular matrix with elements   
-          between -1 and 1, and make the right hand side large so that it   
-          requires scaling. */
+/*        Type 17:  Generate a unit triangular matrix with elements */
+/*        between -1 and 1, and make the right hand side large so that it */
+/*        requires scaling. */
 
 	if (upper) {
 	    i__2 = *n;
@@ -893,10 +899,10 @@ static integer c_n1 = -1;
 
     } else if (*imat == 18) {
 
-/*        Type 18:  Generate a triangular matrix with elements between   
-          BIGNUM/(KD+1) and BIGNUM so that at least one of the column   
-          norms will exceed BIGNUM.   
-          1/3/91:  ZLATBS no longer can handle this case */
+/*        Type 18:  Generate a triangular matrix with elements between */
+/*        BIGNUM/(KD+1) and BIGNUM so that at least one of the column */
+/*        norms will exceed BIGNUM. */
+/*        1/3/91:  ZLATBS no longer can handle this case */
 
 	tleft = bignum / (doublereal) (*kd + 1);
 	tscal = bignum * ((doublereal) (*kd + 1) / (doublereal) (*kd + 2));
