@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* zlavhp.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -30,9 +18,9 @@ static integer c__1 = 1;
     void d_cnjg(doublecomplex *, doublecomplex *);
 
     /* Local variables */
-    static integer j, k;
-    static doublecomplex t1, t2, d11, d12, d21, d22;
-    static integer kc, kp;
+    integer j, k;
+    doublecomplex t1, t2, d11, d12, d21, d22;
+    integer kc, kp;
     extern logical lsame_(char *, char *);
     extern /* Subroutine */ int zscal_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *), zgemv_(char *, integer *, integer *, 
@@ -41,112 +29,127 @@ static integer c__1 = 1;
 	    zgeru_(integer *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *, integer *, doublecomplex *, integer *)
 	    , zswap_(integer *, doublecomplex *, integer *, doublecomplex *, 
-	    integer *), xerbla_(char *, integer *), zlacgv_(integer *,
+	    integer *), xerbla_(char *, integer *), zlacgv_(integer *, 
 	     doublecomplex *, integer *);
-    static integer kcnext;
-    static logical nounit;
+    integer kcnext;
+    logical nounit;
 
 
-/*  -- LAPACK auxiliary routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       ZLAVHP  performs one of the matrix-vector operations   
-          x := A*x  or  x := A^H*x,   
-       where x is an N element vector and  A is one of the factors   
-       from the symmetric factorization computed by ZHPTRF.   
-       ZHPTRF produces a factorization of the form   
-            U * D * U^H     or     L * D * L^H,   
-       where U (or L) is a product of permutation and unit upper (lower)   
-       triangular matrices, U^H (or L^H) is the conjugate transpose of   
-       U (or L), and D is Hermitian and block diagonal with 1 x 1 and   
-       2 x 2 diagonal blocks.  The multipliers for the transformations   
-       and the upper or lower triangular parts of the diagonal blocks   
-       are stored columnwise in packed format in the linear array A.   
+/*     ZLAVHP  performs one of the matrix-vector operations */
+/*        x := A*x  or  x := A^H*x, */
+/*     where x is an N element vector and  A is one of the factors */
+/*     from the symmetric factorization computed by ZHPTRF. */
+/*     ZHPTRF produces a factorization of the form */
+/*          U * D * U^H     or     L * D * L^H, */
+/*     where U (or L) is a product of permutation and unit upper (lower) */
+/*     triangular matrices, U^H (or L^H) is the conjugate transpose of */
+/*     U (or L), and D is Hermitian and block diagonal with 1 x 1 and */
+/*     2 x 2 diagonal blocks.  The multipliers for the transformations */
+/*     and the upper or lower triangular parts of the diagonal blocks */
+/*     are stored columnwise in packed format in the linear array A. */
 
-       If TRANS = 'N' or 'n', ZLAVHP multiplies either by U or U * D   
-       (or L or L * D).   
-       If TRANS = 'C' or 'c', ZLAVHP multiplies either by U^H or D * U^H   
-       (or L^H or D * L^H ).   
+/*     If TRANS = 'N' or 'n', ZLAVHP multiplies either by U or U * D */
+/*     (or L or L * D). */
+/*     If TRANS = 'C' or 'c', ZLAVHP multiplies either by U^H or D * U^H */
+/*     (or L^H or D * L^H ). */
 
-    Arguments   
-    ==========   
+/*  Arguments */
+/*  ========== */
 
-    UPLO   - CHARACTER*1   
-             On entry, UPLO specifies whether the triangular matrix   
-             stored in A is upper or lower triangular.   
-                UPLO = 'U' or 'u'   The matrix is upper triangular.   
-                UPLO = 'L' or 'l'   The matrix is lower triangular.   
-             Unchanged on exit.   
+/*  UPLO   - CHARACTER*1 */
+/*           On entry, UPLO specifies whether the triangular matrix */
+/*           stored in A is upper or lower triangular. */
+/*              UPLO = 'U' or 'u'   The matrix is upper triangular. */
+/*              UPLO = 'L' or 'l'   The matrix is lower triangular. */
+/*           Unchanged on exit. */
 
-    TRANS  - CHARACTER*1   
-             On entry, TRANS specifies the operation to be performed as   
-             follows:   
-                TRANS = 'N' or 'n'   x := A*x.   
-                TRANS = 'C' or 'c'   x := A^H*x.   
-             Unchanged on exit.   
+/*  TRANS  - CHARACTER*1 */
+/*           On entry, TRANS specifies the operation to be performed as */
+/*           follows: */
+/*              TRANS = 'N' or 'n'   x := A*x. */
+/*              TRANS = 'C' or 'c'   x := A^H*x. */
+/*           Unchanged on exit. */
 
-    DIAG   - CHARACTER*1   
-             On entry, DIAG specifies whether the diagonal blocks are   
-             assumed to be unit matrices, as follows:   
-                DIAG = 'U' or 'u'   Diagonal blocks are unit matrices.   
-                DIAG = 'N' or 'n'   Diagonal blocks are non-unit.   
-             Unchanged on exit.   
+/*  DIAG   - CHARACTER*1 */
+/*           On entry, DIAG specifies whether the diagonal blocks are */
+/*           assumed to be unit matrices, as follows: */
+/*              DIAG = 'U' or 'u'   Diagonal blocks are unit matrices. */
+/*              DIAG = 'N' or 'n'   Diagonal blocks are non-unit. */
+/*           Unchanged on exit. */
 
-    N      - INTEGER   
-             On entry, N specifies the order of the matrix A.   
-             N must be at least zero.   
-             Unchanged on exit.   
+/*  N      - INTEGER */
+/*           On entry, N specifies the order of the matrix A. */
+/*           N must be at least zero. */
+/*           Unchanged on exit. */
 
-    NRHS   - INTEGER   
-             On entry, NRHS specifies the number of right hand sides,   
-             i.e., the number of vectors x to be multiplied by A.   
-             NRHS must be at least zero.   
-             Unchanged on exit.   
+/*  NRHS   - INTEGER */
+/*           On entry, NRHS specifies the number of right hand sides, */
+/*           i.e., the number of vectors x to be multiplied by A. */
+/*           NRHS must be at least zero. */
+/*           Unchanged on exit. */
 
-    A      - COMPLEX*16 array, dimension( N*(N+1)/2 )   
-             On entry, A contains a block diagonal matrix and the   
-             multipliers of the transformations used to obtain it,   
-             stored as a packed triangular matrix.   
-             Unchanged on exit.   
+/*  A      - COMPLEX*16 array, dimension( N*(N+1)/2 ) */
+/*           On entry, A contains a block diagonal matrix and the */
+/*           multipliers of the transformations used to obtain it, */
+/*           stored as a packed triangular matrix. */
+/*           Unchanged on exit. */
 
-    IPIV   - INTEGER array, dimension( N )   
-             On entry, IPIV contains the vector of pivot indices as   
-             determined by ZSPTRF or ZHPTRF.   
-             If IPIV( K ) = K, no interchange was done.   
-             If IPIV( K ) <> K but IPIV( K ) > 0, then row K was inter-   
-             changed with row IPIV( K ) and a 1 x 1 pivot block was used.   
-             If IPIV( K ) < 0 and UPLO = 'U', then row K-1 was exchanged   
-             with row | IPIV( K ) | and a 2 x 2 pivot block was used.   
-             If IPIV( K ) < 0 and UPLO = 'L', then row K+1 was exchanged   
-             with row | IPIV( K ) | and a 2 x 2 pivot block was used.   
+/*  IPIV   - INTEGER array, dimension( N ) */
+/*           On entry, IPIV contains the vector of pivot indices as */
+/*           determined by ZSPTRF or ZHPTRF. */
+/*           If IPIV( K ) = K, no interchange was done. */
+/*           If IPIV( K ) <> K but IPIV( K ) > 0, then row K was inter- */
+/*           changed with row IPIV( K ) and a 1 x 1 pivot block was used. */
+/*           If IPIV( K ) < 0 and UPLO = 'U', then row K-1 was exchanged */
+/*           with row | IPIV( K ) | and a 2 x 2 pivot block was used. */
+/*           If IPIV( K ) < 0 and UPLO = 'L', then row K+1 was exchanged */
+/*           with row | IPIV( K ) | and a 2 x 2 pivot block was used. */
 
-    B      - COMPLEX*16 array, dimension( LDB, NRHS )   
-             On entry, B contains NRHS vectors of length N.   
-             On exit, B is overwritten with the product A * B.   
+/*  B      - COMPLEX*16 array, dimension( LDB, NRHS ) */
+/*           On entry, B contains NRHS vectors of length N. */
+/*           On exit, B is overwritten with the product A * B. */
 
-    LDB    - INTEGER   
-             On entry, LDB contains the leading dimension of B as   
-             declared in the calling program.  LDB must be at least   
-             max( 1, N ).   
-             Unchanged on exit.   
+/*  LDB    - INTEGER */
+/*           On entry, LDB contains the leading dimension of B as */
+/*           declared in the calling program.  LDB must be at least */
+/*           max( 1, N ). */
+/*           Unchanged on exit. */
 
-    INFO   - INTEGER   
-             INFO is the error flag.   
-             On exit, a value of 0 indicates a successful exit.   
-             A negative value, say -K, indicates that the K-th argument   
-             has an illegal value.   
+/*  INFO   - INTEGER */
+/*           INFO is the error flag. */
+/*           On exit, a value of 0 indicates a successful exit. */
+/*           A negative value, say -K, indicates that the K-th argument */
+/*           has an illegal value. */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       Test the input parameters.   
+/*     Test the input parameters. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --a;
     --ipiv;
     b_dim1 = *ldb;
@@ -181,15 +184,15 @@ static integer c__1 = 1;
     }
 
     nounit = lsame_(diag, "N");
-/* ------------------------------------------   
+/* ------------------------------------------ */
 
-       Compute  B := A * B  (No transpose)   
+/*     Compute  B := A * B  (No transpose) */
 
-   ------------------------------------------ */
+/* ------------------------------------------ */
     if (lsame_(trans, "N")) {
 
-/*        Compute  B := U*B   
-          where U = P(m)*inv(U(m))* ... *P(1)*inv(U(1)) */
+/*        Compute  B := U*B */
+/*        where U = P(m)*inv(U(m))* ... *P(1)*inv(U(1)) */
 
 	if (lsame_(uplo, "U")) {
 
@@ -300,8 +303,8 @@ L10:
 	    goto L10;
 L30:
 
-/*        Compute  B := L*B   
-          where L = P(1)*inv(L(1))* ... *P(m)*inv(L(m)) . */
+/*        Compute  B := L*B */
+/*        where L = P(1)*inv(L(1))* ... *P(m)*inv(L(m)) . */
 
 	    ;
 	} else {
@@ -316,14 +319,14 @@ L40:
 	    }
 	    kc -= *n - k + 1;
 
-/*           Test the pivot index.  If greater than zero, a 1 x 1   
-             pivot was used, otherwise a 2 x 2 pivot was used. */
+/*           Test the pivot index.  If greater than zero, a 1 x 1 */
+/*           pivot was used, otherwise a 2 x 2 pivot was used. */
 
 	    if (ipiv[k] > 0) {
 
-/*              1 x 1 pivot block:   
+/*              1 x 1 pivot block: */
 
-                Multiply by the diagonal element if forming L * D. */
+/*              Multiply by the diagonal element if forming L * D. */
 
 		if (nounit) {
 		    zscal_(nrhs, &a[kc], &b[k + b_dim1], ldb);
@@ -340,8 +343,8 @@ L40:
 		    zgeru_(&i__1, nrhs, &c_b1, &a[kc + 1], &c__1, &b[k + 
 			    b_dim1], ldb, &b[k + 1 + b_dim1], ldb);
 
-/*                 Interchange if a permutation was applied at the   
-                   K-th step of the factorization. */
+/*                 Interchange if a permutation was applied at the */
+/*                 K-th step of the factorization. */
 
 		    if (kp != k) {
 			zswap_(nrhs, &b[k + b_dim1], ldb, &b[kp + b_dim1], 
@@ -404,8 +407,8 @@ L40:
 		    zgeru_(&i__1, nrhs, &c_b1, &a[kcnext + 2], &c__1, &b[k - 
 			    1 + b_dim1], ldb, &b[k + 1 + b_dim1], ldb);
 
-/*                 Interchange if a permutation was applied at the   
-                   K-th step of the factorization. */
+/*                 Interchange if a permutation was applied at the */
+/*                 K-th step of the factorization. */
 
 		    kp = (i__1 = ipiv[k], abs(i__1));
 		    if (kp != k) {
@@ -420,16 +423,16 @@ L40:
 L60:
 	    ;
 	}
-/* -------------------------------------------------   
+/* ------------------------------------------------- */
 
-       Compute  B := A^H * B  (conjugate transpose)   
+/*     Compute  B := A^H * B  (conjugate transpose) */
 
-   ------------------------------------------------- */
+/* ------------------------------------------------- */
     } else {
 
-/*        Form  B := U^H*B   
-          where U  = P(m)*inv(U(m))* ... *P(1)*inv(U(1))   
-          and   U^H = inv(U^H(1))*P(1)* ... *inv(U^H(m))*P(m) */
+/*        Form  B := U^H*B */
+/*        where U  = P(m)*inv(U(m))* ... *P(1)*inv(U(1)) */
+/*        and   U^H = inv(U^H(1))*P(1)* ... *inv(U^H(m))*P(m) */
 
 	if (lsame_(uplo, "U")) {
 
@@ -456,9 +459,9 @@ L70:
 				ldb);
 		    }
 
-/*                 Apply the transformation:   
-                      y := y - B' * conjg(x)   
-                   where x is a column of A and y is a row of B. */
+/*                 Apply the transformation: */
+/*                    y := y - B' * conjg(x) */
+/*                 where x is a column of A and y is a row of B. */
 
 		    zlacgv_(nrhs, &b[k + b_dim1], ldb);
 		    i__1 = k - 1;
@@ -541,9 +544,9 @@ L70:
 	    goto L70;
 L90:
 
-/*        Form  B := L^H*B   
-          where L  = P(1)*inv(L(1))* ... *P(m)*inv(L(m))   
-          and   L^H = inv(L(m))*P(m)* ... *inv(L(1))*P(1) */
+/*        Form  B := L^H*B */
+/*        where L  = P(1)*inv(L(1))* ... *P(m)*inv(L(m)) */
+/*        and   L^H = inv(L(m))*P(m)* ... *inv(L(1))*P(1) */
 
 	    ;
 	} else {
