@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* clatm5.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -21,7 +9,7 @@ static complex c_b5 = {20.f,0.f};
 
 /* Subroutine */ int clatm5_(integer *prtype, integer *m, integer *n, complex 
 	*a, integer *lda, complex *b, integer *ldb, complex *c__, integer *
-	ldc, complex *d__, integer *ldd, complex *e, integer *lde, complex *f,
+	ldc, complex *d__, integer *ldd, complex *e, integer *lde, complex *f, 
 	 integer *ldf, complex *r__, integer *ldr, complex *l, integer *ldl, 
 	real *alpha, integer *qblcka, integer *qblckb)
 {
@@ -36,178 +24,191 @@ static complex c_b5 = {20.f,0.f};
     void c_sin(complex *, complex *), c_div(complex *, complex *, complex *);
 
     /* Local variables */
-    static integer i__, j, k;
+    integer i__, j, k;
     extern /* Subroutine */ int cgemm_(char *, char *, integer *, integer *, 
 	    integer *, complex *, complex *, integer *, complex *, integer *, 
 	    complex *, complex *, integer *);
-    static complex imeps, reeps;
+    complex imeps, reeps;
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
+
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
+
+/*  Purpose */
+/*  ======= */
+
+/*  CLATM5 generates matrices involved in the Generalized Sylvester */
+/*  equation: */
+
+/*      A * R - L * B = C */
+/*      D * R - L * E = F */
+
+/*  They also satisfy (the diagonalization condition) */
+
+/*   [ I -L ] ( [ A  -C ], [ D -F ] ) [ I  R ] = ( [ A    ], [ D    ] ) */
+/*   [    I ] ( [     B ]  [    E ] ) [    I ]   ( [    B ]  [    E ] ) */
 
 
-    Purpose   
-    =======   
+/*  Arguments */
+/*  ========= */
 
-    CLATM5 generates matrices involved in the Generalized Sylvester   
-    equation:   
+/*  PRTYPE  (input) INTEGER */
+/*          "Points" to a certian type of the matrices to generate */
+/*          (see futher details). */
 
-        A * R - L * B = C   
-        D * R - L * E = F   
+/*  M       (input) INTEGER */
+/*          Specifies the order of A and D and the number of rows in */
+/*          C, F,  R and L. */
 
-    They also satisfy (the diagonalization condition)   
+/*  N       (input) INTEGER */
+/*          Specifies the order of B and E and the number of columns in */
+/*          C, F, R and L. */
 
-     [ I -L ] ( [ A  -C ], [ D -F ] ) [ I  R ] = ( [ A    ], [ D    ] )   
-     [    I ] ( [     B ]  [    E ] ) [    I ]   ( [    B ]  [    E ] )   
+/*  A       (output) COMPLEX array, dimension (LDA, M). */
+/*          On exit A M-by-M is initialized according to PRTYPE. */
+
+/*  LDA     (input) INTEGER */
+/*          The leading dimension of A. */
+
+/*  B       (output) COMPLEX array, dimension (LDB, N). */
+/*          On exit B N-by-N is initialized according to PRTYPE. */
+
+/*  LDB     (input) INTEGER */
+/*          The leading dimension of B. */
+
+/*  C       (output) COMPLEX array, dimension (LDC, N). */
+/*          On exit C M-by-N is initialized according to PRTYPE. */
+
+/*  LDC     (input) INTEGER */
+/*          The leading dimension of C. */
+
+/*  D       (output) COMPLEX array, dimension (LDD, M). */
+/*          On exit D M-by-M is initialized according to PRTYPE. */
+
+/*  LDD     (input) INTEGER */
+/*          The leading dimension of D. */
+
+/*  E       (output) COMPLEX array, dimension (LDE, N). */
+/*          On exit E N-by-N is initialized according to PRTYPE. */
+
+/*  LDE     (input) INTEGER */
+/*          The leading dimension of E. */
+
+/*  F       (output) COMPLEX array, dimension (LDF, N). */
+/*          On exit F M-by-N is initialized according to PRTYPE. */
+
+/*  LDF     (input) INTEGER */
+/*          The leading dimension of F. */
+
+/*  R       (output) COMPLEX array, dimension (LDR, N). */
+/*          On exit R M-by-N is initialized according to PRTYPE. */
+
+/*  LDR     (input) INTEGER */
+/*          The leading dimension of R. */
+
+/*  L       (output) COMPLEX array, dimension (LDL, N). */
+/*          On exit L M-by-N is initialized according to PRTYPE. */
+
+/*  LDL     (input) INTEGER */
+/*          The leading dimension of L. */
+
+/*  ALPHA   (input) REAL */
+/*          Parameter used in generating PRTYPE = 1 and 5 matrices. */
+
+/*  QBLCKA  (input) INTEGER */
+/*          When PRTYPE = 3, specifies the distance between 2-by-2 */
+/*          blocks on the diagonal in A. Otherwise, QBLCKA is not */
+/*          referenced. QBLCKA > 1. */
+
+/*  QBLCKB  (input) INTEGER */
+/*          When PRTYPE = 3, specifies the distance between 2-by-2 */
+/*          blocks on the diagonal in B. Otherwise, QBLCKB is not */
+/*          referenced. QBLCKB > 1. */
 
 
-    Arguments   
-    =========   
+/*  Further Details */
+/*  =============== */
 
-    PRTYPE  (input) INTEGER   
-            "Points" to a certian type of the matrices to generate   
-            (see futher details).   
+/*  PRTYPE = 1: A and B are Jordan blocks, D and E are identity matrices */
 
-    M       (input) INTEGER   
-            Specifies the order of A and D and the number of rows in   
-            C, F,  R and L.   
+/*             A : if (i == j) then A(i, j) = 1.0 */
+/*                 if (j == i + 1) then A(i, j) = -1.0 */
+/*                 else A(i, j) = 0.0,            i, j = 1...M */
 
-    N       (input) INTEGER   
-            Specifies the order of B and E and the number of columns in   
-            C, F, R and L.   
+/*             B : if (i == j) then B(i, j) = 1.0 - ALPHA */
+/*                 if (j == i + 1) then B(i, j) = 1.0 */
+/*                 else B(i, j) = 0.0,            i, j = 1...N */
 
-    A       (output) COMPLEX array, dimension (LDA, M).   
-            On exit A M-by-M is initialized according to PRTYPE.   
+/*             D : if (i == j) then D(i, j) = 1.0 */
+/*                 else D(i, j) = 0.0,            i, j = 1...M */
 
-    LDA     (input) INTEGER   
-            The leading dimension of A.   
+/*             E : if (i == j) then E(i, j) = 1.0 */
+/*                 else E(i, j) = 0.0,            i, j = 1...N */
 
-    B       (output) COMPLEX array, dimension (LDB, N).   
-            On exit B N-by-N is initialized according to PRTYPE.   
+/*             L =  R are chosen from [-10...10], */
+/*                  which specifies the right hand sides (C, F). */
 
-    LDB     (input) INTEGER   
-            The leading dimension of B.   
+/*  PRTYPE = 2 or 3: Triangular and/or quasi- triangular. */
 
-    C       (output) COMPLEX array, dimension (LDC, N).   
-            On exit C M-by-N is initialized according to PRTYPE.   
+/*             A : if (i <= j) then A(i, j) = [-1...1] */
+/*                 else A(i, j) = 0.0,             i, j = 1...M */
 
-    LDC     (input) INTEGER   
-            The leading dimension of C.   
+/*                 if (PRTYPE = 3) then */
+/*                    A(k + 1, k + 1) = A(k, k) */
+/*                    A(k + 1, k) = [-1...1] */
+/*                    sign(A(k, k + 1) = -(sin(A(k + 1, k)) */
+/*                        k = 1, M - 1, QBLCKA */
 
-    D       (output) COMPLEX array, dimension (LDD, M).   
-            On exit D M-by-M is initialized according to PRTYPE.   
+/*             B : if (i <= j) then B(i, j) = [-1...1] */
+/*                 else B(i, j) = 0.0,            i, j = 1...N */
 
-    LDD     (input) INTEGER   
-            The leading dimension of D.   
+/*                 if (PRTYPE = 3) then */
+/*                    B(k + 1, k + 1) = B(k, k) */
+/*                    B(k + 1, k) = [-1...1] */
+/*                    sign(B(k, k + 1) = -(sign(B(k + 1, k)) */
+/*                        k = 1, N - 1, QBLCKB */
 
-    E       (output) COMPLEX array, dimension (LDE, N).   
-            On exit E N-by-N is initialized according to PRTYPE.   
-
-    LDE     (input) INTEGER   
-            The leading dimension of E.   
-
-    F       (output) COMPLEX array, dimension (LDF, N).   
-            On exit F M-by-N is initialized according to PRTYPE.   
-
-    LDF     (input) INTEGER   
-            The leading dimension of F.   
-
-    R       (output) COMPLEX array, dimension (LDR, N).   
-            On exit R M-by-N is initialized according to PRTYPE.   
-
-    LDR     (input) INTEGER   
-            The leading dimension of R.   
-
-    L       (output) COMPLEX array, dimension (LDL, N).   
-            On exit L M-by-N is initialized according to PRTYPE.   
-
-    LDL     (input) INTEGER   
-            The leading dimension of L.   
-
-    ALPHA   (input) REAL   
-            Parameter used in generating PRTYPE = 1 and 5 matrices.   
-
-    QBLCKA  (input) INTEGER   
-            When PRTYPE = 3, specifies the distance between 2-by-2   
-            blocks on the diagonal in A. Otherwise, QBLCKA is not   
-            referenced. QBLCKA > 1.   
-
-    QBLCKB  (input) INTEGER   
-            When PRTYPE = 3, specifies the distance between 2-by-2   
-            blocks on the diagonal in B. Otherwise, QBLCKB is not   
-            referenced. QBLCKB > 1.   
+/*             D : if (i <= j) then D(i, j) = [-1...1]. */
+/*                 else D(i, j) = 0.0,            i, j = 1...M */
 
 
-    Further Details   
-    ===============   
+/*             E : if (i <= j) then D(i, j) = [-1...1] */
+/*                 else E(i, j) = 0.0,            i, j = 1...N */
 
-    PRTYPE = 1: A and B are Jordan blocks, D and E are identity matrices   
+/*                 L, R are chosen from [-10...10], */
+/*                 which specifies the right hand sides (C, F). */
 
-               A : if (i == j) then A(i, j) = 1.0   
-                   if (j == i + 1) then A(i, j) = -1.0   
-                   else A(i, j) = 0.0,            i, j = 1...M   
+/*  PRTYPE = 4 Full */
+/*             A(i, j) = [-10...10] */
+/*             D(i, j) = [-1...1]    i,j = 1...M */
+/*             B(i, j) = [-10...10] */
+/*             E(i, j) = [-1...1]    i,j = 1...N */
+/*             R(i, j) = [-10...10] */
+/*             L(i, j) = [-1...1]    i = 1..M ,j = 1...N */
 
-               B : if (i == j) then B(i, j) = 1.0 - ALPHA   
-                   if (j == i + 1) then B(i, j) = 1.0   
-                   else B(i, j) = 0.0,            i, j = 1...N   
+/*             L, R specifies the right hand sides (C, F). */
 
-               D : if (i == j) then D(i, j) = 1.0   
-                   else D(i, j) = 0.0,            i, j = 1...M   
+/*  PRTYPE = 5 special case common and/or close eigs. */
 
-               E : if (i == j) then E(i, j) = 1.0   
-                   else E(i, j) = 0.0,            i, j = 1...N   
+/*  ===================================================================== */
 
-               L =  R are chosen from [-10...10],   
-                    which specifies the right hand sides (C, F).   
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-    PRTYPE = 2 or 3: Triangular and/or quasi- triangular.   
-
-               A : if (i <= j) then A(i, j) = [-1...1]   
-                   else A(i, j) = 0.0,             i, j = 1...M   
-
-                   if (PRTYPE = 3) then   
-                      A(k + 1, k + 1) = A(k, k)   
-                      A(k + 1, k) = [-1...1]   
-                      sign(A(k, k + 1) = -(sin(A(k + 1, k))   
-                          k = 1, M - 1, QBLCKA   
-
-               B : if (i <= j) then B(i, j) = [-1...1]   
-                   else B(i, j) = 0.0,            i, j = 1...N   
-
-                   if (PRTYPE = 3) then   
-                      B(k + 1, k + 1) = B(k, k)   
-                      B(k + 1, k) = [-1...1]   
-                      sign(B(k, k + 1) = -(sign(B(k + 1, k))   
-                          k = 1, N - 1, QBLCKB   
-
-               D : if (i <= j) then D(i, j) = [-1...1].   
-                   else D(i, j) = 0.0,            i, j = 1...M   
-
-
-               E : if (i <= j) then D(i, j) = [-1...1]   
-                   else E(i, j) = 0.0,            i, j = 1...N   
-
-                   L, R are chosen from [-10...10],   
-                   which specifies the right hand sides (C, F).   
-
-    PRTYPE = 4 Full   
-               A(i, j) = [-10...10]   
-               D(i, j) = [-1...1]    i,j = 1...M   
-               B(i, j) = [-10...10]   
-               E(i, j) = [-1...1]    i,j = 1...N   
-               R(i, j) = [-10...10]   
-               L(i, j) = [-1...1]    i = 1..M ,j = 1...N   
-
-               L, R specifies the right hand sides (C, F).   
-
-    PRTYPE = 5 special case common and/or close eigs.   
-
-    =====================================================================   
-
-
-       Parameter adjustments */
+    /* Parameter adjustments */
     a_dim1 = *lda;
     a_offset = 1 + a_dim1;
     a -= a_offset;
