@@ -1,17 +1,5 @@
-#include "blaswrap.h"
-/* dlatms.f -- translated by f2c (version 20061008).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
-*/
-
 #include "f2c.h"
+#include "blaswrap.h"
 
 /* Table of constant values */
 
@@ -34,288 +22,303 @@ static logical c_false = FALSE_;
     double cos(doublereal), sin(doublereal);
 
     /* Local variables */
-    static doublereal c__;
-    static integer i__, j, k;
-    static doublereal s;
-    static integer ic, jc, nc, il, ir, jr, mr, ir1, ir2, jch, llb, jkl, jku, 
-	    uub, ilda, icol;
-    static doublereal temp;
-    static integer irow, isym;
-    static doublereal alpha, angle;
-    static integer ipack;
+    doublereal c__;
+    integer i__, j, k;
+    doublereal s;
+    integer ic, jc, nc, il, ir, jr, mr, ir1, ir2, jch, llb, jkl, jku, uub, 
+	    ilda, icol;
+    doublereal temp;
+    integer irow, isym;
+    doublereal alpha, angle;
+    integer ipack;
     extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
-    static integer ioffg;
+    integer ioffg;
     extern logical lsame_(char *, char *);
-    static integer iinfo, idist, mnmin;
+    integer iinfo, idist, mnmin;
     extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
-    static integer iskew;
-    static doublereal extra, dummy;
+    integer iskew;
+    doublereal extra, dummy;
     extern /* Subroutine */ int dlatm1_(integer *, doublereal *, integer *, 
 	    integer *, integer *, doublereal *, integer *, integer *), 
 	    dlagge_(integer *, integer *, integer *, integer *, doublereal *, 
 	    doublereal *, integer *, integer *, doublereal *, integer *);
-    static integer iendch, ipackg, minlda;
+    integer iendch, ipackg, minlda;
     extern doublereal dlarnd_(integer *, integer *);
     extern /* Subroutine */ int dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *), 
 	    dlartg_(doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *), xerbla_(char *, integer *), dlagsy_(
 	    integer *, integer *, doublereal *, doublereal *, integer *, 
-	    integer *, doublereal *, integer *), dlarot_(logical *, logical *,
+	    integer *, doublereal *, integer *), dlarot_(logical *, logical *, 
 	     logical *, integer *, doublereal *, doublereal *, doublereal *, 
 	    integer *, doublereal *, doublereal *);
-    static logical iltemp, givens;
-    static integer ioffst, irsign;
-    static logical ilextr, topdwn;
-    static integer isympk;
+    logical iltemp, givens;
+    integer ioffst, irsign;
+    logical ilextr, topdwn;
+    integer isympk;
 
 
-/*  -- LAPACK test routine (version 3.1) --   
-       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
-       November 2006   
+/*  -- LAPACK test routine (version 3.1) -- */
+/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
+/*     November 2006 */
 
+/*     .. Scalar Arguments .. */
+/*     .. */
+/*     .. Array Arguments .. */
+/*     .. */
 
-    Purpose   
-    =======   
+/*  Purpose */
+/*  ======= */
 
-       DLATMS generates random matrices with specified singular values   
-       (or symmetric/hermitian with specified eigenvalues)   
-       for testing LAPACK programs.   
+/*     DLATMS generates random matrices with specified singular values */
+/*     (or symmetric/hermitian with specified eigenvalues) */
+/*     for testing LAPACK programs. */
 
-       DLATMS operates by applying the following sequence of   
-       operations:   
+/*     DLATMS operates by applying the following sequence of */
+/*     operations: */
 
-         Set the diagonal to D, where D may be input or   
-            computed according to MODE, COND, DMAX, and SYM   
-            as described below.   
+/*       Set the diagonal to D, where D may be input or */
+/*          computed according to MODE, COND, DMAX, and SYM */
+/*          as described below. */
 
-         Generate a matrix with the appropriate band structure, by one   
-            of two methods:   
+/*       Generate a matrix with the appropriate band structure, by one */
+/*          of two methods: */
 
-         Method A:   
-             Generate a dense M x N matrix by multiplying D on the left   
-                 and the right by random unitary matrices, then:   
+/*       Method A: */
+/*           Generate a dense M x N matrix by multiplying D on the left */
+/*               and the right by random unitary matrices, then: */
 
-             Reduce the bandwidth according to KL and KU, using   
-             Householder transformations.   
+/*           Reduce the bandwidth according to KL and KU, using */
+/*           Householder transformations. */
 
-         Method B:   
-             Convert the bandwidth-0 (i.e., diagonal) matrix to a   
-                 bandwidth-1 matrix using Givens rotations, "chasing"   
-                 out-of-band elements back, much as in QR; then   
-                 convert the bandwidth-1 to a bandwidth-2 matrix, etc.   
-                 Note that for reasonably small bandwidths (relative to   
-                 M and N) this requires less storage, as a dense matrix   
-                 is not generated.  Also, for symmetric matrices, only   
-                 one triangle is generated.   
+/*       Method B: */
+/*           Convert the bandwidth-0 (i.e., diagonal) matrix to a */
+/*               bandwidth-1 matrix using Givens rotations, "chasing" */
+/*               out-of-band elements back, much as in QR; then */
+/*               convert the bandwidth-1 to a bandwidth-2 matrix, etc. */
+/*               Note that for reasonably small bandwidths (relative to */
+/*               M and N) this requires less storage, as a dense matrix */
+/*               is not generated.  Also, for symmetric matrices, only */
+/*               one triangle is generated. */
 
-         Method A is chosen if the bandwidth is a large fraction of the   
-             order of the matrix, and LDA is at least M (so a dense   
-             matrix can be stored.)  Method B is chosen if the bandwidth   
-             is small (< 1/2 N for symmetric, < .3 N+M for   
-             non-symmetric), or LDA is less than M and not less than the   
-             bandwidth.   
+/*       Method A is chosen if the bandwidth is a large fraction of the */
+/*           order of the matrix, and LDA is at least M (so a dense */
+/*           matrix can be stored.)  Method B is chosen if the bandwidth */
+/*           is small (< 1/2 N for symmetric, < .3 N+M for */
+/*           non-symmetric), or LDA is less than M and not less than the */
+/*           bandwidth. */
 
-         Pack the matrix if desired. Options specified by PACK are:   
-            no packing   
-            zero out upper half (if symmetric)   
-            zero out lower half (if symmetric)   
-            store the upper half columnwise (if symmetric or upper   
-                  triangular)   
-            store the lower half columnwise (if symmetric or lower   
-                  triangular)   
-            store the lower triangle in banded format (if symmetric   
-                  or lower triangular)   
-            store the upper triangle in banded format (if symmetric   
-                  or upper triangular)   
-            store the entire matrix in banded format   
-         If Method B is chosen, and band format is specified, then the   
-            matrix will be generated in the band format, so no repacking   
-            will be necessary.   
+/*       Pack the matrix if desired. Options specified by PACK are: */
+/*          no packing */
+/*          zero out upper half (if symmetric) */
+/*          zero out lower half (if symmetric) */
+/*          store the upper half columnwise (if symmetric or upper */
+/*                triangular) */
+/*          store the lower half columnwise (if symmetric or lower */
+/*                triangular) */
+/*          store the lower triangle in banded format (if symmetric */
+/*                or lower triangular) */
+/*          store the upper triangle in banded format (if symmetric */
+/*                or upper triangular) */
+/*          store the entire matrix in banded format */
+/*       If Method B is chosen, and band format is specified, then the */
+/*          matrix will be generated in the band format, so no repacking */
+/*          will be necessary. */
 
-    Arguments   
-    =========   
+/*  Arguments */
+/*  ========= */
 
-    M      - INTEGER   
-             The number of rows of A. Not modified.   
+/*  M      - INTEGER */
+/*           The number of rows of A. Not modified. */
 
-    N      - INTEGER   
-             The number of columns of A. Not modified.   
+/*  N      - INTEGER */
+/*           The number of columns of A. Not modified. */
 
-    DIST   - CHARACTER*1   
-             On entry, DIST specifies the type of distribution to be used   
-             to generate the random eigen-/singular values.   
-             'U' => UNIFORM( 0, 1 )  ( 'U' for uniform )   
-             'S' => UNIFORM( -1, 1 ) ( 'S' for symmetric )   
-             'N' => NORMAL( 0, 1 )   ( 'N' for normal )   
-             Not modified.   
+/*  DIST   - CHARACTER*1 */
+/*           On entry, DIST specifies the type of distribution to be used */
+/*           to generate the random eigen-/singular values. */
+/*           'U' => UNIFORM( 0, 1 )  ( 'U' for uniform ) */
+/*           'S' => UNIFORM( -1, 1 ) ( 'S' for symmetric ) */
+/*           'N' => NORMAL( 0, 1 )   ( 'N' for normal ) */
+/*           Not modified. */
 
-    ISEED  - INTEGER array, dimension ( 4 )   
-             On entry ISEED specifies the seed of the random number   
-             generator. They should lie between 0 and 4095 inclusive,   
-             and ISEED(4) should be odd. The random number generator   
-             uses a linear congruential sequence limited to small   
-             integers, and so should produce machine independent   
-             random numbers. The values of ISEED are changed on   
-             exit, and can be used in the next call to DLATMS   
-             to continue the same random number sequence.   
-             Changed on exit.   
+/*  ISEED  - INTEGER array, dimension ( 4 ) */
+/*           On entry ISEED specifies the seed of the random number */
+/*           generator. They should lie between 0 and 4095 inclusive, */
+/*           and ISEED(4) should be odd. The random number generator */
+/*           uses a linear congruential sequence limited to small */
+/*           integers, and so should produce machine independent */
+/*           random numbers. The values of ISEED are changed on */
+/*           exit, and can be used in the next call to DLATMS */
+/*           to continue the same random number sequence. */
+/*           Changed on exit. */
 
-    SYM    - CHARACTER*1   
-             If SYM='S' or 'H', the generated matrix is symmetric, with   
-               eigenvalues specified by D, COND, MODE, and DMAX; they   
-               may be positive, negative, or zero.   
-             If SYM='P', the generated matrix is symmetric, with   
-               eigenvalues (= singular values) specified by D, COND,   
-               MODE, and DMAX; they will not be negative.   
-             If SYM='N', the generated matrix is nonsymmetric, with   
-               singular values specified by D, COND, MODE, and DMAX;   
-               they will not be negative.   
-             Not modified.   
+/*  SYM    - CHARACTER*1 */
+/*           If SYM='S' or 'H', the generated matrix is symmetric, with */
+/*             eigenvalues specified by D, COND, MODE, and DMAX; they */
+/*             may be positive, negative, or zero. */
+/*           If SYM='P', the generated matrix is symmetric, with */
+/*             eigenvalues (= singular values) specified by D, COND, */
+/*             MODE, and DMAX; they will not be negative. */
+/*           If SYM='N', the generated matrix is nonsymmetric, with */
+/*             singular values specified by D, COND, MODE, and DMAX; */
+/*             they will not be negative. */
+/*           Not modified. */
 
-    D      - DOUBLE PRECISION array, dimension ( MIN( M , N ) )   
-             This array is used to specify the singular values or   
-             eigenvalues of A (see SYM, above.)  If MODE=0, then D is   
-             assumed to contain the singular/eigenvalues, otherwise   
-             they will be computed according to MODE, COND, and DMAX,   
-             and placed in D.   
-             Modified if MODE is nonzero.   
+/*  D      - DOUBLE PRECISION array, dimension ( MIN( M , N ) ) */
+/*           This array is used to specify the singular values or */
+/*           eigenvalues of A (see SYM, above.)  If MODE=0, then D is */
+/*           assumed to contain the singular/eigenvalues, otherwise */
+/*           they will be computed according to MODE, COND, and DMAX, */
+/*           and placed in D. */
+/*           Modified if MODE is nonzero. */
 
-    MODE   - INTEGER   
-             On entry this describes how the singular/eigenvalues are to   
-             be specified:   
-             MODE = 0 means use D as input   
-             MODE = 1 sets D(1)=1 and D(2:N)=1.0/COND   
-             MODE = 2 sets D(1:N-1)=1 and D(N)=1.0/COND   
-             MODE = 3 sets D(I)=COND**(-(I-1)/(N-1))   
-             MODE = 4 sets D(i)=1 - (i-1)/(N-1)*(1 - 1/COND)   
-             MODE = 5 sets D to random numbers in the range   
-                      ( 1/COND , 1 ) such that their logarithms   
-                      are uniformly distributed.   
-             MODE = 6 set D to random numbers from same distribution   
-                      as the rest of the matrix.   
-             MODE < 0 has the same meaning as ABS(MODE), except that   
-                the order of the elements of D is reversed.   
-             Thus if MODE is positive, D has entries ranging from   
-                1 to 1/COND, if negative, from 1/COND to 1,   
-             If SYM='S' or 'H', and MODE is neither 0, 6, nor -6, then   
-                the elements of D will also be multiplied by a random   
-                sign (i.e., +1 or -1.)   
-             Not modified.   
+/*  MODE   - INTEGER */
+/*           On entry this describes how the singular/eigenvalues are to */
+/*           be specified: */
+/*           MODE = 0 means use D as input */
+/*           MODE = 1 sets D(1)=1 and D(2:N)=1.0/COND */
+/*           MODE = 2 sets D(1:N-1)=1 and D(N)=1.0/COND */
+/*           MODE = 3 sets D(I)=COND**(-(I-1)/(N-1)) */
+/*           MODE = 4 sets D(i)=1 - (i-1)/(N-1)*(1 - 1/COND) */
+/*           MODE = 5 sets D to random numbers in the range */
+/*                    ( 1/COND , 1 ) such that their logarithms */
+/*                    are uniformly distributed. */
+/*           MODE = 6 set D to random numbers from same distribution */
+/*                    as the rest of the matrix. */
+/*           MODE < 0 has the same meaning as ABS(MODE), except that */
+/*              the order of the elements of D is reversed. */
+/*           Thus if MODE is positive, D has entries ranging from */
+/*              1 to 1/COND, if negative, from 1/COND to 1, */
+/*           If SYM='S' or 'H', and MODE is neither 0, 6, nor -6, then */
+/*              the elements of D will also be multiplied by a random */
+/*              sign (i.e., +1 or -1.) */
+/*           Not modified. */
 
-    COND   - DOUBLE PRECISION   
-             On entry, this is used as described under MODE above.   
-             If used, it must be >= 1. Not modified.   
+/*  COND   - DOUBLE PRECISION */
+/*           On entry, this is used as described under MODE above. */
+/*           If used, it must be >= 1. Not modified. */
 
-    DMAX   - DOUBLE PRECISION   
-             If MODE is neither -6, 0 nor 6, the contents of D, as   
-             computed according to MODE and COND, will be scaled by   
-             DMAX / max(abs(D(i))); thus, the maximum absolute eigen- or   
-             singular value (which is to say the norm) will be abs(DMAX).   
-             Note that DMAX need not be positive: if DMAX is negative   
-             (or zero), D will be scaled by a negative number (or zero).   
-             Not modified.   
+/*  DMAX   - DOUBLE PRECISION */
+/*           If MODE is neither -6, 0 nor 6, the contents of D, as */
+/*           computed according to MODE and COND, will be scaled by */
+/*           DMAX / max(abs(D(i))); thus, the maximum absolute eigen- or */
+/*           singular value (which is to say the norm) will be abs(DMAX). */
+/*           Note that DMAX need not be positive: if DMAX is negative */
+/*           (or zero), D will be scaled by a negative number (or zero). */
+/*           Not modified. */
 
-    KL     - INTEGER   
-             This specifies the lower bandwidth of the  matrix. For   
-             example, KL=0 implies upper triangular, KL=1 implies upper   
-             Hessenberg, and KL being at least M-1 means that the matrix   
-             has full lower bandwidth.  KL must equal KU if the matrix   
-             is symmetric.   
-             Not modified.   
+/*  KL     - INTEGER */
+/*           This specifies the lower bandwidth of the  matrix. For */
+/*           example, KL=0 implies upper triangular, KL=1 implies upper */
+/*           Hessenberg, and KL being at least M-1 means that the matrix */
+/*           has full lower bandwidth.  KL must equal KU if the matrix */
+/*           is symmetric. */
+/*           Not modified. */
 
-    KU     - INTEGER   
-             This specifies the upper bandwidth of the  matrix. For   
-             example, KU=0 implies lower triangular, KU=1 implies lower   
-             Hessenberg, and KU being at least N-1 means that the matrix   
-             has full upper bandwidth.  KL must equal KU if the matrix   
-             is symmetric.   
-             Not modified.   
+/*  KU     - INTEGER */
+/*           This specifies the upper bandwidth of the  matrix. For */
+/*           example, KU=0 implies lower triangular, KU=1 implies lower */
+/*           Hessenberg, and KU being at least N-1 means that the matrix */
+/*           has full upper bandwidth.  KL must equal KU if the matrix */
+/*           is symmetric. */
+/*           Not modified. */
 
-    PACK   - CHARACTER*1   
-             This specifies packing of matrix as follows:   
-             'N' => no packing   
-             'U' => zero out all subdiagonal entries (if symmetric)   
-             'L' => zero out all superdiagonal entries (if symmetric)   
-             'C' => store the upper triangle columnwise   
-                    (only if the matrix is symmetric or upper triangular)   
-             'R' => store the lower triangle columnwise   
-                    (only if the matrix is symmetric or lower triangular)   
-             'B' => store the lower triangle in band storage scheme   
-                    (only if matrix symmetric or lower triangular)   
-             'Q' => store the upper triangle in band storage scheme   
-                    (only if matrix symmetric or upper triangular)   
-             'Z' => store the entire matrix in band storage scheme   
-                        (pivoting can be provided for by using this   
-                        option to store A in the trailing rows of   
-                        the allocated storage)   
+/*  PACK   - CHARACTER*1 */
+/*           This specifies packing of matrix as follows: */
+/*           'N' => no packing */
+/*           'U' => zero out all subdiagonal entries (if symmetric) */
+/*           'L' => zero out all superdiagonal entries (if symmetric) */
+/*           'C' => store the upper triangle columnwise */
+/*                  (only if the matrix is symmetric or upper triangular) */
+/*           'R' => store the lower triangle columnwise */
+/*                  (only if the matrix is symmetric or lower triangular) */
+/*           'B' => store the lower triangle in band storage scheme */
+/*                  (only if matrix symmetric or lower triangular) */
+/*           'Q' => store the upper triangle in band storage scheme */
+/*                  (only if matrix symmetric or upper triangular) */
+/*           'Z' => store the entire matrix in band storage scheme */
+/*                      (pivoting can be provided for by using this */
+/*                      option to store A in the trailing rows of */
+/*                      the allocated storage) */
 
-             Using these options, the various LAPACK packed and banded   
-             storage schemes can be obtained:   
-             GB               - use 'Z'   
-             PB, SB or TB     - use 'B' or 'Q'   
-             PP, SP or TP     - use 'C' or 'R'   
+/*           Using these options, the various LAPACK packed and banded */
+/*           storage schemes can be obtained: */
+/*           GB               - use 'Z' */
+/*           PB, SB or TB     - use 'B' or 'Q' */
+/*           PP, SP or TP     - use 'C' or 'R' */
 
-             If two calls to DLATMS differ only in the PACK parameter,   
-             they will generate mathematically equivalent matrices.   
-             Not modified.   
+/*           If two calls to DLATMS differ only in the PACK parameter, */
+/*           they will generate mathematically equivalent matrices. */
+/*           Not modified. */
 
-    A      - DOUBLE PRECISION array, dimension ( LDA, N )   
-             On exit A is the desired test matrix.  A is first generated   
-             in full (unpacked) form, and then packed, if so specified   
-             by PACK.  Thus, the first M elements of the first N   
-             columns will always be modified.  If PACK specifies a   
-             packed or banded storage scheme, all LDA elements of the   
-             first N columns will be modified; the elements of the   
-             array which do not correspond to elements of the generated   
-             matrix are set to zero.   
-             Modified.   
+/*  A      - DOUBLE PRECISION array, dimension ( LDA, N ) */
+/*           On exit A is the desired test matrix.  A is first generated */
+/*           in full (unpacked) form, and then packed, if so specified */
+/*           by PACK.  Thus, the first M elements of the first N */
+/*           columns will always be modified.  If PACK specifies a */
+/*           packed or banded storage scheme, all LDA elements of the */
+/*           first N columns will be modified; the elements of the */
+/*           array which do not correspond to elements of the generated */
+/*           matrix are set to zero. */
+/*           Modified. */
 
-    LDA    - INTEGER   
-             LDA specifies the first dimension of A as declared in the   
-             calling program.  If PACK='N', 'U', 'L', 'C', or 'R', then   
-             LDA must be at least M.  If PACK='B' or 'Q', then LDA must   
-             be at least MIN( KL, M-1) (which is equal to MIN(KU,N-1)).   
-             If PACK='Z', LDA must be large enough to hold the packed   
-             array: MIN( KU, N-1) + MIN( KL, M-1) + 1.   
-             Not modified.   
+/*  LDA    - INTEGER */
+/*           LDA specifies the first dimension of A as declared in the */
+/*           calling program.  If PACK='N', 'U', 'L', 'C', or 'R', then */
+/*           LDA must be at least M.  If PACK='B' or 'Q', then LDA must */
+/*           be at least MIN( KL, M-1) (which is equal to MIN(KU,N-1)). */
+/*           If PACK='Z', LDA must be large enough to hold the packed */
+/*           array: MIN( KU, N-1) + MIN( KL, M-1) + 1. */
+/*           Not modified. */
 
-    WORK   - DOUBLE PRECISION array, dimension ( 3*MAX( N , M ) )   
-             Workspace.   
-             Modified.   
+/*  WORK   - DOUBLE PRECISION array, dimension ( 3*MAX( N , M ) ) */
+/*           Workspace. */
+/*           Modified. */
 
-    INFO   - INTEGER   
-             Error code.  On exit, INFO will be set to one of the   
-             following values:   
-               0 => normal return   
-              -1 => M negative or unequal to N and SYM='S', 'H', or 'P'   
-              -2 => N negative   
-              -3 => DIST illegal string   
-              -5 => SYM illegal string   
-              -7 => MODE not in range -6 to 6   
-              -8 => COND less than 1.0, and MODE neither -6, 0 nor 6   
-             -10 => KL negative   
-             -11 => KU negative, or SYM='S' or 'H' and KU not equal to KL   
-             -12 => PACK illegal string, or PACK='U' or 'L', and SYM='N';   
-                    or PACK='C' or 'Q' and SYM='N' and KL is not zero;   
-                    or PACK='R' or 'B' and SYM='N' and KU is not zero;   
-                    or PACK='U', 'L', 'C', 'R', 'B', or 'Q', and M is not   
-                    N.   
-             -14 => LDA is less than M, or PACK='Z' and LDA is less than   
-                    MIN(KU,N-1) + MIN(KL,M-1) + 1.   
-              1  => Error return from DLATM1   
-              2  => Cannot scale to DMAX (max. sing. value is 0)   
-              3  => Error return from DLAGGE or SLAGSY   
+/*  INFO   - INTEGER */
+/*           Error code.  On exit, INFO will be set to one of the */
+/*           following values: */
+/*             0 => normal return */
+/*            -1 => M negative or unequal to N and SYM='S', 'H', or 'P' */
+/*            -2 => N negative */
+/*            -3 => DIST illegal string */
+/*            -5 => SYM illegal string */
+/*            -7 => MODE not in range -6 to 6 */
+/*            -8 => COND less than 1.0, and MODE neither -6, 0 nor 6 */
+/*           -10 => KL negative */
+/*           -11 => KU negative, or SYM='S' or 'H' and KU not equal to KL */
+/*           -12 => PACK illegal string, or PACK='U' or 'L', and SYM='N'; */
+/*                  or PACK='C' or 'Q' and SYM='N' and KL is not zero; */
+/*                  or PACK='R' or 'B' and SYM='N' and KU is not zero; */
+/*                  or PACK='U', 'L', 'C', 'R', 'B', or 'Q', and M is not */
+/*                  N. */
+/*           -14 => LDA is less than M, or PACK='Z' and LDA is less than */
+/*                  MIN(KU,N-1) + MIN(KL,M-1) + 1. */
+/*            1  => Error return from DLATM1 */
+/*            2  => Cannot scale to DMAX (max. sing. value is 0) */
+/*            3  => Error return from DLAGGE or SLAGSY */
 
-    =====================================================================   
+/*  ===================================================================== */
 
+/*     .. Parameters .. */
+/*     .. */
+/*     .. Local Scalars .. */
+/*     .. */
+/*     .. External Functions .. */
+/*     .. */
+/*     .. External Subroutines .. */
+/*     .. */
+/*     .. Intrinsic Functions .. */
+/*     .. */
+/*     .. Executable Statements .. */
 
-       1)      Decode and Test the input parameters.   
-               Initialize flags & seed.   
+/*     1)      Decode and Test the input parameters. */
+/*             Initialize flags & seed. */
 
-       Parameter adjustments */
+    /* Parameter adjustments */
     --iseed;
     --d__;
     a_dim1 = *lda;
@@ -415,8 +418,8 @@ static logical c_false = FALSE_;
 	minlda = *m;
     }
 
-/*     Use Givens rotation method if bandwidth small enough,   
-       or if LDA is too small to store the matrix unpacked. */
+/*     Use Givens rotation method if bandwidth small enough, */
+/*     or if LDA is too small to store the matrix unpacked. */
 
     givens = FALSE_;
     if (isym == 1) {
@@ -479,9 +482,9 @@ static logical c_false = FALSE_;
 	++iseed[4];
     }
 
-/*     2)      Set up D  if indicated.   
+/*     2)      Set up D  if indicated. */
 
-               Compute D according to COND and MODE */
+/*             Compute D according to COND and MODE */
 
     dlatm1_(mode, cond, &irsign, &idist, &iseed[1], &d__[1], &mnmin, &iinfo);
     if (iinfo != 0) {
@@ -489,8 +492,8 @@ static logical c_false = FALSE_;
 	return 0;
     }
 
-/*     Choose Top-Down if D is (apparently) increasing,   
-       Bottom-Up if D is (apparently) decreasing. */
+/*     Choose Top-Down if D is (apparently) increasing, */
+/*     Bottom-Up if D is (apparently) decreasing. */
 
     if (abs(d__[1]) <= (d__1 = d__[mnmin], abs(d__1))) {
 	topdwn = TRUE_;
@@ -522,14 +525,14 @@ static logical c_false = FALSE_;
 
     }
 
-/*     3)      Generate Banded Matrix using Givens rotations.   
-               Also the special case of UUB=LLB=0   
+/*     3)      Generate Banded Matrix using Givens rotations. */
+/*             Also the special case of UUB=LLB=0 */
 
-                 Compute Addressing constants to cover all   
-                 storage formats.  Whether GE, SY, GB, or SB,   
-                 upper or lower triangle or both,   
-                 the (i,j)-th element is in   
-                 A( i - ISKEW*j + IOFFST, j ) */
+/*               Compute Addressing constants to cover all */
+/*               storage formats.  Whether GE, SY, GB, or SB, */
+/*               upper or lower triangle or both, */
+/*               the (i,j)-th element is in */
+/*               A( i - ISKEW*j + IOFFST, j ) */
 
     if (ipack > 4) {
 	ilda = *lda - 1;
@@ -545,15 +548,15 @@ static logical c_false = FALSE_;
 	ioffst = 0;
     }
 
-/*     IPACKG is the format that the matrix is generated in. If this is   
-       different from IPACK, then the matrix must be repacked at the   
-       end.  It also signals how to compute the norm, for scaling. */
+/*     IPACKG is the format that the matrix is generated in. If this is */
+/*     different from IPACK, then the matrix must be repacked at the */
+/*     end.  It also signals how to compute the norm, for scaling. */
 
     ipackg = 0;
     dlaset_("Full", lda, n, &c_b22, &c_b22, &a[a_offset], lda);
 
-/*     Diagonal Matrix -- We are done, unless it   
-       is to be stored SP/PP/TP (PACK='R' or 'C') */
+/*     Diagonal Matrix -- We are done, unless it */
+/*     is to be stored SP/PP/TP (PACK='R' or 'C') */
 
     if (llb == 0 && uub == 0) {
 	i__1 = ilda + 1;
@@ -565,8 +568,8 @@ static logical c_false = FALSE_;
 
     } else if (givens) {
 
-/*        Check whether to use Givens rotations,   
-          Householder transformations, or nothing. */
+/*        Check whether to use Givens rotations, */
+/*        Householder transformations, or nothing. */
 
 	if (isym == 1) {
 
@@ -587,12 +590,12 @@ static logical c_false = FALSE_;
 		i__1 = uub;
 		for (jku = 1; jku <= i__1; ++jku) {
 
-/*                 Transform from bandwidth JKL, JKU-1 to JKL, JKU   
+/*                 Transform from bandwidth JKL, JKU-1 to JKL, JKU */
 
-                   Last row actually rotated is M   
-                   Last column actually rotated is MIN( M+JKU, N )   
+/*                 Last row actually rotated is M */
+/*                 Last column actually rotated is MIN( M+JKU, N ) */
 
-   Computing MIN */
+/* Computing MIN */
 		    i__3 = *m + jku;
 		    i__2 = min(i__3,*n) + jkl - 1;
 		    for (jr = 1; jr <= i__2; ++jr) {
@@ -665,9 +668,9 @@ static logical c_false = FALSE_;
 		i__1 = llb;
 		for (jkl = 1; jkl <= i__1; ++jkl) {
 
-/*                 Transform from bandwidth JKL-1, JKU to JKL, JKU   
+/*                 Transform from bandwidth JKL-1, JKU to JKL, JKU */
 
-   Computing MIN */
+/* Computing MIN */
 		    i__3 = *n + jkl;
 		    i__2 = min(i__3,*m) + jku - 1;
 		    for (jc = 1; jc <= i__2; ++jc) {
@@ -744,12 +747,12 @@ static logical c_false = FALSE_;
 		i__1 = uub;
 		for (jku = 1; jku <= i__1; ++jku) {
 
-/*                 Transform from bandwidth JKL, JKU-1 to JKL, JKU   
+/*                 Transform from bandwidth JKL, JKU-1 to JKL, JKU */
 
-                   First row actually rotated is M   
-                   First column actually rotated is MIN( M+JKU, N )   
+/*                 First row actually rotated is M */
+/*                 First column actually rotated is MIN( M+JKU, N ) */
 
-   Computing MIN */
+/* Computing MIN */
 		    i__2 = *m, i__3 = *n + jkl;
 		    iendch = min(i__2,i__3) - 1;
 /* Computing MIN */
@@ -820,12 +823,12 @@ static logical c_false = FALSE_;
 		i__1 = llb;
 		for (jkl = 1; jkl <= i__1; ++jkl) {
 
-/*                 Transform from bandwidth JKL-1, JKU to JKL, JKU   
+/*                 Transform from bandwidth JKL-1, JKU to JKL, JKU */
 
-                   First row actually rotated is MIN( N+JKL, M )   
-                   First column actually rotated is N   
+/*                 First row actually rotated is MIN( N+JKL, M ) */
+/*                 First column actually rotated is N */
 
-   Computing MIN */
+/* Computing MIN */
 		    i__3 = *n, i__4 = *m + jku;
 		    iendch = min(i__3,i__4) - 1;
 /* Computing MIN */
@@ -978,8 +981,8 @@ static logical c_false = FALSE_;
 /* L170: */
 		}
 
-/*              If we need lower triangle, copy from upper. Note that   
-                the order of copying is chosen to work for 'q' -> 'b' */
+/*              If we need lower triangle, copy from upper. Note that */
+/*              the order of copying is chosen to work for 'q' -> 'b' */
 
 		if (ipack != ipackg && ipack != 3) {
 		    i__1 = *n;
@@ -1042,7 +1045,7 @@ static logical c_false = FALSE_;
 			s = -sin(angle);
 			L__1 = *n - jc > k;
 			dlarot_(&c_false, &c_true, &L__1, &il, &c__, &s, &a[(
-				1 - iskew) * jc + ioffg + jc * a_dim1], &ilda,
+				1 - iskew) * jc + ioffg + jc * a_dim1], &ilda, 
 				 &temp, &extra);
 /* Computing MAX */
 			i__4 = 1, i__2 = jc - k + 1;
@@ -1083,8 +1086,8 @@ static logical c_false = FALSE_;
 /* L240: */
 		}
 
-/*              If we need upper triangle, copy from lower. Note that   
-                the order of copying is chosen to work for 'b' -> 'q' */
+/*              If we need upper triangle, copy from lower. Note that */
+/*              the order of copying is chosen to work for 'b' -> 'q' */
 
 		if (ipack != ipackg && ipack != 4) {
 		    for (jc = *n; jc >= 1; --jc) {
@@ -1121,12 +1124,12 @@ static logical c_false = FALSE_;
 
     } else {
 
-/*        4)      Generate Banded Matrix by first   
-                  Rotating by random Unitary matrices,   
-                  then reducing the bandwidth using Householder   
-                  transformations.   
+/*        4)      Generate Banded Matrix by first */
+/*                Rotating by random Unitary matrices, */
+/*                then reducing the bandwidth using Householder */
+/*                transformations. */
 
-                  Note: we should get here only if LDA .ge. N */
+/*                Note: we should get here only if LDA .ge. N */
 
 	if (isym == 1) {
 
@@ -1223,9 +1226,9 @@ static logical c_false = FALSE_;
 
 	} else if (ipack >= 5) {
 
-/*           'B' -- The lower triangle is packed as a band matrix.   
-             'Q' -- The upper triangle is packed as a band matrix.   
-             'Z' -- The whole matrix is packed as a band matrix. */
+/*           'B' -- The lower triangle is packed as a band matrix. */
+/*           'Q' -- The upper triangle is packed as a band matrix. */
+/*           'Z' -- The whole matrix is packed as a band matrix. */
 
 	    if (ipack == 5) {
 		uub = 0;
@@ -1258,10 +1261,10 @@ static logical c_false = FALSE_;
 	    }
 	}
 
-/*        If packed, zero out extraneous elements.   
+/*        If packed, zero out extraneous elements. */
 
-          Symmetric/Triangular Packed --   
-          zero out everything after A(IROW,ICOL) */
+/*        Symmetric/Triangular Packed -- */
+/*        zero out everything after A(IROW,ICOL) */
 
 	if (ipack == 3 || ipack == 4) {
 	    i__1 = *m;
@@ -1277,11 +1280,11 @@ static logical c_false = FALSE_;
 
 	} else if (ipack >= 5) {
 
-/*           Packed Band --   
-                1st row is now in A( UUB+2-j, j), zero above it   
-                m-th row is now in A( M+UUB-j,j), zero below it   
-                last non-zero diagonal is now in A( UUB+LLB+1,j ),   
-                   zero below it, too. */
+/*           Packed Band -- */
+/*              1st row is now in A( UUB+2-j, j), zero above it */
+/*              m-th row is now in A( M+UUB-j,j), zero below it */
+/*              last non-zero diagonal is now in A( UUB+LLB+1,j ), */
+/*                 zero below it, too. */
 
 	    ir1 = uub + llb + 2;
 	    ir2 = uub + *m + 2;
@@ -1292,8 +1295,8 @@ static logical c_false = FALSE_;
 		    a[jr + jc * a_dim1] = 0.;
 /* L430: */
 		}
-/* Computing MAX   
-   Computing MIN */
+/* Computing MAX */
+/* Computing MIN */
 		i__3 = ir1, i__5 = ir2 - jc;
 		i__2 = 1, i__4 = min(i__3,i__5);
 		i__6 = *lda;
